// Code generated by protoc-gen-go. DO NOT EDIT.
// source: google/ads/googleads/v1/errors/image_error.proto

package errors

import (
	fmt "fmt"
	math "math"

	proto "github.com/golang/protobuf/proto"
	_ "google.golang.org/genproto/googleapis/api/annotations"
)

// Reference imports to suppress errors if they are not otherwise used.
var _ = proto.Marshal
var _ = fmt.Errorf
var _ = math.Inf

// This is a compile-time assertion to ensure that this generated file
// is compatible with the proto package it is being compiled against.
// A compilation error at this line likely means your copy of the
// proto package needs to be updated.
const _ = proto.ProtoPackageIsVersion3 // please upgrade the proto package

// Enum describing possible image errors.
type ImageErrorEnum_ImageError int32

const (
	// Enum unspecified.
	ImageErrorEnum_UNSPECIFIED ImageErrorEnum_ImageError = 0
	// The received error code is not known in this version.
	ImageErrorEnum_UNKNOWN ImageErrorEnum_ImageError = 1
	// The image is not valid.
	ImageErrorEnum_INVALID_IMAGE ImageErrorEnum_ImageError = 2
	// The image could not be stored.
	ImageErrorEnum_STORAGE_ERROR ImageErrorEnum_ImageError = 3
	// There was a problem with the request.
	ImageErrorEnum_BAD_REQUEST ImageErrorEnum_ImageError = 4
	// The image is not of legal dimensions.
	ImageErrorEnum_UNEXPECTED_SIZE ImageErrorEnum_ImageError = 5
	// Animated image are not permitted.
	ImageErrorEnum_ANIMATED_NOT_ALLOWED ImageErrorEnum_ImageError = 6
	// Animation is too long.
	ImageErrorEnum_ANIMATION_TOO_LONG ImageErrorEnum_ImageError = 7
	// There was an error on the server.
	ImageErrorEnum_SERVER_ERROR ImageErrorEnum_ImageError = 8
	// Image cannot be in CMYK color format.
	ImageErrorEnum_CMYK_JPEG_NOT_ALLOWED ImageErrorEnum_ImageError = 9
	// Flash images are not permitted.
	ImageErrorEnum_FLASH_NOT_ALLOWED ImageErrorEnum_ImageError = 10
	// Flash images must support clickTag.
	ImageErrorEnum_FLASH_WITHOUT_CLICKTAG ImageErrorEnum_ImageError = 11
	// A flash error has occurred after fixing the click tag.
	ImageErrorEnum_FLASH_ERROR_AFTER_FIXING_CLICK_TAG ImageErrorEnum_ImageError = 12
	// Unacceptable visual effects.
	ImageErrorEnum_ANIMATED_VISUAL_EFFECT ImageErrorEnum_ImageError = 13
	// There was a problem with the flash image.
	ImageErrorEnum_FLASH_ERROR ImageErrorEnum_ImageError = 14
	// Incorrect image layout.
	ImageErrorEnum_LAYOUT_PROBLEM ImageErrorEnum_ImageError = 15
	// There was a problem reading the image file.
	ImageErrorEnum_PROBLEM_READING_IMAGE_FILE ImageErrorEnum_ImageError = 16
	// There was an error storing the image.
	ImageErrorEnum_ERROR_STORING_IMAGE ImageErrorEnum_ImageError = 17
	// The aspect ratio of the image is not allowed.
	ImageErrorEnum_ASPECT_RATIO_NOT_ALLOWED ImageErrorEnum_ImageError = 18
	// Flash cannot have network objects.
	ImageErrorEnum_FLASH_HAS_NETWORK_OBJECTS ImageErrorEnum_ImageError = 19
	// Flash cannot have network methods.
	ImageErrorEnum_FLASH_HAS_NETWORK_METHODS ImageErrorEnum_ImageError = 20
	// Flash cannot have a Url.
	ImageErrorEnum_FLASH_HAS_URL ImageErrorEnum_ImageError = 21
	// Flash cannot use mouse tracking.
	ImageErrorEnum_FLASH_HAS_MOUSE_TRACKING ImageErrorEnum_ImageError = 22
	// Flash cannot have a random number.
	ImageErrorEnum_FLASH_HAS_RANDOM_NUM ImageErrorEnum_ImageError = 23
	// Ad click target cannot be '_self'.
	ImageErrorEnum_FLASH_SELF_TARGETS ImageErrorEnum_ImageError = 24
	// GetUrl method should only use '_blank'.
	ImageErrorEnum_FLASH_BAD_GETURL_TARGET ImageErrorEnum_ImageError = 25
	// Flash version is not supported.
	ImageErrorEnum_FLASH_VERSION_NOT_SUPPORTED ImageErrorEnum_ImageError = 26
	// Flash movies need to have hard coded click URL or clickTAG
	ImageErrorEnum_FLASH_WITHOUT_HARD_CODED_CLICK_URL ImageErrorEnum_ImageError = 27
	// Uploaded flash file is corrupted.
	ImageErrorEnum_INVALID_FLASH_FILE ImageErrorEnum_ImageError = 28
	// Uploaded flash file can be parsed, but the click tag can not be fixed
	// properly.
	ImageErrorEnum_FAILED_TO_FIX_CLICK_TAG_IN_FLASH ImageErrorEnum_ImageError = 29
	// Flash movie accesses network resources
	ImageErrorEnum_FLASH_ACCESSES_NETWORK_RESOURCES ImageErrorEnum_ImageError = 30
	// Flash movie attempts to call external javascript code
	ImageErrorEnum_FLASH_EXTERNAL_JS_CALL ImageErrorEnum_ImageError = 31
	// Flash movie attempts to call flash system commands
	ImageErrorEnum_FLASH_EXTERNAL_FS_CALL ImageErrorEnum_ImageError = 32
	// Image file is too large.
	ImageErrorEnum_FILE_TOO_LARGE ImageErrorEnum_ImageError = 33
	// Image data is too large.
	ImageErrorEnum_IMAGE_DATA_TOO_LARGE ImageErrorEnum_ImageError = 34
	// Error while processing the image.
	ImageErrorEnum_IMAGE_PROCESSING_ERROR ImageErrorEnum_ImageError = 35
	// Image is too small.
	ImageErrorEnum_IMAGE_TOO_SMALL ImageErrorEnum_ImageError = 36
	// Input was invalid.
	ImageErrorEnum_INVALID_INPUT ImageErrorEnum_ImageError = 37
	// There was a problem reading the image file.
	ImageErrorEnum_PROBLEM_READING_FILE ImageErrorEnum_ImageError = 38
)

var ImageErrorEnum_ImageError_name = map[int32]string{
	0:  "UNSPECIFIED",
	1:  "UNKNOWN",
	2:  "INVALID_IMAGE",
	3:  "STORAGE_ERROR",
	4:  "BAD_REQUEST",
	5:  "UNEXPECTED_SIZE",
	6:  "ANIMATED_NOT_ALLOWED",
	7:  "ANIMATION_TOO_LONG",
	8:  "SERVER_ERROR",
	9:  "CMYK_JPEG_NOT_ALLOWED",
	10: "FLASH_NOT_ALLOWED",
	11: "FLASH_WITHOUT_CLICKTAG",
	12: "FLASH_ERROR_AFTER_FIXING_CLICK_TAG",
	13: "ANIMATED_VISUAL_EFFECT",
	14: "FLASH_ERROR",
	15: "LAYOUT_PROBLEM",
	16: "PROBLEM_READING_IMAGE_FILE",
	17: "ERROR_STORING_IMAGE",
	18: "ASPECT_RATIO_NOT_ALLOWED",
	19: "FLASH_HAS_NETWORK_OBJECTS",
	20: "FLASH_HAS_NETWORK_METHODS",
	21: "FLASH_HAS_URL",
	22: "FLASH_HAS_MOUSE_TRACKING",
	23: "FLASH_HAS_RANDOM_NUM",
	24: "FLASH_SELF_TARGETS",
	25: "FLASH_BAD_GETURL_TARGET",
	26: "FLASH_VERSION_NOT_SUPPORTED",
	27: "FLASH_WITHOUT_HARD_CODED_CLICK_URL",
	28: "INVALID_FLASH_FILE",
	29: "FAILED_TO_FIX_CLICK_TAG_IN_FLASH",
	30: "FLASH_ACCESSES_NETWORK_RESOURCES",
	31: "FLASH_EXTERNAL_JS_CALL",
	32: "FLASH_EXTERNAL_FS_CALL",
	33: "FILE_TOO_LARGE",
	34: "IMAGE_DATA_TOO_LARGE",
	35: "IMAGE_PROCESSING_ERROR",
	36: "IMAGE_TOO_SMALL",
	37: "INVALID_INPUT",
	38: "PROBLEM_READING_FILE",
}

var ImageErrorEnum_ImageError_value = map[string]int32{
	"UNSPECIFIED":                        0,
	"UNKNOWN":                            1,
	"INVALID_IMAGE":                      2,
	"STORAGE_ERROR":                      3,
	"BAD_REQUEST":                        4,
	"UNEXPECTED_SIZE":                    5,
	"ANIMATED_NOT_ALLOWED":               6,
	"ANIMATION_TOO_LONG":                 7,
	"SERVER_ERROR":                       8,
	"CMYK_JPEG_NOT_ALLOWED":              9,
	"FLASH_NOT_ALLOWED":                  10,
	"FLASH_WITHOUT_CLICKTAG":             11,
	"FLASH_ERROR_AFTER_FIXING_CLICK_TAG": 12,
	"ANIMATED_VISUAL_EFFECT":             13,
	"FLASH_ERROR":                        14,
	"LAYOUT_PROBLEM":                     15,
	"PROBLEM_READING_IMAGE_FILE":         16,
	"ERROR_STORING_IMAGE":                17,
	"ASPECT_RATIO_NOT_ALLOWED":           18,
	"FLASH_HAS_NETWORK_OBJECTS":          19,
	"FLASH_HAS_NETWORK_METHODS":          20,
	"FLASH_HAS_URL":                      21,
	"FLASH_HAS_MOUSE_TRACKING":           22,
	"FLASH_HAS_RANDOM_NUM":               23,
	"FLASH_SELF_TARGETS":                 24,
	"FLASH_BAD_GETURL_TARGET":            25,
	"FLASH_VERSION_NOT_SUPPORTED":        26,
	"FLASH_WITHOUT_HARD_CODED_CLICK_URL": 27,
	"INVALID_FLASH_FILE":                 28,
	"FAILED_TO_FIX_CLICK_TAG_IN_FLASH":   29,
	"FLASH_ACCESSES_NETWORK_RESOURCES":   30,
	"FLASH_EXTERNAL_JS_CALL":             31,
	"FLASH_EXTERNAL_FS_CALL":             32,
	"FILE_TOO_LARGE":                     33,
	"IMAGE_DATA_TOO_LARGE":               34,
	"IMAGE_PROCESSING_ERROR":             35,
	"IMAGE_TOO_SMALL":                    36,
	"INVALID_INPUT":                      37,
	"PROBLEM_READING_FILE":               38,
}

func (x ImageErrorEnum_ImageError) String() string {
	return proto.EnumName(ImageErrorEnum_ImageError_name, int32(x))
}

func (ImageErrorEnum_ImageError) EnumDescriptor() ([]byte, []int) {
	return fileDescriptor_9dd554b8a72a1295, []int{0, 0}
}

// Container for enum describing possible image errors.
type ImageErrorEnum struct {
	XXX_NoUnkeyedLiteral struct{} `json:"-"`
	XXX_unrecognized     []byte   `json:"-"`
	XXX_sizecache        int32    `json:"-"`
}

func (m *ImageErrorEnum) Reset()         { *m = ImageErrorEnum{} }
func (m *ImageErrorEnum) String() string { return proto.CompactTextString(m) }
func (*ImageErrorEnum) ProtoMessage()    {}
func (*ImageErrorEnum) Descriptor() ([]byte, []int) {
	return fileDescriptor_9dd554b8a72a1295, []int{0}
}

func (m *ImageErrorEnum) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_ImageErrorEnum.Unmarshal(m, b)
}
func (m *ImageErrorEnum) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_ImageErrorEnum.Marshal(b, m, deterministic)
}
func (m *ImageErrorEnum) XXX_Merge(src proto.Message) {
	xxx_messageInfo_ImageErrorEnum.Merge(m, src)
}
func (m *ImageErrorEnum) XXX_Size() int {
	return xxx_messageInfo_ImageErrorEnum.Size(m)
}
func (m *ImageErrorEnum) XXX_DiscardUnknown() {
	xxx_messageInfo_ImageErrorEnum.DiscardUnknown(m)
}

var xxx_messageInfo_ImageErrorEnum proto.InternalMessageInfo

func init() {
	proto.RegisterEnum("google.ads.googleads.v1.errors.ImageErrorEnum_ImageError", ImageErrorEnum_ImageError_name, ImageErrorEnum_ImageError_value)
	proto.RegisterType((*ImageErrorEnum)(nil), "google.ads.googleads.v1.errors.ImageErrorEnum")
}

func init() {
	proto.RegisterFile("google/ads/googleads/v1/errors/image_error.proto", fileDescriptor_9dd554b8a72a1295)
}

var fileDescriptor_9dd554b8a72a1295 = []byte{
	// 786 bytes of a gzipped FileDescriptorProto
	0x1f, 0x8b, 0x08, 0x00, 0x00, 0x00, 0x00, 0x00, 0x02, 0xff, 0x7c, 0x54, 0xcd, 0x72, 0xdb, 0x36,
	0x10, 0xae, 0x9d, 0x36, 0x4e, 0xe1, 0xc4, 0x86, 0xe1, 0xf8, 0xdf, 0x71, 0x52, 0x35, 0xcd, 0x51,
	0xaa, 0xa6, 0x37, 0xf5, 0x04, 0x91, 0x4b, 0x0a, 0x16, 0x08, 0xb0, 0x00, 0x28, 0x3b, 0x19, 0xcf,
	0x60, 0xd4, 0xca, 0xa3, 0xf1, 0x4c, 0x2c, 0x7a, 0x44, 0x37, 0x0f, 0xd1, 0xc7, 0xe8, 0xb1, 0x8f,
	0xd2, 0x47, 0xc9, 0x0b, 0xf4, 0xda, 0x59, 0x42, 0x12, 0xe3, 0x4e, 0x9a, 0x93, 0xa0, 0xfd, 0x3e,
	0x7c, 0xbb, 0xd8, 0x6f, 0xb9, 0xe4, 0xc7, 0x69, 0x59, 0x4e, 0xdf, 0x5f, 0x77, 0xc6, 0x93, 0xaa,
	0x13, 0x8e, 0x78, 0xfa, 0xd0, 0xed, 0x5c, 0xcf, 0xe7, 0xe5, 0xbc, 0xea, 0xdc, 0xdc, 0x8e, 0xa7,
	0xd7, 0xbe, 0xfe, 0xd3, 0xbe, 0x9b, 0x97, 0xf7, 0x25, 0x3b, 0x0b, 0xb4, 0xf6, 0x78, 0x52, 0xb5,
	0x57, 0x37, 0xda, 0x1f, 0xba, 0xed, 0x70, 0xe3, 0xf8, 0x74, 0xa9, 0x78, 0x77, 0xd3, 0x19, 0xcf,
	0x66, 0xe5, 0xfd, 0xf8, 0xfe, 0xa6, 0x9c, 0x55, 0xe1, 0x76, 0xeb, 0x8f, 0x27, 0x64, 0x4b, 0xa0,
	0x26, 0x20, 0x1b, 0x66, 0xbf, 0xdf, 0xb6, 0xfe, 0xd9, 0x20, 0xa4, 0x09, 0xb1, 0x6d, 0xb2, 0x59,
	0x28, 0x9b, 0x43, 0x24, 0x12, 0x01, 0x31, 0xfd, 0x8a, 0x6d, 0x92, 0x8d, 0x42, 0x0d, 0x95, 0xbe,
	0x50, 0x74, 0x8d, 0xed, 0x90, 0x67, 0x42, 0x8d, 0xb8, 0x14, 0xb1, 0x17, 0x19, 0x4f, 0x81, 0xae,
	0x63, 0xc8, 0x3a, 0x6d, 0x78, 0x0a, 0x1e, 0x8c, 0xd1, 0x86, 0x3e, 0x42, 0x8d, 0x3e, 0x8f, 0xbd,
	0x81, 0x5f, 0x0a, 0xb0, 0x8e, 0x7e, 0xcd, 0x76, 0xc9, 0x76, 0xa1, 0xe0, 0x32, 0x87, 0xc8, 0x41,
	0xec, 0xad, 0x78, 0x07, 0xf4, 0x1b, 0x76, 0x48, 0x9e, 0x73, 0x25, 0x32, 0x8e, 0x21, 0xa5, 0x9d,
	0xe7, 0x52, 0xea, 0x0b, 0x88, 0xe9, 0x63, 0xb6, 0x4f, 0x58, 0x40, 0x84, 0x56, 0xde, 0x69, 0xed,
	0xa5, 0x56, 0x29, 0xdd, 0x60, 0x94, 0x3c, 0xb5, 0x60, 0x46, 0x60, 0x16, 0x99, 0x9e, 0xb0, 0x23,
	0xb2, 0x17, 0x65, 0x6f, 0x87, 0xfe, 0x3c, 0x87, 0xf4, 0x81, 0xc8, 0xb7, 0x6c, 0x8f, 0xec, 0x24,
	0x92, 0xdb, 0xc1, 0x83, 0x30, 0x61, 0xc7, 0x64, 0x3f, 0x84, 0x2f, 0x84, 0x1b, 0xe8, 0xc2, 0xf9,
	0x48, 0x8a, 0x68, 0xe8, 0x78, 0x4a, 0x37, 0xd9, 0x1b, 0xd2, 0x0a, 0x58, 0x2d, 0xef, 0x79, 0xe2,
	0xc0, 0xf8, 0x44, 0x5c, 0x0a, 0x95, 0x06, 0x9a, 0x47, 0xde, 0x53, 0xd4, 0x58, 0x55, 0x3e, 0x12,
	0xb6, 0xe0, 0xd2, 0x43, 0x92, 0x40, 0xe4, 0xe8, 0x33, 0x7c, 0xfb, 0x27, 0x1a, 0x74, 0x8b, 0x31,
	0xb2, 0x25, 0xf9, 0x5b, 0xcc, 0x94, 0x1b, 0xdd, 0x97, 0x90, 0xd1, 0x6d, 0x76, 0x46, 0x8e, 0x17,
	0x7f, 0xbc, 0x01, 0x1e, 0xa3, 0x7e, 0xdd, 0x4e, 0x9f, 0x08, 0x09, 0x94, 0xb2, 0x03, 0xb2, 0x1b,
	0x4a, 0xc0, 0xce, 0xae, 0x50, 0xba, 0xc3, 0x4e, 0xc9, 0x21, 0x47, 0x73, 0x9c, 0x37, 0xd8, 0x9d,
	0x07, 0x6f, 0x63, 0xec, 0x05, 0x39, 0x0a, 0xb9, 0x07, 0xdc, 0x7a, 0x05, 0xee, 0x42, 0x9b, 0xa1,
	0xd7, 0xfd, 0x73, 0x88, 0x9c, 0xa5, 0xbb, 0x9f, 0x87, 0x33, 0x70, 0x03, 0x1d, 0x5b, 0xfa, 0x1c,
	0x8d, 0x6c, 0xe0, 0xc2, 0x48, 0xba, 0x87, 0xe9, 0x9a, 0x50, 0xa6, 0x0b, 0x0b, 0xde, 0x19, 0x1e,
	0x0d, 0x85, 0x4a, 0xe9, 0x3e, 0x1a, 0xd8, 0xa0, 0x86, 0xab, 0x58, 0x67, 0x5e, 0x15, 0x19, 0x3d,
	0x40, 0x03, 0x03, 0x62, 0x41, 0x26, 0xde, 0x71, 0x93, 0x82, 0xb3, 0xf4, 0x90, 0x9d, 0x90, 0x83,
	0x10, 0xc7, 0xf1, 0x48, 0xc1, 0x15, 0x46, 0x2e, 0x50, 0x7a, 0xc4, 0x5e, 0x92, 0x93, 0x00, 0x8e,
	0xc0, 0x58, 0x74, 0x1e, 0x1f, 0x67, 0x8b, 0x3c, 0xd7, 0xc6, 0x41, 0x4c, 0x8f, 0x1b, 0x7b, 0x96,
	0xd6, 0x0d, 0xb8, 0x89, 0x7d, 0xa4, 0x63, 0x88, 0x17, 0xf6, 0x60, 0xd5, 0x27, 0x98, 0x7d, 0x39,
	0xa4, 0x81, 0x5f, 0x77, 0xf5, 0x94, 0xbd, 0x26, 0xaf, 0x12, 0x2e, 0x24, 0xc4, 0xde, 0x69, 0xb4,
	0xb5, 0xf1, 0xd4, 0x0b, 0x15, 0xa8, 0xf4, 0x45, 0xcd, 0xaa, 0x6f, 0xf1, 0x28, 0x02, 0x6b, 0xa1,
	0x69, 0x95, 0x01, 0xab, 0x0b, 0x13, 0x81, 0xa5, 0x67, 0xcd, 0x18, 0xc1, 0xa5, 0x03, 0xa3, 0xb8,
	0xf4, 0xe7, 0xd6, 0x47, 0x5c, 0x4a, 0xfa, 0xf2, 0x33, 0x58, 0xb2, 0xc0, 0x5e, 0xe1, 0x34, 0x60,
	0x35, 0x61, 0xaa, 0xf1, 0xe5, 0xf4, 0x3b, 0xec, 0x63, 0x70, 0x3f, 0xe6, 0x8e, 0x7f, 0x82, 0xb4,
	0x50, 0x29, 0x20, 0xb9, 0xd1, 0x58, 0x0c, 0x8e, 0x42, 0x98, 0xab, 0xef, 0xf1, 0x9b, 0x0a, 0x18,
	0x5e, 0xb0, 0x19, 0xca, 0xbf, 0x7e, 0xf0, 0x7d, 0xaa, 0xbc, 0x70, 0xf4, 0x07, 0x54, 0xff, 0xef,
	0xac, 0xd5, 0xfd, 0x78, 0xd3, 0xff, 0xb8, 0x46, 0x5a, 0xbf, 0x95, 0xb7, 0xed, 0x2f, 0x6f, 0x94,
	0xfe, 0x76, 0xb3, 0x1d, 0x72, 0x5c, 0x22, 0xf9, 0xda, 0xbb, 0x78, 0x71, 0x65, 0x5a, 0xbe, 0x1f,
	0xcf, 0xa6, 0xed, 0x72, 0x3e, 0xed, 0x4c, 0xaf, 0x67, 0xf5, 0x8a, 0x59, 0xae, 0xb1, 0xbb, 0x9b,
	0xea, 0xff, 0xb6, 0xda, 0xcf, 0xe1, 0xe7, 0xcf, 0xf5, 0x47, 0x29, 0xe7, 0x7f, 0xad, 0x9f, 0xa5,
	0x41, 0x8c, 0x4f, 0xaa, 0x76, 0x38, 0xe2, 0x69, 0xd4, 0x6d, 0xd7, 0x29, 0xab, 0xbf, 0x97, 0x84,
	0x2b, 0x3e, 0xa9, 0xae, 0x56, 0x84, 0xab, 0x51, 0xf7, 0x2a, 0x10, 0x3e, 0xae, 0xb7, 0x42, 0xb4,
	0xd7, 0xe3, 0x93, 0xaa, 0xd7, 0x5b, 0x51, 0x7a, 0xbd, 0x51, 0xb7, 0xd7, 0x0b, 0xa4, 0x5f, 0x1f,
	0xd7, 0xd5, 0xfd, 0xf4, 0x6f, 0x00, 0x00, 0x00, 0xff, 0xff, 0xa4, 0xb5, 0x22, 0x81, 0x72, 0x05,
	0x00, 0x00,
}
