// Code generated by protoc-gen-go. DO NOT EDIT.
// source: google/ads/googleads/v2/common/url_collection.proto

package common

import (
	fmt "fmt"
	math "math"

	proto "github.com/golang/protobuf/proto"
	wrappers "github.com/golang/protobuf/ptypes/wrappers"
	_ "google.golang.org/genproto/googleapis/api/annotations"
)

// Reference imports to suppress errors if they are not otherwise used.
var _ = proto.Marshal
var _ = fmt.Errorf
var _ = math.Inf

// This is a compile-time assertion to ensure that this generated file
// is compatible with the proto package it is being compiled against.
// A compilation error at this line likely means your copy of the
// proto package needs to be updated.
const _ = proto.ProtoPackageIsVersion3 // please upgrade the proto package

// Collection of urls that is tagged with a unique identifier.
type UrlCollection struct {
	// Unique identifier for this UrlCollection instance.
	UrlCollectionId *wrappers.StringValue `protobuf:"bytes,1,opt,name=url_collection_id,json=urlCollectionId,proto3" json:"url_collection_id,omitempty"`
	// A list of possible final URLs.
	FinalUrls []*wrappers.StringValue `protobuf:"bytes,2,rep,name=final_urls,json=finalUrls,proto3" json:"final_urls,omitempty"`
	// A list of possible final mobile URLs.
	FinalMobileUrls []*wrappers.StringValue `protobuf:"bytes,3,rep,name=final_mobile_urls,json=finalMobileUrls,proto3" json:"final_mobile_urls,omitempty"`
	// URL template for constructing a tracking URL.
	TrackingUrlTemplate  *wrappers.StringValue `protobuf:"bytes,4,opt,name=tracking_url_template,json=trackingUrlTemplate,proto3" json:"tracking_url_template,omitempty"`
	XXX_NoUnkeyedLiteral struct{}              `json:"-"`
	XXX_unrecognized     []byte                `json:"-"`
	XXX_sizecache        int32                 `json:"-"`
}

func (m *UrlCollection) Reset()         { *m = UrlCollection{} }
func (m *UrlCollection) String() string { return proto.CompactTextString(m) }
func (*UrlCollection) ProtoMessage()    {}
func (*UrlCollection) Descriptor() ([]byte, []int) {
	return fileDescriptor_a7b42947fa099ffb, []int{0}
}

func (m *UrlCollection) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_UrlCollection.Unmarshal(m, b)
}
func (m *UrlCollection) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_UrlCollection.Marshal(b, m, deterministic)
}
func (m *UrlCollection) XXX_Merge(src proto.Message) {
	xxx_messageInfo_UrlCollection.Merge(m, src)
}
func (m *UrlCollection) XXX_Size() int {
	return xxx_messageInfo_UrlCollection.Size(m)
}
func (m *UrlCollection) XXX_DiscardUnknown() {
	xxx_messageInfo_UrlCollection.DiscardUnknown(m)
}

var xxx_messageInfo_UrlCollection proto.InternalMessageInfo

func (m *UrlCollection) GetUrlCollectionId() *wrappers.StringValue {
	if m != nil {
		return m.UrlCollectionId
	}
	return nil
}

func (m *UrlCollection) GetFinalUrls() []*wrappers.StringValue {
	if m != nil {
		return m.FinalUrls
	}
	return nil
}

func (m *UrlCollection) GetFinalMobileUrls() []*wrappers.StringValue {
	if m != nil {
		return m.FinalMobileUrls
	}
	return nil
}

func (m *UrlCollection) GetTrackingUrlTemplate() *wrappers.StringValue {
	if m != nil {
		return m.TrackingUrlTemplate
	}
	return nil
}

func init() {
	proto.RegisterType((*UrlCollection)(nil), "google.ads.googleads.v2.common.UrlCollection")
}

func init() {
	proto.RegisterFile("google/ads/googleads/v2/common/url_collection.proto", fileDescriptor_a7b42947fa099ffb)
}

var fileDescriptor_a7b42947fa099ffb = []byte{
	// 370 bytes of a gzipped FileDescriptorProto
	0x1f, 0x8b, 0x08, 0x00, 0x00, 0x00, 0x00, 0x00, 0x02, 0xff, 0x8c, 0x92, 0x41, 0x4b, 0xf3, 0x30,
	0x18, 0xc7, 0x69, 0xf7, 0xf2, 0xc2, 0xdb, 0x17, 0x19, 0x56, 0x84, 0x31, 0xc6, 0x18, 0x3b, 0x79,
	0x4a, 0xa0, 0xbb, 0x65, 0xa7, 0x6e, 0xc2, 0xf4, 0x20, 0x0c, 0x75, 0x3d, 0x48, 0xa1, 0x64, 0x6d,
	0x16, 0x82, 0x69, 0x52, 0x92, 0x76, 0x7e, 0x1f, 0x8f, 0x1e, 0xfd, 0x18, 0x7e, 0x14, 0xc1, 0xef,
	0x20, 0x4d, 0xda, 0xe2, 0x0e, 0xea, 0x4e, 0x7d, 0x68, 0xfe, 0xbf, 0xdf, 0xf3, 0xb4, 0x79, 0xbc,
	0x19, 0x95, 0x92, 0x72, 0x02, 0x71, 0xa6, 0xa1, 0x2d, 0xeb, 0x6a, 0x1f, 0xc0, 0x54, 0xe6, 0xb9,
	0x14, 0xb0, 0x52, 0x3c, 0x49, 0x25, 0xe7, 0x24, 0x2d, 0x99, 0x14, 0xa0, 0x50, 0xb2, 0x94, 0xfe,
	0xd8, 0x26, 0x01, 0xce, 0x34, 0xe8, 0x20, 0xb0, 0x0f, 0x80, 0x85, 0x86, 0xcd, 0x39, 0x34, 0xe9,
	0x6d, 0xb5, 0x83, 0x4f, 0x0a, 0x17, 0x05, 0x51, 0xda, 0xf2, 0xc3, 0x51, 0xdb, 0xb4, 0x60, 0x10,
	0x0b, 0x21, 0x4b, 0x5c, 0xcb, 0x9b, 0xd3, 0xe9, 0xab, 0xeb, 0x9d, 0x6c, 0x14, 0x5f, 0x76, 0x5d,
	0xfd, 0x2b, 0xef, 0xf4, 0x70, 0x8e, 0x84, 0x65, 0x03, 0x67, 0xe2, 0x5c, 0xfc, 0x0f, 0x46, 0xcd,
	0x00, 0xa0, 0xed, 0x05, 0xee, 0x4a, 0xc5, 0x04, 0x8d, 0x30, 0xaf, 0xc8, 0x6d, 0xbf, 0xfa, 0xea,
	0xb9, 0xce, 0xfc, 0xb9, 0xe7, 0xed, 0x98, 0xc0, 0x3c, 0xa9, 0x14, 0xd7, 0x03, 0x77, 0xd2, 0xfb,
	0x55, 0xf1, 0xcf, 0xe4, 0x37, 0x8a, 0xeb, 0x7a, 0x0c, 0x0b, 0xe7, 0x72, 0xcb, 0x38, 0xb1, 0x8e,
	0xde, 0x11, 0x8e, 0xbe, 0xc1, 0x6e, 0x0c, 0x65, 0x4c, 0x6b, 0xef, 0xbc, 0x54, 0x38, 0x7d, 0x64,
	0x82, 0xd6, 0x96, 0xa4, 0x24, 0x79, 0xc1, 0x71, 0x49, 0x06, 0x7f, 0x8e, 0xf8, 0xa8, 0xb3, 0x16,
	0xdd, 0x28, 0x7e, 0xdf, 0x80, 0x8b, 0x0f, 0xc7, 0x9b, 0xa6, 0x32, 0x07, 0x3f, 0xdf, 0xcc, 0xc2,
	0x3f, 0xf8, 0xb1, 0xeb, 0x5a, 0xbf, 0x76, 0x1e, 0x2e, 0x1b, 0x8a, 0x4a, 0x8e, 0x05, 0x05, 0x52,
	0x51, 0x48, 0x89, 0x30, 0xcd, 0xdb, 0xa5, 0x28, 0x98, 0xfe, 0x6e, 0x47, 0xe6, 0xf6, 0xf1, 0xec,
	0xf6, 0x56, 0x61, 0xf8, 0xe2, 0x8e, 0x57, 0x56, 0x16, 0x66, 0x1a, 0xd8, 0xb2, 0xae, 0xa2, 0x00,
	0x2c, 0x4d, 0xec, 0xad, 0x0d, 0xc4, 0x61, 0xa6, 0xe3, 0x2e, 0x10, 0x47, 0x41, 0x6c, 0x03, 0xef,
	0xee, 0xd4, 0xbe, 0x45, 0x28, 0xcc, 0x34, 0x42, 0x5d, 0x04, 0xa1, 0x28, 0x40, 0xc8, 0x86, 0xb6,
	0x7f, 0xcd, 0x74, 0xb3, 0xcf, 0x00, 0x00, 0x00, 0xff, 0xff, 0xf5, 0x54, 0x57, 0x6b, 0xc0, 0x02,
	0x00, 0x00,
}
