// Code generated by protoc-gen-go. DO NOT EDIT.
// source: google/ads/googleads/v2/enums/user_list_type.proto

package enums

import (
	fmt "fmt"
	math "math"

	proto "github.com/golang/protobuf/proto"
	_ "google.golang.org/genproto/googleapis/api/annotations"
)

// Reference imports to suppress errors if they are not otherwise used.
var _ = proto.Marshal
var _ = fmt.Errorf
var _ = math.Inf

// This is a compile-time assertion to ensure that this generated file
// is compatible with the proto package it is being compiled against.
// A compilation error at this line likely means your copy of the
// proto package needs to be updated.
const _ = proto.ProtoPackageIsVersion3 // please upgrade the proto package

// Enum containing possible user list types.
type UserListTypeEnum_UserListType int32

const (
	// Not specified.
	UserListTypeEnum_UNSPECIFIED UserListTypeEnum_UserListType = 0
	// Used for return value only. Represents value unknown in this version.
	UserListTypeEnum_UNKNOWN UserListTypeEnum_UserListType = 1
	// UserList represented as a collection of conversion types.
	UserListTypeEnum_REMARKETING UserListTypeEnum_UserListType = 2
	// UserList represented as a combination of other user lists/interests.
	UserListTypeEnum_LOGICAL UserListTypeEnum_UserListType = 3
	// UserList created in the Google Ad Manager platform.
	UserListTypeEnum_EXTERNAL_REMARKETING UserListTypeEnum_UserListType = 4
	// UserList associated with a rule.
	UserListTypeEnum_RULE_BASED UserListTypeEnum_UserListType = 5
	// UserList with users similar to users of another UserList.
	UserListTypeEnum_SIMILAR UserListTypeEnum_UserListType = 6
	// UserList of first-party CRM data provided by advertiser in the form of
	// emails or other formats.
	UserListTypeEnum_CRM_BASED UserListTypeEnum_UserListType = 7
)

var UserListTypeEnum_UserListType_name = map[int32]string{
	0: "UNSPECIFIED",
	1: "UNKNOWN",
	2: "REMARKETING",
	3: "LOGICAL",
	4: "EXTERNAL_REMARKETING",
	5: "RULE_BASED",
	6: "SIMILAR",
	7: "CRM_BASED",
}

var UserListTypeEnum_UserListType_value = map[string]int32{
	"UNSPECIFIED":          0,
	"UNKNOWN":              1,
	"REMARKETING":          2,
	"LOGICAL":              3,
	"EXTERNAL_REMARKETING": 4,
	"RULE_BASED":           5,
	"SIMILAR":              6,
	"CRM_BASED":            7,
}

func (x UserListTypeEnum_UserListType) String() string {
	return proto.EnumName(UserListTypeEnum_UserListType_name, int32(x))
}

func (UserListTypeEnum_UserListType) EnumDescriptor() ([]byte, []int) {
	return fileDescriptor_5c791a4600ee3508, []int{0, 0}
}

// The user list types.
type UserListTypeEnum struct {
	XXX_NoUnkeyedLiteral struct{} `json:"-"`
	XXX_unrecognized     []byte   `json:"-"`
	XXX_sizecache        int32    `json:"-"`
}

func (m *UserListTypeEnum) Reset()         { *m = UserListTypeEnum{} }
func (m *UserListTypeEnum) String() string { return proto.CompactTextString(m) }
func (*UserListTypeEnum) ProtoMessage()    {}
func (*UserListTypeEnum) Descriptor() ([]byte, []int) {
	return fileDescriptor_5c791a4600ee3508, []int{0}
}

func (m *UserListTypeEnum) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_UserListTypeEnum.Unmarshal(m, b)
}
func (m *UserListTypeEnum) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_UserListTypeEnum.Marshal(b, m, deterministic)
}
func (m *UserListTypeEnum) XXX_Merge(src proto.Message) {
	xxx_messageInfo_UserListTypeEnum.Merge(m, src)
}
func (m *UserListTypeEnum) XXX_Size() int {
	return xxx_messageInfo_UserListTypeEnum.Size(m)
}
func (m *UserListTypeEnum) XXX_DiscardUnknown() {
	xxx_messageInfo_UserListTypeEnum.DiscardUnknown(m)
}

var xxx_messageInfo_UserListTypeEnum proto.InternalMessageInfo

func init() {
	proto.RegisterEnum("google.ads.googleads.v2.enums.UserListTypeEnum_UserListType", UserListTypeEnum_UserListType_name, UserListTypeEnum_UserListType_value)
	proto.RegisterType((*UserListTypeEnum)(nil), "google.ads.googleads.v2.enums.UserListTypeEnum")
}

func init() {
	proto.RegisterFile("google/ads/googleads/v2/enums/user_list_type.proto", fileDescriptor_5c791a4600ee3508)
}

var fileDescriptor_5c791a4600ee3508 = []byte{
	// 358 bytes of a gzipped FileDescriptorProto
	0x1f, 0x8b, 0x08, 0x00, 0x00, 0x00, 0x00, 0x00, 0x02, 0xff, 0x7c, 0x90, 0xcf, 0x4a, 0xf3, 0x40,
	0x14, 0xc5, 0xbf, 0xa4, 0x9f, 0x2d, 0x4e, 0xfd, 0x13, 0x83, 0x0b, 0x11, 0xbb, 0x68, 0x1f, 0x60,
	0x02, 0x71, 0x37, 0xae, 0x26, 0xed, 0x18, 0x42, 0xd3, 0xb4, 0xa4, 0x4d, 0x15, 0x09, 0x84, 0x68,
	0x86, 0x10, 0x68, 0x67, 0x42, 0x26, 0x2d, 0xf4, 0x2d, 0x7c, 0x06, 0xc1, 0x8d, 0x8f, 0xe2, 0x83,
	0xb8, 0xf0, 0x29, 0x64, 0x92, 0xb6, 0x74, 0xa3, 0x9b, 0xe1, 0x30, 0xbf, 0x73, 0x2e, 0xf7, 0x1e,
	0x60, 0xa6, 0x9c, 0xa7, 0x0b, 0x6a, 0xc4, 0x89, 0x30, 0x6a, 0x29, 0xd5, 0xda, 0x34, 0x28, 0x5b,
	0x2d, 0x85, 0xb1, 0x12, 0xb4, 0x88, 0x16, 0x99, 0x28, 0xa3, 0x72, 0x93, 0x53, 0x98, 0x17, 0xbc,
	0xe4, 0x7a, 0xa7, 0x36, 0xc2, 0x38, 0x11, 0x70, 0x9f, 0x81, 0x6b, 0x13, 0x56, 0x99, 0xeb, 0x9b,
	0xdd, 0xc8, 0x3c, 0x33, 0x62, 0xc6, 0x78, 0x19, 0x97, 0x19, 0x67, 0xa2, 0x0e, 0xf7, 0xde, 0x15,
	0xa0, 0x05, 0x82, 0x16, 0x6e, 0x26, 0xca, 0xd9, 0x26, 0xa7, 0x84, 0xad, 0x96, 0xbd, 0x57, 0x05,
	0x9c, 0x1c, 0x7e, 0xea, 0xe7, 0xa0, 0x1d, 0x78, 0xd3, 0x09, 0xe9, 0x3b, 0xf7, 0x0e, 0x19, 0x68,
	0xff, 0xf4, 0x36, 0x68, 0x05, 0xde, 0xd0, 0x1b, 0x3f, 0x78, 0x9a, 0x22, 0xa9, 0x4f, 0x46, 0xd8,
	0x1f, 0x92, 0x99, 0xe3, 0xd9, 0x9a, 0x2a, 0xa9, 0x3b, 0xb6, 0x9d, 0x3e, 0x76, 0xb5, 0x86, 0x7e,
	0x05, 0x2e, 0xc9, 0xe3, 0x8c, 0xf8, 0x1e, 0x76, 0xa3, 0x43, 0xdb, 0x7f, 0xfd, 0x0c, 0x00, 0x3f,
	0x70, 0x49, 0x64, 0xe1, 0x29, 0x19, 0x68, 0x47, 0x32, 0x36, 0x75, 0x46, 0x8e, 0x8b, 0x7d, 0xad,
	0xa9, 0x9f, 0x82, 0xe3, 0xbe, 0x3f, 0xda, 0xb2, 0x96, 0xf5, 0xa5, 0x80, 0xee, 0x0b, 0x5f, 0xc2,
	0x3f, 0x6f, 0xb5, 0x2e, 0x0e, 0xb7, 0x9e, 0xc8, 0x03, 0x27, 0xca, 0x93, 0xb5, 0xcd, 0xa4, 0x7c,
	0x11, 0xb3, 0x14, 0xf2, 0x22, 0x35, 0x52, 0xca, 0xaa, 0xf3, 0x77, 0x1d, 0xe7, 0x99, 0xf8, 0xa5,
	0xf2, 0xbb, 0xea, 0x7d, 0x53, 0x1b, 0x36, 0xc6, 0x1f, 0x6a, 0xc7, 0xae, 0x47, 0xe1, 0x44, 0xc0,
	0x5a, 0x4a, 0x35, 0x37, 0xa1, 0xac, 0x4d, 0x7c, 0xee, 0x78, 0x88, 0x13, 0x11, 0xee, 0x79, 0x38,
	0x37, 0xc3, 0x8a, 0x7f, 0xab, 0xdd, 0xfa, 0x13, 0x21, 0x9c, 0x08, 0x84, 0xf6, 0x0e, 0x84, 0xe6,
	0x26, 0x42, 0x95, 0xe7, 0xb9, 0x59, 0x2d, 0x76, 0xfb, 0x13, 0x00, 0x00, 0xff, 0xff, 0x68, 0x24,
	0x59, 0x0d, 0x0a, 0x02, 0x00, 0x00,
}
