// Code generated by protoc-gen-go. DO NOT EDIT.
// source: google/ads/googleads/v2/services/parental_status_view_service.proto

package services

import (
	context "context"
	fmt "fmt"
	math "math"

	proto "github.com/golang/protobuf/proto"
	resources "google.golang.org/genproto/googleapis/ads/googleads/v2/resources"
	_ "google.golang.org/genproto/googleapis/api/annotations"
	grpc "google.golang.org/grpc"
)

// Reference imports to suppress errors if they are not otherwise used.
var _ = proto.Marshal
var _ = fmt.Errorf
var _ = math.Inf

// This is a compile-time assertion to ensure that this generated file
// is compatible with the proto package it is being compiled against.
// A compilation error at this line likely means your copy of the
// proto package needs to be updated.
const _ = proto.ProtoPackageIsVersion3 // please upgrade the proto package

// Request message for [ParentalStatusViewService.GetParentalStatusView][google.ads.googleads.v2.services.ParentalStatusViewService.GetParentalStatusView].
type GetParentalStatusViewRequest struct {
	// The resource name of the parental status view to fetch.
	ResourceName         string   `protobuf:"bytes,1,opt,name=resource_name,json=resourceName,proto3" json:"resource_name,omitempty"`
	XXX_NoUnkeyedLiteral struct{} `json:"-"`
	XXX_unrecognized     []byte   `json:"-"`
	XXX_sizecache        int32    `json:"-"`
}

func (m *GetParentalStatusViewRequest) Reset()         { *m = GetParentalStatusViewRequest{} }
func (m *GetParentalStatusViewRequest) String() string { return proto.CompactTextString(m) }
func (*GetParentalStatusViewRequest) ProtoMessage()    {}
func (*GetParentalStatusViewRequest) Descriptor() ([]byte, []int) {
	return fileDescriptor_3677998f9a8d2f2f, []int{0}
}

func (m *GetParentalStatusViewRequest) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_GetParentalStatusViewRequest.Unmarshal(m, b)
}
func (m *GetParentalStatusViewRequest) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_GetParentalStatusViewRequest.Marshal(b, m, deterministic)
}
func (m *GetParentalStatusViewRequest) XXX_Merge(src proto.Message) {
	xxx_messageInfo_GetParentalStatusViewRequest.Merge(m, src)
}
func (m *GetParentalStatusViewRequest) XXX_Size() int {
	return xxx_messageInfo_GetParentalStatusViewRequest.Size(m)
}
func (m *GetParentalStatusViewRequest) XXX_DiscardUnknown() {
	xxx_messageInfo_GetParentalStatusViewRequest.DiscardUnknown(m)
}

var xxx_messageInfo_GetParentalStatusViewRequest proto.InternalMessageInfo

func (m *GetParentalStatusViewRequest) GetResourceName() string {
	if m != nil {
		return m.ResourceName
	}
	return ""
}

func init() {
	proto.RegisterType((*GetParentalStatusViewRequest)(nil), "google.ads.googleads.v2.services.GetParentalStatusViewRequest")
}

func init() {
	proto.RegisterFile("google/ads/googleads/v2/services/parental_status_view_service.proto", fileDescriptor_3677998f9a8d2f2f)
}

var fileDescriptor_3677998f9a8d2f2f = []byte{
	// 396 bytes of a gzipped FileDescriptorProto
	0x1f, 0x8b, 0x08, 0x00, 0x00, 0x00, 0x00, 0x00, 0x02, 0xff, 0x84, 0x52, 0xcf, 0x8a, 0xd3, 0x40,
	0x18, 0x27, 0x11, 0x04, 0x83, 0x5e, 0x02, 0x62, 0x8d, 0x45, 0x4a, 0xed, 0x41, 0x7a, 0x98, 0x81,
	0x48, 0x11, 0x46, 0x2b, 0xa4, 0x3d, 0xd4, 0x93, 0x94, 0x16, 0x72, 0x90, 0x40, 0x18, 0x93, 0x21,
	0x04, 0x92, 0x99, 0x98, 0x6f, 0x92, 0x1e, 0xc4, 0x8b, 0x20, 0x78, 0xf7, 0x0d, 0x3c, 0xfa, 0x28,
	0x85, 0x3d, 0xed, 0x2b, 0xec, 0x69, 0x9f, 0x62, 0x49, 0x27, 0x93, 0xee, 0xd2, 0xcd, 0xf6, 0xf6,
	0x63, 0xbe, 0xdf, 0x9f, 0xf9, 0x7e, 0x33, 0xd6, 0x32, 0x11, 0x22, 0xc9, 0x18, 0xa6, 0x31, 0x60,
	0x05, 0x1b, 0x54, 0xbb, 0x18, 0x58, 0x59, 0xa7, 0x11, 0x03, 0x5c, 0xd0, 0x92, 0x71, 0x49, 0xb3,
	0x10, 0x24, 0x95, 0x15, 0x84, 0x75, 0xca, 0x76, 0x61, 0x3b, 0x45, 0x45, 0x29, 0xa4, 0xb0, 0x47,
	0x4a, 0x89, 0x68, 0x0c, 0xa8, 0x33, 0x41, 0xb5, 0x8b, 0xb4, 0x89, 0xf3, 0xb1, 0x2f, 0xa6, 0x64,
	0x20, 0xaa, 0xb2, 0x2f, 0x47, 0xf9, 0x3b, 0x43, 0xad, 0x2e, 0x52, 0x4c, 0x39, 0x17, 0x92, 0xca,
	0x54, 0x70, 0x68, 0xa7, 0x2f, 0x6e, 0x4d, 0xa3, 0x2c, 0x65, 0x5c, 0xaa, 0xc1, 0x78, 0x69, 0x0d,
	0x57, 0x4c, 0xae, 0x5b, 0xdf, 0xed, 0xc1, 0xd6, 0x4f, 0xd9, 0x6e, 0xc3, 0xbe, 0x57, 0x0c, 0xa4,
	0xfd, 0xc6, 0x7a, 0xa6, 0xe3, 0x43, 0x4e, 0x73, 0x36, 0x30, 0x46, 0xc6, 0xdb, 0x27, 0x9b, 0xa7,
	0xfa, 0xf0, 0x0b, 0xcd, 0x99, 0xfb, 0xc7, 0xb4, 0x5e, 0x9e, 0x5a, 0x6c, 0xd5, 0x62, 0xf6, 0x85,
	0x61, 0x3d, 0xbf, 0x37, 0xc3, 0xfe, 0x84, 0xce, 0x95, 0x82, 0x1e, 0xba, 0x9c, 0x33, 0xeb, 0xd5,
	0x77, 0x95, 0xa1, 0x53, 0xf5, 0x78, 0xfe, 0xeb, 0xf2, 0xea, 0xaf, 0xf9, 0xde, 0x9e, 0x35, 0xe5,
	0xfe, 0xb8, 0xb3, 0xde, 0x3c, 0xaa, 0x40, 0x8a, 0x9c, 0x95, 0x80, 0xa7, 0x5d, 0xdb, 0x47, 0x29,
	0xe0, 0xe9, 0x4f, 0xe7, 0xd5, 0xde, 0x1b, 0x1c, 0xc3, 0x5a, 0x54, 0xa4, 0x80, 0x22, 0x91, 0x2f,
	0x7e, 0x9b, 0xd6, 0x24, 0x12, 0xf9, 0xd9, 0xc5, 0x16, 0xaf, 0x7b, 0x0b, 0x5b, 0x37, 0x0f, 0xb3,
	0x36, 0xbe, 0x7e, 0x6e, 0x3d, 0x12, 0x91, 0x51, 0x9e, 0x20, 0x51, 0x26, 0x38, 0x61, 0xfc, 0xf0,
	0x6c, 0xf8, 0x98, 0xda, 0xff, 0x2b, 0x3f, 0x68, 0xf0, 0xcf, 0x7c, 0xb4, 0xf2, 0xbc, 0xff, 0xe6,
	0x68, 0xa5, 0x0c, 0xbd, 0x18, 0x90, 0x82, 0x0d, 0xf2, 0x5d, 0xd4, 0x06, 0xc3, 0x5e, 0x53, 0x02,
	0x2f, 0x86, 0xa0, 0xa3, 0x04, 0xbe, 0x1b, 0x68, 0xca, 0xb5, 0x39, 0x51, 0xe7, 0x84, 0x78, 0x31,
	0x10, 0xd2, 0x91, 0x08, 0xf1, 0x5d, 0x42, 0x34, 0xed, 0xdb, 0xe3, 0xc3, 0x3d, 0xdf, 0xdd, 0x04,
	0x00, 0x00, 0xff, 0xff, 0x3e, 0x4b, 0x00, 0xae, 0x3c, 0x03, 0x00, 0x00,
}

// Reference imports to suppress errors if they are not otherwise used.
var _ context.Context
var _ grpc.ClientConn

// This is a compile-time assertion to ensure that this generated file
// is compatible with the grpc package it is being compiled against.
const _ = grpc.SupportPackageIsVersion4

// ParentalStatusViewServiceClient is the client API for ParentalStatusViewService service.
//
// For semantics around ctx use and closing/ending streaming RPCs, please refer to https://godoc.org/google.golang.org/grpc#ClientConn.NewStream.
type ParentalStatusViewServiceClient interface {
	// Returns the requested parental status view in full detail.
	GetParentalStatusView(ctx context.Context, in *GetParentalStatusViewRequest, opts ...grpc.CallOption) (*resources.ParentalStatusView, error)
}

type parentalStatusViewServiceClient struct {
	cc *grpc.ClientConn
}

func NewParentalStatusViewServiceClient(cc *grpc.ClientConn) ParentalStatusViewServiceClient {
	return &parentalStatusViewServiceClient{cc}
}

func (c *parentalStatusViewServiceClient) GetParentalStatusView(ctx context.Context, in *GetParentalStatusViewRequest, opts ...grpc.CallOption) (*resources.ParentalStatusView, error) {
	out := new(resources.ParentalStatusView)
	err := c.cc.Invoke(ctx, "/google.ads.googleads.v2.services.ParentalStatusViewService/GetParentalStatusView", in, out, opts...)
	if err != nil {
		return nil, err
	}
	return out, nil
}

// ParentalStatusViewServiceServer is the server API for ParentalStatusViewService service.
type ParentalStatusViewServiceServer interface {
	// Returns the requested parental status view in full detail.
	GetParentalStatusView(context.Context, *GetParentalStatusViewRequest) (*resources.ParentalStatusView, error)
}

func RegisterParentalStatusViewServiceServer(s *grpc.Server, srv ParentalStatusViewServiceServer) {
	s.RegisterService(&_ParentalStatusViewService_serviceDesc, srv)
}

func _ParentalStatusViewService_GetParentalStatusView_Handler(srv interface{}, ctx context.Context, dec func(interface{}) error, interceptor grpc.UnaryServerInterceptor) (interface{}, error) {
	in := new(GetParentalStatusViewRequest)
	if err := dec(in); err != nil {
		return nil, err
	}
	if interceptor == nil {
		return srv.(ParentalStatusViewServiceServer).GetParentalStatusView(ctx, in)
	}
	info := &grpc.UnaryServerInfo{
		Server:     srv,
		FullMethod: "/google.ads.googleads.v2.services.ParentalStatusViewService/GetParentalStatusView",
	}
	handler := func(ctx context.Context, req interface{}) (interface{}, error) {
		return srv.(ParentalStatusViewServiceServer).GetParentalStatusView(ctx, req.(*GetParentalStatusViewRequest))
	}
	return interceptor(ctx, in, info, handler)
}

var _ParentalStatusViewService_serviceDesc = grpc.ServiceDesc{
	ServiceName: "google.ads.googleads.v2.services.ParentalStatusViewService",
	HandlerType: (*ParentalStatusViewServiceServer)(nil),
	Methods: []grpc.MethodDesc{
		{
			MethodName: "GetParentalStatusView",
			Handler:    _ParentalStatusViewService_GetParentalStatusView_Handler,
		},
	},
	Streams:  []grpc.StreamDesc{},
	Metadata: "google/ads/googleads/v2/services/parental_status_view_service.proto",
}
