// Code generated by protoc-gen-go. DO NOT EDIT.
// source: google/ads/googleads/v2/errors/shared_set_error.proto

package errors

import (
	fmt "fmt"
	math "math"

	proto "github.com/golang/protobuf/proto"
	_ "google.golang.org/genproto/googleapis/api/annotations"
)

// Reference imports to suppress errors if they are not otherwise used.
var _ = proto.Marshal
var _ = fmt.Errorf
var _ = math.Inf

// This is a compile-time assertion to ensure that this generated file
// is compatible with the proto package it is being compiled against.
// A compilation error at this line likely means your copy of the
// proto package needs to be updated.
const _ = proto.ProtoPackageIsVersion3 // please upgrade the proto package

// Enum describing possible shared set errors.
type SharedSetErrorEnum_SharedSetError int32

const (
	// Enum unspecified.
	SharedSetErrorEnum_UNSPECIFIED SharedSetErrorEnum_SharedSetError = 0
	// The received error code is not known in this version.
	SharedSetErrorEnum_UNKNOWN SharedSetErrorEnum_SharedSetError = 1
	// The customer cannot create this type of shared set.
	SharedSetErrorEnum_CUSTOMER_CANNOT_CREATE_SHARED_SET_OF_THIS_TYPE SharedSetErrorEnum_SharedSetError = 2
	// A shared set with this name already exists.
	SharedSetErrorEnum_DUPLICATE_NAME SharedSetErrorEnum_SharedSetError = 3
	// Removed shared sets cannot be mutated.
	SharedSetErrorEnum_SHARED_SET_REMOVED SharedSetErrorEnum_SharedSetError = 4
	// The shared set cannot be removed because it is in use.
	SharedSetErrorEnum_SHARED_SET_IN_USE SharedSetErrorEnum_SharedSetError = 5
)

var SharedSetErrorEnum_SharedSetError_name = map[int32]string{
	0: "UNSPECIFIED",
	1: "UNKNOWN",
	2: "CUSTOMER_CANNOT_CREATE_SHARED_SET_OF_THIS_TYPE",
	3: "DUPLICATE_NAME",
	4: "SHARED_SET_REMOVED",
	5: "SHARED_SET_IN_USE",
}

var SharedSetErrorEnum_SharedSetError_value = map[string]int32{
	"UNSPECIFIED": 0,
	"UNKNOWN":     1,
	"CUSTOMER_CANNOT_CREATE_SHARED_SET_OF_THIS_TYPE": 2,
	"DUPLICATE_NAME":     3,
	"SHARED_SET_REMOVED": 4,
	"SHARED_SET_IN_USE":  5,
}

func (x SharedSetErrorEnum_SharedSetError) String() string {
	return proto.EnumName(SharedSetErrorEnum_SharedSetError_name, int32(x))
}

func (SharedSetErrorEnum_SharedSetError) EnumDescriptor() ([]byte, []int) {
	return fileDescriptor_420ae8c2968cfad8, []int{0, 0}
}

// Container for enum describing possible shared set errors.
type SharedSetErrorEnum struct {
	XXX_NoUnkeyedLiteral struct{} `json:"-"`
	XXX_unrecognized     []byte   `json:"-"`
	XXX_sizecache        int32    `json:"-"`
}

func (m *SharedSetErrorEnum) Reset()         { *m = SharedSetErrorEnum{} }
func (m *SharedSetErrorEnum) String() string { return proto.CompactTextString(m) }
func (*SharedSetErrorEnum) ProtoMessage()    {}
func (*SharedSetErrorEnum) Descriptor() ([]byte, []int) {
	return fileDescriptor_420ae8c2968cfad8, []int{0}
}

func (m *SharedSetErrorEnum) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_SharedSetErrorEnum.Unmarshal(m, b)
}
func (m *SharedSetErrorEnum) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_SharedSetErrorEnum.Marshal(b, m, deterministic)
}
func (m *SharedSetErrorEnum) XXX_Merge(src proto.Message) {
	xxx_messageInfo_SharedSetErrorEnum.Merge(m, src)
}
func (m *SharedSetErrorEnum) XXX_Size() int {
	return xxx_messageInfo_SharedSetErrorEnum.Size(m)
}
func (m *SharedSetErrorEnum) XXX_DiscardUnknown() {
	xxx_messageInfo_SharedSetErrorEnum.DiscardUnknown(m)
}

var xxx_messageInfo_SharedSetErrorEnum proto.InternalMessageInfo

func init() {
	proto.RegisterEnum("google.ads.googleads.v2.errors.SharedSetErrorEnum_SharedSetError", SharedSetErrorEnum_SharedSetError_name, SharedSetErrorEnum_SharedSetError_value)
	proto.RegisterType((*SharedSetErrorEnum)(nil), "google.ads.googleads.v2.errors.SharedSetErrorEnum")
}

func init() {
	proto.RegisterFile("google/ads/googleads/v2/errors/shared_set_error.proto", fileDescriptor_420ae8c2968cfad8)
}

var fileDescriptor_420ae8c2968cfad8 = []byte{
	// 372 bytes of a gzipped FileDescriptorProto
	0x1f, 0x8b, 0x08, 0x00, 0x00, 0x00, 0x00, 0x00, 0x02, 0xff, 0x7c, 0x91, 0xdf, 0x8a, 0x9b, 0x40,
	0x18, 0xc5, 0xab, 0xe9, 0x1f, 0x98, 0x40, 0x6a, 0xa7, 0xb4, 0x17, 0xa5, 0xe4, 0xc2, 0x07, 0x18,
	0xc1, 0xd2, 0x9b, 0xe9, 0xd5, 0x44, 0x27, 0x89, 0xb4, 0x19, 0xc5, 0x51, 0x4b, 0x8b, 0x30, 0xd8,
	0x2a, 0x6e, 0x20, 0x71, 0x82, 0xe3, 0xe6, 0x81, 0x16, 0xf6, 0x66, 0x9f, 0x61, 0x9f, 0x60, 0x1f,
	0x65, 0x2f, 0xf6, 0x19, 0x16, 0x9d, 0x4d, 0x48, 0x2e, 0x76, 0xaf, 0x3c, 0x1c, 0x7e, 0xe7, 0x38,
	0xdf, 0xf7, 0x81, 0xef, 0xb5, 0x94, 0xf5, 0xa6, 0x72, 0x8a, 0x52, 0x39, 0x5a, 0xf6, 0x6a, 0xef,
	0x3a, 0x55, 0xdb, 0xca, 0x56, 0x39, 0xea, 0xa2, 0x68, 0xab, 0x52, 0xa8, 0xaa, 0x13, 0x83, 0x83,
	0x76, 0xad, 0xec, 0x24, 0x9c, 0x6a, 0x16, 0x15, 0xa5, 0x42, 0xc7, 0x18, 0xda, 0xbb, 0x48, 0xc7,
	0xbe, 0x7c, 0x3d, 0xd4, 0xee, 0xd6, 0x4e, 0xd1, 0x34, 0xb2, 0x2b, 0xba, 0xb5, 0x6c, 0x94, 0x4e,
	0xdb, 0xb7, 0x06, 0x80, 0x7c, 0x28, 0xe6, 0x55, 0x47, 0xfb, 0x04, 0x6d, 0x2e, 0xb7, 0xf6, 0xb5,
	0x01, 0x26, 0xe7, 0x36, 0x7c, 0x0f, 0xc6, 0x29, 0xe3, 0x11, 0xf5, 0x82, 0x79, 0x40, 0x7d, 0xeb,
	0x15, 0x1c, 0x83, 0x77, 0x29, 0xfb, 0xc9, 0xc2, 0xdf, 0xcc, 0x32, 0xa0, 0x0b, 0x90, 0x97, 0xf2,
	0x24, 0x5c, 0xd1, 0x58, 0x78, 0x84, 0xb1, 0x30, 0x11, 0x5e, 0x4c, 0x49, 0x42, 0x05, 0x5f, 0x92,
	0x98, 0xfa, 0x82, 0xd3, 0x44, 0x84, 0x73, 0x91, 0x2c, 0x03, 0x2e, 0x92, 0x3f, 0x11, 0xb5, 0x4c,
	0x08, 0xc1, 0xc4, 0x4f, 0xa3, 0x5f, 0x81, 0xd7, 0x63, 0x8c, 0xac, 0xa8, 0x35, 0x82, 0x9f, 0x01,
	0x3c, 0x09, 0xc4, 0x74, 0x15, 0x66, 0xd4, 0xb7, 0x5e, 0xc3, 0x4f, 0xe0, 0xc3, 0x89, 0x1f, 0x30,
	0x91, 0x72, 0x6a, 0xbd, 0x99, 0x3d, 0x18, 0xc0, 0xfe, 0x2f, 0xb7, 0xe8, 0xe5, 0x1d, 0xcc, 0x3e,
	0x9e, 0xcf, 0x12, 0xf5, 0xa3, 0x47, 0xc6, 0x5f, 0xff, 0x29, 0x56, 0xcb, 0x4d, 0xd1, 0xd4, 0x48,
	0xb6, 0xb5, 0x53, 0x57, 0xcd, 0xb0, 0x98, 0xc3, 0x05, 0x76, 0x6b, 0xf5, 0xdc, 0x41, 0x7e, 0xe8,
	0xcf, 0x95, 0x39, 0x5a, 0x10, 0x72, 0x63, 0x4e, 0x17, 0xba, 0x8c, 0x94, 0x0a, 0x69, 0xd9, 0xab,
	0xcc, 0x45, 0xc3, 0x2f, 0xd5, 0xdd, 0x01, 0xc8, 0x49, 0xa9, 0xf2, 0x23, 0x90, 0x67, 0x6e, 0xae,
	0x81, 0x7b, 0xd3, 0xd6, 0x2e, 0xc6, 0xa4, 0x54, 0x18, 0x1f, 0x11, 0x8c, 0x33, 0x17, 0x63, 0x0d,
	0xfd, 0x7b, 0x3b, 0xbc, 0xee, 0xdb, 0x63, 0x00, 0x00, 0x00, 0xff, 0xff, 0xb9, 0xc5, 0x46, 0xed,
	0x2d, 0x02, 0x00, 0x00,
}
