// Code generated by protoc-gen-go. DO NOT EDIT.
// source: google/ads/googleads/v2/enums/customer_match_upload_key_type.proto

package enums

import (
	fmt "fmt"
	math "math"

	proto "github.com/golang/protobuf/proto"
	_ "google.golang.org/genproto/googleapis/api/annotations"
)

// Reference imports to suppress errors if they are not otherwise used.
var _ = proto.Marshal
var _ = fmt.Errorf
var _ = math.Inf

// This is a compile-time assertion to ensure that this generated file
// is compatible with the proto package it is being compiled against.
// A compilation error at this line likely means your copy of the
// proto package needs to be updated.
const _ = proto.ProtoPackageIsVersion3 // please upgrade the proto package

// Enum describing possible customer match upload key types.
type CustomerMatchUploadKeyTypeEnum_CustomerMatchUploadKeyType int32

const (
	// Not specified.
	CustomerMatchUploadKeyTypeEnum_UNSPECIFIED CustomerMatchUploadKeyTypeEnum_CustomerMatchUploadKeyType = 0
	// Used for return value only. Represents value unknown in this version.
	CustomerMatchUploadKeyTypeEnum_UNKNOWN CustomerMatchUploadKeyTypeEnum_CustomerMatchUploadKeyType = 1
	// Members are matched from customer info such as email address, phone
	// number or physical address.
	CustomerMatchUploadKeyTypeEnum_CONTACT_INFO CustomerMatchUploadKeyTypeEnum_CustomerMatchUploadKeyType = 2
	// Members are matched from a user id generated and assigned by the
	// advertiser.
	CustomerMatchUploadKeyTypeEnum_CRM_ID CustomerMatchUploadKeyTypeEnum_CustomerMatchUploadKeyType = 3
	// Members are matched from mobile advertising ids.
	CustomerMatchUploadKeyTypeEnum_MOBILE_ADVERTISING_ID CustomerMatchUploadKeyTypeEnum_CustomerMatchUploadKeyType = 4
)

var CustomerMatchUploadKeyTypeEnum_CustomerMatchUploadKeyType_name = map[int32]string{
	0: "UNSPECIFIED",
	1: "UNKNOWN",
	2: "CONTACT_INFO",
	3: "CRM_ID",
	4: "MOBILE_ADVERTISING_ID",
}

var CustomerMatchUploadKeyTypeEnum_CustomerMatchUploadKeyType_value = map[string]int32{
	"UNSPECIFIED":           0,
	"UNKNOWN":               1,
	"CONTACT_INFO":          2,
	"CRM_ID":                3,
	"MOBILE_ADVERTISING_ID": 4,
}

func (x CustomerMatchUploadKeyTypeEnum_CustomerMatchUploadKeyType) String() string {
	return proto.EnumName(CustomerMatchUploadKeyTypeEnum_CustomerMatchUploadKeyType_name, int32(x))
}

func (CustomerMatchUploadKeyTypeEnum_CustomerMatchUploadKeyType) EnumDescriptor() ([]byte, []int) {
	return fileDescriptor_c4c81d55f65f43f0, []int{0, 0}
}

// Indicates what type of data are the user list's members matched from.
type CustomerMatchUploadKeyTypeEnum struct {
	XXX_NoUnkeyedLiteral struct{} `json:"-"`
	XXX_unrecognized     []byte   `json:"-"`
	XXX_sizecache        int32    `json:"-"`
}

func (m *CustomerMatchUploadKeyTypeEnum) Reset()         { *m = CustomerMatchUploadKeyTypeEnum{} }
func (m *CustomerMatchUploadKeyTypeEnum) String() string { return proto.CompactTextString(m) }
func (*CustomerMatchUploadKeyTypeEnum) ProtoMessage()    {}
func (*CustomerMatchUploadKeyTypeEnum) Descriptor() ([]byte, []int) {
	return fileDescriptor_c4c81d55f65f43f0, []int{0}
}

func (m *CustomerMatchUploadKeyTypeEnum) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_CustomerMatchUploadKeyTypeEnum.Unmarshal(m, b)
}
func (m *CustomerMatchUploadKeyTypeEnum) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_CustomerMatchUploadKeyTypeEnum.Marshal(b, m, deterministic)
}
func (m *CustomerMatchUploadKeyTypeEnum) XXX_Merge(src proto.Message) {
	xxx_messageInfo_CustomerMatchUploadKeyTypeEnum.Merge(m, src)
}
func (m *CustomerMatchUploadKeyTypeEnum) XXX_Size() int {
	return xxx_messageInfo_CustomerMatchUploadKeyTypeEnum.Size(m)
}
func (m *CustomerMatchUploadKeyTypeEnum) XXX_DiscardUnknown() {
	xxx_messageInfo_CustomerMatchUploadKeyTypeEnum.DiscardUnknown(m)
}

var xxx_messageInfo_CustomerMatchUploadKeyTypeEnum proto.InternalMessageInfo

func init() {
	proto.RegisterEnum("google.ads.googleads.v2.enums.CustomerMatchUploadKeyTypeEnum_CustomerMatchUploadKeyType", CustomerMatchUploadKeyTypeEnum_CustomerMatchUploadKeyType_name, CustomerMatchUploadKeyTypeEnum_CustomerMatchUploadKeyType_value)
	proto.RegisterType((*CustomerMatchUploadKeyTypeEnum)(nil), "google.ads.googleads.v2.enums.CustomerMatchUploadKeyTypeEnum")
}

func init() {
	proto.RegisterFile("google/ads/googleads/v2/enums/customer_match_upload_key_type.proto", fileDescriptor_c4c81d55f65f43f0)
}

var fileDescriptor_c4c81d55f65f43f0 = []byte{
	// 352 bytes of a gzipped FileDescriptorProto
	0x1f, 0x8b, 0x08, 0x00, 0x00, 0x00, 0x00, 0x00, 0x02, 0xff, 0x7c, 0x51, 0x41, 0x6a, 0x83, 0x40,
	0x14, 0xad, 0xa6, 0xa4, 0x30, 0x29, 0x54, 0x84, 0x2e, 0x1a, 0x9a, 0x96, 0xe4, 0x00, 0x23, 0xd8,
	0xdd, 0x74, 0xa5, 0xc6, 0x04, 0x49, 0xa3, 0x21, 0x31, 0x16, 0x8a, 0x30, 0x4c, 0xe3, 0x60, 0x43,
	0xe3, 0x8c, 0x64, 0x34, 0xe0, 0x41, 0x7a, 0x81, 0x2e, 0x7b, 0x94, 0x1e, 0xa5, 0xeb, 0x1e, 0xa0,
	0x38, 0x26, 0xd9, 0xa5, 0x1b, 0x79, 0xf8, 0xfe, 0x7f, 0xef, 0xbf, 0x37, 0xc0, 0x4e, 0x39, 0x4f,
	0x37, 0xd4, 0x20, 0x89, 0x30, 0x1a, 0x58, 0xa3, 0x9d, 0x69, 0x50, 0x56, 0x66, 0xc2, 0x58, 0x95,
	0xa2, 0xe0, 0x19, 0xdd, 0xe2, 0x8c, 0x14, 0xab, 0x37, 0x5c, 0xe6, 0x1b, 0x4e, 0x12, 0xfc, 0x4e,
	0x2b, 0x5c, 0x54, 0x39, 0x85, 0xf9, 0x96, 0x17, 0x5c, 0xef, 0x35, 0x8b, 0x90, 0x24, 0x02, 0x1e,
	0x35, 0xe0, 0xce, 0x84, 0x52, 0xa3, 0x7b, 0x7b, 0xb0, 0xc8, 0xd7, 0x06, 0x61, 0x8c, 0x17, 0xa4,
	0x58, 0x73, 0x26, 0x9a, 0xe5, 0xc1, 0x87, 0x02, 0xee, 0x9c, 0xbd, 0xcb, 0xb4, 0x36, 0x59, 0x4a,
	0x8f, 0x09, 0xad, 0xc2, 0x2a, 0xa7, 0x2e, 0x2b, 0xb3, 0x81, 0x00, 0xdd, 0xd3, 0x13, 0xfa, 0x15,
	0xe8, 0x2c, 0xfd, 0xc5, 0xcc, 0x75, 0xbc, 0x91, 0xe7, 0x0e, 0xb5, 0x33, 0xbd, 0x03, 0x2e, 0x96,
	0xfe, 0xc4, 0x0f, 0x9e, 0x7d, 0x4d, 0xd1, 0x35, 0x70, 0xe9, 0x04, 0x7e, 0x68, 0x39, 0x21, 0xf6,
	0xfc, 0x51, 0xa0, 0xa9, 0x3a, 0x00, 0x6d, 0x67, 0x3e, 0xc5, 0xde, 0x50, 0x6b, 0xe9, 0x37, 0xe0,
	0x7a, 0x1a, 0xd8, 0xde, 0x93, 0x8b, 0xad, 0x61, 0xe4, 0xce, 0x43, 0x6f, 0xe1, 0xf9, 0xe3, 0x9a,
	0x3a, 0xb7, 0x7f, 0x15, 0xd0, 0x5f, 0xf1, 0x0c, 0xfe, 0x9b, 0xcd, 0xbe, 0x3f, 0x7d, 0xd8, 0xac,
	0x8e, 0x37, 0x53, 0x5e, 0xf6, 0x0d, 0xc3, 0x94, 0x6f, 0x08, 0x4b, 0x21, 0xdf, 0xa6, 0x46, 0x4a,
	0x99, 0x0c, 0x7f, 0x68, 0x3c, 0x5f, 0x8b, 0x13, 0x0f, 0xf0, 0x28, 0xbf, 0x9f, 0x6a, 0x6b, 0x6c,
	0x59, 0x5f, 0x6a, 0x6f, 0xdc, 0x48, 0x59, 0x89, 0x80, 0x0d, 0xac, 0x51, 0x64, 0xc2, 0xba, 0x26,
	0xf1, 0x7d, 0xe0, 0x63, 0x2b, 0x11, 0xf1, 0x91, 0x8f, 0x23, 0x33, 0x96, 0xfc, 0x8f, 0xda, 0x6f,
	0x7e, 0x22, 0x64, 0x25, 0x02, 0xa1, 0xe3, 0x04, 0x42, 0x91, 0x89, 0x90, 0x9c, 0x79, 0x6d, 0xcb,
	0xc3, 0x1e, 0xfe, 0x02, 0x00, 0x00, 0xff, 0xff, 0x83, 0x87, 0xe9, 0xab, 0x18, 0x02, 0x00, 0x00,
}
