// Code generated by protoc-gen-go. DO NOT EDIT.
// source: google/ads/googleads/v1/resources/campaign_criterion_simulation.proto

package resources

import (
	fmt "fmt"
	math "math"

	proto "github.com/golang/protobuf/proto"
	wrappers "github.com/golang/protobuf/ptypes/wrappers"
	common "google.golang.org/genproto/googleapis/ads/googleads/v1/common"
	enums "google.golang.org/genproto/googleapis/ads/googleads/v1/enums"
	_ "google.golang.org/genproto/googleapis/api/annotations"
)

// Reference imports to suppress errors if they are not otherwise used.
var _ = proto.Marshal
var _ = fmt.Errorf
var _ = math.Inf

// This is a compile-time assertion to ensure that this generated file
// is compatible with the proto package it is being compiled against.
// A compilation error at this line likely means your copy of the
// proto package needs to be updated.
const _ = proto.ProtoPackageIsVersion3 // please upgrade the proto package

// A campaign criterion simulation. Supported combinations of advertising
// channel type, criterion ids, simulation type and simulation modification
// method is detailed below respectively.
//
// SEARCH   30000,30001,30002  BID_MODIFIER  UNIFORM
// DISPLAY  30001              BID_MODIFIER  UNIFORM
type CampaignCriterionSimulation struct {
	// The resource name of the campaign criterion simulation.
	// Campaign criterion simulation resource names have the form:
	//
	//
	// `customers/{customer_id}/campaignCriterionSimulations/{campaign_id}~{criterion_id}~{type}~{modification_method}~{start_date}~{end_date}`
	ResourceName string `protobuf:"bytes,1,opt,name=resource_name,json=resourceName,proto3" json:"resource_name,omitempty"`
	// Campaign ID of the simulation.
	CampaignId *wrappers.Int64Value `protobuf:"bytes,2,opt,name=campaign_id,json=campaignId,proto3" json:"campaign_id,omitempty"`
	// Criterion ID of the simulation.
	CriterionId *wrappers.Int64Value `protobuf:"bytes,3,opt,name=criterion_id,json=criterionId,proto3" json:"criterion_id,omitempty"`
	// The field that the simulation modifies.
	Type enums.SimulationTypeEnum_SimulationType `protobuf:"varint,4,opt,name=type,proto3,enum=google.ads.googleads.v1.enums.SimulationTypeEnum_SimulationType" json:"type,omitempty"`
	// How the simulation modifies the field.
	ModificationMethod enums.SimulationModificationMethodEnum_SimulationModificationMethod `protobuf:"varint,5,opt,name=modification_method,json=modificationMethod,proto3,enum=google.ads.googleads.v1.enums.SimulationModificationMethodEnum_SimulationModificationMethod" json:"modification_method,omitempty"`
	// First day on which the simulation is based, in YYYY-MM-DD format.
	StartDate *wrappers.StringValue `protobuf:"bytes,6,opt,name=start_date,json=startDate,proto3" json:"start_date,omitempty"`
	// Last day on which the simulation is based, in YYYY-MM-DD format.
	EndDate *wrappers.StringValue `protobuf:"bytes,7,opt,name=end_date,json=endDate,proto3" json:"end_date,omitempty"`
	// List of simulation points.
	//
	// Types that are valid to be assigned to PointList:
	//	*CampaignCriterionSimulation_BidModifierPointList
	PointList            isCampaignCriterionSimulation_PointList `protobuf_oneof:"point_list"`
	XXX_NoUnkeyedLiteral struct{}                                `json:"-"`
	XXX_unrecognized     []byte                                  `json:"-"`
	XXX_sizecache        int32                                   `json:"-"`
}

func (m *CampaignCriterionSimulation) Reset()         { *m = CampaignCriterionSimulation{} }
func (m *CampaignCriterionSimulation) String() string { return proto.CompactTextString(m) }
func (*CampaignCriterionSimulation) ProtoMessage()    {}
func (*CampaignCriterionSimulation) Descriptor() ([]byte, []int) {
	return fileDescriptor_4eae0e5c50ed969c, []int{0}
}

func (m *CampaignCriterionSimulation) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_CampaignCriterionSimulation.Unmarshal(m, b)
}
func (m *CampaignCriterionSimulation) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_CampaignCriterionSimulation.Marshal(b, m, deterministic)
}
func (m *CampaignCriterionSimulation) XXX_Merge(src proto.Message) {
	xxx_messageInfo_CampaignCriterionSimulation.Merge(m, src)
}
func (m *CampaignCriterionSimulation) XXX_Size() int {
	return xxx_messageInfo_CampaignCriterionSimulation.Size(m)
}
func (m *CampaignCriterionSimulation) XXX_DiscardUnknown() {
	xxx_messageInfo_CampaignCriterionSimulation.DiscardUnknown(m)
}

var xxx_messageInfo_CampaignCriterionSimulation proto.InternalMessageInfo

func (m *CampaignCriterionSimulation) GetResourceName() string {
	if m != nil {
		return m.ResourceName
	}
	return ""
}

func (m *CampaignCriterionSimulation) GetCampaignId() *wrappers.Int64Value {
	if m != nil {
		return m.CampaignId
	}
	return nil
}

func (m *CampaignCriterionSimulation) GetCriterionId() *wrappers.Int64Value {
	if m != nil {
		return m.CriterionId
	}
	return nil
}

func (m *CampaignCriterionSimulation) GetType() enums.SimulationTypeEnum_SimulationType {
	if m != nil {
		return m.Type
	}
	return enums.SimulationTypeEnum_UNSPECIFIED
}

func (m *CampaignCriterionSimulation) GetModificationMethod() enums.SimulationModificationMethodEnum_SimulationModificationMethod {
	if m != nil {
		return m.ModificationMethod
	}
	return enums.SimulationModificationMethodEnum_UNSPECIFIED
}

func (m *CampaignCriterionSimulation) GetStartDate() *wrappers.StringValue {
	if m != nil {
		return m.StartDate
	}
	return nil
}

func (m *CampaignCriterionSimulation) GetEndDate() *wrappers.StringValue {
	if m != nil {
		return m.EndDate
	}
	return nil
}

type isCampaignCriterionSimulation_PointList interface {
	isCampaignCriterionSimulation_PointList()
}

type CampaignCriterionSimulation_BidModifierPointList struct {
	BidModifierPointList *common.BidModifierSimulationPointList `protobuf:"bytes,8,opt,name=bid_modifier_point_list,json=bidModifierPointList,proto3,oneof"`
}

func (*CampaignCriterionSimulation_BidModifierPointList) isCampaignCriterionSimulation_PointList() {}

func (m *CampaignCriterionSimulation) GetPointList() isCampaignCriterionSimulation_PointList {
	if m != nil {
		return m.PointList
	}
	return nil
}

func (m *CampaignCriterionSimulation) GetBidModifierPointList() *common.BidModifierSimulationPointList {
	if x, ok := m.GetPointList().(*CampaignCriterionSimulation_BidModifierPointList); ok {
		return x.BidModifierPointList
	}
	return nil
}

// XXX_OneofWrappers is for the internal use of the proto package.
func (*CampaignCriterionSimulation) XXX_OneofWrappers() []interface{} {
	return []interface{}{
		(*CampaignCriterionSimulation_BidModifierPointList)(nil),
	}
}

func init() {
	proto.RegisterType((*CampaignCriterionSimulation)(nil), "google.ads.googleads.v1.resources.CampaignCriterionSimulation")
}

func init() {
	proto.RegisterFile("google/ads/googleads/v1/resources/campaign_criterion_simulation.proto", fileDescriptor_4eae0e5c50ed969c)
}

var fileDescriptor_4eae0e5c50ed969c = []byte{
	// 554 bytes of a gzipped FileDescriptorProto
	0x1f, 0x8b, 0x08, 0x00, 0x00, 0x00, 0x00, 0x00, 0x02, 0xff, 0x8c, 0x54, 0xdd, 0x6a, 0xdb, 0x30,
	0x14, 0x9e, 0xd3, 0x7f, 0x35, 0xdb, 0x85, 0x37, 0x98, 0x69, 0xcb, 0x48, 0x37, 0x0a, 0xb9, 0x92,
	0x49, 0x3b, 0x36, 0x70, 0x47, 0x59, 0xd2, 0x95, 0x2e, 0x63, 0x19, 0xc1, 0x2d, 0xb9, 0x18, 0x01,
	0xa3, 0x58, 0xaa, 0x27, 0x88, 0x24, 0x23, 0xc9, 0x2d, 0x7d, 0x88, 0xbe, 0xc4, 0x76, 0xb7, 0x47,
	0xd9, 0xa3, 0xec, 0x29, 0x46, 0x64, 0x59, 0x29, 0xc9, 0xd2, 0xe6, 0xee, 0xe8, 0x9c, 0xef, 0xc7,
	0xfa, 0x24, 0x19, 0x9c, 0x65, 0x42, 0x64, 0x63, 0x12, 0x22, 0xac, 0xc2, 0xb2, 0x9c, 0x54, 0xd7,
	0xad, 0x50, 0x12, 0x25, 0x0a, 0x99, 0x12, 0x15, 0xa6, 0x88, 0xe5, 0x88, 0x66, 0x3c, 0x49, 0x25,
	0xd5, 0x44, 0x52, 0xc1, 0x13, 0x45, 0x59, 0x31, 0x46, 0x9a, 0x0a, 0x0e, 0x73, 0x29, 0xb4, 0xf0,
	0xf7, 0x4b, 0x2e, 0x44, 0x58, 0x41, 0x27, 0x03, 0xaf, 0x5b, 0xd0, 0xc9, 0xec, 0x84, 0x8b, 0x9c,
	0x52, 0xc1, 0x98, 0xe0, 0xe1, 0xac, 0xe6, 0x4e, 0x67, 0x11, 0x81, 0xf0, 0x82, 0xa9, 0x7b, 0xf8,
	0x84, 0x09, 0x4c, 0xaf, 0x68, 0x6a, 0x17, 0x44, 0xff, 0x10, 0xd8, 0x6a, 0x1c, 0x2d, 0xad, 0xa1,
	0x6f, 0x73, 0x62, 0x49, 0x7b, 0x15, 0x29, 0xa7, 0x21, 0xe2, 0x5c, 0x68, 0x83, 0x50, 0x76, 0xfa,
	0xca, 0x4e, 0xcd, 0x6a, 0x54, 0x5c, 0x85, 0x37, 0x12, 0xe5, 0x39, 0x91, 0x76, 0xfe, 0xfa, 0xd7,
	0x1a, 0xd8, 0x3d, 0xb5, 0x91, 0x9d, 0x56, 0x89, 0x5d, 0x38, 0x23, 0xff, 0x0d, 0x78, 0x5a, 0x85,
	0x92, 0x70, 0xc4, 0x48, 0xe0, 0x35, 0xbc, 0xe6, 0x56, 0x5c, 0xaf, 0x9a, 0xdf, 0x10, 0x23, 0xfe,
	0x07, 0xb0, 0xed, 0x62, 0xa7, 0x38, 0xa8, 0x35, 0xbc, 0xe6, 0xf6, 0xe1, 0xae, 0x8d, 0x16, 0x56,
	0xd6, 0xb0, 0xcb, 0xf5, 0xbb, 0xb7, 0x03, 0x34, 0x2e, 0x48, 0x0c, 0x2a, 0x7c, 0x17, 0xfb, 0x27,
	0xa0, 0x3e, 0x3d, 0x2b, 0x8a, 0x83, 0x95, 0xc7, 0xe9, 0xdb, 0x8e, 0xd0, 0xc5, 0xfe, 0x25, 0x58,
	0x9d, 0xc4, 0x11, 0xac, 0x36, 0xbc, 0xe6, 0xb3, 0xc3, 0x8f, 0x70, 0xd1, 0xe1, 0x9a, 0x10, 0xe1,
	0x74, 0x6f, 0x97, 0xb7, 0x39, 0x39, 0xe3, 0x05, 0x9b, 0x69, 0xc5, 0x46, 0xcd, 0xbf, 0xf3, 0xc0,
	0xf3, 0xff, 0x9c, 0x54, 0xb0, 0x66, 0x5c, 0x86, 0x4b, 0xbb, 0xf4, 0xee, 0x69, 0xf4, 0x8c, 0xc4,
	0x8c, 0xe7, 0x3c, 0x20, 0xf6, 0xd9, 0x5c, 0xcf, 0x3f, 0x06, 0x40, 0x69, 0x24, 0x75, 0x82, 0x91,
	0x26, 0xc1, 0xba, 0xc9, 0x68, 0x6f, 0x2e, 0xa3, 0x0b, 0x2d, 0x29, 0xcf, 0xca, 0x90, 0xb6, 0x0c,
	0xfe, 0x13, 0xd2, 0xc4, 0x7f, 0x0f, 0x36, 0x09, 0xc7, 0x25, 0x75, 0x63, 0x09, 0xea, 0x06, 0xe1,
	0xd8, 0x10, 0x6f, 0xc0, 0xcb, 0x11, 0xc5, 0xf6, 0xca, 0x12, 0x99, 0xe4, 0x82, 0x72, 0x9d, 0x8c,
	0xa9, 0xd2, 0xc1, 0xa6, 0xd1, 0x39, 0x59, 0x18, 0x44, 0xf9, 0x50, 0x60, 0x87, 0xe2, 0x9e, 0x65,
	0x4f, 0xf7, 0xdc, 0x9f, 0xc8, 0x7c, 0xa5, 0x4a, 0x7f, 0x7e, 0x12, 0xbf, 0x18, 0x4d, 0x11, 0xae,
	0xdf, 0xa9, 0x03, 0x30, 0xf5, 0xea, 0xdc, 0xd5, 0xc0, 0x41, 0x2a, 0x18, 0x7c, 0xf4, 0xdd, 0x76,
	0x1a, 0x0f, 0x5c, 0xe6, 0xfe, 0x64, 0xab, 0x7d, 0xef, 0xfb, 0x17, 0x2b, 0x93, 0x89, 0x31, 0xe2,
	0x19, 0x14, 0x32, 0x0b, 0x33, 0xc2, 0x4d, 0x10, 0xd5, 0xb3, 0xcb, 0xa9, 0x7a, 0xe0, 0x27, 0x73,
	0xec, 0xaa, 0x9f, 0xb5, 0x95, 0xf3, 0x76, 0xfb, 0x77, 0x6d, 0xff, 0xbc, 0x94, 0x6c, 0x63, 0x05,
	0xcb, 0x72, 0x52, 0x0d, 0x5a, 0x30, 0xae, 0x90, 0x7f, 0x2a, 0xcc, 0xb0, 0x8d, 0xd5, 0xd0, 0x61,
	0x86, 0x83, 0xd6, 0xd0, 0x61, 0xfe, 0xd6, 0x0e, 0xca, 0x41, 0x14, 0xb5, 0xb1, 0x8a, 0x22, 0x87,
	0x8a, 0xa2, 0x41, 0x2b, 0x8a, 0x1c, 0x6e, 0xb4, 0x6e, 0x3e, 0xf6, 0xe8, 0x5f, 0x00, 0x00, 0x00,
	0xff, 0xff, 0x76, 0xb4, 0xe0, 0x7e, 0x10, 0x05, 0x00, 0x00,
}
