// Code generated by protoc-gen-go. DO NOT EDIT.
// source: google/cloud/dataproc/v1/operations.proto

package dataproc

import (
	fmt "fmt"
	math "math"

	proto "github.com/golang/protobuf/proto"
	timestamp "github.com/golang/protobuf/ptypes/timestamp"
	_ "google.golang.org/genproto/googleapis/api/annotations"
)

// Reference imports to suppress errors if they are not otherwise used.
var _ = proto.Marshal
var _ = fmt.Errorf
var _ = math.Inf

// This is a compile-time assertion to ensure that this generated file
// is compatible with the proto package it is being compiled against.
// A compilation error at this line likely means your copy of the
// proto package needs to be updated.
const _ = proto.ProtoPackageIsVersion3 // please upgrade the proto package

// The operation state.
type ClusterOperationStatus_State int32

const (
	// Unused.
	ClusterOperationStatus_UNKNOWN ClusterOperationStatus_State = 0
	// The operation has been created.
	ClusterOperationStatus_PENDING ClusterOperationStatus_State = 1
	// The operation is running.
	ClusterOperationStatus_RUNNING ClusterOperationStatus_State = 2
	// The operation is done; either cancelled or completed.
	ClusterOperationStatus_DONE ClusterOperationStatus_State = 3
)

var ClusterOperationStatus_State_name = map[int32]string{
	0: "UNKNOWN",
	1: "PENDING",
	2: "RUNNING",
	3: "DONE",
}

var ClusterOperationStatus_State_value = map[string]int32{
	"UNKNOWN": 0,
	"PENDING": 1,
	"RUNNING": 2,
	"DONE":    3,
}

func (x ClusterOperationStatus_State) String() string {
	return proto.EnumName(ClusterOperationStatus_State_name, int32(x))
}

func (ClusterOperationStatus_State) EnumDescriptor() ([]byte, []int) {
	return fileDescriptor_78b4f56947714756, []int{0, 0}
}

// The status of the operation.
type ClusterOperationStatus struct {
	// Output only. A message containing the operation state.
	State ClusterOperationStatus_State `protobuf:"varint,1,opt,name=state,proto3,enum=google.cloud.dataproc.v1.ClusterOperationStatus_State" json:"state,omitempty"`
	// Output only. A message containing the detailed operation state.
	InnerState string `protobuf:"bytes,2,opt,name=inner_state,json=innerState,proto3" json:"inner_state,omitempty"`
	// Output only. A message containing any operation metadata details.
	Details string `protobuf:"bytes,3,opt,name=details,proto3" json:"details,omitempty"`
	// Output only. The time this state was entered.
	StateStartTime       *timestamp.Timestamp `protobuf:"bytes,4,opt,name=state_start_time,json=stateStartTime,proto3" json:"state_start_time,omitempty"`
	XXX_NoUnkeyedLiteral struct{}             `json:"-"`
	XXX_unrecognized     []byte               `json:"-"`
	XXX_sizecache        int32                `json:"-"`
}

func (m *ClusterOperationStatus) Reset()         { *m = ClusterOperationStatus{} }
func (m *ClusterOperationStatus) String() string { return proto.CompactTextString(m) }
func (*ClusterOperationStatus) ProtoMessage()    {}
func (*ClusterOperationStatus) Descriptor() ([]byte, []int) {
	return fileDescriptor_78b4f56947714756, []int{0}
}

func (m *ClusterOperationStatus) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_ClusterOperationStatus.Unmarshal(m, b)
}
func (m *ClusterOperationStatus) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_ClusterOperationStatus.Marshal(b, m, deterministic)
}
func (m *ClusterOperationStatus) XXX_Merge(src proto.Message) {
	xxx_messageInfo_ClusterOperationStatus.Merge(m, src)
}
func (m *ClusterOperationStatus) XXX_Size() int {
	return xxx_messageInfo_ClusterOperationStatus.Size(m)
}
func (m *ClusterOperationStatus) XXX_DiscardUnknown() {
	xxx_messageInfo_ClusterOperationStatus.DiscardUnknown(m)
}

var xxx_messageInfo_ClusterOperationStatus proto.InternalMessageInfo

func (m *ClusterOperationStatus) GetState() ClusterOperationStatus_State {
	if m != nil {
		return m.State
	}
	return ClusterOperationStatus_UNKNOWN
}

func (m *ClusterOperationStatus) GetInnerState() string {
	if m != nil {
		return m.InnerState
	}
	return ""
}

func (m *ClusterOperationStatus) GetDetails() string {
	if m != nil {
		return m.Details
	}
	return ""
}

func (m *ClusterOperationStatus) GetStateStartTime() *timestamp.Timestamp {
	if m != nil {
		return m.StateStartTime
	}
	return nil
}

// Metadata describing the operation.
type ClusterOperationMetadata struct {
	// Output only. Name of the cluster for the operation.
	ClusterName string `protobuf:"bytes,7,opt,name=cluster_name,json=clusterName,proto3" json:"cluster_name,omitempty"`
	// Output only. Cluster UUID for the operation.
	ClusterUuid string `protobuf:"bytes,8,opt,name=cluster_uuid,json=clusterUuid,proto3" json:"cluster_uuid,omitempty"`
	// Output only. Current operation status.
	Status *ClusterOperationStatus `protobuf:"bytes,9,opt,name=status,proto3" json:"status,omitempty"`
	// Output only. The previous operation status.
	StatusHistory []*ClusterOperationStatus `protobuf:"bytes,10,rep,name=status_history,json=statusHistory,proto3" json:"status_history,omitempty"`
	// Output only. The operation type.
	OperationType string `protobuf:"bytes,11,opt,name=operation_type,json=operationType,proto3" json:"operation_type,omitempty"`
	// Output only. Short description of operation.
	Description string `protobuf:"bytes,12,opt,name=description,proto3" json:"description,omitempty"`
	// Output only. Labels associated with the operation
	Labels map[string]string `protobuf:"bytes,13,rep,name=labels,proto3" json:"labels,omitempty" protobuf_key:"bytes,1,opt,name=key,proto3" protobuf_val:"bytes,2,opt,name=value,proto3"`
	// Output only. Errors encountered during operation execution.
	Warnings             []string `protobuf:"bytes,14,rep,name=warnings,proto3" json:"warnings,omitempty"`
	XXX_NoUnkeyedLiteral struct{} `json:"-"`
	XXX_unrecognized     []byte   `json:"-"`
	XXX_sizecache        int32    `json:"-"`
}

func (m *ClusterOperationMetadata) Reset()         { *m = ClusterOperationMetadata{} }
func (m *ClusterOperationMetadata) String() string { return proto.CompactTextString(m) }
func (*ClusterOperationMetadata) ProtoMessage()    {}
func (*ClusterOperationMetadata) Descriptor() ([]byte, []int) {
	return fileDescriptor_78b4f56947714756, []int{1}
}

func (m *ClusterOperationMetadata) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_ClusterOperationMetadata.Unmarshal(m, b)
}
func (m *ClusterOperationMetadata) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_ClusterOperationMetadata.Marshal(b, m, deterministic)
}
func (m *ClusterOperationMetadata) XXX_Merge(src proto.Message) {
	xxx_messageInfo_ClusterOperationMetadata.Merge(m, src)
}
func (m *ClusterOperationMetadata) XXX_Size() int {
	return xxx_messageInfo_ClusterOperationMetadata.Size(m)
}
func (m *ClusterOperationMetadata) XXX_DiscardUnknown() {
	xxx_messageInfo_ClusterOperationMetadata.DiscardUnknown(m)
}

var xxx_messageInfo_ClusterOperationMetadata proto.InternalMessageInfo

func (m *ClusterOperationMetadata) GetClusterName() string {
	if m != nil {
		return m.ClusterName
	}
	return ""
}

func (m *ClusterOperationMetadata) GetClusterUuid() string {
	if m != nil {
		return m.ClusterUuid
	}
	return ""
}

func (m *ClusterOperationMetadata) GetStatus() *ClusterOperationStatus {
	if m != nil {
		return m.Status
	}
	return nil
}

func (m *ClusterOperationMetadata) GetStatusHistory() []*ClusterOperationStatus {
	if m != nil {
		return m.StatusHistory
	}
	return nil
}

func (m *ClusterOperationMetadata) GetOperationType() string {
	if m != nil {
		return m.OperationType
	}
	return ""
}

func (m *ClusterOperationMetadata) GetDescription() string {
	if m != nil {
		return m.Description
	}
	return ""
}

func (m *ClusterOperationMetadata) GetLabels() map[string]string {
	if m != nil {
		return m.Labels
	}
	return nil
}

func (m *ClusterOperationMetadata) GetWarnings() []string {
	if m != nil {
		return m.Warnings
	}
	return nil
}

func init() {
	proto.RegisterEnum("google.cloud.dataproc.v1.ClusterOperationStatus_State", ClusterOperationStatus_State_name, ClusterOperationStatus_State_value)
	proto.RegisterType((*ClusterOperationStatus)(nil), "google.cloud.dataproc.v1.ClusterOperationStatus")
	proto.RegisterType((*ClusterOperationMetadata)(nil), "google.cloud.dataproc.v1.ClusterOperationMetadata")
	proto.RegisterMapType((map[string]string)(nil), "google.cloud.dataproc.v1.ClusterOperationMetadata.LabelsEntry")
}

func init() {
	proto.RegisterFile("google/cloud/dataproc/v1/operations.proto", fileDescriptor_78b4f56947714756)
}

var fileDescriptor_78b4f56947714756 = []byte{
	// 531 bytes of a gzipped FileDescriptorProto
	0x1f, 0x8b, 0x08, 0x00, 0x00, 0x00, 0x00, 0x00, 0x02, 0xff, 0x9c, 0x53, 0x5d, 0x8b, 0xd3, 0x40,
	0x14, 0x35, 0xcd, 0xee, 0xb6, 0xbd, 0xd9, 0xd6, 0x32, 0x88, 0x0c, 0x65, 0x61, 0x63, 0x41, 0xa8,
	0x2f, 0x89, 0xbb, 0x82, 0xac, 0x0a, 0x22, 0x6b, 0x8b, 0x2b, 0xae, 0x69, 0xc9, 0x6e, 0x5d, 0xf0,
	0xa5, 0x4c, 0x9b, 0x31, 0x06, 0xd3, 0x99, 0x30, 0x33, 0xa9, 0xf4, 0xe7, 0xf8, 0x3b, 0x7d, 0x91,
	0x99, 0x49, 0x4a, 0xfd, 0x58, 0x50, 0x9f, 0x3a, 0xf7, 0xde, 0x73, 0x4e, 0xce, 0xb9, 0xdc, 0xc2,
	0xa3, 0x94, 0xf3, 0x34, 0xa7, 0xe1, 0x32, 0xe7, 0x65, 0x12, 0x26, 0x44, 0x91, 0x42, 0xf0, 0x65,
	0xb8, 0x3e, 0x09, 0x79, 0x41, 0x05, 0x51, 0x19, 0x67, 0x32, 0x28, 0x04, 0x57, 0x1c, 0x61, 0x0b,
	0x0d, 0x0c, 0x34, 0xa8, 0xa1, 0xc1, 0xfa, 0xa4, 0x7f, 0x54, 0x89, 0x90, 0x22, 0x0b, 0x09, 0x63,
	0x5c, 0xed, 0xf2, 0xfa, 0xc7, 0xd5, 0xd4, 0x54, 0x8b, 0xf2, 0x53, 0xa8, 0xb2, 0x15, 0x95, 0x8a,
	0xac, 0x0a, 0x0b, 0x18, 0x7c, 0x6b, 0xc0, 0xfd, 0xd7, 0x79, 0x29, 0x15, 0x15, 0x93, 0xfa, 0xa3,
	0x57, 0x8a, 0xa8, 0x52, 0xa2, 0x4b, 0xd8, 0x97, 0x8a, 0x28, 0x8a, 0x1d, 0xdf, 0x19, 0x76, 0x4f,
	0x9f, 0x06, 0xb7, 0x79, 0x08, 0xfe, 0x2c, 0x10, 0xe8, 0x1f, 0x1a, 0x5b, 0x11, 0x74, 0x0c, 0x5e,
	0xc6, 0x18, 0x15, 0x73, 0xab, 0xd9, 0xf0, 0x9d, 0x61, 0x3b, 0x06, 0xd3, 0x32, 0x38, 0x84, 0xa1,
	0x99, 0x50, 0x45, 0xb2, 0x5c, 0x62, 0xd7, 0x0c, 0xeb, 0x12, 0x8d, 0xa0, 0x67, 0x48, 0x9a, 0x2a,
	0xd4, 0x5c, 0x47, 0xc0, 0x7b, 0xbe, 0x33, 0xf4, 0x4e, 0xfb, 0xb5, 0xa7, 0x3a, 0x5f, 0x70, 0x5d,
	0xe7, 0x8b, 0xbb, 0x86, 0x73, 0xa5, 0x29, 0xba, 0x39, 0x38, 0x83, 0x7d, 0xfb, 0x21, 0x0f, 0x9a,
	0xb3, 0xe8, 0x5d, 0x34, 0xb9, 0x89, 0x7a, 0x77, 0x74, 0x31, 0x1d, 0x47, 0xa3, 0xb7, 0xd1, 0x9b,
	0x9e, 0xa3, 0x8b, 0x78, 0x16, 0x45, 0xba, 0x68, 0xa0, 0x16, 0xec, 0x8d, 0x26, 0xd1, 0xb8, 0xe7,
	0x0e, 0xbe, 0xbb, 0x80, 0x7f, 0x8d, 0xf8, 0x9e, 0x2a, 0xa2, 0x57, 0x80, 0x1e, 0xc0, 0xe1, 0xd2,
	0xce, 0xe6, 0x8c, 0xac, 0x28, 0x6e, 0x1a, 0xef, 0x5e, 0xd5, 0x8b, 0xc8, 0x8a, 0xee, 0x42, 0xca,
	0x32, 0x4b, 0x70, 0xeb, 0x27, 0xc8, 0xac, 0xcc, 0x12, 0x74, 0x01, 0x07, 0xd2, 0x2c, 0x0d, 0xb7,
	0x4d, 0xb0, 0xc7, 0xff, 0xba, 0xec, 0xb8, 0xe2, 0xa3, 0x1b, 0xe8, 0xda, 0xd7, 0xfc, 0x73, 0x26,
	0x15, 0x17, 0x1b, 0x0c, 0xbe, 0xfb, 0x5f, 0x8a, 0x1d, 0xab, 0x73, 0x61, 0x65, 0xd0, 0x43, 0xe8,
	0x6e, 0xcf, 0x72, 0xae, 0x36, 0x05, 0xc5, 0x9e, 0xc9, 0xd1, 0xd9, 0x76, 0xaf, 0x37, 0x05, 0x45,
	0x3e, 0x78, 0x09, 0x95, 0x4b, 0x91, 0x15, 0xba, 0x85, 0x0f, 0x6d, 0xd6, 0x9d, 0x16, 0xfa, 0x00,
	0x07, 0x39, 0x59, 0xd0, 0x5c, 0xe2, 0x8e, 0x71, 0xf6, 0xf2, 0xef, 0x9d, 0xd5, 0x5b, 0x0f, 0x2e,
	0x8d, 0xc0, 0x98, 0x29, 0xb1, 0x89, 0x2b, 0x35, 0xd4, 0x87, 0xd6, 0x57, 0x22, 0x58, 0xc6, 0x52,
	0x89, 0xbb, 0xbe, 0x3b, 0x6c, 0xc7, 0xdb, 0xba, 0xff, 0x0c, 0xbc, 0x1d, 0x0a, 0xea, 0x81, 0xfb,
	0x85, 0x6e, 0xcc, 0x61, 0xb7, 0x63, 0xfd, 0x44, 0xf7, 0x60, 0x7f, 0x4d, 0xf2, 0xb2, 0x3e, 0x4c,
	0x5b, 0x3c, 0x6f, 0x9c, 0x39, 0xe7, 0x12, 0x8e, 0x96, 0x7c, 0x75, 0xab, 0xc7, 0xf3, 0xbb, 0x5b,
	0x77, 0x72, 0xaa, 0xaf, 0x70, 0xea, 0x7c, 0x7c, 0x55, 0x81, 0x53, 0x9e, 0x13, 0x96, 0x06, 0x5c,
	0xa4, 0x61, 0x4a, 0x99, 0xb9, 0xd1, 0xd0, 0x8e, 0x48, 0x91, 0xc9, 0xdf, 0xff, 0xf7, 0x2f, 0xea,
	0xf7, 0xe2, 0xc0, 0x80, 0x9f, 0xfc, 0x08, 0x00, 0x00, 0xff, 0xff, 0xad, 0xc8, 0x5f, 0xe0, 0x23,
	0x04, 0x00, 0x00,
}
