// Code generated by protoc-gen-go. DO NOT EDIT.
// source: google/cloud/automl/v1beta1/column_spec.proto

package automl

import (
	fmt "fmt"
	math "math"

	proto "github.com/golang/protobuf/proto"
	_ "google.golang.org/genproto/googleapis/api/annotations"
)

// Reference imports to suppress errors if they are not otherwise used.
var _ = proto.Marshal
var _ = fmt.Errorf
var _ = math.Inf

// This is a compile-time assertion to ensure that this generated file
// is compatible with the proto package it is being compiled against.
// A compilation error at this line likely means your copy of the
// proto package needs to be updated.
const _ = proto.ProtoPackageIsVersion3 // please upgrade the proto package

// A representation of a column in a relational table. When listing them, column specs are returned in the same order in which they were
// given on import .
// Used by:
//   *   Tables
type ColumnSpec struct {
	// Output only. The resource name of the column specs.
	// Form:
	//
	// `projects/{project_id}/locations/{location_id}/datasets/{dataset_id}/tableSpecs/{table_spec_id}/columnSpecs/{column_spec_id}`
	Name string `protobuf:"bytes,1,opt,name=name,proto3" json:"name,omitempty"`
	// The data type of elements stored in the column.
	DataType *DataType `protobuf:"bytes,2,opt,name=data_type,json=dataType,proto3" json:"data_type,omitempty"`
	// Output only. The name of the column to show in the interface. The name can
	// be up to 100 characters long and can consist only of ASCII Latin letters
	// A-Z and a-z, ASCII digits 0-9, underscores(_), and forward slashes(/), and
	// must start with a letter or a digit.
	DisplayName string `protobuf:"bytes,3,opt,name=display_name,json=displayName,proto3" json:"display_name,omitempty"`
	// Output only. Stats of the series of values in the column.
	// This field may be stale, see the ancestor's
	// Dataset.tables_dataset_metadata.stats_update_time field
	// for the timestamp at which these stats were last updated.
	DataStats *DataStats `protobuf:"bytes,4,opt,name=data_stats,json=dataStats,proto3" json:"data_stats,omitempty"`
	// Output only. Top 10 most correlated with this column columns of the table,
	// ordered by
	// [cramers_v][google.cloud.automl.v1beta1.CorrelationStats.cramers_v] metric.
	// This field may be stale, see the ancestor's
	// Dataset.tables_dataset_metadata.stats_update_time field
	// for the timestamp at which these stats were last updated.
	TopCorrelatedColumns []*ColumnSpec_CorrelatedColumn `protobuf:"bytes,5,rep,name=top_correlated_columns,json=topCorrelatedColumns,proto3" json:"top_correlated_columns,omitempty"`
	// Used to perform consistent read-modify-write updates. If not set, a blind
	// "overwrite" update happens.
	Etag                 string   `protobuf:"bytes,6,opt,name=etag,proto3" json:"etag,omitempty"`
	XXX_NoUnkeyedLiteral struct{} `json:"-"`
	XXX_unrecognized     []byte   `json:"-"`
	XXX_sizecache        int32    `json:"-"`
}

func (m *ColumnSpec) Reset()         { *m = ColumnSpec{} }
func (m *ColumnSpec) String() string { return proto.CompactTextString(m) }
func (*ColumnSpec) ProtoMessage()    {}
func (*ColumnSpec) Descriptor() ([]byte, []int) {
	return fileDescriptor_828eac69e0599d60, []int{0}
}

func (m *ColumnSpec) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_ColumnSpec.Unmarshal(m, b)
}
func (m *ColumnSpec) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_ColumnSpec.Marshal(b, m, deterministic)
}
func (m *ColumnSpec) XXX_Merge(src proto.Message) {
	xxx_messageInfo_ColumnSpec.Merge(m, src)
}
func (m *ColumnSpec) XXX_Size() int {
	return xxx_messageInfo_ColumnSpec.Size(m)
}
func (m *ColumnSpec) XXX_DiscardUnknown() {
	xxx_messageInfo_ColumnSpec.DiscardUnknown(m)
}

var xxx_messageInfo_ColumnSpec proto.InternalMessageInfo

func (m *ColumnSpec) GetName() string {
	if m != nil {
		return m.Name
	}
	return ""
}

func (m *ColumnSpec) GetDataType() *DataType {
	if m != nil {
		return m.DataType
	}
	return nil
}

func (m *ColumnSpec) GetDisplayName() string {
	if m != nil {
		return m.DisplayName
	}
	return ""
}

func (m *ColumnSpec) GetDataStats() *DataStats {
	if m != nil {
		return m.DataStats
	}
	return nil
}

func (m *ColumnSpec) GetTopCorrelatedColumns() []*ColumnSpec_CorrelatedColumn {
	if m != nil {
		return m.TopCorrelatedColumns
	}
	return nil
}

func (m *ColumnSpec) GetEtag() string {
	if m != nil {
		return m.Etag
	}
	return ""
}

// Identifies the table's column, and its correlation with the column this
// ColumnSpec describes.
type ColumnSpec_CorrelatedColumn struct {
	// The column_spec_id of the correlated column, which belongs to the same
	// table as the in-context column.
	ColumnSpecId string `protobuf:"bytes,1,opt,name=column_spec_id,json=columnSpecId,proto3" json:"column_spec_id,omitempty"`
	// Correlation between this and the in-context column.
	CorrelationStats     *CorrelationStats `protobuf:"bytes,2,opt,name=correlation_stats,json=correlationStats,proto3" json:"correlation_stats,omitempty"`
	XXX_NoUnkeyedLiteral struct{}          `json:"-"`
	XXX_unrecognized     []byte            `json:"-"`
	XXX_sizecache        int32             `json:"-"`
}

func (m *ColumnSpec_CorrelatedColumn) Reset()         { *m = ColumnSpec_CorrelatedColumn{} }
func (m *ColumnSpec_CorrelatedColumn) String() string { return proto.CompactTextString(m) }
func (*ColumnSpec_CorrelatedColumn) ProtoMessage()    {}
func (*ColumnSpec_CorrelatedColumn) Descriptor() ([]byte, []int) {
	return fileDescriptor_828eac69e0599d60, []int{0, 0}
}

func (m *ColumnSpec_CorrelatedColumn) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_ColumnSpec_CorrelatedColumn.Unmarshal(m, b)
}
func (m *ColumnSpec_CorrelatedColumn) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_ColumnSpec_CorrelatedColumn.Marshal(b, m, deterministic)
}
func (m *ColumnSpec_CorrelatedColumn) XXX_Merge(src proto.Message) {
	xxx_messageInfo_ColumnSpec_CorrelatedColumn.Merge(m, src)
}
func (m *ColumnSpec_CorrelatedColumn) XXX_Size() int {
	return xxx_messageInfo_ColumnSpec_CorrelatedColumn.Size(m)
}
func (m *ColumnSpec_CorrelatedColumn) XXX_DiscardUnknown() {
	xxx_messageInfo_ColumnSpec_CorrelatedColumn.DiscardUnknown(m)
}

var xxx_messageInfo_ColumnSpec_CorrelatedColumn proto.InternalMessageInfo

func (m *ColumnSpec_CorrelatedColumn) GetColumnSpecId() string {
	if m != nil {
		return m.ColumnSpecId
	}
	return ""
}

func (m *ColumnSpec_CorrelatedColumn) GetCorrelationStats() *CorrelationStats {
	if m != nil {
		return m.CorrelationStats
	}
	return nil
}

func init() {
	proto.RegisterType((*ColumnSpec)(nil), "google.cloud.automl.v1beta1.ColumnSpec")
	proto.RegisterType((*ColumnSpec_CorrelatedColumn)(nil), "google.cloud.automl.v1beta1.ColumnSpec.CorrelatedColumn")
}

func init() {
	proto.RegisterFile("google/cloud/automl/v1beta1/column_spec.proto", fileDescriptor_828eac69e0599d60)
}

var fileDescriptor_828eac69e0599d60 = []byte{
	// 415 bytes of a gzipped FileDescriptorProto
	0x1f, 0x8b, 0x08, 0x00, 0x00, 0x00, 0x00, 0x00, 0x02, 0xff, 0x8c, 0x92, 0xd1, 0x8a, 0xd3, 0x40,
	0x14, 0x86, 0x49, 0xbb, 0x2e, 0xee, 0x74, 0x91, 0x75, 0x10, 0x09, 0xbb, 0xa2, 0x55, 0x54, 0x7a,
	0xe1, 0x4e, 0xd8, 0x7a, 0x23, 0xf1, 0xaa, 0xad, 0x22, 0x82, 0x8a, 0xa4, 0xe2, 0x45, 0x29, 0x84,
	0xd3, 0xc9, 0x10, 0x02, 0x93, 0x39, 0x43, 0x32, 0x11, 0xfa, 0x1e, 0xbe, 0x82, 0x2f, 0xe3, 0x9b,
	0xe8, 0x53, 0x48, 0x66, 0xa6, 0xa9, 0x14, 0x49, 0xbd, 0x3b, 0x3d, 0xff, 0xd7, 0xff, 0x9c, 0xf9,
	0x73, 0xc8, 0x75, 0x8e, 0x98, 0x4b, 0x11, 0x71, 0x89, 0x4d, 0x16, 0x41, 0x63, 0xb0, 0x94, 0xd1,
	0xb7, 0x9b, 0x8d, 0x30, 0x70, 0x13, 0x71, 0x94, 0x4d, 0xa9, 0xd2, 0x5a, 0x0b, 0xce, 0x74, 0x85,
	0x06, 0xe9, 0x95, 0xc3, 0x99, 0xc5, 0x99, 0xc3, 0x99, 0xc7, 0x2f, 0x5f, 0xf4, 0x79, 0x65, 0x60,
	0x20, 0xad, 0x0d, 0x98, 0xda, 0x59, 0xfd, 0x07, 0x6d, 0xb6, 0x5a, 0xec, 0xe8, 0x07, 0x9e, 0x06,
	0x5d, 0x44, 0xa0, 0x14, 0x1a, 0x30, 0x05, 0x2a, 0xaf, 0x3e, 0xf9, 0x35, 0x24, 0x64, 0x61, 0x97,
	0x5d, 0x6a, 0xc1, 0x29, 0x25, 0x27, 0x0a, 0x4a, 0x11, 0x06, 0xe3, 0x60, 0x72, 0x96, 0xd8, 0x9a,
	0xce, 0xc9, 0x59, 0x67, 0x1a, 0x0e, 0xc6, 0xc1, 0x64, 0x34, 0x7d, 0xc6, 0x7a, 0x5e, 0xc3, 0xde,
	0x80, 0x81, 0x2f, 0x5b, 0x2d, 0x92, 0xdb, 0x99, 0xaf, 0xe8, 0x63, 0x72, 0x9e, 0x15, 0xb5, 0x96,
	0xb0, 0x4d, 0xad, 0xff, 0xd0, 0xfa, 0x8f, 0x7c, 0xef, 0x53, 0x3b, 0xe6, 0x2d, 0x21, 0xfb, 0x97,
	0x86, 0x27, 0x76, 0xce, 0xf3, 0xa3, 0x73, 0x96, 0x2d, 0x9d, 0xd8, 0x05, 0x6d, 0x49, 0x15, 0xb9,
	0x6f, 0x50, 0xa7, 0x1c, 0xab, 0x4a, 0x48, 0x30, 0x22, 0x4b, 0xdd, 0xb7, 0xa8, 0xc3, 0x5b, 0xe3,
	0xe1, 0x64, 0x34, 0x7d, 0xd5, 0x6b, 0xb9, 0x8f, 0x82, 0x2d, 0x3a, 0x07, 0xd7, 0x4c, 0xee, 0x19,
	0xd4, 0x87, 0xcd, 0xba, 0x4d, 0x4c, 0x18, 0xc8, 0xc3, 0x53, 0x97, 0x58, 0x5b, 0x5f, 0x7e, 0x0f,
	0xc8, 0xc5, 0x21, 0x49, 0x9f, 0x92, 0x3b, 0x7f, 0x5d, 0x45, 0x5a, 0x64, 0x3e, 0xe4, 0x73, 0xde,
	0xcd, 0x7c, 0x9f, 0xd1, 0x15, 0xb9, 0xbb, 0x5b, 0xbd, 0x40, 0xe5, 0xc3, 0x70, 0xa1, 0x5f, 0x1f,
	0xd9, 0xbc, 0xfb, 0x97, 0xcb, 0xe4, 0x82, 0x1f, 0x74, 0xe6, 0x3f, 0x02, 0xf2, 0x88, 0x63, 0xd9,
	0x67, 0xf3, 0x39, 0x58, 0xcd, 0xbc, 0x9c, 0xa3, 0x04, 0x95, 0x33, 0xac, 0xf2, 0x28, 0x17, 0xca,
	0x5e, 0x4b, 0xe4, 0x24, 0xd0, 0x45, 0xfd, 0xcf, 0xe3, 0x7b, 0xed, 0x7e, 0xfe, 0x1c, 0x5c, 0xbd,
	0xb3, 0xe0, 0x7a, 0xd1, 0x42, 0xeb, 0x59, 0x63, 0xf0, 0xa3, 0x5c, 0x7f, 0x75, 0xd0, 0xef, 0xc1,
	0x43, 0xa7, 0xc6, 0xb1, 0x95, 0xe3, 0xd8, 0xea, 0x1f, 0xe2, 0xd8, 0x03, 0x9b, 0x53, 0x3b, 0xec,
	0xe5, 0x9f, 0x00, 0x00, 0x00, 0xff, 0xff, 0x53, 0x68, 0x0b, 0x87, 0x62, 0x03, 0x00, 0x00,
}
