// Code generated by protoc-gen-go. DO NOT EDIT.
// source: google/ads/googleads/v2/errors/ad_group_feed_error.proto

package errors

import (
	fmt "fmt"
	math "math"

	proto "github.com/golang/protobuf/proto"
	_ "google.golang.org/genproto/googleapis/api/annotations"
)

// Reference imports to suppress errors if they are not otherwise used.
var _ = proto.Marshal
var _ = fmt.Errorf
var _ = math.Inf

// This is a compile-time assertion to ensure that this generated file
// is compatible with the proto package it is being compiled against.
// A compilation error at this line likely means your copy of the
// proto package needs to be updated.
const _ = proto.ProtoPackageIsVersion3 // please upgrade the proto package

// Enum describing possible ad group feed errors.
type AdGroupFeedErrorEnum_AdGroupFeedError int32

const (
	// Enum unspecified.
	AdGroupFeedErrorEnum_UNSPECIFIED AdGroupFeedErrorEnum_AdGroupFeedError = 0
	// The received error code is not known in this version.
	AdGroupFeedErrorEnum_UNKNOWN AdGroupFeedErrorEnum_AdGroupFeedError = 1
	// An active feed already exists for this ad group and place holder type.
	AdGroupFeedErrorEnum_FEED_ALREADY_EXISTS_FOR_PLACEHOLDER_TYPE AdGroupFeedErrorEnum_AdGroupFeedError = 2
	// The specified feed is removed.
	AdGroupFeedErrorEnum_CANNOT_CREATE_FOR_REMOVED_FEED AdGroupFeedErrorEnum_AdGroupFeedError = 3
	// The AdGroupFeed already exists. UPDATE operation should be used to modify
	// the existing AdGroupFeed.
	AdGroupFeedErrorEnum_ADGROUP_FEED_ALREADY_EXISTS AdGroupFeedErrorEnum_AdGroupFeedError = 4
	// Cannot operate on removed AdGroupFeed.
	AdGroupFeedErrorEnum_CANNOT_OPERATE_ON_REMOVED_ADGROUP_FEED AdGroupFeedErrorEnum_AdGroupFeedError = 5
	// Invalid placeholder type.
	AdGroupFeedErrorEnum_INVALID_PLACEHOLDER_TYPE AdGroupFeedErrorEnum_AdGroupFeedError = 6
	// Feed mapping for this placeholder type does not exist.
	AdGroupFeedErrorEnum_MISSING_FEEDMAPPING_FOR_PLACEHOLDER_TYPE AdGroupFeedErrorEnum_AdGroupFeedError = 7
	// Location AdGroupFeeds cannot be created unless there is a location
	// CustomerFeed for the specified feed.
	AdGroupFeedErrorEnum_NO_EXISTING_LOCATION_CUSTOMER_FEED AdGroupFeedErrorEnum_AdGroupFeedError = 8
)

var AdGroupFeedErrorEnum_AdGroupFeedError_name = map[int32]string{
	0: "UNSPECIFIED",
	1: "UNKNOWN",
	2: "FEED_ALREADY_EXISTS_FOR_PLACEHOLDER_TYPE",
	3: "CANNOT_CREATE_FOR_REMOVED_FEED",
	4: "ADGROUP_FEED_ALREADY_EXISTS",
	5: "CANNOT_OPERATE_ON_REMOVED_ADGROUP_FEED",
	6: "INVALID_PLACEHOLDER_TYPE",
	7: "MISSING_FEEDMAPPING_FOR_PLACEHOLDER_TYPE",
	8: "NO_EXISTING_LOCATION_CUSTOMER_FEED",
}

var AdGroupFeedErrorEnum_AdGroupFeedError_value = map[string]int32{
	"UNSPECIFIED": 0,
	"UNKNOWN":     1,
	"FEED_ALREADY_EXISTS_FOR_PLACEHOLDER_TYPE": 2,
	"CANNOT_CREATE_FOR_REMOVED_FEED":           3,
	"ADGROUP_FEED_ALREADY_EXISTS":              4,
	"CANNOT_OPERATE_ON_REMOVED_ADGROUP_FEED":   5,
	"INVALID_PLACEHOLDER_TYPE":                 6,
	"MISSING_FEEDMAPPING_FOR_PLACEHOLDER_TYPE": 7,
	"NO_EXISTING_LOCATION_CUSTOMER_FEED":       8,
}

func (x AdGroupFeedErrorEnum_AdGroupFeedError) String() string {
	return proto.EnumName(AdGroupFeedErrorEnum_AdGroupFeedError_name, int32(x))
}

func (AdGroupFeedErrorEnum_AdGroupFeedError) EnumDescriptor() ([]byte, []int) {
	return fileDescriptor_44c760554a19ed2d, []int{0, 0}
}

// Container for enum describing possible ad group feed errors.
type AdGroupFeedErrorEnum struct {
	XXX_NoUnkeyedLiteral struct{} `json:"-"`
	XXX_unrecognized     []byte   `json:"-"`
	XXX_sizecache        int32    `json:"-"`
}

func (m *AdGroupFeedErrorEnum) Reset()         { *m = AdGroupFeedErrorEnum{} }
func (m *AdGroupFeedErrorEnum) String() string { return proto.CompactTextString(m) }
func (*AdGroupFeedErrorEnum) ProtoMessage()    {}
func (*AdGroupFeedErrorEnum) Descriptor() ([]byte, []int) {
	return fileDescriptor_44c760554a19ed2d, []int{0}
}

func (m *AdGroupFeedErrorEnum) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_AdGroupFeedErrorEnum.Unmarshal(m, b)
}
func (m *AdGroupFeedErrorEnum) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_AdGroupFeedErrorEnum.Marshal(b, m, deterministic)
}
func (m *AdGroupFeedErrorEnum) XXX_Merge(src proto.Message) {
	xxx_messageInfo_AdGroupFeedErrorEnum.Merge(m, src)
}
func (m *AdGroupFeedErrorEnum) XXX_Size() int {
	return xxx_messageInfo_AdGroupFeedErrorEnum.Size(m)
}
func (m *AdGroupFeedErrorEnum) XXX_DiscardUnknown() {
	xxx_messageInfo_AdGroupFeedErrorEnum.DiscardUnknown(m)
}

var xxx_messageInfo_AdGroupFeedErrorEnum proto.InternalMessageInfo

func init() {
	proto.RegisterEnum("google.ads.googleads.v2.errors.AdGroupFeedErrorEnum_AdGroupFeedError", AdGroupFeedErrorEnum_AdGroupFeedError_name, AdGroupFeedErrorEnum_AdGroupFeedError_value)
	proto.RegisterType((*AdGroupFeedErrorEnum)(nil), "google.ads.googleads.v2.errors.AdGroupFeedErrorEnum")
}

func init() {
	proto.RegisterFile("google/ads/googleads/v2/errors/ad_group_feed_error.proto", fileDescriptor_44c760554a19ed2d)
}

var fileDescriptor_44c760554a19ed2d = []byte{
	// 445 bytes of a gzipped FileDescriptorProto
	0x1f, 0x8b, 0x08, 0x00, 0x00, 0x00, 0x00, 0x00, 0x02, 0xff, 0x7c, 0x92, 0xc1, 0x6a, 0xd4, 0x40,
	0x1c, 0xc6, 0xdd, 0x54, 0x5b, 0x99, 0x1e, 0x0c, 0x41, 0x41, 0xb4, 0xac, 0x90, 0x43, 0x11, 0x91,
	0x09, 0xc4, 0x8b, 0xc4, 0xd3, 0x34, 0xf9, 0x6f, 0x0c, 0x66, 0x67, 0x86, 0x24, 0x1b, 0xad, 0x2c,
	0x0c, 0xd1, 0x89, 0x61, 0xa1, 0xcd, 0x2c, 0x99, 0x6d, 0x1f, 0xc8, 0xa3, 0xaf, 0xe1, 0xcd, 0x67,
	0xf0, 0x09, 0x3c, 0xf9, 0x08, 0x32, 0x99, 0xee, 0x22, 0xb5, 0xf6, 0x94, 0x8f, 0xc9, 0xef, 0xfb,
	0xe6, 0x63, 0xfe, 0x7f, 0xf4, 0xba, 0x53, 0xaa, 0x3b, 0x6b, 0x83, 0x46, 0xea, 0xc0, 0x4a, 0xa3,
	0x2e, 0xc3, 0xa0, 0x1d, 0x06, 0x35, 0xe8, 0xa0, 0x91, 0xa2, 0x1b, 0xd4, 0xc5, 0x5a, 0x7c, 0x69,
	0x5b, 0x29, 0xc6, 0x43, 0xbc, 0x1e, 0xd4, 0x46, 0x79, 0x53, 0x8b, 0xe3, 0x46, 0x6a, 0xbc, 0x73,
	0xe2, 0xcb, 0x10, 0x5b, 0xe7, 0x93, 0xa3, 0x6d, 0xf2, 0x7a, 0x15, 0x34, 0x7d, 0xaf, 0x36, 0xcd,
	0x66, 0xa5, 0x7a, 0x6d, 0xdd, 0xfe, 0x4f, 0x07, 0x3d, 0x24, 0x32, 0x35, 0xd1, 0xb3, 0xb6, 0x95,
	0x60, 0x3c, 0xd0, 0x5f, 0x9c, 0xfb, 0xdf, 0x1d, 0xe4, 0x5e, 0xff, 0xe1, 0x3d, 0x40, 0x87, 0x0b,
	0x5a, 0x72, 0x88, 0xb3, 0x59, 0x06, 0x89, 0x7b, 0xc7, 0x3b, 0x44, 0x07, 0x0b, 0xfa, 0x8e, 0xb2,
	0xf7, 0xd4, 0x9d, 0x78, 0x2f, 0xd1, 0xf3, 0x19, 0x40, 0x22, 0x48, 0x5e, 0x00, 0x49, 0x4e, 0x05,
	0x7c, 0xc8, 0xca, 0xaa, 0x14, 0x33, 0x56, 0x08, 0x9e, 0x93, 0x18, 0xde, 0xb2, 0x3c, 0x81, 0x42,
	0x54, 0xa7, 0x1c, 0x5c, 0xc7, 0xf3, 0xd1, 0x34, 0x26, 0x94, 0xb2, 0x4a, 0xc4, 0x05, 0x90, 0x0a,
	0x46, 0xae, 0x80, 0x39, 0xab, 0x21, 0x11, 0x26, 0xc7, 0xdd, 0xf3, 0x9e, 0xa1, 0xa7, 0x24, 0x49,
	0x0b, 0xb6, 0xe0, 0xe2, 0x86, 0x64, 0xf7, 0xae, 0xf7, 0x02, 0x1d, 0x5f, 0x85, 0x30, 0x0e, 0x85,
	0x49, 0x61, 0x74, 0x17, 0xf2, 0xb7, 0xd5, 0xbd, 0xe7, 0x1d, 0xa1, 0xc7, 0x19, 0xad, 0x49, 0x9e,
	0x25, 0xff, 0xd6, 0xd9, 0x37, 0xe5, 0xe7, 0x59, 0x59, 0x66, 0x34, 0x1d, 0xf9, 0x39, 0xe1, 0x7c,
	0xd4, 0x37, 0x95, 0x3f, 0xf0, 0x8e, 0x91, 0x4f, 0x99, 0xad, 0x61, 0xa8, 0x9c, 0xc5, 0xa4, 0xca,
	0x18, 0x15, 0xf1, 0xa2, 0xac, 0xd8, 0x1c, 0x0a, 0x7b, 0xe7, 0xfd, 0x93, 0xdf, 0x13, 0xe4, 0x7f,
	0x56, 0xe7, 0xf8, 0xf6, 0x19, 0x9d, 0x3c, 0xba, 0xfe, 0xd2, 0xdc, 0x0c, 0x87, 0x4f, 0x3e, 0x26,
	0x57, 0xc6, 0x4e, 0x9d, 0x35, 0x7d, 0x87, 0xd5, 0xd0, 0x05, 0x5d, 0xdb, 0x8f, 0xa3, 0xdb, 0xae,
	0xc9, 0x7a, 0xa5, 0xff, 0xb7, 0x35, 0x6f, 0xec, 0xe7, 0xab, 0xb3, 0x97, 0x12, 0xf2, 0xcd, 0x99,
	0xa6, 0x36, 0x8c, 0x48, 0x8d, 0xad, 0x34, 0xaa, 0x0e, 0xf1, 0x78, 0xa5, 0xfe, 0xb1, 0x05, 0x96,
	0x44, 0xea, 0xe5, 0x0e, 0x58, 0xd6, 0xe1, 0xd2, 0x02, 0xbf, 0x1c, 0xdf, 0x9e, 0x46, 0x11, 0x91,
	0x3a, 0x8a, 0x76, 0x48, 0x14, 0xd5, 0x61, 0x14, 0x59, 0xe8, 0xd3, 0xfe, 0xd8, 0xee, 0xd5, 0x9f,
	0x00, 0x00, 0x00, 0xff, 0xff, 0x1b, 0x4d, 0xd4, 0xc6, 0xd2, 0x02, 0x00, 0x00,
}
