// Code generated by protoc-gen-go. DO NOT EDIT.
// source: google/ads/googleads/v1/enums/negative_geo_target_type.proto

package enums

import (
	fmt "fmt"
	math "math"

	proto "github.com/golang/protobuf/proto"
	_ "google.golang.org/genproto/googleapis/api/annotations"
)

// Reference imports to suppress errors if they are not otherwise used.
var _ = proto.Marshal
var _ = fmt.Errorf
var _ = math.Inf

// This is a compile-time assertion to ensure that this generated file
// is compatible with the proto package it is being compiled against.
// A compilation error at this line likely means your copy of the
// proto package needs to be updated.
const _ = proto.ProtoPackageIsVersion3 // please upgrade the proto package

// The possible negative geo target types.
type NegativeGeoTargetTypeEnum_NegativeGeoTargetType int32

const (
	// Not specified.
	NegativeGeoTargetTypeEnum_UNSPECIFIED NegativeGeoTargetTypeEnum_NegativeGeoTargetType = 0
	// The value is unknown in this version.
	NegativeGeoTargetTypeEnum_UNKNOWN NegativeGeoTargetTypeEnum_NegativeGeoTargetType = 1
	// Specifies that a user is excluded from seeing the ad if they
	// are in, or show interest in, advertiser's excluded locations.
	NegativeGeoTargetTypeEnum_DONT_CARE NegativeGeoTargetTypeEnum_NegativeGeoTargetType = 2
	// Specifies that a user is excluded from seeing the ad if they
	// are in advertiser's excluded locations.
	NegativeGeoTargetTypeEnum_LOCATION_OF_PRESENCE NegativeGeoTargetTypeEnum_NegativeGeoTargetType = 3
)

var NegativeGeoTargetTypeEnum_NegativeGeoTargetType_name = map[int32]string{
	0: "UNSPECIFIED",
	1: "UNKNOWN",
	2: "DONT_CARE",
	3: "LOCATION_OF_PRESENCE",
}

var NegativeGeoTargetTypeEnum_NegativeGeoTargetType_value = map[string]int32{
	"UNSPECIFIED":          0,
	"UNKNOWN":              1,
	"DONT_CARE":            2,
	"LOCATION_OF_PRESENCE": 3,
}

func (x NegativeGeoTargetTypeEnum_NegativeGeoTargetType) String() string {
	return proto.EnumName(NegativeGeoTargetTypeEnum_NegativeGeoTargetType_name, int32(x))
}

func (NegativeGeoTargetTypeEnum_NegativeGeoTargetType) EnumDescriptor() ([]byte, []int) {
	return fileDescriptor_66c4692eef99de00, []int{0, 0}
}

// Container for enum describing possible negative geo target types.
type NegativeGeoTargetTypeEnum struct {
	XXX_NoUnkeyedLiteral struct{} `json:"-"`
	XXX_unrecognized     []byte   `json:"-"`
	XXX_sizecache        int32    `json:"-"`
}

func (m *NegativeGeoTargetTypeEnum) Reset()         { *m = NegativeGeoTargetTypeEnum{} }
func (m *NegativeGeoTargetTypeEnum) String() string { return proto.CompactTextString(m) }
func (*NegativeGeoTargetTypeEnum) ProtoMessage()    {}
func (*NegativeGeoTargetTypeEnum) Descriptor() ([]byte, []int) {
	return fileDescriptor_66c4692eef99de00, []int{0}
}

func (m *NegativeGeoTargetTypeEnum) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_NegativeGeoTargetTypeEnum.Unmarshal(m, b)
}
func (m *NegativeGeoTargetTypeEnum) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_NegativeGeoTargetTypeEnum.Marshal(b, m, deterministic)
}
func (m *NegativeGeoTargetTypeEnum) XXX_Merge(src proto.Message) {
	xxx_messageInfo_NegativeGeoTargetTypeEnum.Merge(m, src)
}
func (m *NegativeGeoTargetTypeEnum) XXX_Size() int {
	return xxx_messageInfo_NegativeGeoTargetTypeEnum.Size(m)
}
func (m *NegativeGeoTargetTypeEnum) XXX_DiscardUnknown() {
	xxx_messageInfo_NegativeGeoTargetTypeEnum.DiscardUnknown(m)
}

var xxx_messageInfo_NegativeGeoTargetTypeEnum proto.InternalMessageInfo

func init() {
	proto.RegisterEnum("google.ads.googleads.v1.enums.NegativeGeoTargetTypeEnum_NegativeGeoTargetType", NegativeGeoTargetTypeEnum_NegativeGeoTargetType_name, NegativeGeoTargetTypeEnum_NegativeGeoTargetType_value)
	proto.RegisterType((*NegativeGeoTargetTypeEnum)(nil), "google.ads.googleads.v1.enums.NegativeGeoTargetTypeEnum")
}

func init() {
	proto.RegisterFile("google/ads/googleads/v1/enums/negative_geo_target_type.proto", fileDescriptor_66c4692eef99de00)
}

var fileDescriptor_66c4692eef99de00 = []byte{
	// 332 bytes of a gzipped FileDescriptorProto
	0x1f, 0x8b, 0x08, 0x00, 0x00, 0x00, 0x00, 0x00, 0x02, 0xff, 0x7c, 0x90, 0xd1, 0x4a, 0xeb, 0x30,
	0x1c, 0xc6, 0xcf, 0x3a, 0x38, 0x87, 0x93, 0x21, 0x96, 0xa2, 0xa0, 0xc3, 0x5d, 0x6c, 0x0f, 0x90,
	0x52, 0xbc, 0x8b, 0xde, 0x64, 0x5d, 0x36, 0x86, 0x92, 0x96, 0xad, 0x9b, 0x20, 0xc5, 0x12, 0x6d,
	0x08, 0x85, 0x2d, 0x29, 0x4b, 0x36, 0x18, 0xbe, 0x8d, 0x97, 0x3e, 0x8a, 0x8f, 0xe2, 0x8d, 0xaf,
	0x20, 0x4d, 0xb7, 0x5d, 0x4d, 0x6f, 0xc2, 0x47, 0xbe, 0xff, 0xef, 0xe3, 0xff, 0xff, 0xc0, 0xad,
	0x50, 0x4a, 0x2c, 0xb8, 0xcf, 0x72, 0xed, 0xd7, 0xb2, 0x52, 0x9b, 0xc0, 0xe7, 0x72, 0xbd, 0xd4,
	0xbe, 0xe4, 0x82, 0x99, 0x62, 0xc3, 0x33, 0xc1, 0x55, 0x66, 0xd8, 0x4a, 0x70, 0x93, 0x99, 0x6d,
	0xc9, 0x61, 0xb9, 0x52, 0x46, 0x79, 0x9d, 0x1a, 0x81, 0x2c, 0xd7, 0xf0, 0x40, 0xc3, 0x4d, 0x00,
	0x2d, 0xdd, 0xbe, 0xda, 0x87, 0x97, 0x85, 0xcf, 0xa4, 0x54, 0x86, 0x99, 0x42, 0x49, 0x5d, 0xc3,
	0xbd, 0x57, 0x70, 0x49, 0x77, 0xf1, 0x23, 0xae, 0x12, 0x1b, 0x9e, 0x6c, 0x4b, 0x4e, 0xe4, 0x7a,
	0xd9, 0x7b, 0x02, 0xe7, 0x47, 0x4d, 0xef, 0x14, 0xb4, 0x66, 0x74, 0x1a, 0x93, 0x70, 0x3c, 0x1c,
	0x93, 0x81, 0xfb, 0xc7, 0x6b, 0x81, 0x7f, 0x33, 0x7a, 0x47, 0xa3, 0x07, 0xea, 0x36, 0xbc, 0x13,
	0xf0, 0x7f, 0x10, 0xd1, 0x24, 0x0b, 0xf1, 0x84, 0xb8, 0x8e, 0x77, 0x01, 0xce, 0xee, 0xa3, 0x10,
	0x27, 0xe3, 0x88, 0x66, 0xd1, 0x30, 0x8b, 0x27, 0x64, 0x4a, 0x68, 0x48, 0xdc, 0x66, 0xff, 0xab,
	0x01, 0xba, 0x2f, 0x6a, 0x09, 0x7f, 0x3d, 0xa0, 0xdf, 0x3e, 0xba, 0x43, 0x5c, 0xad, 0x1f, 0x37,
	0x1e, 0xfb, 0x3b, 0x58, 0xa8, 0x05, 0x93, 0x02, 0xaa, 0x95, 0xf0, 0x05, 0x97, 0xf6, 0xb8, 0x7d,
	0x97, 0x65, 0xa1, 0x7f, 0xa8, 0xf6, 0xc6, 0xbe, 0x6f, 0x4e, 0x73, 0x84, 0xf1, 0xbb, 0xd3, 0x19,
	0xd5, 0x51, 0x38, 0xd7, 0xb0, 0x96, 0x95, 0x9a, 0x07, 0xb0, 0x2a, 0x43, 0x7f, 0xec, 0xfd, 0x14,
	0xe7, 0x3a, 0x3d, 0xf8, 0xe9, 0x3c, 0x48, 0xad, 0xff, 0xe9, 0x74, 0xeb, 0x4f, 0x84, 0x70, 0xae,
	0x11, 0x3a, 0x4c, 0x20, 0x34, 0x0f, 0x10, 0xb2, 0x33, 0xcf, 0x7f, 0xed, 0x62, 0xd7, 0xdf, 0x01,
	0x00, 0x00, 0xff, 0xff, 0xdd, 0xf9, 0x7e, 0x8a, 0xf2, 0x01, 0x00, 0x00,
}
