// Code generated by protoc-gen-go. DO NOT EDIT.
// source: google/ads/googleads/v1/enums/tracking_code_type.proto

package enums

import (
	fmt "fmt"
	math "math"

	proto "github.com/golang/protobuf/proto"
	_ "google.golang.org/genproto/googleapis/api/annotations"
)

// Reference imports to suppress errors if they are not otherwise used.
var _ = proto.Marshal
var _ = fmt.Errorf
var _ = math.Inf

// This is a compile-time assertion to ensure that this generated file
// is compatible with the proto package it is being compiled against.
// A compilation error at this line likely means your copy of the
// proto package needs to be updated.
const _ = proto.ProtoPackageIsVersion3 // please upgrade the proto package

// The type of the generated tag snippets for tracking conversions.
type TrackingCodeTypeEnum_TrackingCodeType int32

const (
	// Not specified.
	TrackingCodeTypeEnum_UNSPECIFIED TrackingCodeTypeEnum_TrackingCodeType = 0
	// Used for return value only. Represents value unknown in this version.
	TrackingCodeTypeEnum_UNKNOWN TrackingCodeTypeEnum_TrackingCodeType = 1
	// The snippet that is fired as a result of a website page loading.
	TrackingCodeTypeEnum_WEBPAGE TrackingCodeTypeEnum_TrackingCodeType = 2
	// The snippet contains a JavaScript function which fires the tag. This
	// function is typically called from an onClick handler added to a link or
	// button element on the page.
	TrackingCodeTypeEnum_WEBPAGE_ONCLICK TrackingCodeTypeEnum_TrackingCodeType = 3
	// For embedding on a mobile webpage. The snippet contains a JavaScript
	// function which fires the tag.
	TrackingCodeTypeEnum_CLICK_TO_CALL TrackingCodeTypeEnum_TrackingCodeType = 4
)

var TrackingCodeTypeEnum_TrackingCodeType_name = map[int32]string{
	0: "UNSPECIFIED",
	1: "UNKNOWN",
	2: "WEBPAGE",
	3: "WEBPAGE_ONCLICK",
	4: "CLICK_TO_CALL",
}

var TrackingCodeTypeEnum_TrackingCodeType_value = map[string]int32{
	"UNSPECIFIED":     0,
	"UNKNOWN":         1,
	"WEBPAGE":         2,
	"WEBPAGE_ONCLICK": 3,
	"CLICK_TO_CALL":   4,
}

func (x TrackingCodeTypeEnum_TrackingCodeType) String() string {
	return proto.EnumName(TrackingCodeTypeEnum_TrackingCodeType_name, int32(x))
}

func (TrackingCodeTypeEnum_TrackingCodeType) EnumDescriptor() ([]byte, []int) {
	return fileDescriptor_3fe4bb6a9d0a0750, []int{0, 0}
}

// Container for enum describing the type of the generated tag snippets for
// tracking conversions.
type TrackingCodeTypeEnum struct {
	XXX_NoUnkeyedLiteral struct{} `json:"-"`
	XXX_unrecognized     []byte   `json:"-"`
	XXX_sizecache        int32    `json:"-"`
}

func (m *TrackingCodeTypeEnum) Reset()         { *m = TrackingCodeTypeEnum{} }
func (m *TrackingCodeTypeEnum) String() string { return proto.CompactTextString(m) }
func (*TrackingCodeTypeEnum) ProtoMessage()    {}
func (*TrackingCodeTypeEnum) Descriptor() ([]byte, []int) {
	return fileDescriptor_3fe4bb6a9d0a0750, []int{0}
}

func (m *TrackingCodeTypeEnum) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_TrackingCodeTypeEnum.Unmarshal(m, b)
}
func (m *TrackingCodeTypeEnum) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_TrackingCodeTypeEnum.Marshal(b, m, deterministic)
}
func (m *TrackingCodeTypeEnum) XXX_Merge(src proto.Message) {
	xxx_messageInfo_TrackingCodeTypeEnum.Merge(m, src)
}
func (m *TrackingCodeTypeEnum) XXX_Size() int {
	return xxx_messageInfo_TrackingCodeTypeEnum.Size(m)
}
func (m *TrackingCodeTypeEnum) XXX_DiscardUnknown() {
	xxx_messageInfo_TrackingCodeTypeEnum.DiscardUnknown(m)
}

var xxx_messageInfo_TrackingCodeTypeEnum proto.InternalMessageInfo

func init() {
	proto.RegisterEnum("google.ads.googleads.v1.enums.TrackingCodeTypeEnum_TrackingCodeType", TrackingCodeTypeEnum_TrackingCodeType_name, TrackingCodeTypeEnum_TrackingCodeType_value)
	proto.RegisterType((*TrackingCodeTypeEnum)(nil), "google.ads.googleads.v1.enums.TrackingCodeTypeEnum")
}

func init() {
	proto.RegisterFile("google/ads/googleads/v1/enums/tracking_code_type.proto", fileDescriptor_3fe4bb6a9d0a0750)
}

var fileDescriptor_3fe4bb6a9d0a0750 = []byte{
	// 327 bytes of a gzipped FileDescriptorProto
	0x1f, 0x8b, 0x08, 0x00, 0x00, 0x00, 0x00, 0x00, 0x02, 0xff, 0x7c, 0x50, 0xdf, 0x4a, 0xfb, 0x30,
	0x18, 0xfd, 0xad, 0xfb, 0xa1, 0x90, 0x21, 0xab, 0x55, 0x6f, 0xc4, 0x5d, 0x6c, 0x0f, 0x90, 0x50,
	0x04, 0x2f, 0xe2, 0x55, 0x5a, 0xeb, 0x18, 0x1b, 0x5d, 0xc1, 0xfd, 0x01, 0x29, 0x94, 0xb8, 0x84,
	0x50, 0xdc, 0x92, 0xb2, 0x74, 0x83, 0x5d, 0xf8, 0x32, 0x5e, 0xfa, 0x28, 0x3e, 0xca, 0x9e, 0x42,
	0x9a, 0x6c, 0xbd, 0x18, 0xe8, 0x4d, 0x38, 0xf9, 0xbe, 0x73, 0x0e, 0xe7, 0x3b, 0xe0, 0x41, 0x28,
	0x25, 0x96, 0x1c, 0x51, 0xa6, 0x91, 0x85, 0x15, 0xda, 0xfa, 0x88, 0xcb, 0xcd, 0x4a, 0xa3, 0x72,
	0x4d, 0x17, 0xef, 0xb9, 0x14, 0xd9, 0x42, 0x31, 0x9e, 0x95, 0xbb, 0x82, 0xc3, 0x62, 0xad, 0x4a,
	0xe5, 0x75, 0x2c, 0x19, 0x52, 0xa6, 0x61, 0xad, 0x83, 0x5b, 0x1f, 0x1a, 0xdd, 0xed, 0xdd, 0xd1,
	0xb6, 0xc8, 0x11, 0x95, 0x52, 0x95, 0xb4, 0xcc, 0x95, 0xd4, 0x56, 0xdc, 0xfb, 0x00, 0xd7, 0x93,
	0x83, 0x71, 0xa8, 0x18, 0x9f, 0xec, 0x0a, 0x1e, 0xc9, 0xcd, 0xaa, 0xc7, 0x81, 0x7b, 0x3a, 0xf7,
	0xda, 0xa0, 0x35, 0x8d, 0x5f, 0x92, 0x28, 0x1c, 0x3c, 0x0f, 0xa2, 0x27, 0xf7, 0x9f, 0xd7, 0x02,
	0xe7, 0xd3, 0x78, 0x18, 0x8f, 0xe7, 0xb1, 0xdb, 0xa8, 0x3e, 0xf3, 0x28, 0x48, 0x48, 0x3f, 0x72,
	0x1d, 0xef, 0x0a, 0xb4, 0x0f, 0x9f, 0x6c, 0x1c, 0x87, 0xa3, 0x41, 0x38, 0x74, 0x9b, 0xde, 0x25,
	0xb8, 0x30, 0x30, 0x9b, 0x8c, 0xb3, 0x90, 0x8c, 0x46, 0xee, 0xff, 0x60, 0xdf, 0x00, 0xdd, 0x85,
	0x5a, 0xc1, 0x3f, 0x4f, 0x08, 0x6e, 0x4e, 0xa3, 0x24, 0x55, 0xf6, 0xa4, 0xf1, 0x1a, 0x1c, 0x74,
	0x42, 0x2d, 0xa9, 0x14, 0x50, 0xad, 0x05, 0x12, 0x5c, 0x9a, 0xcb, 0x8e, 0x15, 0x16, 0xb9, 0xfe,
	0xa5, 0xd1, 0x47, 0xf3, 0x7e, 0x3a, 0xcd, 0x3e, 0x21, 0x5f, 0x4e, 0xa7, 0x6f, 0xad, 0x08, 0xd3,
	0xd0, 0xc2, 0x0a, 0xcd, 0x7c, 0x58, 0xd5, 0xa1, 0xbf, 0x8f, 0xfb, 0x94, 0x30, 0x9d, 0xd6, 0xfb,
	0x74, 0xe6, 0xa7, 0x66, 0xbf, 0x77, 0xba, 0x76, 0x88, 0x31, 0x61, 0x1a, 0xe3, 0x9a, 0x81, 0xf1,
	0xcc, 0xc7, 0xd8, 0x70, 0xde, 0xce, 0x4c, 0xb0, 0xfb, 0x9f, 0x00, 0x00, 0x00, 0xff, 0xff, 0x3c,
	0xb2, 0xe6, 0x9c, 0xe9, 0x01, 0x00, 0x00,
}
