// Code generated by protoc-gen-go. DO NOT EDIT.
// source: google/ads/googleads/v1/enums/feed_item_target_device.proto

package enums

import (
	fmt "fmt"
	math "math"

	proto "github.com/golang/protobuf/proto"
	_ "google.golang.org/genproto/googleapis/api/annotations"
)

// Reference imports to suppress errors if they are not otherwise used.
var _ = proto.Marshal
var _ = fmt.Errorf
var _ = math.Inf

// This is a compile-time assertion to ensure that this generated file
// is compatible with the proto package it is being compiled against.
// A compilation error at this line likely means your copy of the
// proto package needs to be updated.
const _ = proto.ProtoPackageIsVersion3 // please upgrade the proto package

// Possible data types for a feed item target device.
type FeedItemTargetDeviceEnum_FeedItemTargetDevice int32

const (
	// Not specified.
	FeedItemTargetDeviceEnum_UNSPECIFIED FeedItemTargetDeviceEnum_FeedItemTargetDevice = 0
	// Used for return value only. Represents value unknown in this version.
	FeedItemTargetDeviceEnum_UNKNOWN FeedItemTargetDeviceEnum_FeedItemTargetDevice = 1
	// Mobile.
	FeedItemTargetDeviceEnum_MOBILE FeedItemTargetDeviceEnum_FeedItemTargetDevice = 2
)

var FeedItemTargetDeviceEnum_FeedItemTargetDevice_name = map[int32]string{
	0: "UNSPECIFIED",
	1: "UNKNOWN",
	2: "MOBILE",
}

var FeedItemTargetDeviceEnum_FeedItemTargetDevice_value = map[string]int32{
	"UNSPECIFIED": 0,
	"UNKNOWN":     1,
	"MOBILE":      2,
}

func (x FeedItemTargetDeviceEnum_FeedItemTargetDevice) String() string {
	return proto.EnumName(FeedItemTargetDeviceEnum_FeedItemTargetDevice_name, int32(x))
}

func (FeedItemTargetDeviceEnum_FeedItemTargetDevice) EnumDescriptor() ([]byte, []int) {
	return fileDescriptor_7bbd78c5de847bc3, []int{0, 0}
}

// Container for enum describing possible data types for a feed item target
// device.
type FeedItemTargetDeviceEnum struct {
	XXX_NoUnkeyedLiteral struct{} `json:"-"`
	XXX_unrecognized     []byte   `json:"-"`
	XXX_sizecache        int32    `json:"-"`
}

func (m *FeedItemTargetDeviceEnum) Reset()         { *m = FeedItemTargetDeviceEnum{} }
func (m *FeedItemTargetDeviceEnum) String() string { return proto.CompactTextString(m) }
func (*FeedItemTargetDeviceEnum) ProtoMessage()    {}
func (*FeedItemTargetDeviceEnum) Descriptor() ([]byte, []int) {
	return fileDescriptor_7bbd78c5de847bc3, []int{0}
}

func (m *FeedItemTargetDeviceEnum) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_FeedItemTargetDeviceEnum.Unmarshal(m, b)
}
func (m *FeedItemTargetDeviceEnum) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_FeedItemTargetDeviceEnum.Marshal(b, m, deterministic)
}
func (m *FeedItemTargetDeviceEnum) XXX_Merge(src proto.Message) {
	xxx_messageInfo_FeedItemTargetDeviceEnum.Merge(m, src)
}
func (m *FeedItemTargetDeviceEnum) XXX_Size() int {
	return xxx_messageInfo_FeedItemTargetDeviceEnum.Size(m)
}
func (m *FeedItemTargetDeviceEnum) XXX_DiscardUnknown() {
	xxx_messageInfo_FeedItemTargetDeviceEnum.DiscardUnknown(m)
}

var xxx_messageInfo_FeedItemTargetDeviceEnum proto.InternalMessageInfo

func init() {
	proto.RegisterEnum("google.ads.googleads.v1.enums.FeedItemTargetDeviceEnum_FeedItemTargetDevice", FeedItemTargetDeviceEnum_FeedItemTargetDevice_name, FeedItemTargetDeviceEnum_FeedItemTargetDevice_value)
	proto.RegisterType((*FeedItemTargetDeviceEnum)(nil), "google.ads.googleads.v1.enums.FeedItemTargetDeviceEnum")
}

func init() {
	proto.RegisterFile("google/ads/googleads/v1/enums/feed_item_target_device.proto", fileDescriptor_7bbd78c5de847bc3)
}

var fileDescriptor_7bbd78c5de847bc3 = []byte{
	// 303 bytes of a gzipped FileDescriptorProto
	0x1f, 0x8b, 0x08, 0x00, 0x00, 0x00, 0x00, 0x00, 0x02, 0xff, 0x7c, 0x90, 0xc1, 0x4a, 0xc3, 0x30,
	0x1c, 0xc6, 0x5d, 0x85, 0x09, 0xd9, 0xc1, 0x51, 0x3c, 0xa8, 0xb8, 0xc3, 0xf6, 0x00, 0x09, 0xc5,
	0x5b, 0x76, 0xb1, 0x75, 0xdd, 0x28, 0x6a, 0x37, 0xd0, 0x4d, 0x90, 0xc2, 0x88, 0xcb, 0xdf, 0x50,
	0x58, 0x93, 0xd1, 0x64, 0x7d, 0x20, 0x8f, 0x3e, 0x8a, 0x8f, 0xe2, 0xc1, 0x67, 0x90, 0x26, 0xb6,
	0xa7, 0xe9, 0x25, 0x7c, 0xe4, 0xfb, 0xff, 0xbe, 0x7c, 0xf9, 0xa3, 0xb1, 0x50, 0x4a, 0x6c, 0x81,
	0x30, 0xae, 0x89, 0x93, 0xb5, 0xaa, 0x02, 0x02, 0x72, 0x5f, 0x68, 0xf2, 0x06, 0xc0, 0xd7, 0xb9,
	0x81, 0x62, 0x6d, 0x58, 0x29, 0xc0, 0xac, 0x39, 0x54, 0xf9, 0x06, 0xf0, 0xae, 0x54, 0x46, 0xf9,
	0x03, 0x47, 0x60, 0xc6, 0x35, 0x6e, 0x61, 0x5c, 0x05, 0xd8, 0xc2, 0x97, 0x57, 0x4d, 0xf6, 0x2e,
	0x27, 0x4c, 0x4a, 0x65, 0x98, 0xc9, 0x95, 0xd4, 0x0e, 0x1e, 0x65, 0xe8, 0x7c, 0x0a, 0xc0, 0x13,
	0x03, 0xc5, 0x93, 0xcd, 0x9e, 0xd8, 0xe8, 0x58, 0xee, 0x8b, 0xd1, 0x0d, 0x3a, 0x3b, 0xe4, 0xf9,
	0xa7, 0xa8, 0xb7, 0x4c, 0x1f, 0x17, 0xf1, 0x6d, 0x32, 0x4d, 0xe2, 0x49, 0xff, 0xc8, 0xef, 0xa1,
	0x93, 0x65, 0x7a, 0x97, 0xce, 0x9f, 0xd3, 0x7e, 0xc7, 0x47, 0xa8, 0xfb, 0x30, 0x8f, 0x92, 0xfb,
	0xb8, 0xef, 0x45, 0xdf, 0x1d, 0x34, 0xdc, 0xa8, 0x02, 0xff, 0xdb, 0x30, 0xba, 0x38, 0xf4, 0xca,
	0xa2, 0xae, 0xb7, 0xe8, 0xbc, 0x44, 0xbf, 0xac, 0x50, 0x5b, 0x26, 0x05, 0x56, 0xa5, 0x20, 0x02,
	0xa4, 0x2d, 0xdf, 0xac, 0x6a, 0x97, 0xeb, 0x3f, 0x36, 0x37, 0xb6, 0xe7, 0xbb, 0x77, 0x3c, 0x0b,
	0xc3, 0x0f, 0x6f, 0x30, 0x73, 0x51, 0x21, 0xd7, 0xd8, 0xc9, 0x5a, 0xad, 0x02, 0x5c, 0xff, 0x56,
	0x7f, 0x36, 0x7e, 0x16, 0x72, 0x9d, 0xb5, 0x7e, 0xb6, 0x0a, 0x32, 0xeb, 0x7f, 0x79, 0x43, 0x77,
	0x49, 0x69, 0xc8, 0x35, 0xa5, 0xed, 0x04, 0xa5, 0xab, 0x80, 0x52, 0x3b, 0xf3, 0xda, 0xb5, 0xc5,
	0xae, 0x7f, 0x02, 0x00, 0x00, 0xff, 0xff, 0x72, 0x4a, 0xe8, 0x09, 0xd1, 0x01, 0x00, 0x00,
}
