// Code generated by protoc-gen-go. DO NOT EDIT.
// source: google/cloud/automl/v1beta1/annotation_spec.proto

package automl

import (
	fmt "fmt"
	math "math"

	proto "github.com/golang/protobuf/proto"
	_ "google.golang.org/genproto/googleapis/api/annotations"
)

// Reference imports to suppress errors if they are not otherwise used.
var _ = proto.Marshal
var _ = fmt.Errorf
var _ = math.Inf

// This is a compile-time assertion to ensure that this generated file
// is compatible with the proto package it is being compiled against.
// A compilation error at this line likely means your copy of the
// proto package needs to be updated.
const _ = proto.ProtoPackageIsVersion3 // please upgrade the proto package

// A definition of an annotation spec.
type AnnotationSpec struct {
	// Output only. Resource name of the annotation spec.
	// Form:
	//
	// 'projects/{project_id}/locations/{location_id}/datasets/{dataset_id}/annotationSpecs/{annotation_spec_id}'
	Name string `protobuf:"bytes,1,opt,name=name,proto3" json:"name,omitempty"`
	// Required.
	// The name of the annotation spec to show in the interface. The name can be
	// up to 32 characters long and must match the regexp `[a-zA-Z0-9_]+`.
	// (_), and ASCII digits 0-9.
	DisplayName string `protobuf:"bytes,2,opt,name=display_name,json=displayName,proto3" json:"display_name,omitempty"`
	// Output only. The number of examples in the parent dataset
	// labeled by the annotation spec.
	ExampleCount         int32    `protobuf:"varint,9,opt,name=example_count,json=exampleCount,proto3" json:"example_count,omitempty"`
	XXX_NoUnkeyedLiteral struct{} `json:"-"`
	XXX_unrecognized     []byte   `json:"-"`
	XXX_sizecache        int32    `json:"-"`
}

func (m *AnnotationSpec) Reset()         { *m = AnnotationSpec{} }
func (m *AnnotationSpec) String() string { return proto.CompactTextString(m) }
func (*AnnotationSpec) ProtoMessage()    {}
func (*AnnotationSpec) Descriptor() ([]byte, []int) {
	return fileDescriptor_584ed6bab6ac13f7, []int{0}
}

func (m *AnnotationSpec) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_AnnotationSpec.Unmarshal(m, b)
}
func (m *AnnotationSpec) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_AnnotationSpec.Marshal(b, m, deterministic)
}
func (m *AnnotationSpec) XXX_Merge(src proto.Message) {
	xxx_messageInfo_AnnotationSpec.Merge(m, src)
}
func (m *AnnotationSpec) XXX_Size() int {
	return xxx_messageInfo_AnnotationSpec.Size(m)
}
func (m *AnnotationSpec) XXX_DiscardUnknown() {
	xxx_messageInfo_AnnotationSpec.DiscardUnknown(m)
}

var xxx_messageInfo_AnnotationSpec proto.InternalMessageInfo

func (m *AnnotationSpec) GetName() string {
	if m != nil {
		return m.Name
	}
	return ""
}

func (m *AnnotationSpec) GetDisplayName() string {
	if m != nil {
		return m.DisplayName
	}
	return ""
}

func (m *AnnotationSpec) GetExampleCount() int32 {
	if m != nil {
		return m.ExampleCount
	}
	return 0
}

func init() {
	proto.RegisterType((*AnnotationSpec)(nil), "google.cloud.automl.v1beta1.AnnotationSpec")
}

func init() {
	proto.RegisterFile("google/cloud/automl/v1beta1/annotation_spec.proto", fileDescriptor_584ed6bab6ac13f7)
}

var fileDescriptor_584ed6bab6ac13f7 = []byte{
	// 265 bytes of a gzipped FileDescriptorProto
	0x1f, 0x8b, 0x08, 0x00, 0x00, 0x00, 0x00, 0x00, 0x02, 0xff, 0x7c, 0x90, 0x41, 0x4a, 0xc4, 0x30,
	0x14, 0x86, 0x49, 0x51, 0x61, 0xe2, 0xe8, 0xa2, 0xab, 0xc1, 0x11, 0x1d, 0x75, 0x33, 0xab, 0x84,
	0xe2, 0x2e, 0xae, 0xea, 0x2c, 0xdc, 0xa8, 0xc8, 0x08, 0x2e, 0xa4, 0x50, 0xde, 0x64, 0x42, 0x28,
	0xa4, 0x79, 0xa1, 0x4d, 0x45, 0x0f, 0xe4, 0x65, 0x3c, 0x8a, 0xa7, 0x90, 0x26, 0x41, 0x5c, 0xc8,
	0xec, 0x92, 0xff, 0xfb, 0xbf, 0xe4, 0xf1, 0x68, 0xa1, 0x11, 0xb5, 0x51, 0x5c, 0x1a, 0x1c, 0xb6,
	0x1c, 0x06, 0x8f, 0xad, 0xe1, 0x6f, 0xc5, 0x46, 0x79, 0x28, 0x38, 0x58, 0x8b, 0x1e, 0x7c, 0x83,
	0xb6, 0xee, 0x9d, 0x92, 0xcc, 0x75, 0xe8, 0x31, 0x9f, 0x47, 0x85, 0x05, 0x85, 0x45, 0x85, 0x25,
	0xe5, 0xe4, 0x34, 0xbd, 0x07, 0xae, 0xf9, 0xa3, 0xf7, 0x51, 0xbd, 0x34, 0xf4, 0xb8, 0xfc, 0x0d,
	0x9f, 0x9d, 0x92, 0x79, 0x4e, 0xf7, 0x2c, 0xb4, 0x6a, 0x46, 0x16, 0x64, 0x39, 0x59, 0x87, 0x73,
	0x7e, 0x41, 0xa7, 0xdb, 0xa6, 0x77, 0x06, 0x3e, 0xea, 0xc0, 0xb2, 0xc0, 0x0e, 0x53, 0xf6, 0x38,
	0x56, 0xae, 0xe8, 0x91, 0x7a, 0x87, 0xd6, 0x19, 0x55, 0x4b, 0x1c, 0xac, 0x9f, 0x4d, 0x16, 0x64,
	0xb9, 0xbf, 0x9e, 0xa6, 0x70, 0x35, 0x66, 0xb7, 0x9f, 0x84, 0x9e, 0x4b, 0x6c, 0xd9, 0x8e, 0x79,
	0x9f, 0xc8, 0x6b, 0x99, 0xb0, 0x46, 0x03, 0x56, 0x33, 0xec, 0x34, 0xd7, 0xca, 0x86, 0x79, 0x79,
	0x44, 0xe0, 0x9a, 0xfe, 0xdf, 0x05, 0xdd, 0xc4, 0xeb, 0x57, 0x36, 0xbf, 0x0b, 0xc5, 0x6a, 0x35,
	0x96, 0xaa, 0x72, 0xf0, 0xf8, 0x60, 0xaa, 0x97, 0x58, 0xfa, 0xce, 0xce, 0x22, 0x15, 0x22, 0x60,
	0x21, 0x02, 0xbf, 0x17, 0x22, 0x15, 0x36, 0x07, 0xe1, 0xb3, 0xeb, 0x9f, 0x00, 0x00, 0x00, 0xff,
	0xff, 0x71, 0x3a, 0x58, 0x4c, 0x8c, 0x01, 0x00, 0x00,
}
