// Code generated by protoc-gen-go. DO NOT EDIT.
// source: google/ads/googleads/v2/enums/app_placeholder_field.proto

package enums

import (
	fmt "fmt"
	math "math"

	proto "github.com/golang/protobuf/proto"
	_ "google.golang.org/genproto/googleapis/api/annotations"
)

// Reference imports to suppress errors if they are not otherwise used.
var _ = proto.Marshal
var _ = fmt.Errorf
var _ = math.Inf

// This is a compile-time assertion to ensure that this generated file
// is compatible with the proto package it is being compiled against.
// A compilation error at this line likely means your copy of the
// proto package needs to be updated.
const _ = proto.ProtoPackageIsVersion3 // please upgrade the proto package

// Possible values for App placeholder fields.
type AppPlaceholderFieldEnum_AppPlaceholderField int32

const (
	// Not specified.
	AppPlaceholderFieldEnum_UNSPECIFIED AppPlaceholderFieldEnum_AppPlaceholderField = 0
	// Used for return value only. Represents value unknown in this version.
	AppPlaceholderFieldEnum_UNKNOWN AppPlaceholderFieldEnum_AppPlaceholderField = 1
	// Data Type: INT64. The application store that the target application
	// belongs to. Valid values are: 1 = Apple iTunes Store; 2 = Google Play
	// Store.
	AppPlaceholderFieldEnum_STORE AppPlaceholderFieldEnum_AppPlaceholderField = 2
	// Data Type: STRING. The store-specific ID for the target application.
	AppPlaceholderFieldEnum_ID AppPlaceholderFieldEnum_AppPlaceholderField = 3
	// Data Type: STRING. The visible text displayed when the link is rendered
	// in an ad.
	AppPlaceholderFieldEnum_LINK_TEXT AppPlaceholderFieldEnum_AppPlaceholderField = 4
	// Data Type: STRING. The destination URL of the in-app link.
	AppPlaceholderFieldEnum_URL AppPlaceholderFieldEnum_AppPlaceholderField = 5
	// Data Type: URL_LIST. Final URLs for the in-app link when using Upgraded
	// URLs.
	AppPlaceholderFieldEnum_FINAL_URLS AppPlaceholderFieldEnum_AppPlaceholderField = 6
	// Data Type: URL_LIST. Final Mobile URLs for the in-app link when using
	// Upgraded URLs.
	AppPlaceholderFieldEnum_FINAL_MOBILE_URLS AppPlaceholderFieldEnum_AppPlaceholderField = 7
	// Data Type: URL. Tracking template for the in-app link when using Upgraded
	// URLs.
	AppPlaceholderFieldEnum_TRACKING_URL AppPlaceholderFieldEnum_AppPlaceholderField = 8
	// Data Type: STRING. Final URL suffix for the in-app link when using
	// parallel tracking.
	AppPlaceholderFieldEnum_FINAL_URL_SUFFIX AppPlaceholderFieldEnum_AppPlaceholderField = 9
)

var AppPlaceholderFieldEnum_AppPlaceholderField_name = map[int32]string{
	0: "UNSPECIFIED",
	1: "UNKNOWN",
	2: "STORE",
	3: "ID",
	4: "LINK_TEXT",
	5: "URL",
	6: "FINAL_URLS",
	7: "FINAL_MOBILE_URLS",
	8: "TRACKING_URL",
	9: "FINAL_URL_SUFFIX",
}

var AppPlaceholderFieldEnum_AppPlaceholderField_value = map[string]int32{
	"UNSPECIFIED":       0,
	"UNKNOWN":           1,
	"STORE":             2,
	"ID":                3,
	"LINK_TEXT":         4,
	"URL":               5,
	"FINAL_URLS":        6,
	"FINAL_MOBILE_URLS": 7,
	"TRACKING_URL":      8,
	"FINAL_URL_SUFFIX":  9,
}

func (x AppPlaceholderFieldEnum_AppPlaceholderField) String() string {
	return proto.EnumName(AppPlaceholderFieldEnum_AppPlaceholderField_name, int32(x))
}

func (AppPlaceholderFieldEnum_AppPlaceholderField) EnumDescriptor() ([]byte, []int) {
	return fileDescriptor_f5ec45d31ec104f1, []int{0, 0}
}

// Values for App placeholder fields.
type AppPlaceholderFieldEnum struct {
	XXX_NoUnkeyedLiteral struct{} `json:"-"`
	XXX_unrecognized     []byte   `json:"-"`
	XXX_sizecache        int32    `json:"-"`
}

func (m *AppPlaceholderFieldEnum) Reset()         { *m = AppPlaceholderFieldEnum{} }
func (m *AppPlaceholderFieldEnum) String() string { return proto.CompactTextString(m) }
func (*AppPlaceholderFieldEnum) ProtoMessage()    {}
func (*AppPlaceholderFieldEnum) Descriptor() ([]byte, []int) {
	return fileDescriptor_f5ec45d31ec104f1, []int{0}
}

func (m *AppPlaceholderFieldEnum) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_AppPlaceholderFieldEnum.Unmarshal(m, b)
}
func (m *AppPlaceholderFieldEnum) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_AppPlaceholderFieldEnum.Marshal(b, m, deterministic)
}
func (m *AppPlaceholderFieldEnum) XXX_Merge(src proto.Message) {
	xxx_messageInfo_AppPlaceholderFieldEnum.Merge(m, src)
}
func (m *AppPlaceholderFieldEnum) XXX_Size() int {
	return xxx_messageInfo_AppPlaceholderFieldEnum.Size(m)
}
func (m *AppPlaceholderFieldEnum) XXX_DiscardUnknown() {
	xxx_messageInfo_AppPlaceholderFieldEnum.DiscardUnknown(m)
}

var xxx_messageInfo_AppPlaceholderFieldEnum proto.InternalMessageInfo

func init() {
	proto.RegisterEnum("google.ads.googleads.v2.enums.AppPlaceholderFieldEnum_AppPlaceholderField", AppPlaceholderFieldEnum_AppPlaceholderField_name, AppPlaceholderFieldEnum_AppPlaceholderField_value)
	proto.RegisterType((*AppPlaceholderFieldEnum)(nil), "google.ads.googleads.v2.enums.AppPlaceholderFieldEnum")
}

func init() {
	proto.RegisterFile("google/ads/googleads/v2/enums/app_placeholder_field.proto", fileDescriptor_f5ec45d31ec104f1)
}

var fileDescriptor_f5ec45d31ec104f1 = []byte{
	// 382 bytes of a gzipped FileDescriptorProto
	0x1f, 0x8b, 0x08, 0x00, 0x00, 0x00, 0x00, 0x00, 0x02, 0xff, 0x7c, 0x51, 0xdd, 0xce, 0x93, 0x30,
	0x18, 0x16, 0xe6, 0xb7, 0xb9, 0x7e, 0xfe, 0xd4, 0xaa, 0xd1, 0x18, 0x77, 0xb0, 0x5d, 0x40, 0x49,
	0xf0, 0xc8, 0x7a, 0x54, 0x36, 0x58, 0x9a, 0x21, 0x23, 0xfc, 0xcc, 0xc5, 0x90, 0x10, 0x1c, 0x88,
	0x24, 0x8c, 0x36, 0xeb, 0xb6, 0x0b, 0xf2, 0xd0, 0xc4, 0x0b, 0xd1, 0x4b, 0x31, 0xf1, 0x1e, 0x0c,
	0xd4, 0xe1, 0xc9, 0xf4, 0xa4, 0x79, 0xfa, 0x3e, 0x3f, 0x69, 0x9f, 0x17, 0xbc, 0x29, 0x39, 0x2f,
	0xeb, 0xc2, 0xc8, 0x72, 0x69, 0x28, 0xd8, 0xa2, 0xb3, 0x69, 0x14, 0xcd, 0x69, 0x2f, 0x8d, 0x4c,
	0x88, 0x54, 0xd4, 0xd9, 0xae, 0xf8, 0xcc, 0xeb, 0xbc, 0x38, 0xa4, 0x9f, 0xaa, 0xa2, 0xce, 0xb1,
	0x38, 0xf0, 0x23, 0x47, 0x13, 0xa5, 0xc7, 0x59, 0x2e, 0x71, 0x6f, 0xc5, 0x67, 0x13, 0x77, 0xd6,
	0x97, 0xaf, 0x2e, 0xc9, 0xa2, 0x32, 0xb2, 0xa6, 0xe1, 0xc7, 0xec, 0x58, 0xf1, 0x46, 0x2a, 0xf3,
	0xec, 0xbb, 0x06, 0x9e, 0x53, 0x21, 0xfc, 0xbf, 0xd9, 0x4e, 0x1b, 0x6d, 0x37, 0xa7, 0xfd, 0xec,
	0x9b, 0x06, 0x9e, 0x5c, 0xe1, 0xd0, 0x23, 0x70, 0x1b, 0x7b, 0xa1, 0x6f, 0xcf, 0x99, 0xc3, 0xec,
	0x05, 0xbc, 0x83, 0x6e, 0xc1, 0x28, 0xf6, 0x56, 0xde, 0xfa, 0xbd, 0x07, 0x35, 0x34, 0x06, 0x37,
	0x61, 0xb4, 0x0e, 0x6c, 0xa8, 0xa3, 0x21, 0xd0, 0xd9, 0x02, 0x0e, 0xd0, 0x03, 0x30, 0x76, 0x99,
	0xb7, 0x4a, 0x23, 0x7b, 0x1b, 0xc1, 0xbb, 0x68, 0x04, 0x06, 0x71, 0xe0, 0xc2, 0x1b, 0xf4, 0x10,
	0x00, 0x87, 0x79, 0xd4, 0x4d, 0xe3, 0xc0, 0x0d, 0xe1, 0x10, 0x3d, 0x03, 0x8f, 0xd5, 0xfd, 0xdd,
	0xda, 0x62, 0xae, 0xad, 0xc6, 0x23, 0x04, 0xc1, 0xfd, 0x28, 0xa0, 0xf3, 0x15, 0xf3, 0x96, 0xed,
	0x08, 0xde, 0x43, 0x4f, 0x01, 0xec, 0x8d, 0x69, 0x18, 0x3b, 0x0e, 0xdb, 0xc2, 0xb1, 0xf5, 0x4b,
	0x03, 0xd3, 0x1d, 0xdf, 0xe3, 0xff, 0xf6, 0x61, 0xbd, 0xb8, 0xf2, 0x25, 0xbf, 0xed, 0xc2, 0xd7,
	0x3e, 0x58, 0x7f, 0xac, 0x25, 0xaf, 0xb3, 0xa6, 0xc4, 0xfc, 0x50, 0x1a, 0x65, 0xd1, 0x74, 0x4d,
	0x5d, 0xb6, 0x22, 0x2a, 0xf9, 0x8f, 0x25, 0xbd, 0xed, 0xce, 0x2f, 0xfa, 0x60, 0x49, 0xe9, 0x57,
	0x7d, 0xb2, 0x54, 0x51, 0x34, 0x97, 0x58, 0xc1, 0x16, 0x6d, 0x4c, 0xdc, 0x56, 0x2b, 0x7f, 0x5c,
	0xf8, 0x84, 0xe6, 0x32, 0xe9, 0xf9, 0x64, 0x63, 0x26, 0x1d, 0xff, 0x53, 0x9f, 0xaa, 0x21, 0x21,
	0x34, 0x97, 0x84, 0xf4, 0x0a, 0x42, 0x36, 0x26, 0x21, 0x9d, 0xe6, 0xe3, 0xb0, 0x7b, 0xd8, 0xeb,
	0xdf, 0x01, 0x00, 0x00, 0xff, 0xff, 0xe5, 0xce, 0xc7, 0xff, 0x3c, 0x02, 0x00, 0x00,
}
