// Code generated by protoc-gen-go. DO NOT EDIT.
// source: google/cloud/automl/v1beta1/temporal.proto

package automl

import (
	fmt "fmt"
	math "math"

	proto "github.com/golang/protobuf/proto"
	duration "github.com/golang/protobuf/ptypes/duration"
	_ "google.golang.org/genproto/googleapis/api/annotations"
)

// Reference imports to suppress errors if they are not otherwise used.
var _ = proto.Marshal
var _ = fmt.Errorf
var _ = math.Inf

// This is a compile-time assertion to ensure that this generated file
// is compatible with the proto package it is being compiled against.
// A compilation error at this line likely means your copy of the
// proto package needs to be updated.
const _ = proto.ProtoPackageIsVersion3 // please upgrade the proto package

// A time period inside of an example that has a time dimension (e.g. video).
type TimeSegment struct {
	// Start of the time segment (inclusive), represented as the duration since
	// the example start.
	StartTimeOffset *duration.Duration `protobuf:"bytes,1,opt,name=start_time_offset,json=startTimeOffset,proto3" json:"start_time_offset,omitempty"`
	// End of the time segment (exclusive), represented as the duration since the
	// example start.
	EndTimeOffset        *duration.Duration `protobuf:"bytes,2,opt,name=end_time_offset,json=endTimeOffset,proto3" json:"end_time_offset,omitempty"`
	XXX_NoUnkeyedLiteral struct{}           `json:"-"`
	XXX_unrecognized     []byte             `json:"-"`
	XXX_sizecache        int32              `json:"-"`
}

func (m *TimeSegment) Reset()         { *m = TimeSegment{} }
func (m *TimeSegment) String() string { return proto.CompactTextString(m) }
func (*TimeSegment) ProtoMessage()    {}
func (*TimeSegment) Descriptor() ([]byte, []int) {
	return fileDescriptor_7ab98b0922d3bd6f, []int{0}
}

func (m *TimeSegment) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_TimeSegment.Unmarshal(m, b)
}
func (m *TimeSegment) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_TimeSegment.Marshal(b, m, deterministic)
}
func (m *TimeSegment) XXX_Merge(src proto.Message) {
	xxx_messageInfo_TimeSegment.Merge(m, src)
}
func (m *TimeSegment) XXX_Size() int {
	return xxx_messageInfo_TimeSegment.Size(m)
}
func (m *TimeSegment) XXX_DiscardUnknown() {
	xxx_messageInfo_TimeSegment.DiscardUnknown(m)
}

var xxx_messageInfo_TimeSegment proto.InternalMessageInfo

func (m *TimeSegment) GetStartTimeOffset() *duration.Duration {
	if m != nil {
		return m.StartTimeOffset
	}
	return nil
}

func (m *TimeSegment) GetEndTimeOffset() *duration.Duration {
	if m != nil {
		return m.EndTimeOffset
	}
	return nil
}

func init() {
	proto.RegisterType((*TimeSegment)(nil), "google.cloud.automl.v1beta1.TimeSegment")
}

func init() {
	proto.RegisterFile("google/cloud/automl/v1beta1/temporal.proto", fileDescriptor_7ab98b0922d3bd6f)
}

var fileDescriptor_7ab98b0922d3bd6f = []byte{
	// 280 bytes of a gzipped FileDescriptorProto
	0x1f, 0x8b, 0x08, 0x00, 0x00, 0x00, 0x00, 0x00, 0x02, 0xff, 0x84, 0x90, 0xcd, 0x4a, 0xc4, 0x30,
	0x10, 0x80, 0xe9, 0x1e, 0x3c, 0x74, 0x91, 0xc5, 0x9e, 0x74, 0x57, 0x56, 0xf1, 0x24, 0x1e, 0x12,
	0x56, 0x6f, 0xf1, 0x54, 0x7f, 0xf0, 0xa2, 0x28, 0x2a, 0x1e, 0xa4, 0xb0, 0xa4, 0xdb, 0x69, 0x28,
	0x24, 0x99, 0xd2, 0x4e, 0x7d, 0x15, 0x9f, 0xc0, 0x97, 0xf1, 0x51, 0x7c, 0x0a, 0xd9, 0x49, 0x44,
	0x04, 0xd1, 0x63, 0xf8, 0xbe, 0xf9, 0x26, 0x49, 0x7a, 0x64, 0x10, 0x8d, 0x05, 0xb9, 0xb2, 0x38,
	0x54, 0x52, 0x0f, 0x84, 0xce, 0xca, 0x97, 0x45, 0x09, 0xa4, 0x17, 0x92, 0xc0, 0xb5, 0xd8, 0x69,
	0x2b, 0xda, 0x0e, 0x09, 0xb3, 0x59, 0x70, 0x05, 0xbb, 0x22, 0xb8, 0x22, 0xba, 0xd3, 0x79, 0x0c,
	0xb1, 0x5a, 0x0e, 0xb5, 0xac, 0x86, 0x4e, 0x53, 0x83, 0x3e, 0x0c, 0x4f, 0x77, 0x23, 0xd7, 0x6d,
	0x23, 0xb5, 0xf7, 0x48, 0x0c, 0xfb, 0x40, 0x0f, 0x5e, 0x93, 0x74, 0xfc, 0xd8, 0x38, 0x78, 0x00,
	0xe3, 0xc0, 0x53, 0x76, 0x99, 0x6e, 0xf5, 0xa4, 0x3b, 0x5a, 0x52, 0xe3, 0x60, 0x89, 0x75, 0xdd,
	0x03, 0x6d, 0x27, 0xfb, 0xc9, 0xe1, 0xf8, 0x78, 0x47, 0xc4, 0x6b, 0x7c, 0x6d, 0x12, 0x17, 0x71,
	0xd3, 0xfd, 0x84, 0x67, 0xd6, 0x9d, 0x5b, 0x9e, 0xc8, 0xf2, 0x74, 0x02, 0xbe, 0xfa, 0x11, 0x19,
	0xfd, 0x17, 0xd9, 0x04, 0x5f, 0x7d, 0x27, 0xce, 0xde, 0x92, 0x74, 0x6f, 0x85, 0x4e, 0xfc, 0xf1,
	0xf6, 0xbb, 0xe4, 0x39, 0x8f, 0xd8, 0xa0, 0xd5, 0xde, 0x08, 0xec, 0x8c, 0x34, 0xe0, 0x39, 0x2e,
	0x03, 0xd2, 0x6d, 0xd3, 0xff, 0xfa, 0xcb, 0xa7, 0xe1, 0xf8, 0x3e, 0x9a, 0x5d, 0xb1, 0x58, 0x9c,
	0xaf, 0xa5, 0x22, 0x1f, 0x08, 0x6f, 0x6c, 0xf1, 0x14, 0xa4, 0x8f, 0xd1, 0x3c, 0x50, 0xa5, 0x18,
	0x2b, 0xc5, 0xfc, 0x5a, 0xa9, 0x28, 0x94, 0x1b, 0xbc, 0xec, 0xe4, 0x33, 0x00, 0x00, 0xff, 0xff,
	0x96, 0x9e, 0xa0, 0xcd, 0xd1, 0x01, 0x00, 0x00,
}
