// Code generated by protoc-gen-go. DO NOT EDIT.
// source: google/ads/googleads/v2/resources/campaign_feed.proto

package resources

import (
	fmt "fmt"
	math "math"

	proto "github.com/golang/protobuf/proto"
	wrappers "github.com/golang/protobuf/ptypes/wrappers"
	common "google.golang.org/genproto/googleapis/ads/googleads/v2/common"
	enums "google.golang.org/genproto/googleapis/ads/googleads/v2/enums"
	_ "google.golang.org/genproto/googleapis/api/annotations"
)

// Reference imports to suppress errors if they are not otherwise used.
var _ = proto.Marshal
var _ = fmt.Errorf
var _ = math.Inf

// This is a compile-time assertion to ensure that this generated file
// is compatible with the proto package it is being compiled against.
// A compilation error at this line likely means your copy of the
// proto package needs to be updated.
const _ = proto.ProtoPackageIsVersion3 // please upgrade the proto package

// A campaign feed.
type CampaignFeed struct {
	// The resource name of the campaign feed.
	// Campaign feed resource names have the form:
	//
	// `customers/{customer_id}/campaignFeeds/{campaign_id}~{feed_id}
	ResourceName string `protobuf:"bytes,1,opt,name=resource_name,json=resourceName,proto3" json:"resource_name,omitempty"`
	// The feed to which the CampaignFeed belongs.
	Feed *wrappers.StringValue `protobuf:"bytes,2,opt,name=feed,proto3" json:"feed,omitempty"`
	// The campaign to which the CampaignFeed belongs.
	Campaign *wrappers.StringValue `protobuf:"bytes,3,opt,name=campaign,proto3" json:"campaign,omitempty"`
	// Indicates which placeholder types the feed may populate under the connected
	// campaign. Required.
	PlaceholderTypes []enums.PlaceholderTypeEnum_PlaceholderType `protobuf:"varint,4,rep,packed,name=placeholder_types,json=placeholderTypes,proto3,enum=google.ads.googleads.v2.enums.PlaceholderTypeEnum_PlaceholderType" json:"placeholder_types,omitempty"`
	// Matching function associated with the CampaignFeed.
	// The matching function is used to filter the set of feed items selected.
	// Required.
	MatchingFunction *common.MatchingFunction `protobuf:"bytes,5,opt,name=matching_function,json=matchingFunction,proto3" json:"matching_function,omitempty"`
	// Status of the campaign feed.
	// This field is read-only.
	Status               enums.FeedLinkStatusEnum_FeedLinkStatus `protobuf:"varint,6,opt,name=status,proto3,enum=google.ads.googleads.v2.enums.FeedLinkStatusEnum_FeedLinkStatus" json:"status,omitempty"`
	XXX_NoUnkeyedLiteral struct{}                                `json:"-"`
	XXX_unrecognized     []byte                                  `json:"-"`
	XXX_sizecache        int32                                   `json:"-"`
}

func (m *CampaignFeed) Reset()         { *m = CampaignFeed{} }
func (m *CampaignFeed) String() string { return proto.CompactTextString(m) }
func (*CampaignFeed) ProtoMessage()    {}
func (*CampaignFeed) Descriptor() ([]byte, []int) {
	return fileDescriptor_0d62b83685c9f63e, []int{0}
}

func (m *CampaignFeed) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_CampaignFeed.Unmarshal(m, b)
}
func (m *CampaignFeed) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_CampaignFeed.Marshal(b, m, deterministic)
}
func (m *CampaignFeed) XXX_Merge(src proto.Message) {
	xxx_messageInfo_CampaignFeed.Merge(m, src)
}
func (m *CampaignFeed) XXX_Size() int {
	return xxx_messageInfo_CampaignFeed.Size(m)
}
func (m *CampaignFeed) XXX_DiscardUnknown() {
	xxx_messageInfo_CampaignFeed.DiscardUnknown(m)
}

var xxx_messageInfo_CampaignFeed proto.InternalMessageInfo

func (m *CampaignFeed) GetResourceName() string {
	if m != nil {
		return m.ResourceName
	}
	return ""
}

func (m *CampaignFeed) GetFeed() *wrappers.StringValue {
	if m != nil {
		return m.Feed
	}
	return nil
}

func (m *CampaignFeed) GetCampaign() *wrappers.StringValue {
	if m != nil {
		return m.Campaign
	}
	return nil
}

func (m *CampaignFeed) GetPlaceholderTypes() []enums.PlaceholderTypeEnum_PlaceholderType {
	if m != nil {
		return m.PlaceholderTypes
	}
	return nil
}

func (m *CampaignFeed) GetMatchingFunction() *common.MatchingFunction {
	if m != nil {
		return m.MatchingFunction
	}
	return nil
}

func (m *CampaignFeed) GetStatus() enums.FeedLinkStatusEnum_FeedLinkStatus {
	if m != nil {
		return m.Status
	}
	return enums.FeedLinkStatusEnum_UNSPECIFIED
}

func init() {
	proto.RegisterType((*CampaignFeed)(nil), "google.ads.googleads.v2.resources.CampaignFeed")
}

func init() {
	proto.RegisterFile("google/ads/googleads/v2/resources/campaign_feed.proto", fileDescriptor_0d62b83685c9f63e)
}

var fileDescriptor_0d62b83685c9f63e = []byte{
	// 483 bytes of a gzipped FileDescriptorProto
	0x1f, 0x8b, 0x08, 0x00, 0x00, 0x00, 0x00, 0x00, 0x02, 0xff, 0x8c, 0x93, 0xdd, 0x6a, 0xd4, 0x40,
	0x14, 0xc7, 0xc9, 0x6e, 0x5d, 0x74, 0xac, 0xa5, 0x9b, 0xab, 0x50, 0x8a, 0x6c, 0x95, 0xc2, 0x5e,
	0xcd, 0x94, 0xf8, 0x81, 0xc4, 0x1b, 0xb3, 0x62, 0x0b, 0xa2, 0xb2, 0xa4, 0xb2, 0x88, 0xac, 0x84,
	0x69, 0x72, 0x76, 0x1a, 0x9a, 0xf9, 0x20, 0x93, 0x54, 0xfa, 0x3a, 0x5e, 0xfa, 0x26, 0xfa, 0x28,
	0x3e, 0x84, 0x48, 0x92, 0x99, 0x68, 0x57, 0xd2, 0xee, 0xdd, 0xd9, 0x33, 0xff, 0xdf, 0xd9, 0x73,
	0xce, 0xff, 0x04, 0x3d, 0x63, 0x52, 0xb2, 0x1c, 0x08, 0x4d, 0x35, 0x69, 0xc3, 0x3a, 0xba, 0xf4,
	0x49, 0x01, 0x5a, 0x56, 0x45, 0x02, 0x9a, 0x24, 0x94, 0x2b, 0x9a, 0x31, 0x11, 0xaf, 0x00, 0x52,
	0xac, 0x0a, 0x59, 0x4a, 0xf7, 0xa0, 0xd5, 0x62, 0x9a, 0x6a, 0xdc, 0x61, 0xf8, 0xd2, 0xc7, 0x1d,
	0xb6, 0xf7, 0xbc, 0xaf, 0x72, 0x22, 0x39, 0x97, 0x82, 0x70, 0x5a, 0x26, 0xe7, 0x99, 0x60, 0xf1,
	0xaa, 0x12, 0x49, 0x99, 0x49, 0xd1, 0x96, 0xde, 0x7b, 0xda, 0xc7, 0x81, 0xa8, 0xb8, 0x26, 0x75,
	0x13, 0x71, 0x9e, 0x89, 0x8b, 0x58, 0x97, 0xb4, 0xac, 0xf4, 0x66, 0x94, 0xca, 0x69, 0x02, 0xe7,
	0x32, 0x4f, 0xa1, 0x88, 0xcb, 0x2b, 0x05, 0x86, 0x7a, 0x68, 0xa8, 0xe6, 0xd7, 0x59, 0xb5, 0x22,
	0x5f, 0x0b, 0xaa, 0x14, 0x14, 0xb6, 0xea, 0xbe, 0xad, 0xaa, 0x32, 0x42, 0x85, 0x90, 0x25, 0xad,
	0x1b, 0x35, 0xaf, 0x8f, 0x7e, 0x0c, 0xd1, 0xf6, 0x6b, 0xb3, 0x9c, 0x63, 0x80, 0xd4, 0x7d, 0x8c,
	0x1e, 0xd8, 0xf9, 0x63, 0x41, 0x39, 0x78, 0xce, 0xc4, 0x99, 0xde, 0x8b, 0xb6, 0x6d, 0xf2, 0x03,
	0xe5, 0xe0, 0x1e, 0xa1, 0xad, 0x7a, 0x06, 0x6f, 0x30, 0x71, 0xa6, 0xf7, 0xfd, 0x7d, 0xb3, 0x3e,
	0x6c, 0x5b, 0xc0, 0xa7, 0x65, 0x91, 0x09, 0xb6, 0xa0, 0x79, 0x05, 0x51, 0xa3, 0x74, 0x5f, 0xa0,
	0xbb, 0xd6, 0x03, 0x6f, 0xb8, 0x01, 0xd5, 0xa9, 0x5d, 0x89, 0xc6, 0xeb, 0x93, 0x6b, 0x6f, 0x6b,
	0x32, 0x9c, 0xee, 0xf8, 0x33, 0xdc, 0x67, 0x61, 0xb3, 0x31, 0x3c, 0xff, 0xcb, 0x7d, 0xbc, 0x52,
	0xf0, 0x46, 0x54, 0x7c, 0x3d, 0x17, 0xed, 0xaa, 0xeb, 0x09, 0xed, 0x7e, 0x41, 0xe3, 0xff, 0x7c,
	0xf5, 0xee, 0x34, 0x3d, 0x1f, 0xf5, 0xfe, 0x61, 0x7b, 0x10, 0xf8, 0xbd, 0x01, 0x8f, 0x0d, 0x17,
	0xed, 0xf2, 0xb5, 0x8c, 0xfb, 0x09, 0x8d, 0x5a, 0xd7, 0xbd, 0xd1, 0xc4, 0x99, 0xee, 0xf8, 0xaf,
	0x6e, 0x19, 0xa2, 0x76, 0xe5, 0x5d, 0x26, 0x2e, 0x4e, 0x1b, 0xa8, 0x99, 0xe1, 0x7a, 0x2a, 0x32,
	0xf5, 0x66, 0xbf, 0x1d, 0x74, 0x98, 0x48, 0x8e, 0x6f, 0xbd, 0xeb, 0xd9, 0xf8, 0x5f, 0xcb, 0xe7,
	0xf5, 0xfe, 0xe7, 0xce, 0xe7, 0xb7, 0x86, 0x63, 0x32, 0xa7, 0x82, 0x61, 0x59, 0x30, 0xc2, 0x40,
	0x34, 0xee, 0xd8, 0x73, 0x54, 0x99, 0xbe, 0xe1, 0x2b, 0x7b, 0xd9, 0x45, 0xdf, 0x06, 0xc3, 0x93,
	0x30, 0xfc, 0x3e, 0x38, 0x38, 0x69, 0x4b, 0x86, 0xa9, 0xc6, 0x6d, 0x58, 0x47, 0x0b, 0x1f, 0x47,
	0x56, 0xf9, 0xd3, 0x6a, 0x96, 0x61, 0xaa, 0x97, 0x9d, 0x66, 0xb9, 0xf0, 0x97, 0x9d, 0xe6, 0xd7,
	0xe0, 0xb0, 0x7d, 0x08, 0x82, 0x30, 0xd5, 0x41, 0xd0, 0xa9, 0x82, 0x60, 0xe1, 0x07, 0x41, 0xa7,
	0x3b, 0x1b, 0x35, 0xcd, 0x3e, 0xf9, 0x13, 0x00, 0x00, 0xff, 0xff, 0xbb, 0xa4, 0x8e, 0xc8, 0x11,
	0x04, 0x00, 0x00,
}
