// Code generated by protoc-gen-go. DO NOT EDIT.
// source: google/ads/googleads/v2/enums/feed_origin.proto

package enums

import (
	fmt "fmt"
	math "math"

	proto "github.com/golang/protobuf/proto"
	_ "google.golang.org/genproto/googleapis/api/annotations"
)

// Reference imports to suppress errors if they are not otherwise used.
var _ = proto.Marshal
var _ = fmt.Errorf
var _ = math.Inf

// This is a compile-time assertion to ensure that this generated file
// is compatible with the proto package it is being compiled against.
// A compilation error at this line likely means your copy of the
// proto package needs to be updated.
const _ = proto.ProtoPackageIsVersion3 // please upgrade the proto package

// Possible values for a feed origin.
type FeedOriginEnum_FeedOrigin int32

const (
	// Not specified.
	FeedOriginEnum_UNSPECIFIED FeedOriginEnum_FeedOrigin = 0
	// Used for return value only. Represents value unknown in this version.
	FeedOriginEnum_UNKNOWN FeedOriginEnum_FeedOrigin = 1
	// The FeedAttributes for this Feed are managed by the
	// user. Users can add FeedAttributes to this Feed.
	FeedOriginEnum_USER FeedOriginEnum_FeedOrigin = 2
	// The FeedAttributes for an GOOGLE Feed are created by Google. A feed of
	// this type is maintained by Google and will have the correct attributes
	// for the placeholder type of the feed.
	FeedOriginEnum_GOOGLE FeedOriginEnum_FeedOrigin = 3
)

var FeedOriginEnum_FeedOrigin_name = map[int32]string{
	0: "UNSPECIFIED",
	1: "UNKNOWN",
	2: "USER",
	3: "GOOGLE",
}

var FeedOriginEnum_FeedOrigin_value = map[string]int32{
	"UNSPECIFIED": 0,
	"UNKNOWN":     1,
	"USER":        2,
	"GOOGLE":      3,
}

func (x FeedOriginEnum_FeedOrigin) String() string {
	return proto.EnumName(FeedOriginEnum_FeedOrigin_name, int32(x))
}

func (FeedOriginEnum_FeedOrigin) EnumDescriptor() ([]byte, []int) {
	return fileDescriptor_ecdea2469f0758a0, []int{0, 0}
}

// Container for enum describing possible values for a feed origin.
type FeedOriginEnum struct {
	XXX_NoUnkeyedLiteral struct{} `json:"-"`
	XXX_unrecognized     []byte   `json:"-"`
	XXX_sizecache        int32    `json:"-"`
}

func (m *FeedOriginEnum) Reset()         { *m = FeedOriginEnum{} }
func (m *FeedOriginEnum) String() string { return proto.CompactTextString(m) }
func (*FeedOriginEnum) ProtoMessage()    {}
func (*FeedOriginEnum) Descriptor() ([]byte, []int) {
	return fileDescriptor_ecdea2469f0758a0, []int{0}
}

func (m *FeedOriginEnum) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_FeedOriginEnum.Unmarshal(m, b)
}
func (m *FeedOriginEnum) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_FeedOriginEnum.Marshal(b, m, deterministic)
}
func (m *FeedOriginEnum) XXX_Merge(src proto.Message) {
	xxx_messageInfo_FeedOriginEnum.Merge(m, src)
}
func (m *FeedOriginEnum) XXX_Size() int {
	return xxx_messageInfo_FeedOriginEnum.Size(m)
}
func (m *FeedOriginEnum) XXX_DiscardUnknown() {
	xxx_messageInfo_FeedOriginEnum.DiscardUnknown(m)
}

var xxx_messageInfo_FeedOriginEnum proto.InternalMessageInfo

func init() {
	proto.RegisterEnum("google.ads.googleads.v2.enums.FeedOriginEnum_FeedOrigin", FeedOriginEnum_FeedOrigin_name, FeedOriginEnum_FeedOrigin_value)
	proto.RegisterType((*FeedOriginEnum)(nil), "google.ads.googleads.v2.enums.FeedOriginEnum")
}

func init() {
	proto.RegisterFile("google/ads/googleads/v2/enums/feed_origin.proto", fileDescriptor_ecdea2469f0758a0)
}

var fileDescriptor_ecdea2469f0758a0 = []byte{
	// 293 bytes of a gzipped FileDescriptorProto
	0x1f, 0x8b, 0x08, 0x00, 0x00, 0x00, 0x00, 0x00, 0x02, 0xff, 0x7c, 0x50, 0x4d, 0x4a, 0xc3, 0x40,
	0x14, 0x36, 0xa9, 0x54, 0x99, 0x82, 0x0d, 0x59, 0x8a, 0x5d, 0xb4, 0x07, 0x98, 0x81, 0xb8, 0x1b,
	0x37, 0x26, 0x9a, 0x86, 0xa2, 0x24, 0xa1, 0x25, 0x11, 0x24, 0x20, 0xd1, 0x19, 0x87, 0x40, 0x33,
	0x2f, 0x64, 0xd2, 0x1e, 0xc8, 0xa5, 0x47, 0xf1, 0x1c, 0xae, 0x3c, 0x85, 0x64, 0xd2, 0xa4, 0x2b,
	0xdd, 0x0c, 0x1f, 0xef, 0xfb, 0x99, 0xef, 0x3d, 0x44, 0x04, 0x80, 0xd8, 0x72, 0x92, 0x33, 0x75,
	0x80, 0x2d, 0xda, 0x3b, 0x84, 0xcb, 0x5d, 0xa9, 0xc8, 0x3b, 0xe7, 0xec, 0x05, 0xea, 0x42, 0x14,
	0x12, 0x57, 0x35, 0x34, 0x60, 0xcf, 0x3a, 0x15, 0xce, 0x99, 0xc2, 0x83, 0x01, 0xef, 0x1d, 0xac,
	0x0d, 0x97, 0x57, 0x7d, 0x5e, 0x55, 0x90, 0x5c, 0x4a, 0x68, 0xf2, 0xa6, 0x00, 0xa9, 0x3a, 0xf3,
	0x62, 0x8d, 0x2e, 0x96, 0x9c, 0xb3, 0x48, 0x07, 0xfa, 0x72, 0x57, 0x2e, 0x6e, 0x11, 0x3a, 0x4e,
	0xec, 0x29, 0x9a, 0x24, 0xe1, 0x26, 0xf6, 0xef, 0x56, 0xcb, 0x95, 0x7f, 0x6f, 0x9d, 0xd8, 0x13,
	0x74, 0x96, 0x84, 0x0f, 0x61, 0xf4, 0x14, 0x5a, 0x86, 0x7d, 0x8e, 0x4e, 0x93, 0x8d, 0xbf, 0xb6,
	0x4c, 0x1b, 0xa1, 0x71, 0x10, 0x45, 0xc1, 0xa3, 0x6f, 0x8d, 0xbc, 0x6f, 0x03, 0xcd, 0xdf, 0xa0,
	0xc4, 0xff, 0xf6, 0xf2, 0xa6, 0xc7, 0x5f, 0xe2, 0xb6, 0x4a, 0x6c, 0x3c, 0x7b, 0x07, 0x87, 0x80,
	0x6d, 0x2e, 0x05, 0x86, 0x5a, 0x10, 0xc1, 0xa5, 0x2e, 0xda, 0x9f, 0xa2, 0x2a, 0xd4, 0x1f, 0x97,
	0xb9, 0xd1, 0xef, 0x87, 0x39, 0x0a, 0x5c, 0xf7, 0xd3, 0x9c, 0x05, 0x5d, 0x94, 0xcb, 0x14, 0xee,
	0x60, 0x8b, 0x52, 0x07, 0xb7, 0x3b, 0xaa, 0xaf, 0x9e, 0xcf, 0x5c, 0xa6, 0xb2, 0x81, 0xcf, 0x52,
	0x27, 0xd3, 0xfc, 0x8f, 0x39, 0xef, 0x86, 0x94, 0xba, 0x4c, 0x51, 0x3a, 0x28, 0x28, 0x4d, 0x1d,
	0x4a, 0xb5, 0xe6, 0x75, 0xac, 0x8b, 0x5d, 0xff, 0x06, 0x00, 0x00, 0xff, 0xff, 0x04, 0x3c, 0x87,
	0x25, 0xb1, 0x01, 0x00, 0x00,
}
