// Code generated by protoc-gen-go. DO NOT EDIT.
// source: google/ads/googleads/v1/resources/campaign_experiment.proto

package resources

import (
	fmt "fmt"
	math "math"

	proto "github.com/golang/protobuf/proto"
	wrappers "github.com/golang/protobuf/ptypes/wrappers"
	enums "google.golang.org/genproto/googleapis/ads/googleads/v1/enums"
	_ "google.golang.org/genproto/googleapis/api/annotations"
)

// Reference imports to suppress errors if they are not otherwise used.
var _ = proto.Marshal
var _ = fmt.Errorf
var _ = math.Inf

// This is a compile-time assertion to ensure that this generated file
// is compatible with the proto package it is being compiled against.
// A compilation error at this line likely means your copy of the
// proto package needs to be updated.
const _ = proto.ProtoPackageIsVersion3 // please upgrade the proto package

// An A/B experiment that compares the performance of the base campaign
// (the control) and a variation of that campaign (the experiment).
type CampaignExperiment struct {
	// The resource name of the campaign experiment.
	// Campaign experiment resource names have the form:
	//
	// `customers/{customer_id}/campaignExperiments/{campaign_experiment_id}`
	ResourceName string `protobuf:"bytes,1,opt,name=resource_name,json=resourceName,proto3" json:"resource_name,omitempty"`
	// The ID of the campaign experiment.
	//
	// This field is read-only.
	Id *wrappers.Int64Value `protobuf:"bytes,2,opt,name=id,proto3" json:"id,omitempty"`
	// The campaign draft with staged changes to the base campaign.
	CampaignDraft *wrappers.StringValue `protobuf:"bytes,3,opt,name=campaign_draft,json=campaignDraft,proto3" json:"campaign_draft,omitempty"`
	// The name of the campaign experiment.
	//
	// This field is required when creating new campaign experiments
	// and must not conflict with the name of another non-removed
	// campaign experiment or campaign.
	//
	// It must not contain any null (code point 0x0), NL line feed
	// (code point 0xA) or carriage return (code point 0xD) characters.
	Name *wrappers.StringValue `protobuf:"bytes,4,opt,name=name,proto3" json:"name,omitempty"`
	// The description of the experiment.
	Description *wrappers.StringValue `protobuf:"bytes,5,opt,name=description,proto3" json:"description,omitempty"`
	// Share of traffic directed to experiment as a percent (must be between 1 and
	// 99 inclusive. Base campaign receives the remainder of the traffic
	// (100 - traffic_split_percent). Required for create.
	TrafficSplitPercent *wrappers.Int64Value `protobuf:"bytes,6,opt,name=traffic_split_percent,json=trafficSplitPercent,proto3" json:"traffic_split_percent,omitempty"`
	// Determines the behavior of the traffic split.
	TrafficSplitType enums.CampaignExperimentTrafficSplitTypeEnum_CampaignExperimentTrafficSplitType `protobuf:"varint,7,opt,name=traffic_split_type,json=trafficSplitType,proto3,enum=google.ads.googleads.v1.enums.CampaignExperimentTrafficSplitTypeEnum_CampaignExperimentTrafficSplitType" json:"traffic_split_type,omitempty"`
	// The experiment campaign, as opposed to the base campaign.
	ExperimentCampaign *wrappers.StringValue `protobuf:"bytes,8,opt,name=experiment_campaign,json=experimentCampaign,proto3" json:"experiment_campaign,omitempty"`
	// The status of the campaign experiment. This field is read-only.
	Status enums.CampaignExperimentStatusEnum_CampaignExperimentStatus `protobuf:"varint,9,opt,name=status,proto3,enum=google.ads.googleads.v1.enums.CampaignExperimentStatusEnum_CampaignExperimentStatus" json:"status,omitempty"`
	// The resource name of the long-running operation that can be used to poll
	// for completion of experiment create or promote. The most recent long
	// running operation is returned.
	LongRunningOperation *wrappers.StringValue `protobuf:"bytes,10,opt,name=long_running_operation,json=longRunningOperation,proto3" json:"long_running_operation,omitempty"`
	// Date when the campaign experiment starts. By default, the experiment starts
	// now or on the campaign's start date, whichever is later. If this field is
	// set, then the experiment starts at the beginning of the specified date in
	// the customer's time zone. Cannot be changed once the experiment starts.
	//
	// Format: YYYY-MM-DD
	// Example: 2019-03-14
	StartDate *wrappers.StringValue `protobuf:"bytes,11,opt,name=start_date,json=startDate,proto3" json:"start_date,omitempty"`
	// Date when the campaign experiment ends. By default, the experiment ends on
	// the campaign's end date. If this field is set, then the experiment ends at
	// the end of the specified date in the customer's time zone.
	//
	// Format: YYYY-MM-DD
	// Example: 2019-04-18
	EndDate              *wrappers.StringValue `protobuf:"bytes,12,opt,name=end_date,json=endDate,proto3" json:"end_date,omitempty"`
	XXX_NoUnkeyedLiteral struct{}              `json:"-"`
	XXX_unrecognized     []byte                `json:"-"`
	XXX_sizecache        int32                 `json:"-"`
}

func (m *CampaignExperiment) Reset()         { *m = CampaignExperiment{} }
func (m *CampaignExperiment) String() string { return proto.CompactTextString(m) }
func (*CampaignExperiment) ProtoMessage()    {}
func (*CampaignExperiment) Descriptor() ([]byte, []int) {
	return fileDescriptor_34963f70880a8622, []int{0}
}

func (m *CampaignExperiment) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_CampaignExperiment.Unmarshal(m, b)
}
func (m *CampaignExperiment) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_CampaignExperiment.Marshal(b, m, deterministic)
}
func (m *CampaignExperiment) XXX_Merge(src proto.Message) {
	xxx_messageInfo_CampaignExperiment.Merge(m, src)
}
func (m *CampaignExperiment) XXX_Size() int {
	return xxx_messageInfo_CampaignExperiment.Size(m)
}
func (m *CampaignExperiment) XXX_DiscardUnknown() {
	xxx_messageInfo_CampaignExperiment.DiscardUnknown(m)
}

var xxx_messageInfo_CampaignExperiment proto.InternalMessageInfo

func (m *CampaignExperiment) GetResourceName() string {
	if m != nil {
		return m.ResourceName
	}
	return ""
}

func (m *CampaignExperiment) GetId() *wrappers.Int64Value {
	if m != nil {
		return m.Id
	}
	return nil
}

func (m *CampaignExperiment) GetCampaignDraft() *wrappers.StringValue {
	if m != nil {
		return m.CampaignDraft
	}
	return nil
}

func (m *CampaignExperiment) GetName() *wrappers.StringValue {
	if m != nil {
		return m.Name
	}
	return nil
}

func (m *CampaignExperiment) GetDescription() *wrappers.StringValue {
	if m != nil {
		return m.Description
	}
	return nil
}

func (m *CampaignExperiment) GetTrafficSplitPercent() *wrappers.Int64Value {
	if m != nil {
		return m.TrafficSplitPercent
	}
	return nil
}

func (m *CampaignExperiment) GetTrafficSplitType() enums.CampaignExperimentTrafficSplitTypeEnum_CampaignExperimentTrafficSplitType {
	if m != nil {
		return m.TrafficSplitType
	}
	return enums.CampaignExperimentTrafficSplitTypeEnum_UNSPECIFIED
}

func (m *CampaignExperiment) GetExperimentCampaign() *wrappers.StringValue {
	if m != nil {
		return m.ExperimentCampaign
	}
	return nil
}

func (m *CampaignExperiment) GetStatus() enums.CampaignExperimentStatusEnum_CampaignExperimentStatus {
	if m != nil {
		return m.Status
	}
	return enums.CampaignExperimentStatusEnum_UNSPECIFIED
}

func (m *CampaignExperiment) GetLongRunningOperation() *wrappers.StringValue {
	if m != nil {
		return m.LongRunningOperation
	}
	return nil
}

func (m *CampaignExperiment) GetStartDate() *wrappers.StringValue {
	if m != nil {
		return m.StartDate
	}
	return nil
}

func (m *CampaignExperiment) GetEndDate() *wrappers.StringValue {
	if m != nil {
		return m.EndDate
	}
	return nil
}

func init() {
	proto.RegisterType((*CampaignExperiment)(nil), "google.ads.googleads.v1.resources.CampaignExperiment")
}

func init() {
	proto.RegisterFile("google/ads/googleads/v1/resources/campaign_experiment.proto", fileDescriptor_34963f70880a8622)
}

var fileDescriptor_34963f70880a8622 = []byte{
	// 585 bytes of a gzipped FileDescriptorProto
	0x1f, 0x8b, 0x08, 0x00, 0x00, 0x00, 0x00, 0x00, 0x02, 0xff, 0x94, 0x94, 0x5d, 0x6b, 0xd4, 0x4c,
	0x14, 0xc7, 0x49, 0xda, 0xa7, 0x2f, 0xd3, 0x17, 0x1e, 0xa6, 0xbe, 0x84, 0x5a, 0xa4, 0x55, 0x0a,
	0x05, 0x61, 0xe2, 0x56, 0x51, 0x48, 0xa1, 0xb0, 0x7d, 0xa1, 0x28, 0x68, 0x4b, 0x5a, 0xf6, 0x42,
	0x16, 0xc2, 0x34, 0x33, 0x1b, 0x07, 0x92, 0x99, 0x61, 0x66, 0x52, 0xed, 0xbd, 0xd7, 0x5e, 0xfa,
	0x01, 0xbc, 0xf4, 0xa3, 0xf8, 0x51, 0xfc, 0x14, 0x92, 0x4c, 0x26, 0xae, 0xae, 0x6b, 0xd3, 0xbb,
	0x93, 0xcc, 0xff, 0x77, 0xfe, 0x73, 0xce, 0x1c, 0x0e, 0xd8, 0xcb, 0x84, 0xc8, 0x72, 0x1a, 0x62,
	0xa2, 0x43, 0x1b, 0x56, 0xd1, 0x55, 0x2f, 0x54, 0x54, 0x8b, 0x52, 0xa5, 0x54, 0x87, 0x29, 0x2e,
	0x24, 0x66, 0x19, 0x4f, 0xe8, 0x47, 0x49, 0x15, 0x2b, 0x28, 0x37, 0x48, 0x2a, 0x61, 0x04, 0xdc,
	0xb2, 0x04, 0xc2, 0x44, 0xa3, 0x16, 0x46, 0x57, 0x3d, 0xd4, 0xc2, 0xeb, 0xfb, 0xd3, 0xf2, 0x53,
	0x5e, 0x16, 0x7f, 0xcd, 0x9d, 0x68, 0x83, 0x4d, 0xa9, 0xad, 0xc5, 0xfa, 0xeb, 0xdb, 0xf3, 0x46,
	0xe1, 0xd1, 0x88, 0xa5, 0x89, 0x96, 0x39, 0x33, 0x89, 0xb9, 0x96, 0xb4, 0xc9, 0xf5, 0xb0, 0xc9,
	0x55, 0x7f, 0x5d, 0x96, 0xa3, 0xf0, 0x83, 0xc2, 0x52, 0x52, 0xe5, 0xbc, 0x36, 0x9c, 0x97, 0x64,
	0x21, 0xe6, 0x5c, 0x18, 0x6c, 0x98, 0xe0, 0xcd, 0xe9, 0xa3, 0xcf, 0xf3, 0x00, 0x1e, 0x36, 0x76,
	0xc7, 0xad, 0x1b, 0x7c, 0x0c, 0x56, 0x5c, 0xb5, 0x09, 0xc7, 0x05, 0x0d, 0xbc, 0x4d, 0x6f, 0x67,
	0x31, 0x5e, 0x76, 0x3f, 0xdf, 0xe2, 0x82, 0xc2, 0x27, 0xc0, 0x67, 0x24, 0xf0, 0x37, 0xbd, 0x9d,
	0xa5, 0xdd, 0x07, 0x4d, 0xab, 0x90, 0xbb, 0x06, 0x7a, 0xc5, 0xcd, 0x8b, 0xe7, 0x03, 0x9c, 0x97,
	0x34, 0xf6, 0x19, 0x81, 0x87, 0x60, 0xb5, 0x2d, 0x8b, 0x28, 0x3c, 0x32, 0xc1, 0x4c, 0x0d, 0x6e,
	0x4c, 0x80, 0xe7, 0x46, 0x31, 0x9e, 0x59, 0x72, 0xc5, 0x31, 0x47, 0x15, 0x02, 0x9f, 0x82, 0xd9,
	0xfa, 0x36, 0xb3, 0x1d, 0xd0, 0x5a, 0x09, 0xf7, 0xc1, 0x12, 0xa1, 0x3a, 0x55, 0x4c, 0x56, 0x55,
	0x07, 0xff, 0x75, 0x00, 0xc7, 0x01, 0x78, 0x0a, 0xee, 0xfe, 0xde, 0x79, 0x49, 0x55, 0x4a, 0xb9,
	0x09, 0xe6, 0x6e, 0x2e, 0x7b, 0xad, 0x21, 0xcf, 0x2b, 0xf0, 0xcc, 0x72, 0xf0, 0x8b, 0x07, 0xe0,
	0xe4, 0x5b, 0x06, 0xf3, 0x9b, 0xde, 0xce, 0xea, 0xee, 0x7b, 0x34, 0x6d, 0xf6, 0xea, 0xc1, 0x40,
	0x93, 0x2f, 0x75, 0x31, 0x66, 0x71, 0x71, 0x2d, 0xe9, 0x31, 0x2f, 0x8b, 0x0e, 0xb2, 0xf8, 0x7f,
	0xf3, 0xc7, 0x1f, 0xf8, 0x06, 0xac, 0x8d, 0x8d, 0x9b, 0xeb, 0x7b, 0xb0, 0xd0, 0xa1, 0x63, 0xf0,
	0x17, 0xe8, 0xac, 0x61, 0x0e, 0xe6, 0xec, 0xc8, 0x07, 0x8b, 0x75, 0x69, 0x17, 0xb7, 0x2e, 0xed,
	0xbc, 0xc6, 0xa7, 0x14, 0x64, 0x0f, 0xe3, 0xc6, 0x03, 0xc6, 0xe0, 0x5e, 0x2e, 0x78, 0x96, 0xa8,
	0x92, 0x73, 0xc6, 0xb3, 0x44, 0x48, 0xaa, 0xea, 0x39, 0x0f, 0x40, 0x87, 0xfb, 0xdf, 0xa9, 0xd8,
	0xd8, 0xa2, 0xa7, 0x8e, 0x84, 0x7b, 0x00, 0x68, 0x83, 0x95, 0x49, 0x08, 0x36, 0x34, 0x58, 0xea,
	0x90, 0x67, 0xb1, 0xd6, 0x1f, 0x61, 0x43, 0xe1, 0x4b, 0xb0, 0x40, 0x39, 0xb1, 0xe8, 0x72, 0x07,
	0x74, 0x9e, 0x72, 0x52, 0x81, 0x07, 0x9f, 0x7c, 0xb0, 0x9d, 0x8a, 0x02, 0xdd, 0xb8, 0x84, 0x0e,
	0xee, 0x4f, 0x76, 0xe5, 0xac, 0x4a, 0x7d, 0xe6, 0xbd, 0x6b, 0xf6, 0x0b, 0xca, 0x44, 0x8e, 0x79,
	0x86, 0x84, 0xca, 0xc2, 0x8c, 0xf2, 0xda, 0xd8, 0xed, 0x1b, 0xc9, 0xf4, 0x3f, 0xd6, 0xe3, 0x5e,
	0x1b, 0x7d, 0xf5, 0x67, 0x4e, 0xfa, 0xfd, 0x6f, 0xfe, 0xd6, 0x89, 0x4d, 0xd9, 0x27, 0x1a, 0xd9,
	0xb0, 0x8a, 0x06, 0x3d, 0x14, 0x3b, 0xe5, 0x77, 0xa7, 0x19, 0xf6, 0x89, 0x1e, 0xb6, 0x9a, 0xe1,
	0xa0, 0x37, 0x6c, 0x35, 0x3f, 0xfc, 0x6d, 0x7b, 0x10, 0x45, 0x7d, 0xa2, 0xa3, 0xa8, 0x55, 0x45,
	0xd1, 0xa0, 0x17, 0x45, 0xad, 0xee, 0x72, 0xae, 0xbe, 0xec, 0xb3, 0x9f, 0x01, 0x00, 0x00, 0xff,
	0xff, 0x97, 0x9e, 0x87, 0x83, 0xca, 0x05, 0x00, 0x00,
}
