// Code generated by protoc-gen-go. DO NOT EDIT.
// source: google/ads/googleads/v2/resources/shared_set.proto

package resources

import (
	fmt "fmt"
	math "math"

	proto "github.com/golang/protobuf/proto"
	wrappers "github.com/golang/protobuf/ptypes/wrappers"
	enums "google.golang.org/genproto/googleapis/ads/googleads/v2/enums"
	_ "google.golang.org/genproto/googleapis/api/annotations"
)

// Reference imports to suppress errors if they are not otherwise used.
var _ = proto.Marshal
var _ = fmt.Errorf
var _ = math.Inf

// This is a compile-time assertion to ensure that this generated file
// is compatible with the proto package it is being compiled against.
// A compilation error at this line likely means your copy of the
// proto package needs to be updated.
const _ = proto.ProtoPackageIsVersion3 // please upgrade the proto package

// SharedSets are used for sharing criterion exclusions across multiple
// campaigns.
type SharedSet struct {
	// The resource name of the shared set.
	// Shared set resource names have the form:
	//
	// `customers/{customer_id}/sharedSets/{shared_set_id}`
	ResourceName string `protobuf:"bytes,1,opt,name=resource_name,json=resourceName,proto3" json:"resource_name,omitempty"`
	// The ID of this shared set. Read only.
	Id *wrappers.Int64Value `protobuf:"bytes,2,opt,name=id,proto3" json:"id,omitempty"`
	// The type of this shared set: each shared set holds only a single kind
	// of resource. Required. Immutable.
	Type enums.SharedSetTypeEnum_SharedSetType `protobuf:"varint,3,opt,name=type,proto3,enum=google.ads.googleads.v2.enums.SharedSetTypeEnum_SharedSetType" json:"type,omitempty"`
	// The name of this shared set. Required.
	// Shared Sets must have names that are unique among active shared sets of
	// the same type.
	// The length of this string should be between 1 and 255 UTF-8 bytes,
	// inclusive.
	Name *wrappers.StringValue `protobuf:"bytes,4,opt,name=name,proto3" json:"name,omitempty"`
	// The status of this shared set. Read only.
	Status enums.SharedSetStatusEnum_SharedSetStatus `protobuf:"varint,5,opt,name=status,proto3,enum=google.ads.googleads.v2.enums.SharedSetStatusEnum_SharedSetStatus" json:"status,omitempty"`
	// The number of shared criteria within this shared set. Read only.
	MemberCount *wrappers.Int64Value `protobuf:"bytes,6,opt,name=member_count,json=memberCount,proto3" json:"member_count,omitempty"`
	// The number of campaigns associated with this shared set. Read only.
	ReferenceCount       *wrappers.Int64Value `protobuf:"bytes,7,opt,name=reference_count,json=referenceCount,proto3" json:"reference_count,omitempty"`
	XXX_NoUnkeyedLiteral struct{}             `json:"-"`
	XXX_unrecognized     []byte               `json:"-"`
	XXX_sizecache        int32                `json:"-"`
}

func (m *SharedSet) Reset()         { *m = SharedSet{} }
func (m *SharedSet) String() string { return proto.CompactTextString(m) }
func (*SharedSet) ProtoMessage()    {}
func (*SharedSet) Descriptor() ([]byte, []int) {
	return fileDescriptor_e01c233388407949, []int{0}
}

func (m *SharedSet) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_SharedSet.Unmarshal(m, b)
}
func (m *SharedSet) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_SharedSet.Marshal(b, m, deterministic)
}
func (m *SharedSet) XXX_Merge(src proto.Message) {
	xxx_messageInfo_SharedSet.Merge(m, src)
}
func (m *SharedSet) XXX_Size() int {
	return xxx_messageInfo_SharedSet.Size(m)
}
func (m *SharedSet) XXX_DiscardUnknown() {
	xxx_messageInfo_SharedSet.DiscardUnknown(m)
}

var xxx_messageInfo_SharedSet proto.InternalMessageInfo

func (m *SharedSet) GetResourceName() string {
	if m != nil {
		return m.ResourceName
	}
	return ""
}

func (m *SharedSet) GetId() *wrappers.Int64Value {
	if m != nil {
		return m.Id
	}
	return nil
}

func (m *SharedSet) GetType() enums.SharedSetTypeEnum_SharedSetType {
	if m != nil {
		return m.Type
	}
	return enums.SharedSetTypeEnum_UNSPECIFIED
}

func (m *SharedSet) GetName() *wrappers.StringValue {
	if m != nil {
		return m.Name
	}
	return nil
}

func (m *SharedSet) GetStatus() enums.SharedSetStatusEnum_SharedSetStatus {
	if m != nil {
		return m.Status
	}
	return enums.SharedSetStatusEnum_UNSPECIFIED
}

func (m *SharedSet) GetMemberCount() *wrappers.Int64Value {
	if m != nil {
		return m.MemberCount
	}
	return nil
}

func (m *SharedSet) GetReferenceCount() *wrappers.Int64Value {
	if m != nil {
		return m.ReferenceCount
	}
	return nil
}

func init() {
	proto.RegisterType((*SharedSet)(nil), "google.ads.googleads.v2.resources.SharedSet")
}

func init() {
	proto.RegisterFile("google/ads/googleads/v2/resources/shared_set.proto", fileDescriptor_e01c233388407949)
}

var fileDescriptor_e01c233388407949 = []byte{
	// 456 bytes of a gzipped FileDescriptorProto
	0x1f, 0x8b, 0x08, 0x00, 0x00, 0x00, 0x00, 0x00, 0x02, 0xff, 0x8c, 0x93, 0x41, 0x6b, 0xd4, 0x40,
	0x14, 0xc7, 0x49, 0x76, 0x5d, 0xe9, 0xb4, 0xae, 0x90, 0x53, 0xa8, 0x45, 0xb6, 0x4a, 0x61, 0x41,
	0x98, 0x48, 0xaa, 0x1e, 0x46, 0x28, 0x64, 0x55, 0x8a, 0x1e, 0xa4, 0x64, 0x65, 0x0f, 0x65, 0x61,
	0x99, 0xcd, 0xbc, 0xc6, 0xc0, 0x66, 0x26, 0xcc, 0x4c, 0x2a, 0xfd, 0x3a, 0x1e, 0xfd, 0x1e, 0x5e,
	0xfc, 0x28, 0x7e, 0x05, 0x2f, 0x92, 0x99, 0xcc, 0x60, 0x91, 0x76, 0xf7, 0xf6, 0xf2, 0xe6, 0xff,
	0xff, 0xcd, 0xff, 0x3d, 0x26, 0x28, 0x2d, 0x85, 0x28, 0x37, 0x90, 0x50, 0xa6, 0x12, 0x5b, 0x76,
	0xd5, 0x75, 0x9a, 0x48, 0x50, 0xa2, 0x95, 0x05, 0xa8, 0x44, 0x7d, 0xa5, 0x12, 0xd8, 0x4a, 0x81,
	0xc6, 0x8d, 0x14, 0x5a, 0x44, 0xc7, 0x56, 0x88, 0x29, 0x53, 0xd8, 0x7b, 0xf0, 0x75, 0x8a, 0xbd,
	0xe7, 0xf0, 0xf5, 0x5d, 0x58, 0xe0, 0x6d, 0xfd, 0x2f, 0x72, 0xa5, 0x34, 0xd5, 0xad, 0xb2, 0xe4,
	0xc3, 0xd3, 0x9d, 0x6d, 0xfa, 0xa6, 0x81, 0xde, 0xf4, 0xb4, 0x37, 0x99, 0xaf, 0x75, 0x7b, 0x95,
	0x7c, 0x93, 0xb4, 0x69, 0x40, 0x3a, 0xe8, 0x91, 0x83, 0x36, 0x55, 0x42, 0x39, 0x17, 0x9a, 0xea,
	0x4a, 0xf0, 0xfe, 0xf4, 0xd9, 0xcf, 0x01, 0xda, 0x9b, 0x1b, 0xee, 0x1c, 0x74, 0xf4, 0x1c, 0x3d,
	0x72, 0x43, 0xac, 0x38, 0xad, 0x21, 0x0e, 0x26, 0xc1, 0x74, 0x2f, 0x3f, 0x70, 0xcd, 0xcf, 0xb4,
	0x86, 0xe8, 0x05, 0x0a, 0x2b, 0x16, 0x87, 0x93, 0x60, 0xba, 0x9f, 0x3e, 0xe9, 0x37, 0x80, 0xdd,
	0xed, 0xf8, 0x23, 0xd7, 0x6f, 0x5e, 0x2d, 0xe8, 0xa6, 0x85, 0x3c, 0xac, 0x58, 0x94, 0xa3, 0x61,
	0x97, 0x35, 0x1e, 0x4c, 0x82, 0xe9, 0x38, 0x3d, 0xc3, 0x77, 0xed, 0xce, 0x4c, 0x88, 0x7d, 0x92,
	0x2f, 0x37, 0x0d, 0x7c, 0xe0, 0x6d, 0x7d, 0xbb, 0x93, 0x1b, 0x56, 0xf4, 0x12, 0x0d, 0x4d, 0xb8,
	0xa1, 0x89, 0x70, 0xf4, 0x5f, 0x84, 0xb9, 0x96, 0x15, 0x2f, 0x6d, 0x06, 0xa3, 0x8c, 0x2e, 0xd1,
	0xc8, 0x2e, 0x3a, 0x7e, 0x60, 0x72, 0xcc, 0x76, 0xcd, 0x31, 0x37, 0xae, 0xdb, 0x49, 0x6c, 0x2f,
	0xef, 0x89, 0xd1, 0x19, 0x3a, 0xa8, 0xa1, 0x5e, 0x83, 0x5c, 0x15, 0xa2, 0xe5, 0x3a, 0x1e, 0x6d,
	0x5f, 0xcc, 0xbe, 0x35, 0xbc, 0xeb, 0xf4, 0xd1, 0x7b, 0xf4, 0x58, 0xc2, 0x15, 0x48, 0xe0, 0x05,
	0xf4, 0x88, 0x87, 0xdb, 0x11, 0x63, 0xef, 0x31, 0x94, 0xd9, 0x9f, 0x00, 0x9d, 0x14, 0xa2, 0xc6,
	0x5b, 0xdf, 0xe6, 0x6c, 0xec, 0x07, 0xb9, 0xe8, 0xb8, 0x17, 0xc1, 0xe5, 0xa7, 0xde, 0x54, 0x8a,
	0x0d, 0xe5, 0x25, 0x16, 0xb2, 0x4c, 0x4a, 0xe0, 0xe6, 0x56, 0xf7, 0x0c, 0x9b, 0x4a, 0xdd, 0xf3,
	0x8f, 0xbc, 0xf5, 0xd5, 0xf7, 0x70, 0x70, 0x9e, 0x65, 0x3f, 0xc2, 0xe3, 0x73, 0x8b, 0xcc, 0x98,
	0xc2, 0xb6, 0xec, 0xaa, 0x45, 0x8a, 0x73, 0xa7, 0xfc, 0xe5, 0x34, 0xcb, 0x8c, 0xa9, 0xa5, 0xd7,
	0x2c, 0x17, 0xe9, 0xd2, 0x6b, 0x7e, 0x87, 0x27, 0xf6, 0x80, 0x90, 0x8c, 0x29, 0x42, 0xbc, 0x8a,
	0x90, 0x45, 0x4a, 0x88, 0xd7, 0xad, 0x47, 0x26, 0xec, 0xe9, 0xdf, 0x00, 0x00, 0x00, 0xff, 0xff,
	0xf5, 0x90, 0x33, 0x55, 0xcf, 0x03, 0x00, 0x00,
}
