// Code generated by protoc-gen-go. DO NOT EDIT.
// source: google/ads/googleads/v2/services/customer_extension_setting_service.proto

package services

import (
	context "context"
	fmt "fmt"
	math "math"

	proto "github.com/golang/protobuf/proto"
	resources "google.golang.org/genproto/googleapis/ads/googleads/v2/resources"
	_ "google.golang.org/genproto/googleapis/api/annotations"
	status "google.golang.org/genproto/googleapis/rpc/status"
	field_mask "google.golang.org/genproto/protobuf/field_mask"
	grpc "google.golang.org/grpc"
)

// Reference imports to suppress errors if they are not otherwise used.
var _ = proto.Marshal
var _ = fmt.Errorf
var _ = math.Inf

// This is a compile-time assertion to ensure that this generated file
// is compatible with the proto package it is being compiled against.
// A compilation error at this line likely means your copy of the
// proto package needs to be updated.
const _ = proto.ProtoPackageIsVersion3 // please upgrade the proto package

// Request message for
// [CustomerExtensionSettingService.GetCustomerExtensionSetting][google.ads.googleads.v2.services.CustomerExtensionSettingService.GetCustomerExtensionSetting].
type GetCustomerExtensionSettingRequest struct {
	// The resource name of the customer extension setting to fetch.
	ResourceName         string   `protobuf:"bytes,1,opt,name=resource_name,json=resourceName,proto3" json:"resource_name,omitempty"`
	XXX_NoUnkeyedLiteral struct{} `json:"-"`
	XXX_unrecognized     []byte   `json:"-"`
	XXX_sizecache        int32    `json:"-"`
}

func (m *GetCustomerExtensionSettingRequest) Reset()         { *m = GetCustomerExtensionSettingRequest{} }
func (m *GetCustomerExtensionSettingRequest) String() string { return proto.CompactTextString(m) }
func (*GetCustomerExtensionSettingRequest) ProtoMessage()    {}
func (*GetCustomerExtensionSettingRequest) Descriptor() ([]byte, []int) {
	return fileDescriptor_77598a9212091dbd, []int{0}
}

func (m *GetCustomerExtensionSettingRequest) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_GetCustomerExtensionSettingRequest.Unmarshal(m, b)
}
func (m *GetCustomerExtensionSettingRequest) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_GetCustomerExtensionSettingRequest.Marshal(b, m, deterministic)
}
func (m *GetCustomerExtensionSettingRequest) XXX_Merge(src proto.Message) {
	xxx_messageInfo_GetCustomerExtensionSettingRequest.Merge(m, src)
}
func (m *GetCustomerExtensionSettingRequest) XXX_Size() int {
	return xxx_messageInfo_GetCustomerExtensionSettingRequest.Size(m)
}
func (m *GetCustomerExtensionSettingRequest) XXX_DiscardUnknown() {
	xxx_messageInfo_GetCustomerExtensionSettingRequest.DiscardUnknown(m)
}

var xxx_messageInfo_GetCustomerExtensionSettingRequest proto.InternalMessageInfo

func (m *GetCustomerExtensionSettingRequest) GetResourceName() string {
	if m != nil {
		return m.ResourceName
	}
	return ""
}

// Request message for
// [CustomerExtensionSettingService.MutateCustomerExtensionSettings][google.ads.googleads.v2.services.CustomerExtensionSettingService.MutateCustomerExtensionSettings].
type MutateCustomerExtensionSettingsRequest struct {
	// The ID of the customer whose customer extension settings are being
	// modified.
	CustomerId string `protobuf:"bytes,1,opt,name=customer_id,json=customerId,proto3" json:"customer_id,omitempty"`
	// The list of operations to perform on individual customer extension
	// settings.
	Operations []*CustomerExtensionSettingOperation `protobuf:"bytes,2,rep,name=operations,proto3" json:"operations,omitempty"`
	// If true, successful operations will be carried out and invalid
	// operations will return errors. If false, all operations will be carried
	// out in one transaction if and only if they are all valid.
	// Default is false.
	PartialFailure bool `protobuf:"varint,3,opt,name=partial_failure,json=partialFailure,proto3" json:"partial_failure,omitempty"`
	// If true, the request is validated but not executed. Only errors are
	// returned, not results.
	ValidateOnly         bool     `protobuf:"varint,4,opt,name=validate_only,json=validateOnly,proto3" json:"validate_only,omitempty"`
	XXX_NoUnkeyedLiteral struct{} `json:"-"`
	XXX_unrecognized     []byte   `json:"-"`
	XXX_sizecache        int32    `json:"-"`
}

func (m *MutateCustomerExtensionSettingsRequest) Reset() {
	*m = MutateCustomerExtensionSettingsRequest{}
}
func (m *MutateCustomerExtensionSettingsRequest) String() string { return proto.CompactTextString(m) }
func (*MutateCustomerExtensionSettingsRequest) ProtoMessage()    {}
func (*MutateCustomerExtensionSettingsRequest) Descriptor() ([]byte, []int) {
	return fileDescriptor_77598a9212091dbd, []int{1}
}

func (m *MutateCustomerExtensionSettingsRequest) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_MutateCustomerExtensionSettingsRequest.Unmarshal(m, b)
}
func (m *MutateCustomerExtensionSettingsRequest) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_MutateCustomerExtensionSettingsRequest.Marshal(b, m, deterministic)
}
func (m *MutateCustomerExtensionSettingsRequest) XXX_Merge(src proto.Message) {
	xxx_messageInfo_MutateCustomerExtensionSettingsRequest.Merge(m, src)
}
func (m *MutateCustomerExtensionSettingsRequest) XXX_Size() int {
	return xxx_messageInfo_MutateCustomerExtensionSettingsRequest.Size(m)
}
func (m *MutateCustomerExtensionSettingsRequest) XXX_DiscardUnknown() {
	xxx_messageInfo_MutateCustomerExtensionSettingsRequest.DiscardUnknown(m)
}

var xxx_messageInfo_MutateCustomerExtensionSettingsRequest proto.InternalMessageInfo

func (m *MutateCustomerExtensionSettingsRequest) GetCustomerId() string {
	if m != nil {
		return m.CustomerId
	}
	return ""
}

func (m *MutateCustomerExtensionSettingsRequest) GetOperations() []*CustomerExtensionSettingOperation {
	if m != nil {
		return m.Operations
	}
	return nil
}

func (m *MutateCustomerExtensionSettingsRequest) GetPartialFailure() bool {
	if m != nil {
		return m.PartialFailure
	}
	return false
}

func (m *MutateCustomerExtensionSettingsRequest) GetValidateOnly() bool {
	if m != nil {
		return m.ValidateOnly
	}
	return false
}

// A single operation (create, update, remove) on a customer extension setting.
type CustomerExtensionSettingOperation struct {
	// FieldMask that determines which resource fields are modified in an update.
	UpdateMask *field_mask.FieldMask `protobuf:"bytes,4,opt,name=update_mask,json=updateMask,proto3" json:"update_mask,omitempty"`
	// The mutate operation.
	//
	// Types that are valid to be assigned to Operation:
	//	*CustomerExtensionSettingOperation_Create
	//	*CustomerExtensionSettingOperation_Update
	//	*CustomerExtensionSettingOperation_Remove
	Operation            isCustomerExtensionSettingOperation_Operation `protobuf_oneof:"operation"`
	XXX_NoUnkeyedLiteral struct{}                                      `json:"-"`
	XXX_unrecognized     []byte                                        `json:"-"`
	XXX_sizecache        int32                                         `json:"-"`
}

func (m *CustomerExtensionSettingOperation) Reset()         { *m = CustomerExtensionSettingOperation{} }
func (m *CustomerExtensionSettingOperation) String() string { return proto.CompactTextString(m) }
func (*CustomerExtensionSettingOperation) ProtoMessage()    {}
func (*CustomerExtensionSettingOperation) Descriptor() ([]byte, []int) {
	return fileDescriptor_77598a9212091dbd, []int{2}
}

func (m *CustomerExtensionSettingOperation) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_CustomerExtensionSettingOperation.Unmarshal(m, b)
}
func (m *CustomerExtensionSettingOperation) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_CustomerExtensionSettingOperation.Marshal(b, m, deterministic)
}
func (m *CustomerExtensionSettingOperation) XXX_Merge(src proto.Message) {
	xxx_messageInfo_CustomerExtensionSettingOperation.Merge(m, src)
}
func (m *CustomerExtensionSettingOperation) XXX_Size() int {
	return xxx_messageInfo_CustomerExtensionSettingOperation.Size(m)
}
func (m *CustomerExtensionSettingOperation) XXX_DiscardUnknown() {
	xxx_messageInfo_CustomerExtensionSettingOperation.DiscardUnknown(m)
}

var xxx_messageInfo_CustomerExtensionSettingOperation proto.InternalMessageInfo

func (m *CustomerExtensionSettingOperation) GetUpdateMask() *field_mask.FieldMask {
	if m != nil {
		return m.UpdateMask
	}
	return nil
}

type isCustomerExtensionSettingOperation_Operation interface {
	isCustomerExtensionSettingOperation_Operation()
}

type CustomerExtensionSettingOperation_Create struct {
	Create *resources.CustomerExtensionSetting `protobuf:"bytes,1,opt,name=create,proto3,oneof"`
}

type CustomerExtensionSettingOperation_Update struct {
	Update *resources.CustomerExtensionSetting `protobuf:"bytes,2,opt,name=update,proto3,oneof"`
}

type CustomerExtensionSettingOperation_Remove struct {
	Remove string `protobuf:"bytes,3,opt,name=remove,proto3,oneof"`
}

func (*CustomerExtensionSettingOperation_Create) isCustomerExtensionSettingOperation_Operation() {}

func (*CustomerExtensionSettingOperation_Update) isCustomerExtensionSettingOperation_Operation() {}

func (*CustomerExtensionSettingOperation_Remove) isCustomerExtensionSettingOperation_Operation() {}

func (m *CustomerExtensionSettingOperation) GetOperation() isCustomerExtensionSettingOperation_Operation {
	if m != nil {
		return m.Operation
	}
	return nil
}

func (m *CustomerExtensionSettingOperation) GetCreate() *resources.CustomerExtensionSetting {
	if x, ok := m.GetOperation().(*CustomerExtensionSettingOperation_Create); ok {
		return x.Create
	}
	return nil
}

func (m *CustomerExtensionSettingOperation) GetUpdate() *resources.CustomerExtensionSetting {
	if x, ok := m.GetOperation().(*CustomerExtensionSettingOperation_Update); ok {
		return x.Update
	}
	return nil
}

func (m *CustomerExtensionSettingOperation) GetRemove() string {
	if x, ok := m.GetOperation().(*CustomerExtensionSettingOperation_Remove); ok {
		return x.Remove
	}
	return ""
}

// XXX_OneofWrappers is for the internal use of the proto package.
func (*CustomerExtensionSettingOperation) XXX_OneofWrappers() []interface{} {
	return []interface{}{
		(*CustomerExtensionSettingOperation_Create)(nil),
		(*CustomerExtensionSettingOperation_Update)(nil),
		(*CustomerExtensionSettingOperation_Remove)(nil),
	}
}

// Response message for a customer extension setting mutate.
type MutateCustomerExtensionSettingsResponse struct {
	// Errors that pertain to operation failures in the partial failure mode.
	// Returned only when partial_failure = true and all errors occur inside the
	// operations. If any errors occur outside the operations (e.g. auth errors),
	// we return an RPC level error.
	PartialFailureError *status.Status `protobuf:"bytes,3,opt,name=partial_failure_error,json=partialFailureError,proto3" json:"partial_failure_error,omitempty"`
	// All results for the mutate.
	Results              []*MutateCustomerExtensionSettingResult `protobuf:"bytes,2,rep,name=results,proto3" json:"results,omitempty"`
	XXX_NoUnkeyedLiteral struct{}                                `json:"-"`
	XXX_unrecognized     []byte                                  `json:"-"`
	XXX_sizecache        int32                                   `json:"-"`
}

func (m *MutateCustomerExtensionSettingsResponse) Reset() {
	*m = MutateCustomerExtensionSettingsResponse{}
}
func (m *MutateCustomerExtensionSettingsResponse) String() string { return proto.CompactTextString(m) }
func (*MutateCustomerExtensionSettingsResponse) ProtoMessage()    {}
func (*MutateCustomerExtensionSettingsResponse) Descriptor() ([]byte, []int) {
	return fileDescriptor_77598a9212091dbd, []int{3}
}

func (m *MutateCustomerExtensionSettingsResponse) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_MutateCustomerExtensionSettingsResponse.Unmarshal(m, b)
}
func (m *MutateCustomerExtensionSettingsResponse) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_MutateCustomerExtensionSettingsResponse.Marshal(b, m, deterministic)
}
func (m *MutateCustomerExtensionSettingsResponse) XXX_Merge(src proto.Message) {
	xxx_messageInfo_MutateCustomerExtensionSettingsResponse.Merge(m, src)
}
func (m *MutateCustomerExtensionSettingsResponse) XXX_Size() int {
	return xxx_messageInfo_MutateCustomerExtensionSettingsResponse.Size(m)
}
func (m *MutateCustomerExtensionSettingsResponse) XXX_DiscardUnknown() {
	xxx_messageInfo_MutateCustomerExtensionSettingsResponse.DiscardUnknown(m)
}

var xxx_messageInfo_MutateCustomerExtensionSettingsResponse proto.InternalMessageInfo

func (m *MutateCustomerExtensionSettingsResponse) GetPartialFailureError() *status.Status {
	if m != nil {
		return m.PartialFailureError
	}
	return nil
}

func (m *MutateCustomerExtensionSettingsResponse) GetResults() []*MutateCustomerExtensionSettingResult {
	if m != nil {
		return m.Results
	}
	return nil
}

// The result for the customer extension setting mutate.
type MutateCustomerExtensionSettingResult struct {
	// Returned for successful operations.
	ResourceName         string   `protobuf:"bytes,1,opt,name=resource_name,json=resourceName,proto3" json:"resource_name,omitempty"`
	XXX_NoUnkeyedLiteral struct{} `json:"-"`
	XXX_unrecognized     []byte   `json:"-"`
	XXX_sizecache        int32    `json:"-"`
}

func (m *MutateCustomerExtensionSettingResult) Reset()         { *m = MutateCustomerExtensionSettingResult{} }
func (m *MutateCustomerExtensionSettingResult) String() string { return proto.CompactTextString(m) }
func (*MutateCustomerExtensionSettingResult) ProtoMessage()    {}
func (*MutateCustomerExtensionSettingResult) Descriptor() ([]byte, []int) {
	return fileDescriptor_77598a9212091dbd, []int{4}
}

func (m *MutateCustomerExtensionSettingResult) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_MutateCustomerExtensionSettingResult.Unmarshal(m, b)
}
func (m *MutateCustomerExtensionSettingResult) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_MutateCustomerExtensionSettingResult.Marshal(b, m, deterministic)
}
func (m *MutateCustomerExtensionSettingResult) XXX_Merge(src proto.Message) {
	xxx_messageInfo_MutateCustomerExtensionSettingResult.Merge(m, src)
}
func (m *MutateCustomerExtensionSettingResult) XXX_Size() int {
	return xxx_messageInfo_MutateCustomerExtensionSettingResult.Size(m)
}
func (m *MutateCustomerExtensionSettingResult) XXX_DiscardUnknown() {
	xxx_messageInfo_MutateCustomerExtensionSettingResult.DiscardUnknown(m)
}

var xxx_messageInfo_MutateCustomerExtensionSettingResult proto.InternalMessageInfo

func (m *MutateCustomerExtensionSettingResult) GetResourceName() string {
	if m != nil {
		return m.ResourceName
	}
	return ""
}

func init() {
	proto.RegisterType((*GetCustomerExtensionSettingRequest)(nil), "google.ads.googleads.v2.services.GetCustomerExtensionSettingRequest")
	proto.RegisterType((*MutateCustomerExtensionSettingsRequest)(nil), "google.ads.googleads.v2.services.MutateCustomerExtensionSettingsRequest")
	proto.RegisterType((*CustomerExtensionSettingOperation)(nil), "google.ads.googleads.v2.services.CustomerExtensionSettingOperation")
	proto.RegisterType((*MutateCustomerExtensionSettingsResponse)(nil), "google.ads.googleads.v2.services.MutateCustomerExtensionSettingsResponse")
	proto.RegisterType((*MutateCustomerExtensionSettingResult)(nil), "google.ads.googleads.v2.services.MutateCustomerExtensionSettingResult")
}

func init() {
	proto.RegisterFile("google/ads/googleads/v2/services/customer_extension_setting_service.proto", fileDescriptor_77598a9212091dbd)
}

var fileDescriptor_77598a9212091dbd = []byte{
	// 734 bytes of a gzipped FileDescriptorProto
	0x1f, 0x8b, 0x08, 0x00, 0x00, 0x00, 0x00, 0x00, 0x02, 0xff, 0xac, 0x95, 0xcf, 0x6e, 0xd3, 0x4e,
	0x10, 0xc7, 0x7f, 0x76, 0xab, 0xfe, 0xe8, 0xa6, 0x80, 0xb4, 0x08, 0x11, 0xa5, 0x48, 0x0d, 0x26,
	0xa2, 0x55, 0x0e, 0xb6, 0x64, 0x6e, 0x8e, 0x8a, 0x94, 0x84, 0xa6, 0x8d, 0x50, 0x69, 0xe5, 0x8a,
	0x1e, 0x50, 0x24, 0xb3, 0xb5, 0xb7, 0x96, 0x55, 0xdb, 0x6b, 0x76, 0xd7, 0x11, 0x55, 0xd5, 0x03,
	0x5c, 0x39, 0xf2, 0x06, 0x1c, 0x7b, 0xe7, 0x25, 0x7a, 0xed, 0x2b, 0xc0, 0x85, 0x67, 0xe0, 0x80,
	0xec, 0xf5, 0xba, 0x7f, 0x90, 0xeb, 0x4a, 0xed, 0x6d, 0x32, 0xfb, 0xf5, 0x67, 0x66, 0x76, 0x66,
	0x27, 0x60, 0xec, 0x13, 0xe2, 0x87, 0xd8, 0x40, 0x1e, 0x33, 0x84, 0x99, 0x59, 0x53, 0xd3, 0x60,
	0x98, 0x4e, 0x03, 0x17, 0x33, 0xc3, 0x4d, 0x19, 0x27, 0x11, 0xa6, 0x0e, 0xfe, 0xc4, 0x71, 0xcc,
	0x02, 0x12, 0x3b, 0x0c, 0x73, 0x1e, 0xc4, 0xbe, 0x53, 0x68, 0xf4, 0x84, 0x12, 0x4e, 0x60, 0x5b,
	0x7c, 0xaf, 0x23, 0x8f, 0xe9, 0x25, 0x4a, 0x9f, 0x9a, 0xba, 0x44, 0xb5, 0x06, 0x55, 0xc1, 0x28,
	0x66, 0x24, 0xa5, 0xd7, 0x47, 0x13, 0x51, 0x5a, 0x4f, 0x25, 0x23, 0x09, 0x0c, 0x14, 0xc7, 0x84,
	0x23, 0x1e, 0x90, 0x98, 0x15, 0xa7, 0x45, 0x0e, 0x46, 0xfe, 0x6b, 0x2f, 0xdd, 0x37, 0xf6, 0x03,
	0x1c, 0x7a, 0x4e, 0x84, 0xd8, 0x41, 0xa1, 0x78, 0x52, 0x28, 0x68, 0xe2, 0x1a, 0x8c, 0x23, 0x9e,
	0xb2, 0x2b, 0x07, 0x19, 0xd8, 0x0d, 0x03, 0x1c, 0x73, 0x71, 0xa0, 0x8d, 0x81, 0xb6, 0x8e, 0xf9,
	0xb0, 0x48, 0x6c, 0x4d, 0xe6, 0xb5, 0x23, 0xd2, 0xb2, 0xf1, 0xc7, 0x14, 0x33, 0x0e, 0x9f, 0x83,
	0xfb, 0xb2, 0x0a, 0x27, 0x46, 0x11, 0x6e, 0x2a, 0x6d, 0x65, 0x65, 0xde, 0x5e, 0x90, 0xce, 0xb7,
	0x28, 0xc2, 0xda, 0x1f, 0x05, 0xbc, 0xd8, 0x4c, 0x39, 0xe2, 0xb8, 0x0a, 0xc7, 0x24, 0x6f, 0x09,
	0x34, 0xca, 0xbb, 0x08, 0xbc, 0x82, 0x06, 0xa4, 0x6b, 0xec, 0x41, 0x17, 0x00, 0x92, 0x60, 0x2a,
	0xca, 0x6f, 0xaa, 0xed, 0x99, 0x95, 0x86, 0x39, 0xd4, 0xeb, 0x7a, 0xa0, 0x57, 0x05, 0xde, 0x92,
	0x2c, 0xfb, 0x02, 0x16, 0x2e, 0x83, 0x87, 0x09, 0xa2, 0x3c, 0x40, 0xa1, 0xb3, 0x8f, 0x82, 0x30,
	0xa5, 0xb8, 0x39, 0xd3, 0x56, 0x56, 0xee, 0xd9, 0x0f, 0x0a, 0xf7, 0x48, 0x78, 0xb3, 0xf2, 0xa7,
	0x28, 0x0c, 0x3c, 0xc4, 0xb1, 0x43, 0xe2, 0xf0, 0xb0, 0x39, 0x9b, 0xcb, 0x16, 0xa4, 0x73, 0x2b,
	0x0e, 0x0f, 0xb5, 0x1f, 0x2a, 0x78, 0x56, 0x1b, 0x1f, 0xf6, 0x40, 0x23, 0x4d, 0x72, 0x50, 0xd6,
	0xb6, 0x1c, 0xd4, 0x30, 0x5b, 0xb2, 0x32, 0xd9, 0x59, 0x7d, 0x94, 0x75, 0x76, 0x13, 0xb1, 0x03,
	0x1b, 0x08, 0x79, 0x66, 0xc3, 0x77, 0x60, 0xce, 0xa5, 0x18, 0x71, 0x71, 0xff, 0x0d, 0xb3, 0x57,
	0x79, 0x23, 0xe5, 0xcc, 0x55, 0x5e, 0xc9, 0xc6, 0x7f, 0x76, 0x01, 0xcb, 0xb0, 0x22, 0x48, 0x53,
	0xbd, 0x13, 0xac, 0x80, 0xc1, 0x26, 0x98, 0xa3, 0x38, 0x22, 0x53, 0x71, 0xab, 0xf3, 0xd9, 0x89,
	0xf8, 0x3d, 0x68, 0x80, 0xf9, 0xb2, 0x0d, 0xda, 0x99, 0x02, 0x96, 0x6b, 0xc7, 0x86, 0x25, 0x24,
	0x66, 0x18, 0x8e, 0xc0, 0xe3, 0x2b, 0x1d, 0x73, 0x30, 0xa5, 0x84, 0xe6, 0x11, 0x1a, 0x26, 0x94,
	0x89, 0xd3, 0xc4, 0xd5, 0x77, 0xf2, 0xf9, 0xb7, 0x1f, 0x5d, 0xee, 0xe5, 0x5a, 0x26, 0x87, 0x1f,
	0xc0, 0xff, 0x14, 0xb3, 0x34, 0xe4, 0x72, 0xb6, 0x46, 0xf5, 0xb3, 0x75, 0x7d, 0x8e, 0x76, 0x8e,
	0xb3, 0x25, 0x56, 0x7b, 0x03, 0x3a, 0x37, 0xf9, 0xe0, 0x46, 0x2f, 0xcb, 0x3c, 0x99, 0x05, 0x4b,
	0x55, 0x9c, 0x1d, 0x91, 0x1f, 0xfc, 0xa5, 0x80, 0xc5, 0x6b, 0x5e, 0x32, 0x7c, 0x5d, 0x5f, 0x61,
	0xfd, 0x22, 0x68, 0xdd, 0x66, 0x34, 0xb4, 0xe1, 0x97, 0xb3, 0x9f, 0xdf, 0xd4, 0x55, 0xd8, 0xcb,
	0xb6, 0xe2, 0xd1, 0xa5, 0xb2, 0x57, 0xe5, 0xdb, 0x67, 0x46, 0xb7, 0x5c, 0x93, 0xff, 0xcc, 0x81,
	0xd1, 0x3d, 0x86, 0x9f, 0x55, 0xb0, 0x54, 0x33, 0x2e, 0x70, 0xe3, 0xb6, 0xdd, 0x94, 0x8b, 0xaa,
	0x35, 0xbe, 0x03, 0x92, 0x98, 0x5d, 0x6d, 0x9c, 0x57, 0x3f, 0xd4, 0x5e, 0x65, 0xd5, 0x9f, 0x97,
	0x7b, 0x74, 0x61, 0x11, 0xae, 0x76, 0x8f, 0xab, 0x8b, 0xb7, 0xa2, 0x3c, 0x90, 0xa5, 0x74, 0x5b,
	0x8b, 0xa7, 0xfd, 0xe6, 0x79, 0x32, 0x85, 0x95, 0x04, 0x4c, 0x77, 0x49, 0x34, 0xf8, 0xaa, 0x82,
	0x8e, 0x4b, 0xa2, 0xda, 0xc4, 0x07, 0x9d, 0x9a, 0x91, 0xda, 0xce, 0x96, 0xd1, 0xb6, 0xf2, 0x7e,
	0xa3, 0x20, 0xf9, 0x24, 0x44, 0xb1, 0xaf, 0x13, 0xea, 0x1b, 0x3e, 0x8e, 0xf3, 0x55, 0x65, 0x9c,
	0xc7, 0xae, 0xfe, 0x93, 0xed, 0x49, 0xe3, 0xbb, 0x3a, 0xb3, 0xde, 0xef, 0x9f, 0xa8, 0xed, 0x75,
	0x01, 0xec, 0x7b, 0x4c, 0x17, 0x66, 0x66, 0xed, 0x9a, 0x7a, 0x11, 0x98, 0x9d, 0x4a, 0xc9, 0xa4,
	0xef, 0xb1, 0x49, 0x29, 0x99, 0xec, 0x9a, 0x13, 0x29, 0xf9, 0xad, 0x76, 0x84, 0xdf, 0xb2, 0xfa,
	0x1e, 0xb3, 0xac, 0x52, 0x64, 0x59, 0xbb, 0xa6, 0x65, 0x49, 0xd9, 0xde, 0x5c, 0x9e, 0xe7, 0xcb,
	0xbf, 0x01, 0x00, 0x00, 0xff, 0xff, 0xcf, 0x83, 0xf0, 0x68, 0x0b, 0x08, 0x00, 0x00,
}

// Reference imports to suppress errors if they are not otherwise used.
var _ context.Context
var _ grpc.ClientConn

// This is a compile-time assertion to ensure that this generated file
// is compatible with the grpc package it is being compiled against.
const _ = grpc.SupportPackageIsVersion4

// CustomerExtensionSettingServiceClient is the client API for CustomerExtensionSettingService service.
//
// For semantics around ctx use and closing/ending streaming RPCs, please refer to https://godoc.org/google.golang.org/grpc#ClientConn.NewStream.
type CustomerExtensionSettingServiceClient interface {
	// Returns the requested customer extension setting in full detail.
	GetCustomerExtensionSetting(ctx context.Context, in *GetCustomerExtensionSettingRequest, opts ...grpc.CallOption) (*resources.CustomerExtensionSetting, error)
	// Creates, updates, or removes customer extension settings. Operation
	// statuses are returned.
	MutateCustomerExtensionSettings(ctx context.Context, in *MutateCustomerExtensionSettingsRequest, opts ...grpc.CallOption) (*MutateCustomerExtensionSettingsResponse, error)
}

type customerExtensionSettingServiceClient struct {
	cc *grpc.ClientConn
}

func NewCustomerExtensionSettingServiceClient(cc *grpc.ClientConn) CustomerExtensionSettingServiceClient {
	return &customerExtensionSettingServiceClient{cc}
}

func (c *customerExtensionSettingServiceClient) GetCustomerExtensionSetting(ctx context.Context, in *GetCustomerExtensionSettingRequest, opts ...grpc.CallOption) (*resources.CustomerExtensionSetting, error) {
	out := new(resources.CustomerExtensionSetting)
	err := c.cc.Invoke(ctx, "/google.ads.googleads.v2.services.CustomerExtensionSettingService/GetCustomerExtensionSetting", in, out, opts...)
	if err != nil {
		return nil, err
	}
	return out, nil
}

func (c *customerExtensionSettingServiceClient) MutateCustomerExtensionSettings(ctx context.Context, in *MutateCustomerExtensionSettingsRequest, opts ...grpc.CallOption) (*MutateCustomerExtensionSettingsResponse, error) {
	out := new(MutateCustomerExtensionSettingsResponse)
	err := c.cc.Invoke(ctx, "/google.ads.googleads.v2.services.CustomerExtensionSettingService/MutateCustomerExtensionSettings", in, out, opts...)
	if err != nil {
		return nil, err
	}
	return out, nil
}

// CustomerExtensionSettingServiceServer is the server API for CustomerExtensionSettingService service.
type CustomerExtensionSettingServiceServer interface {
	// Returns the requested customer extension setting in full detail.
	GetCustomerExtensionSetting(context.Context, *GetCustomerExtensionSettingRequest) (*resources.CustomerExtensionSetting, error)
	// Creates, updates, or removes customer extension settings. Operation
	// statuses are returned.
	MutateCustomerExtensionSettings(context.Context, *MutateCustomerExtensionSettingsRequest) (*MutateCustomerExtensionSettingsResponse, error)
}

func RegisterCustomerExtensionSettingServiceServer(s *grpc.Server, srv CustomerExtensionSettingServiceServer) {
	s.RegisterService(&_CustomerExtensionSettingService_serviceDesc, srv)
}

func _CustomerExtensionSettingService_GetCustomerExtensionSetting_Handler(srv interface{}, ctx context.Context, dec func(interface{}) error, interceptor grpc.UnaryServerInterceptor) (interface{}, error) {
	in := new(GetCustomerExtensionSettingRequest)
	if err := dec(in); err != nil {
		return nil, err
	}
	if interceptor == nil {
		return srv.(CustomerExtensionSettingServiceServer).GetCustomerExtensionSetting(ctx, in)
	}
	info := &grpc.UnaryServerInfo{
		Server:     srv,
		FullMethod: "/google.ads.googleads.v2.services.CustomerExtensionSettingService/GetCustomerExtensionSetting",
	}
	handler := func(ctx context.Context, req interface{}) (interface{}, error) {
		return srv.(CustomerExtensionSettingServiceServer).GetCustomerExtensionSetting(ctx, req.(*GetCustomerExtensionSettingRequest))
	}
	return interceptor(ctx, in, info, handler)
}

func _CustomerExtensionSettingService_MutateCustomerExtensionSettings_Handler(srv interface{}, ctx context.Context, dec func(interface{}) error, interceptor grpc.UnaryServerInterceptor) (interface{}, error) {
	in := new(MutateCustomerExtensionSettingsRequest)
	if err := dec(in); err != nil {
		return nil, err
	}
	if interceptor == nil {
		return srv.(CustomerExtensionSettingServiceServer).MutateCustomerExtensionSettings(ctx, in)
	}
	info := &grpc.UnaryServerInfo{
		Server:     srv,
		FullMethod: "/google.ads.googleads.v2.services.CustomerExtensionSettingService/MutateCustomerExtensionSettings",
	}
	handler := func(ctx context.Context, req interface{}) (interface{}, error) {
		return srv.(CustomerExtensionSettingServiceServer).MutateCustomerExtensionSettings(ctx, req.(*MutateCustomerExtensionSettingsRequest))
	}
	return interceptor(ctx, in, info, handler)
}

var _CustomerExtensionSettingService_serviceDesc = grpc.ServiceDesc{
	ServiceName: "google.ads.googleads.v2.services.CustomerExtensionSettingService",
	HandlerType: (*CustomerExtensionSettingServiceServer)(nil),
	Methods: []grpc.MethodDesc{
		{
			MethodName: "GetCustomerExtensionSetting",
			Handler:    _CustomerExtensionSettingService_GetCustomerExtensionSetting_Handler,
		},
		{
			MethodName: "MutateCustomerExtensionSettings",
			Handler:    _CustomerExtensionSettingService_MutateCustomerExtensionSettings_Handler,
		},
	},
	Streams:  []grpc.StreamDesc{},
	Metadata: "google/ads/googleads/v2/services/customer_extension_setting_service.proto",
}
