// Code generated by protoc-gen-go. DO NOT EDIT.
// source: google/cloud/dataproc/v1beta2/shared.proto

package dataproc

import (
	fmt "fmt"
	math "math"

	proto "github.com/golang/protobuf/proto"
	_ "google.golang.org/genproto/googleapis/api/annotations"
)

// Reference imports to suppress errors if they are not otherwise used.
var _ = proto.Marshal
var _ = fmt.Errorf
var _ = math.Inf

// This is a compile-time assertion to ensure that this generated file
// is compatible with the proto package it is being compiled against.
// A compilation error at this line likely means your copy of the
// proto package needs to be updated.
const _ = proto.ProtoPackageIsVersion3 // please upgrade the proto package

// Cluster components that can be activated.
type Component int32

const (
	// Unspecified component.
	Component_COMPONENT_UNSPECIFIED Component = 0
	// The Anaconda python distribution.
	Component_ANACONDA Component = 5
	// The Druid query engine.
	Component_DRUID Component = 9
	// The Hive Web HCatalog (the REST service for accessing HCatalog).
	Component_HIVE_WEBHCAT Component = 3
	// The Jupyter Notebook.
	Component_JUPYTER Component = 1
	// The Kerberos security feature.
	Component_KERBEROS Component = 7
	// The Presto query engine.
	Component_PRESTO Component = 6
	// The Zeppelin notebook.
	Component_ZEPPELIN Component = 4
	// The Zookeeper service.
	Component_ZOOKEEPER Component = 8
)

var Component_name = map[int32]string{
	0: "COMPONENT_UNSPECIFIED",
	5: "ANACONDA",
	9: "DRUID",
	3: "HIVE_WEBHCAT",
	1: "JUPYTER",
	7: "KERBEROS",
	6: "PRESTO",
	4: "ZEPPELIN",
	8: "ZOOKEEPER",
}

var Component_value = map[string]int32{
	"COMPONENT_UNSPECIFIED": 0,
	"ANACONDA":              5,
	"DRUID":                 9,
	"HIVE_WEBHCAT":          3,
	"JUPYTER":               1,
	"KERBEROS":              7,
	"PRESTO":                6,
	"ZEPPELIN":              4,
	"ZOOKEEPER":             8,
}

func (x Component) String() string {
	return proto.EnumName(Component_name, int32(x))
}

func (Component) EnumDescriptor() ([]byte, []int) {
	return fileDescriptor_2474c85b30841989, []int{0}
}

func init() {
	proto.RegisterEnum("google.cloud.dataproc.v1beta2.Component", Component_name, Component_value)
}

func init() {
	proto.RegisterFile("google/cloud/dataproc/v1beta2/shared.proto", fileDescriptor_2474c85b30841989)
}

var fileDescriptor_2474c85b30841989 = []byte{
	// 293 bytes of a gzipped FileDescriptorProto
	0x1f, 0x8b, 0x08, 0x00, 0x00, 0x00, 0x00, 0x00, 0x02, 0xff, 0x7c, 0x90, 0x4d, 0x4f, 0x32, 0x31,
	0x14, 0x85, 0x5f, 0xf2, 0xca, 0xc7, 0x14, 0x4c, 0x9a, 0x26, 0x2e, 0x34, 0xba, 0x70, 0xcb, 0x62,
	0x1a, 0x75, 0xe9, 0x6a, 0x3e, 0xae, 0x61, 0x44, 0xdb, 0xa6, 0x33, 0x68, 0x64, 0x43, 0x0a, 0x4c,
	0x2a, 0x09, 0xf4, 0x4e, 0x86, 0x6a, 0xe2, 0x0f, 0xf1, 0xff, 0x1a, 0x06, 0x58, 0xea, 0xf6, 0x9e,
	0xe7, 0xdc, 0xe4, 0x39, 0x64, 0x68, 0x11, 0xed, 0xba, 0xe4, 0x8b, 0x35, 0x7e, 0x2c, 0xf9, 0xd2,
	0x78, 0x53, 0xd5, 0xb8, 0xe0, 0x9f, 0x37, 0xf3, 0xd2, 0x9b, 0x5b, 0xbe, 0x7d, 0x37, 0x75, 0xb9,
	0x0c, 0xab, 0x1a, 0x3d, 0xb2, 0xab, 0x3d, 0x1b, 0x36, 0x6c, 0x78, 0x64, 0xc3, 0x03, 0x7b, 0x71,
	0x79, 0x78, 0x65, 0xaa, 0x15, 0x37, 0xce, 0xa1, 0x37, 0x7e, 0x85, 0x6e, 0xbb, 0x2f, 0x0f, 0xbf,
	0x5b, 0x24, 0x48, 0x70, 0x53, 0xa1, 0x2b, 0x9d, 0x67, 0xe7, 0xe4, 0x2c, 0x91, 0xcf, 0x4a, 0x0a,
	0x10, 0xc5, 0x6c, 0x22, 0x72, 0x05, 0x49, 0xf6, 0x90, 0x41, 0x4a, 0xff, 0xb1, 0x01, 0xe9, 0x45,
	0x22, 0x4a, 0xa4, 0x48, 0x23, 0xda, 0x66, 0x01, 0x69, 0xa7, 0x7a, 0x92, 0xa5, 0x34, 0x60, 0x94,
	0x0c, 0x46, 0xd9, 0x0b, 0xcc, 0x5e, 0x21, 0x1e, 0x25, 0x51, 0x41, 0xff, 0xb3, 0x3e, 0xe9, 0x3e,
	0x4e, 0xd4, 0x5b, 0x01, 0x9a, 0xb6, 0x76, 0xbd, 0x31, 0xe8, 0x18, 0xb4, 0xcc, 0x69, 0x97, 0x11,
	0xd2, 0x51, 0x1a, 0xf2, 0x42, 0xd2, 0xce, 0x2e, 0x99, 0x82, 0x52, 0xf0, 0x94, 0x09, 0x7a, 0xc2,
	0x4e, 0x49, 0x30, 0x95, 0x72, 0x0c, 0xa0, 0x40, 0xd3, 0x5e, 0xfc, 0x45, 0xae, 0x17, 0xb8, 0x09,
	0xff, 0x54, 0x8b, 0xfb, 0x79, 0xb3, 0x83, 0xda, 0x99, 0xa8, 0xd6, 0x14, 0x0e, 0xb4, 0xc5, 0xb5,
	0x71, 0x36, 0xc4, 0xda, 0x72, 0x5b, 0xba, 0xc6, 0x93, 0xef, 0x23, 0x53, 0xad, 0xb6, 0xbf, 0x6c,
	0x7a, 0x7f, 0x3c, 0xcc, 0x3b, 0x4d, 0xe3, 0xee, 0x27, 0x00, 0x00, 0xff, 0xff, 0xab, 0x0b, 0x45,
	0x10, 0x84, 0x01, 0x00, 0x00,
}
