// Code generated by protoc-gen-go. DO NOT EDIT.
// source: google/ads/googleads/v2/common/real_time_bidding_setting.proto

package common

import (
	fmt "fmt"
	math "math"

	proto "github.com/golang/protobuf/proto"
	wrappers "github.com/golang/protobuf/ptypes/wrappers"
	_ "google.golang.org/genproto/googleapis/api/annotations"
)

// Reference imports to suppress errors if they are not otherwise used.
var _ = proto.Marshal
var _ = fmt.Errorf
var _ = math.Inf

// This is a compile-time assertion to ensure that this generated file
// is compatible with the proto package it is being compiled against.
// A compilation error at this line likely means your copy of the
// proto package needs to be updated.
const _ = proto.ProtoPackageIsVersion3 // please upgrade the proto package

// Settings for Real-Time Bidding, a feature only available for campaigns
// targeting the Ad Exchange network.
type RealTimeBiddingSetting struct {
	// Whether the campaign is opted in to real-time bidding.
	OptIn                *wrappers.BoolValue `protobuf:"bytes,1,opt,name=opt_in,json=optIn,proto3" json:"opt_in,omitempty"`
	XXX_NoUnkeyedLiteral struct{}            `json:"-"`
	XXX_unrecognized     []byte              `json:"-"`
	XXX_sizecache        int32               `json:"-"`
}

func (m *RealTimeBiddingSetting) Reset()         { *m = RealTimeBiddingSetting{} }
func (m *RealTimeBiddingSetting) String() string { return proto.CompactTextString(m) }
func (*RealTimeBiddingSetting) ProtoMessage()    {}
func (*RealTimeBiddingSetting) Descriptor() ([]byte, []int) {
	return fileDescriptor_5b348653b6b76033, []int{0}
}

func (m *RealTimeBiddingSetting) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_RealTimeBiddingSetting.Unmarshal(m, b)
}
func (m *RealTimeBiddingSetting) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_RealTimeBiddingSetting.Marshal(b, m, deterministic)
}
func (m *RealTimeBiddingSetting) XXX_Merge(src proto.Message) {
	xxx_messageInfo_RealTimeBiddingSetting.Merge(m, src)
}
func (m *RealTimeBiddingSetting) XXX_Size() int {
	return xxx_messageInfo_RealTimeBiddingSetting.Size(m)
}
func (m *RealTimeBiddingSetting) XXX_DiscardUnknown() {
	xxx_messageInfo_RealTimeBiddingSetting.DiscardUnknown(m)
}

var xxx_messageInfo_RealTimeBiddingSetting proto.InternalMessageInfo

func (m *RealTimeBiddingSetting) GetOptIn() *wrappers.BoolValue {
	if m != nil {
		return m.OptIn
	}
	return nil
}

func init() {
	proto.RegisterType((*RealTimeBiddingSetting)(nil), "google.ads.googleads.v2.common.RealTimeBiddingSetting")
}

func init() {
	proto.RegisterFile("google/ads/googleads/v2/common/real_time_bidding_setting.proto", fileDescriptor_5b348653b6b76033)
}

var fileDescriptor_5b348653b6b76033 = []byte{
	// 303 bytes of a gzipped FileDescriptorProto
	0x1f, 0x8b, 0x08, 0x00, 0x00, 0x00, 0x00, 0x00, 0x02, 0xff, 0x7c, 0x90, 0xc1, 0x4a, 0xec, 0x30,
	0x14, 0x86, 0xe9, 0x5c, 0xee, 0x2c, 0xea, 0x6e, 0x16, 0x22, 0xa3, 0x0c, 0x32, 0x2b, 0x57, 0x09,
	0xc6, 0x5d, 0x04, 0xa1, 0x55, 0x18, 0xc4, 0xcd, 0x30, 0x4a, 0x17, 0x52, 0x28, 0x99, 0x49, 0x0c,
	0x81, 0x34, 0x27, 0x34, 0x99, 0xf1, 0x7d, 0x5c, 0xfa, 0x28, 0x3e, 0x8a, 0x0f, 0xe0, 0x5a, 0xda,
	0xd3, 0x76, 0xa5, 0xae, 0xfa, 0xd3, 0x7c, 0xff, 0xf9, 0x0e, 0x27, 0xbd, 0xd1, 0x00, 0xda, 0x2a,
	0x2a, 0x64, 0xa0, 0x18, 0xdb, 0x74, 0x60, 0x74, 0x07, 0x75, 0x0d, 0x8e, 0x36, 0x4a, 0xd8, 0x2a,
	0x9a, 0x5a, 0x55, 0x5b, 0x23, 0xa5, 0x71, 0xba, 0x0a, 0x2a, 0x46, 0xe3, 0x34, 0xf1, 0x0d, 0x44,
	0x98, 0x2d, 0xb0, 0x44, 0x84, 0x0c, 0x64, 0xec, 0x93, 0x03, 0x23, 0xd8, 0x9f, 0xf7, 0xef, 0xb4,
	0xa3, 0xb7, 0xfb, 0x17, 0xfa, 0xda, 0x08, 0xef, 0x55, 0x13, 0xb0, 0x3f, 0x3f, 0x1b, 0xfc, 0xde,
	0x50, 0xe1, 0x1c, 0x44, 0x11, 0x0d, 0xb8, 0xfe, 0x75, 0xf9, 0x90, 0x1e, 0x6f, 0x94, 0xb0, 0x4f,
	0xa6, 0x56, 0x39, 0xea, 0x1f, 0xd1, 0x3e, 0xbb, 0x4c, 0xa7, 0xe0, 0x63, 0x65, 0xdc, 0x49, 0x72,
	0x9e, 0x5c, 0x1c, 0xb1, 0x79, 0x6f, 0x27, 0x83, 0x88, 0xe4, 0x00, 0xb6, 0x10, 0x76, 0xaf, 0x36,
	0xff, 0xc1, 0xc7, 0x7b, 0x97, 0x7f, 0x25, 0xe9, 0x72, 0x07, 0x35, 0xf9, 0x7b, 0xe3, 0xfc, 0xf4,
	0x67, 0xe3, 0xba, 0x9d, 0xbb, 0x4e, 0x9e, 0xef, 0xfa, 0xba, 0x06, 0x2b, 0x9c, 0x26, 0xd0, 0x68,
	0xaa, 0x95, 0xeb, 0xac, 0xc3, 0x01, 0xbd, 0x09, 0xbf, 0xdd, 0xf3, 0x1a, 0x3f, 0x6f, 0x93, 0x7f,
	0xab, 0x2c, 0x7b, 0x9f, 0x2c, 0x56, 0x38, 0x2c, 0x93, 0x81, 0x60, 0x6c, 0x53, 0xc1, 0xc8, 0x6d,
	0x87, 0x7d, 0x0c, 0x40, 0x99, 0xc9, 0x50, 0x8e, 0x40, 0x59, 0xb0, 0x12, 0x81, 0xcf, 0xc9, 0x12,
	0xff, 0x72, 0x9e, 0xc9, 0xc0, 0xf9, 0x88, 0x70, 0x5e, 0x30, 0xce, 0x11, 0xda, 0x4e, 0xbb, 0xed,
	0xae, 0xbe, 0x03, 0x00, 0x00, 0xff, 0xff, 0x75, 0x30, 0xe2, 0x3f, 0xec, 0x01, 0x00, 0x00,
}
