// Code generated by protoc-gen-go. DO NOT EDIT.
// source: google/ads/googleads/v1/resources/product_bidding_category_constant.proto

package resources

import (
	fmt "fmt"
	math "math"

	proto "github.com/golang/protobuf/proto"
	wrappers "github.com/golang/protobuf/ptypes/wrappers"
	enums "google.golang.org/genproto/googleapis/ads/googleads/v1/enums"
	_ "google.golang.org/genproto/googleapis/api/annotations"
)

// Reference imports to suppress errors if they are not otherwise used.
var _ = proto.Marshal
var _ = fmt.Errorf
var _ = math.Inf

// This is a compile-time assertion to ensure that this generated file
// is compatible with the proto package it is being compiled against.
// A compilation error at this line likely means your copy of the
// proto package needs to be updated.
const _ = proto.ProtoPackageIsVersion3 // please upgrade the proto package

// A Product Bidding Category.
type ProductBiddingCategoryConstant struct {
	// The resource name of the product bidding category.
	// Product bidding category resource names have the form:
	//
	// `productBiddingCategoryConstants/{country_code}~{level}~{id}`
	ResourceName string `protobuf:"bytes,1,opt,name=resource_name,json=resourceName,proto3" json:"resource_name,omitempty"`
	// ID of the product bidding category.
	//
	// This ID is equivalent to the google_product_category ID as described in
	// this article: https://support.google.com/merchants/answer/6324436.
	Id *wrappers.Int64Value `protobuf:"bytes,2,opt,name=id,proto3" json:"id,omitempty"`
	// Two-letter upper-case country code of the product bidding category.
	CountryCode *wrappers.StringValue `protobuf:"bytes,3,opt,name=country_code,json=countryCode,proto3" json:"country_code,omitempty"`
	// Resource name of the parent product bidding category.
	ProductBiddingCategoryConstantParent *wrappers.StringValue `protobuf:"bytes,4,opt,name=product_bidding_category_constant_parent,json=productBiddingCategoryConstantParent,proto3" json:"product_bidding_category_constant_parent,omitempty"`
	// Level of the product bidding category.
	Level enums.ProductBiddingCategoryLevelEnum_ProductBiddingCategoryLevel `protobuf:"varint,5,opt,name=level,proto3,enum=google.ads.googleads.v1.enums.ProductBiddingCategoryLevelEnum_ProductBiddingCategoryLevel" json:"level,omitempty"`
	// Status of the product bidding category.
	Status enums.ProductBiddingCategoryStatusEnum_ProductBiddingCategoryStatus `protobuf:"varint,6,opt,name=status,proto3,enum=google.ads.googleads.v1.enums.ProductBiddingCategoryStatusEnum_ProductBiddingCategoryStatus" json:"status,omitempty"`
	// Language code of the product bidding category.
	LanguageCode *wrappers.StringValue `protobuf:"bytes,7,opt,name=language_code,json=languageCode,proto3" json:"language_code,omitempty"`
	// Display value of the product bidding category localized according to
	// language_code.
	LocalizedName        *wrappers.StringValue `protobuf:"bytes,8,opt,name=localized_name,json=localizedName,proto3" json:"localized_name,omitempty"`
	XXX_NoUnkeyedLiteral struct{}              `json:"-"`
	XXX_unrecognized     []byte                `json:"-"`
	XXX_sizecache        int32                 `json:"-"`
}

func (m *ProductBiddingCategoryConstant) Reset()         { *m = ProductBiddingCategoryConstant{} }
func (m *ProductBiddingCategoryConstant) String() string { return proto.CompactTextString(m) }
func (*ProductBiddingCategoryConstant) ProtoMessage()    {}
func (*ProductBiddingCategoryConstant) Descriptor() ([]byte, []int) {
	return fileDescriptor_108bf531d72dd437, []int{0}
}

func (m *ProductBiddingCategoryConstant) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_ProductBiddingCategoryConstant.Unmarshal(m, b)
}
func (m *ProductBiddingCategoryConstant) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_ProductBiddingCategoryConstant.Marshal(b, m, deterministic)
}
func (m *ProductBiddingCategoryConstant) XXX_Merge(src proto.Message) {
	xxx_messageInfo_ProductBiddingCategoryConstant.Merge(m, src)
}
func (m *ProductBiddingCategoryConstant) XXX_Size() int {
	return xxx_messageInfo_ProductBiddingCategoryConstant.Size(m)
}
func (m *ProductBiddingCategoryConstant) XXX_DiscardUnknown() {
	xxx_messageInfo_ProductBiddingCategoryConstant.DiscardUnknown(m)
}

var xxx_messageInfo_ProductBiddingCategoryConstant proto.InternalMessageInfo

func (m *ProductBiddingCategoryConstant) GetResourceName() string {
	if m != nil {
		return m.ResourceName
	}
	return ""
}

func (m *ProductBiddingCategoryConstant) GetId() *wrappers.Int64Value {
	if m != nil {
		return m.Id
	}
	return nil
}

func (m *ProductBiddingCategoryConstant) GetCountryCode() *wrappers.StringValue {
	if m != nil {
		return m.CountryCode
	}
	return nil
}

func (m *ProductBiddingCategoryConstant) GetProductBiddingCategoryConstantParent() *wrappers.StringValue {
	if m != nil {
		return m.ProductBiddingCategoryConstantParent
	}
	return nil
}

func (m *ProductBiddingCategoryConstant) GetLevel() enums.ProductBiddingCategoryLevelEnum_ProductBiddingCategoryLevel {
	if m != nil {
		return m.Level
	}
	return enums.ProductBiddingCategoryLevelEnum_UNSPECIFIED
}

func (m *ProductBiddingCategoryConstant) GetStatus() enums.ProductBiddingCategoryStatusEnum_ProductBiddingCategoryStatus {
	if m != nil {
		return m.Status
	}
	return enums.ProductBiddingCategoryStatusEnum_UNSPECIFIED
}

func (m *ProductBiddingCategoryConstant) GetLanguageCode() *wrappers.StringValue {
	if m != nil {
		return m.LanguageCode
	}
	return nil
}

func (m *ProductBiddingCategoryConstant) GetLocalizedName() *wrappers.StringValue {
	if m != nil {
		return m.LocalizedName
	}
	return nil
}

func init() {
	proto.RegisterType((*ProductBiddingCategoryConstant)(nil), "google.ads.googleads.v1.resources.ProductBiddingCategoryConstant")
}

func init() {
	proto.RegisterFile("google/ads/googleads/v1/resources/product_bidding_category_constant.proto", fileDescriptor_108bf531d72dd437)
}

var fileDescriptor_108bf531d72dd437 = []byte{
	// 509 bytes of a gzipped FileDescriptorProto
	0x1f, 0x8b, 0x08, 0x00, 0x00, 0x00, 0x00, 0x00, 0x02, 0xff, 0x9c, 0x94, 0x41, 0x6b, 0xd4, 0x40,
	0x14, 0xc7, 0x49, 0xea, 0xae, 0x3a, 0xdd, 0xed, 0x21, 0xa7, 0x50, 0x4b, 0xd9, 0x5a, 0x0b, 0x0b,
	0xc2, 0x84, 0x54, 0xf1, 0x10, 0x0f, 0x92, 0x0d, 0x52, 0x2a, 0x22, 0x4b, 0x0a, 0x7b, 0x28, 0x81,
	0x30, 0x9b, 0x19, 0x87, 0x40, 0x32, 0x13, 0x66, 0x26, 0x2b, 0xfa, 0x29, 0xbc, 0x7a, 0xf5, 0xe8,
	0x47, 0xf1, 0xa3, 0xf8, 0x29, 0x24, 0x33, 0x99, 0x5c, 0xb4, 0xe9, 0xd2, 0xdb, 0x4b, 0xde, 0xfb,
	0xff, 0x7f, 0x93, 0xf7, 0xde, 0x04, 0x5c, 0x53, 0xce, 0x69, 0x45, 0x02, 0x84, 0x65, 0x60, 0xc2,
	0x2e, 0xda, 0x85, 0x81, 0x20, 0x92, 0xb7, 0xa2, 0x20, 0x32, 0x68, 0x04, 0xc7, 0x6d, 0xa1, 0xf2,
	0x6d, 0x89, 0x71, 0xc9, 0x68, 0x5e, 0x20, 0x45, 0x28, 0x17, 0x5f, 0xf3, 0x82, 0x33, 0xa9, 0x10,
	0x53, 0xb0, 0x11, 0x5c, 0x71, 0xef, 0xcc, 0xe8, 0x21, 0xc2, 0x12, 0x0e, 0x56, 0x70, 0x17, 0xc2,
	0xc1, 0xea, 0x78, 0x75, 0x17, 0x8d, 0xb0, 0xb6, 0x1e, 0x21, 0x55, 0x64, 0x47, 0x2a, 0x83, 0x39,
	0x4e, 0x1e, 0xe8, 0x21, 0x15, 0x52, 0xad, 0xec, 0x4d, 0x4e, 0xac, 0x49, 0x53, 0x06, 0x88, 0x31,
	0xae, 0x90, 0x2a, 0x39, 0xb3, 0xd9, 0xd3, 0x3e, 0xab, 0x9f, 0xb6, 0xed, 0xe7, 0xe0, 0x8b, 0x40,
	0x4d, 0x43, 0x44, 0x9f, 0x7f, 0xfe, 0x63, 0x02, 0x4e, 0xd7, 0x86, 0xb3, 0x32, 0x98, 0xa4, 0xa7,
	0x24, 0x7d, 0x4b, 0xbc, 0x73, 0x30, 0xb7, 0x9f, 0x9d, 0x33, 0x54, 0x13, 0xdf, 0x59, 0x38, 0xcb,
	0xa7, 0xe9, 0xcc, 0xbe, 0xfc, 0x84, 0x6a, 0xe2, 0xbd, 0x04, 0x6e, 0x89, 0x7d, 0x77, 0xe1, 0x2c,
	0x0f, 0x2f, 0x9f, 0xf5, 0x3d, 0x83, 0x16, 0x0a, 0xaf, 0x99, 0x7a, 0xf3, 0x7a, 0x83, 0xaa, 0x96,
	0xa4, 0x6e, 0x89, 0xbd, 0x77, 0x60, 0x56, 0xf0, 0x96, 0x29, 0xdd, 0x78, 0x4c, 0xfc, 0x03, 0x2d,
	0x3b, 0xf9, 0x47, 0x76, 0xa3, 0x44, 0xc9, 0xa8, 0xd1, 0x1d, 0xf6, 0x8a, 0x84, 0x63, 0xe2, 0x29,
	0xb0, 0xbc, 0x77, 0x94, 0x79, 0x83, 0x04, 0x61, 0xca, 0x7f, 0xb4, 0x87, 0xf9, 0x8b, 0x66, 0xb4,
	0x05, 0x6b, 0xed, 0xe4, 0x35, 0x60, 0xa2, 0xa7, 0xe7, 0x4f, 0x16, 0xce, 0xf2, 0xe8, 0xf2, 0x16,
	0xde, 0xb5, 0x25, 0x7a, 0x7c, 0xf0, 0xff, 0x6d, 0xfd, 0xd8, 0x39, 0xbc, 0x67, 0x6d, 0x3d, 0x96,
	0x4f, 0x0d, 0xc8, 0x53, 0x60, 0x6a, 0x66, 0xed, 0x4f, 0x35, 0x32, 0x7b, 0x10, 0xf2, 0x46, 0x5b,
	0x8c, 0x30, 0x4d, 0x41, 0xda, 0xb3, 0xbc, 0x18, 0xcc, 0x2b, 0xc4, 0x68, 0x8b, 0x28, 0x31, 0xf3,
	0x79, 0xbc, 0x47, 0x0b, 0x67, 0x56, 0xa2, 0x07, 0x94, 0x80, 0xa3, 0x8a, 0x17, 0xa8, 0x2a, 0xbf,
	0x11, 0x6c, 0x96, 0xe6, 0xc9, 0x1e, 0x1e, 0xf3, 0x41, 0xd3, 0xed, 0xd4, 0xea, 0xbb, 0x0b, 0x2e,
	0x0a, 0x5e, 0xc3, 0x7b, 0x2f, 0xe3, 0xea, 0x7c, 0x7c, 0x85, 0xd7, 0x1d, 0x6c, 0xed, 0xdc, 0x7e,
	0xe8, 0x9d, 0x28, 0xef, 0x0e, 0x0b, 0xb9, 0xa0, 0x01, 0x25, 0x4c, 0x1f, 0xc5, 0xde, 0xbf, 0xa6,
	0x94, 0x23, 0x3f, 0x90, 0xb7, 0x43, 0xf4, 0xd3, 0x3d, 0xb8, 0x8a, 0xe3, 0x5f, 0xee, 0xd9, 0x95,
	0xb1, 0x8c, 0xb1, 0x84, 0x26, 0xec, 0xa2, 0x4d, 0x08, 0x53, 0x5b, 0xf9, 0xdb, 0xd6, 0x64, 0x31,
	0x96, 0xd9, 0x50, 0x93, 0x6d, 0xc2, 0x6c, 0xa8, 0xf9, 0xe3, 0x5e, 0x98, 0x44, 0x14, 0xc5, 0x58,
	0x46, 0xd1, 0x50, 0x15, 0x45, 0x9b, 0x30, 0x8a, 0x86, 0xba, 0xed, 0x54, 0x1f, 0xf6, 0xd5, 0xdf,
	0x00, 0x00, 0x00, 0xff, 0xff, 0xac, 0xa0, 0x52, 0x02, 0xec, 0x04, 0x00, 0x00,
}
