// Code generated by protoc-gen-go. DO NOT EDIT.
// source: google/devtools/resultstore/v2/file_processing_error.proto

package resultstore

import (
	fmt "fmt"
	math "math"

	proto "github.com/golang/protobuf/proto"
)

// Reference imports to suppress errors if they are not otherwise used.
var _ = proto.Marshal
var _ = fmt.Errorf
var _ = math.Inf

// This is a compile-time assertion to ensure that this generated file
// is compatible with the proto package it is being compiled against.
// A compilation error at this line likely means your copy of the
// proto package needs to be updated.
const _ = proto.ProtoPackageIsVersion3 // please upgrade the proto package

// Errors in file post-processing are categorized using this enum.
type FileProcessingErrorType int32

const (
	// Type unspecified or not listed here.
	FileProcessingErrorType_FILE_PROCESSING_ERROR_TYPE_UNSPECIFIED FileProcessingErrorType = 0
	// A read error occurred trying to read the file.
	FileProcessingErrorType_GENERIC_READ_ERROR FileProcessingErrorType = 1
	// There was an error trying to parse the file.
	FileProcessingErrorType_GENERIC_PARSE_ERROR FileProcessingErrorType = 2
	// File is exceeds size limit.
	FileProcessingErrorType_FILE_TOO_LARGE FileProcessingErrorType = 3
	// The result of parsing the file exceeded size limit.
	FileProcessingErrorType_OUTPUT_TOO_LARGE FileProcessingErrorType = 4
	// Read access to the file was denied by file system.
	FileProcessingErrorType_ACCESS_DENIED FileProcessingErrorType = 5
	// Deadline exceeded trying to read the file.
	FileProcessingErrorType_DEADLINE_EXCEEDED FileProcessingErrorType = 6
	// File not found.
	FileProcessingErrorType_NOT_FOUND FileProcessingErrorType = 7
	// File is empty but was expected to have content.
	FileProcessingErrorType_FILE_EMPTY FileProcessingErrorType = 8
)

var FileProcessingErrorType_name = map[int32]string{
	0: "FILE_PROCESSING_ERROR_TYPE_UNSPECIFIED",
	1: "GENERIC_READ_ERROR",
	2: "GENERIC_PARSE_ERROR",
	3: "FILE_TOO_LARGE",
	4: "OUTPUT_TOO_LARGE",
	5: "ACCESS_DENIED",
	6: "DEADLINE_EXCEEDED",
	7: "NOT_FOUND",
	8: "FILE_EMPTY",
}

var FileProcessingErrorType_value = map[string]int32{
	"FILE_PROCESSING_ERROR_TYPE_UNSPECIFIED": 0,
	"GENERIC_READ_ERROR":                     1,
	"GENERIC_PARSE_ERROR":                    2,
	"FILE_TOO_LARGE":                         3,
	"OUTPUT_TOO_LARGE":                       4,
	"ACCESS_DENIED":                          5,
	"DEADLINE_EXCEEDED":                      6,
	"NOT_FOUND":                              7,
	"FILE_EMPTY":                             8,
}

func (x FileProcessingErrorType) String() string {
	return proto.EnumName(FileProcessingErrorType_name, int32(x))
}

func (FileProcessingErrorType) EnumDescriptor() ([]byte, []int) {
	return fileDescriptor_09a61cbdcc9fd6e0, []int{0}
}

// Stores errors reading or parsing a file during post-processing.
type FileProcessingErrors struct {
	// The uid of the File being read or parsed.
	FileUid string `protobuf:"bytes,1,opt,name=file_uid,json=fileUid,proto3" json:"file_uid,omitempty"`
	// What went wrong.
	FileProcessingErrors []*FileProcessingError `protobuf:"bytes,3,rep,name=file_processing_errors,json=fileProcessingErrors,proto3" json:"file_processing_errors,omitempty"`
	XXX_NoUnkeyedLiteral struct{}               `json:"-"`
	XXX_unrecognized     []byte                 `json:"-"`
	XXX_sizecache        int32                  `json:"-"`
}

func (m *FileProcessingErrors) Reset()         { *m = FileProcessingErrors{} }
func (m *FileProcessingErrors) String() string { return proto.CompactTextString(m) }
func (*FileProcessingErrors) ProtoMessage()    {}
func (*FileProcessingErrors) Descriptor() ([]byte, []int) {
	return fileDescriptor_09a61cbdcc9fd6e0, []int{0}
}

func (m *FileProcessingErrors) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_FileProcessingErrors.Unmarshal(m, b)
}
func (m *FileProcessingErrors) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_FileProcessingErrors.Marshal(b, m, deterministic)
}
func (m *FileProcessingErrors) XXX_Merge(src proto.Message) {
	xxx_messageInfo_FileProcessingErrors.Merge(m, src)
}
func (m *FileProcessingErrors) XXX_Size() int {
	return xxx_messageInfo_FileProcessingErrors.Size(m)
}
func (m *FileProcessingErrors) XXX_DiscardUnknown() {
	xxx_messageInfo_FileProcessingErrors.DiscardUnknown(m)
}

var xxx_messageInfo_FileProcessingErrors proto.InternalMessageInfo

func (m *FileProcessingErrors) GetFileUid() string {
	if m != nil {
		return m.FileUid
	}
	return ""
}

func (m *FileProcessingErrors) GetFileProcessingErrors() []*FileProcessingError {
	if m != nil {
		return m.FileProcessingErrors
	}
	return nil
}

// Stores an error reading or parsing a file during post-processing.
type FileProcessingError struct {
	// The type of error that occurred.
	Type FileProcessingErrorType `protobuf:"varint,1,opt,name=type,proto3,enum=google.devtools.resultstore.v2.FileProcessingErrorType" json:"type,omitempty"`
	// Error message describing the problem.
	Message              string   `protobuf:"bytes,2,opt,name=message,proto3" json:"message,omitempty"`
	XXX_NoUnkeyedLiteral struct{} `json:"-"`
	XXX_unrecognized     []byte   `json:"-"`
	XXX_sizecache        int32    `json:"-"`
}

func (m *FileProcessingError) Reset()         { *m = FileProcessingError{} }
func (m *FileProcessingError) String() string { return proto.CompactTextString(m) }
func (*FileProcessingError) ProtoMessage()    {}
func (*FileProcessingError) Descriptor() ([]byte, []int) {
	return fileDescriptor_09a61cbdcc9fd6e0, []int{1}
}

func (m *FileProcessingError) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_FileProcessingError.Unmarshal(m, b)
}
func (m *FileProcessingError) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_FileProcessingError.Marshal(b, m, deterministic)
}
func (m *FileProcessingError) XXX_Merge(src proto.Message) {
	xxx_messageInfo_FileProcessingError.Merge(m, src)
}
func (m *FileProcessingError) XXX_Size() int {
	return xxx_messageInfo_FileProcessingError.Size(m)
}
func (m *FileProcessingError) XXX_DiscardUnknown() {
	xxx_messageInfo_FileProcessingError.DiscardUnknown(m)
}

var xxx_messageInfo_FileProcessingError proto.InternalMessageInfo

func (m *FileProcessingError) GetType() FileProcessingErrorType {
	if m != nil {
		return m.Type
	}
	return FileProcessingErrorType_FILE_PROCESSING_ERROR_TYPE_UNSPECIFIED
}

func (m *FileProcessingError) GetMessage() string {
	if m != nil {
		return m.Message
	}
	return ""
}

func init() {
	proto.RegisterEnum("google.devtools.resultstore.v2.FileProcessingErrorType", FileProcessingErrorType_name, FileProcessingErrorType_value)
	proto.RegisterType((*FileProcessingErrors)(nil), "google.devtools.resultstore.v2.FileProcessingErrors")
	proto.RegisterType((*FileProcessingError)(nil), "google.devtools.resultstore.v2.FileProcessingError")
}

func init() {
	proto.RegisterFile("google/devtools/resultstore/v2/file_processing_error.proto", fileDescriptor_09a61cbdcc9fd6e0)
}

var fileDescriptor_09a61cbdcc9fd6e0 = []byte{
	// 416 bytes of a gzipped FileDescriptorProto
	0x1f, 0x8b, 0x08, 0x00, 0x00, 0x00, 0x00, 0x00, 0x02, 0xff, 0x9c, 0x92, 0xcd, 0x6a, 0xdb, 0x40,
	0x10, 0x80, 0xab, 0x38, 0x8d, 0x93, 0x29, 0x31, 0xca, 0xc4, 0x4d, 0xdc, 0x4b, 0x09, 0x3e, 0x94,
	0x90, 0x83, 0x04, 0xce, 0xa1, 0xd0, 0x9e, 0x54, 0x69, 0x6c, 0x44, 0x5d, 0x69, 0x59, 0x4b, 0xd0,
	0xf4, 0xb2, 0xb8, 0xf1, 0x66, 0x11, 0x28, 0x5e, 0x75, 0x57, 0x31, 0x04, 0xfa, 0x28, 0x7d, 0xc1,
	0xbe, 0x45, 0xb1, 0xec, 0x14, 0x1f, 0xec, 0x16, 0x72, 0x9c, 0x9f, 0x6f, 0xbe, 0xd9, 0x65, 0xe0,
	0x83, 0xd2, 0x5a, 0x95, 0xd2, 0x9f, 0xc9, 0x45, 0xad, 0x75, 0x69, 0x7d, 0x23, 0xed, 0x43, 0x59,
	0xdb, 0x5a, 0x1b, 0xe9, 0x2f, 0x06, 0xfe, 0x5d, 0x51, 0x4a, 0x51, 0x19, 0x7d, 0x2b, 0xad, 0x2d,
	0xe6, 0x4a, 0x48, 0x63, 0xb4, 0xf1, 0x2a, 0xa3, 0x6b, 0x8d, 0x6f, 0x57, 0xac, 0xf7, 0xc4, 0x7a,
	0x1b, 0xac, 0xb7, 0x18, 0xf4, 0x7f, 0x39, 0xd0, 0x1d, 0x16, 0xa5, 0x64, 0x7f, 0x71, 0x5a, 0xd2,
	0x16, 0xdf, 0xc0, 0x61, 0x33, 0xf7, 0xa1, 0x98, 0xf5, 0x9c, 0x0b, 0xe7, 0xf2, 0x88, 0xb7, 0x97,
	0x71, 0x5e, 0xcc, 0xb0, 0x80, 0xb3, 0xad, 0x4a, 0xdb, 0x6b, 0x5d, 0xb4, 0x2e, 0x5f, 0x0d, 0xae,
	0xbd, 0x7f, 0x4b, 0xbd, 0x2d, 0x42, 0xde, 0xbd, 0xdb, 0xb2, 0x45, 0xff, 0x27, 0x9c, 0x6e, 0x69,
	0xc6, 0xcf, 0xb0, 0x5f, 0x3f, 0x56, 0xb2, 0x59, 0xac, 0x33, 0x78, 0xff, 0x0c, 0x5f, 0xf6, 0x58,
	0x49, 0xde, 0x0c, 0xc1, 0x1e, 0xb4, 0xef, 0xa5, 0xb5, 0x53, 0x25, 0x7b, 0x7b, 0xab, 0x87, 0xae,
	0xc3, 0xab, 0xdf, 0x0e, 0x9c, 0xef, 0x60, 0xf1, 0x0a, 0xde, 0x0d, 0xe3, 0x31, 0x09, 0xc6, 0xd3,
	0x90, 0x26, 0x93, 0x38, 0x19, 0x09, 0xe2, 0x3c, 0xe5, 0x22, 0xbb, 0x61, 0x24, 0xf2, 0x64, 0xc2,
	0x28, 0x8c, 0x87, 0x31, 0x45, 0xee, 0x0b, 0x3c, 0x03, 0x1c, 0x51, 0x42, 0x3c, 0x0e, 0x05, 0xa7,
	0x20, 0x5a, 0x35, 0xba, 0x0e, 0x9e, 0xc3, 0xe9, 0x53, 0x9e, 0x05, 0x7c, 0x42, 0xeb, 0xc2, 0x1e,
	0x22, 0x74, 0x9a, 0xe1, 0x59, 0x9a, 0x8a, 0x71, 0xc0, 0x47, 0xe4, 0xb6, 0xb0, 0x0b, 0x6e, 0x9a,
	0x67, 0x2c, 0xcf, 0x36, 0xb2, 0xfb, 0x78, 0x02, 0xc7, 0x41, 0xb8, 0x5c, 0x40, 0x44, 0x94, 0x2c,
	0x6d, 0x2f, 0xf1, 0x35, 0x9c, 0x44, 0x14, 0x44, 0xe3, 0x38, 0x21, 0x41, 0x5f, 0x43, 0xa2, 0x88,
	0x22, 0xf7, 0x00, 0x8f, 0xe1, 0x28, 0x49, 0x33, 0x31, 0x4c, 0xf3, 0x24, 0x72, 0xdb, 0xd8, 0x01,
	0x68, 0x14, 0xf4, 0x85, 0x65, 0x37, 0xee, 0xe1, 0xa7, 0x1f, 0xd0, 0xbf, 0xd5, 0xf7, 0xff, 0xf9,
	0x49, 0xe6, 0x7c, 0x8b, 0xd7, 0x1d, 0x4a, 0x97, 0xd3, 0xb9, 0xf2, 0xb4, 0x51, 0xbe, 0x92, 0xf3,
	0xe6, 0xd8, 0xfc, 0x55, 0x69, 0x5a, 0x15, 0x76, 0xd7, 0xad, 0x7e, 0xdc, 0x08, 0xbf, 0x1f, 0x34,
	0xd4, 0xf5, 0x9f, 0x00, 0x00, 0x00, 0xff, 0xff, 0x45, 0x58, 0xe8, 0x34, 0xe0, 0x02, 0x00, 0x00,
}
