// Code generated by protoc-gen-go. DO NOT EDIT.
// source: google/ads/googleads/v2/services/dynamic_search_ads_search_term_view_service.proto

package services

import (
	context "context"
	fmt "fmt"
	math "math"

	proto "github.com/golang/protobuf/proto"
	resources "google.golang.org/genproto/googleapis/ads/googleads/v2/resources"
	_ "google.golang.org/genproto/googleapis/api/annotations"
	grpc "google.golang.org/grpc"
)

// Reference imports to suppress errors if they are not otherwise used.
var _ = proto.Marshal
var _ = fmt.Errorf
var _ = math.Inf

// This is a compile-time assertion to ensure that this generated file
// is compatible with the proto package it is being compiled against.
// A compilation error at this line likely means your copy of the
// proto package needs to be updated.
const _ = proto.ProtoPackageIsVersion3 // please upgrade the proto package

// Request message for
// [DynamicSearchAdsSearchTermViewService.GetDynamicSearchAdsSearchTermView][google.ads.googleads.v2.services.DynamicSearchAdsSearchTermViewService.GetDynamicSearchAdsSearchTermView].
type GetDynamicSearchAdsSearchTermViewRequest struct {
	// The resource name of the dynamic search ads search term view to fetch.
	ResourceName         string   `protobuf:"bytes,1,opt,name=resource_name,json=resourceName,proto3" json:"resource_name,omitempty"`
	XXX_NoUnkeyedLiteral struct{} `json:"-"`
	XXX_unrecognized     []byte   `json:"-"`
	XXX_sizecache        int32    `json:"-"`
}

func (m *GetDynamicSearchAdsSearchTermViewRequest) Reset() {
	*m = GetDynamicSearchAdsSearchTermViewRequest{}
}
func (m *GetDynamicSearchAdsSearchTermViewRequest) String() string { return proto.CompactTextString(m) }
func (*GetDynamicSearchAdsSearchTermViewRequest) ProtoMessage()    {}
func (*GetDynamicSearchAdsSearchTermViewRequest) Descriptor() ([]byte, []int) {
	return fileDescriptor_92c56683a8a76be6, []int{0}
}

func (m *GetDynamicSearchAdsSearchTermViewRequest) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_GetDynamicSearchAdsSearchTermViewRequest.Unmarshal(m, b)
}
func (m *GetDynamicSearchAdsSearchTermViewRequest) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_GetDynamicSearchAdsSearchTermViewRequest.Marshal(b, m, deterministic)
}
func (m *GetDynamicSearchAdsSearchTermViewRequest) XXX_Merge(src proto.Message) {
	xxx_messageInfo_GetDynamicSearchAdsSearchTermViewRequest.Merge(m, src)
}
func (m *GetDynamicSearchAdsSearchTermViewRequest) XXX_Size() int {
	return xxx_messageInfo_GetDynamicSearchAdsSearchTermViewRequest.Size(m)
}
func (m *GetDynamicSearchAdsSearchTermViewRequest) XXX_DiscardUnknown() {
	xxx_messageInfo_GetDynamicSearchAdsSearchTermViewRequest.DiscardUnknown(m)
}

var xxx_messageInfo_GetDynamicSearchAdsSearchTermViewRequest proto.InternalMessageInfo

func (m *GetDynamicSearchAdsSearchTermViewRequest) GetResourceName() string {
	if m != nil {
		return m.ResourceName
	}
	return ""
}

func init() {
	proto.RegisterType((*GetDynamicSearchAdsSearchTermViewRequest)(nil), "google.ads.googleads.v2.services.GetDynamicSearchAdsSearchTermViewRequest")
}

func init() {
	proto.RegisterFile("google/ads/googleads/v2/services/dynamic_search_ads_search_term_view_service.proto", fileDescriptor_92c56683a8a76be6)
}

var fileDescriptor_92c56683a8a76be6 = []byte{
	// 412 bytes of a gzipped FileDescriptorProto
	0x1f, 0x8b, 0x08, 0x00, 0x00, 0x00, 0x00, 0x00, 0x02, 0xff, 0x8c, 0x93, 0x4f, 0x8b, 0xd4, 0x30,
	0x18, 0xc6, 0x99, 0x0a, 0x82, 0x45, 0x2f, 0xbd, 0xb8, 0x8c, 0x1e, 0xc6, 0x75, 0x85, 0x65, 0x0e,
	0x09, 0xd4, 0x5b, 0xc4, 0x43, 0x56, 0x61, 0xfc, 0x03, 0xba, 0xcc, 0xca, 0x1c, 0xa4, 0x50, 0x62,
	0xf3, 0x52, 0x03, 0x93, 0x64, 0xcc, 0x9b, 0xe9, 0x22, 0xe2, 0xc5, 0x6f, 0x20, 0x7e, 0x03, 0x8f,
	0x7e, 0x0e, 0x4f, 0x7b, 0xf5, 0x2b, 0x78, 0xf2, 0x3b, 0x08, 0xd2, 0x49, 0xd3, 0x75, 0x0f, 0x9d,
	0x99, 0xdb, 0x43, 0xde, 0x87, 0xdf, 0xf3, 0xfe, 0x69, 0xd3, 0x79, 0x6d, 0x6d, 0xbd, 0x04, 0x2a,
	0x24, 0xd2, 0x20, 0x5b, 0xd5, 0xe4, 0x14, 0xc1, 0x35, 0xaa, 0x02, 0xa4, 0xf2, 0xa3, 0x11, 0x5a,
	0x55, 0x25, 0x82, 0x70, 0xd5, 0xfb, 0x52, 0x48, 0x8c, 0xd2, 0x83, 0xd3, 0x65, 0xa3, 0xe0, 0xbc,
	0xec, 0xcc, 0x64, 0xe5, 0xac, 0xb7, 0xd9, 0x24, 0x80, 0x88, 0x90, 0x48, 0x7a, 0x26, 0x69, 0x72,
	0x12, 0x99, 0xe3, 0x97, 0x43, 0xa9, 0x0e, 0xd0, 0xae, 0xdd, 0x9e, 0xb1, 0x21, 0x6e, 0x7c, 0x37,
	0xc2, 0x56, 0x8a, 0x0a, 0x63, 0xac, 0x17, 0x5e, 0x59, 0x83, 0x5d, 0xf5, 0xf6, 0x7f, 0xd5, 0x6a,
	0xa9, 0xc0, 0xf8, 0x50, 0x38, 0x7c, 0x9d, 0x1e, 0xcf, 0xc0, 0x3f, 0x0d, 0x31, 0x67, 0x1b, 0x34,
	0x97, 0x18, 0xc4, 0x1b, 0x70, 0x7a, 0xa1, 0xe0, 0x7c, 0x0e, 0x1f, 0xd6, 0x80, 0x3e, 0xbb, 0x9f,
	0xde, 0x8a, 0x9d, 0x95, 0x46, 0x68, 0x38, 0x18, 0x4d, 0x46, 0xc7, 0x37, 0xe6, 0x37, 0xe3, 0xe3,
	0x2b, 0xa1, 0x21, 0xff, 0x99, 0xa4, 0x0f, 0xb6, 0xe3, 0xce, 0xc2, 0xfc, 0xd9, 0xdf, 0x51, 0x7a,
	0x6f, 0x67, 0x76, 0xf6, 0x82, 0xec, 0xda, 0x23, 0xd9, 0x77, 0x80, 0x31, 0x1f, 0x64, 0xf5, 0x1b,
	0x27, 0xdb, 0x49, 0x87, 0xcf, 0xbf, 0xfc, 0xfa, 0xfd, 0x2d, 0x79, 0x92, 0xf1, 0xf6, 0x4e, 0x9f,
	0xae, 0xac, 0xe3, 0x71, 0xb5, 0x46, 0x6f, 0x35, 0x38, 0xa4, 0xd3, 0x78, 0xb8, 0x01, 0x0c, 0xd2,
	0xe9, 0xe7, 0xf1, 0x9d, 0x0b, 0x7e, 0x70, 0xd9, 0x44, 0xa7, 0x56, 0x0a, 0x49, 0x65, 0xf5, 0xc9,
	0xd7, 0x24, 0x3d, 0xaa, 0xac, 0xde, 0x39, 0xfc, 0xc9, 0x74, 0xaf, 0x65, 0x9f, 0xb6, 0xc7, 0x3e,
	0x1d, 0xbd, 0x7d, 0xd6, 0xf1, 0x6a, 0xbb, 0x14, 0xa6, 0x26, 0xd6, 0xd5, 0xb4, 0x06, 0xb3, 0xf9,
	0x14, 0xe8, 0x65, 0x07, 0xc3, 0xff, 0xc1, 0xa3, 0x28, 0xbe, 0x27, 0xd7, 0x66, 0x9c, 0xff, 0x48,
	0x26, 0xb3, 0x00, 0xe4, 0x12, 0x49, 0x90, 0xad, 0x5a, 0xe4, 0xa4, 0x0b, 0xc6, 0x8b, 0x68, 0x29,
	0xb8, 0xc4, 0xa2, 0xb7, 0x14, 0x8b, 0xbc, 0x88, 0x96, 0x3f, 0xc9, 0x51, 0x78, 0x67, 0x8c, 0x4b,
	0x64, 0xac, 0x37, 0x31, 0xb6, 0xc8, 0x19, 0x8b, 0xb6, 0x77, 0xd7, 0x37, 0x7d, 0x3e, 0xfc, 0x17,
	0x00, 0x00, 0xff, 0xff, 0x44, 0x70, 0x61, 0x55, 0xae, 0x03, 0x00, 0x00,
}

// Reference imports to suppress errors if they are not otherwise used.
var _ context.Context
var _ grpc.ClientConn

// This is a compile-time assertion to ensure that this generated file
// is compatible with the grpc package it is being compiled against.
const _ = grpc.SupportPackageIsVersion4

// DynamicSearchAdsSearchTermViewServiceClient is the client API for DynamicSearchAdsSearchTermViewService service.
//
// For semantics around ctx use and closing/ending streaming RPCs, please refer to https://godoc.org/google.golang.org/grpc#ClientConn.NewStream.
type DynamicSearchAdsSearchTermViewServiceClient interface {
	// Returns the requested dynamic search ads search term view in full detail.
	GetDynamicSearchAdsSearchTermView(ctx context.Context, in *GetDynamicSearchAdsSearchTermViewRequest, opts ...grpc.CallOption) (*resources.DynamicSearchAdsSearchTermView, error)
}

type dynamicSearchAdsSearchTermViewServiceClient struct {
	cc *grpc.ClientConn
}

func NewDynamicSearchAdsSearchTermViewServiceClient(cc *grpc.ClientConn) DynamicSearchAdsSearchTermViewServiceClient {
	return &dynamicSearchAdsSearchTermViewServiceClient{cc}
}

func (c *dynamicSearchAdsSearchTermViewServiceClient) GetDynamicSearchAdsSearchTermView(ctx context.Context, in *GetDynamicSearchAdsSearchTermViewRequest, opts ...grpc.CallOption) (*resources.DynamicSearchAdsSearchTermView, error) {
	out := new(resources.DynamicSearchAdsSearchTermView)
	err := c.cc.Invoke(ctx, "/google.ads.googleads.v2.services.DynamicSearchAdsSearchTermViewService/GetDynamicSearchAdsSearchTermView", in, out, opts...)
	if err != nil {
		return nil, err
	}
	return out, nil
}

// DynamicSearchAdsSearchTermViewServiceServer is the server API for DynamicSearchAdsSearchTermViewService service.
type DynamicSearchAdsSearchTermViewServiceServer interface {
	// Returns the requested dynamic search ads search term view in full detail.
	GetDynamicSearchAdsSearchTermView(context.Context, *GetDynamicSearchAdsSearchTermViewRequest) (*resources.DynamicSearchAdsSearchTermView, error)
}

func RegisterDynamicSearchAdsSearchTermViewServiceServer(s *grpc.Server, srv DynamicSearchAdsSearchTermViewServiceServer) {
	s.RegisterService(&_DynamicSearchAdsSearchTermViewService_serviceDesc, srv)
}

func _DynamicSearchAdsSearchTermViewService_GetDynamicSearchAdsSearchTermView_Handler(srv interface{}, ctx context.Context, dec func(interface{}) error, interceptor grpc.UnaryServerInterceptor) (interface{}, error) {
	in := new(GetDynamicSearchAdsSearchTermViewRequest)
	if err := dec(in); err != nil {
		return nil, err
	}
	if interceptor == nil {
		return srv.(DynamicSearchAdsSearchTermViewServiceServer).GetDynamicSearchAdsSearchTermView(ctx, in)
	}
	info := &grpc.UnaryServerInfo{
		Server:     srv,
		FullMethod: "/google.ads.googleads.v2.services.DynamicSearchAdsSearchTermViewService/GetDynamicSearchAdsSearchTermView",
	}
	handler := func(ctx context.Context, req interface{}) (interface{}, error) {
		return srv.(DynamicSearchAdsSearchTermViewServiceServer).GetDynamicSearchAdsSearchTermView(ctx, req.(*GetDynamicSearchAdsSearchTermViewRequest))
	}
	return interceptor(ctx, in, info, handler)
}

var _DynamicSearchAdsSearchTermViewService_serviceDesc = grpc.ServiceDesc{
	ServiceName: "google.ads.googleads.v2.services.DynamicSearchAdsSearchTermViewService",
	HandlerType: (*DynamicSearchAdsSearchTermViewServiceServer)(nil),
	Methods: []grpc.MethodDesc{
		{
			MethodName: "GetDynamicSearchAdsSearchTermView",
			Handler:    _DynamicSearchAdsSearchTermViewService_GetDynamicSearchAdsSearchTermView_Handler,
		},
	},
	Streams:  []grpc.StreamDesc{},
	Metadata: "google/ads/googleads/v2/services/dynamic_search_ads_search_term_view_service.proto",
}
