// Code generated by protoc-gen-go. DO NOT EDIT.
// source: google/ads/googleads/v2/enums/targeting_dimension.proto

package enums

import (
	fmt "fmt"
	math "math"

	proto "github.com/golang/protobuf/proto"
	_ "google.golang.org/genproto/googleapis/api/annotations"
)

// Reference imports to suppress errors if they are not otherwise used.
var _ = proto.Marshal
var _ = fmt.Errorf
var _ = math.Inf

// This is a compile-time assertion to ensure that this generated file
// is compatible with the proto package it is being compiled against.
// A compilation error at this line likely means your copy of the
// proto package needs to be updated.
const _ = proto.ProtoPackageIsVersion3 // please upgrade the proto package

// Enum describing possible targeting dimensions.
type TargetingDimensionEnum_TargetingDimension int32

const (
	// Not specified.
	TargetingDimensionEnum_UNSPECIFIED TargetingDimensionEnum_TargetingDimension = 0
	// Used for return value only. Represents value unknown in this version.
	TargetingDimensionEnum_UNKNOWN TargetingDimensionEnum_TargetingDimension = 1
	// Keyword criteria, e.g. 'mars cruise'. KEYWORD may be used as a custom bid
	// dimension. Keywords are always a targeting dimension, so may not be set
	// as a target "ALL" dimension with TargetRestriction.
	TargetingDimensionEnum_KEYWORD TargetingDimensionEnum_TargetingDimension = 2
	// Audience criteria, which include user list, user interest, custom
	// affinity,  and custom in market.
	TargetingDimensionEnum_AUDIENCE TargetingDimensionEnum_TargetingDimension = 3
	// Topic criteria for targeting categories of content, e.g.
	// 'category::Animals>Pets' Used for Display and Video targeting.
	TargetingDimensionEnum_TOPIC TargetingDimensionEnum_TargetingDimension = 4
	// Criteria for targeting gender.
	TargetingDimensionEnum_GENDER TargetingDimensionEnum_TargetingDimension = 5
	// Criteria for targeting age ranges.
	TargetingDimensionEnum_AGE_RANGE TargetingDimensionEnum_TargetingDimension = 6
	// Placement criteria, which include websites like 'www.flowers4sale.com',
	// as well as mobile applications, mobile app categories, YouTube videos,
	// and YouTube channels.
	TargetingDimensionEnum_PLACEMENT TargetingDimensionEnum_TargetingDimension = 7
	// Criteria for parental status targeting.
	TargetingDimensionEnum_PARENTAL_STATUS TargetingDimensionEnum_TargetingDimension = 8
	// Criteria for income range targeting.
	TargetingDimensionEnum_INCOME_RANGE TargetingDimensionEnum_TargetingDimension = 9
)

var TargetingDimensionEnum_TargetingDimension_name = map[int32]string{
	0: "UNSPECIFIED",
	1: "UNKNOWN",
	2: "KEYWORD",
	3: "AUDIENCE",
	4: "TOPIC",
	5: "GENDER",
	6: "AGE_RANGE",
	7: "PLACEMENT",
	8: "PARENTAL_STATUS",
	9: "INCOME_RANGE",
}

var TargetingDimensionEnum_TargetingDimension_value = map[string]int32{
	"UNSPECIFIED":     0,
	"UNKNOWN":         1,
	"KEYWORD":         2,
	"AUDIENCE":        3,
	"TOPIC":           4,
	"GENDER":          5,
	"AGE_RANGE":       6,
	"PLACEMENT":       7,
	"PARENTAL_STATUS": 8,
	"INCOME_RANGE":    9,
}

func (x TargetingDimensionEnum_TargetingDimension) String() string {
	return proto.EnumName(TargetingDimensionEnum_TargetingDimension_name, int32(x))
}

func (TargetingDimensionEnum_TargetingDimension) EnumDescriptor() ([]byte, []int) {
	return fileDescriptor_022a85399765aea5, []int{0, 0}
}

// The dimensions that can be targeted.
type TargetingDimensionEnum struct {
	XXX_NoUnkeyedLiteral struct{} `json:"-"`
	XXX_unrecognized     []byte   `json:"-"`
	XXX_sizecache        int32    `json:"-"`
}

func (m *TargetingDimensionEnum) Reset()         { *m = TargetingDimensionEnum{} }
func (m *TargetingDimensionEnum) String() string { return proto.CompactTextString(m) }
func (*TargetingDimensionEnum) ProtoMessage()    {}
func (*TargetingDimensionEnum) Descriptor() ([]byte, []int) {
	return fileDescriptor_022a85399765aea5, []int{0}
}

func (m *TargetingDimensionEnum) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_TargetingDimensionEnum.Unmarshal(m, b)
}
func (m *TargetingDimensionEnum) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_TargetingDimensionEnum.Marshal(b, m, deterministic)
}
func (m *TargetingDimensionEnum) XXX_Merge(src proto.Message) {
	xxx_messageInfo_TargetingDimensionEnum.Merge(m, src)
}
func (m *TargetingDimensionEnum) XXX_Size() int {
	return xxx_messageInfo_TargetingDimensionEnum.Size(m)
}
func (m *TargetingDimensionEnum) XXX_DiscardUnknown() {
	xxx_messageInfo_TargetingDimensionEnum.DiscardUnknown(m)
}

var xxx_messageInfo_TargetingDimensionEnum proto.InternalMessageInfo

func init() {
	proto.RegisterEnum("google.ads.googleads.v2.enums.TargetingDimensionEnum_TargetingDimension", TargetingDimensionEnum_TargetingDimension_name, TargetingDimensionEnum_TargetingDimension_value)
	proto.RegisterType((*TargetingDimensionEnum)(nil), "google.ads.googleads.v2.enums.TargetingDimensionEnum")
}

func init() {
	proto.RegisterFile("google/ads/googleads/v2/enums/targeting_dimension.proto", fileDescriptor_022a85399765aea5)
}

var fileDescriptor_022a85399765aea5 = []byte{
	// 378 bytes of a gzipped FileDescriptorProto
	0x1f, 0x8b, 0x08, 0x00, 0x00, 0x00, 0x00, 0x00, 0x02, 0xff, 0x7c, 0x51, 0xdf, 0xaa, 0xd3, 0x30,
	0x1c, 0xb6, 0x3d, 0x9e, 0x9d, 0xb3, 0x6c, 0xb2, 0x10, 0x41, 0x41, 0xdc, 0xc5, 0xf6, 0x00, 0x29,
	0xd4, 0x0b, 0x21, 0x5e, 0x65, 0x6d, 0x2c, 0x65, 0x5b, 0x5a, 0xba, 0x76, 0x43, 0x29, 0x8c, 0x6a,
	0x4b, 0x28, 0xac, 0xc9, 0x58, 0xba, 0x3d, 0x90, 0x77, 0xfa, 0x1c, 0x5e, 0xf9, 0x28, 0xe2, 0x43,
	0x48, 0x5b, 0xbb, 0x9b, 0xe1, 0xb9, 0x09, 0xdf, 0x2f, 0xdf, 0x1f, 0x92, 0xef, 0x07, 0xde, 0x0b,
	0xa5, 0xc4, 0xa1, 0xb0, 0xb2, 0x5c, 0x5b, 0x1d, 0x6c, 0xd0, 0xc5, 0xb6, 0x0a, 0x79, 0xae, 0xb4,
	0x55, 0x67, 0x27, 0x51, 0xd4, 0xa5, 0x14, 0xfb, 0xbc, 0xac, 0x0a, 0xa9, 0x4b, 0x25, 0xf1, 0xf1,
	0xa4, 0x6a, 0x85, 0xa6, 0x9d, 0x1a, 0x67, 0xb9, 0xc6, 0x57, 0x23, 0xbe, 0xd8, 0xb8, 0x35, 0xbe,
	0x79, 0xdb, 0xe7, 0x1e, 0x4b, 0x2b, 0x93, 0x52, 0xd5, 0x59, 0x5d, 0x2a, 0xa9, 0x3b, 0xf3, 0xfc,
	0xa7, 0x01, 0x5e, 0xc5, 0x7d, 0xb4, 0xdb, 0x27, 0x33, 0x79, 0xae, 0xe6, 0xdf, 0x0d, 0x80, 0x6e,
	0x29, 0x34, 0x01, 0xa3, 0x84, 0x6f, 0x42, 0xe6, 0xf8, 0x1f, 0x7d, 0xe6, 0xc2, 0x67, 0x68, 0x04,
	0x1e, 0x12, 0xbe, 0xe4, 0xc1, 0x8e, 0x43, 0xa3, 0x19, 0x96, 0xec, 0xd3, 0x2e, 0x88, 0x5c, 0x68,
	0xa2, 0x31, 0x78, 0xa4, 0x89, 0xeb, 0x33, 0xee, 0x30, 0x78, 0x87, 0x86, 0xe0, 0x3e, 0x0e, 0x42,
	0xdf, 0x81, 0xcf, 0x11, 0x00, 0x03, 0x8f, 0x71, 0x97, 0x45, 0xf0, 0x1e, 0xbd, 0x00, 0x43, 0xea,
	0xb1, 0x7d, 0x44, 0xb9, 0xc7, 0xe0, 0xa0, 0x19, 0xc3, 0x15, 0x75, 0xd8, 0x9a, 0xf1, 0x18, 0x3e,
	0xa0, 0x97, 0x60, 0x12, 0xd2, 0x88, 0xf1, 0x98, 0xae, 0xf6, 0x9b, 0x98, 0xc6, 0xc9, 0x06, 0x3e,
	0x22, 0x08, 0xc6, 0x3e, 0x77, 0x82, 0x75, 0xef, 0x1a, 0x2e, 0xfe, 0x18, 0x60, 0xf6, 0x55, 0x55,
	0xf8, 0xc9, 0x2a, 0x16, 0xaf, 0x6f, 0xbf, 0x13, 0x36, 0x2d, 0x84, 0xc6, 0xe7, 0xc5, 0x3f, 0xa7,
	0x50, 0x87, 0x4c, 0x0a, 0xac, 0x4e, 0xc2, 0x12, 0x85, 0x6c, 0x3b, 0xea, 0xb7, 0x71, 0x2c, 0xf5,
	0x7f, 0x96, 0xf3, 0xa1, 0x3d, 0xbf, 0x99, 0x77, 0x1e, 0xa5, 0x3f, 0xcc, 0xa9, 0xd7, 0x45, 0xd1,
	0x5c, 0xe3, 0x0e, 0x36, 0x68, 0x6b, 0xe3, 0xa6, 0x55, 0xfd, 0xab, 0xe7, 0x53, 0x9a, 0xeb, 0xf4,
	0xca, 0xa7, 0x5b, 0x3b, 0x6d, 0xf9, 0xdf, 0xe6, 0xac, 0xbb, 0x24, 0x84, 0xe6, 0x9a, 0x90, 0xab,
	0x82, 0x90, 0xad, 0x4d, 0x48, 0xab, 0xf9, 0x32, 0x68, 0x1f, 0xf6, 0xee, 0x6f, 0x00, 0x00, 0x00,
	0xff, 0xff, 0x7a, 0xa5, 0x32, 0x37, 0x34, 0x02, 0x00, 0x00,
}
