// Code generated by protoc-gen-go. DO NOT EDIT.
// source: google/ads/googleads/v2/services/account_budget_service.proto

package services

import (
	context "context"
	fmt "fmt"
	math "math"

	proto "github.com/golang/protobuf/proto"
	resources "google.golang.org/genproto/googleapis/ads/googleads/v2/resources"
	_ "google.golang.org/genproto/googleapis/api/annotations"
	grpc "google.golang.org/grpc"
)

// Reference imports to suppress errors if they are not otherwise used.
var _ = proto.Marshal
var _ = fmt.Errorf
var _ = math.Inf

// This is a compile-time assertion to ensure that this generated file
// is compatible with the proto package it is being compiled against.
// A compilation error at this line likely means your copy of the
// proto package needs to be updated.
const _ = proto.ProtoPackageIsVersion3 // please upgrade the proto package

// Request message for
// [AccountBudgetService.GetAccountBudget][google.ads.googleads.v2.services.AccountBudgetService.GetAccountBudget].
type GetAccountBudgetRequest struct {
	// The resource name of the account-level budget to fetch.
	ResourceName         string   `protobuf:"bytes,1,opt,name=resource_name,json=resourceName,proto3" json:"resource_name,omitempty"`
	XXX_NoUnkeyedLiteral struct{} `json:"-"`
	XXX_unrecognized     []byte   `json:"-"`
	XXX_sizecache        int32    `json:"-"`
}

func (m *GetAccountBudgetRequest) Reset()         { *m = GetAccountBudgetRequest{} }
func (m *GetAccountBudgetRequest) String() string { return proto.CompactTextString(m) }
func (*GetAccountBudgetRequest) ProtoMessage()    {}
func (*GetAccountBudgetRequest) Descriptor() ([]byte, []int) {
	return fileDescriptor_b0a8f4e7a5a98254, []int{0}
}

func (m *GetAccountBudgetRequest) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_GetAccountBudgetRequest.Unmarshal(m, b)
}
func (m *GetAccountBudgetRequest) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_GetAccountBudgetRequest.Marshal(b, m, deterministic)
}
func (m *GetAccountBudgetRequest) XXX_Merge(src proto.Message) {
	xxx_messageInfo_GetAccountBudgetRequest.Merge(m, src)
}
func (m *GetAccountBudgetRequest) XXX_Size() int {
	return xxx_messageInfo_GetAccountBudgetRequest.Size(m)
}
func (m *GetAccountBudgetRequest) XXX_DiscardUnknown() {
	xxx_messageInfo_GetAccountBudgetRequest.DiscardUnknown(m)
}

var xxx_messageInfo_GetAccountBudgetRequest proto.InternalMessageInfo

func (m *GetAccountBudgetRequest) GetResourceName() string {
	if m != nil {
		return m.ResourceName
	}
	return ""
}

func init() {
	proto.RegisterType((*GetAccountBudgetRequest)(nil), "google.ads.googleads.v2.services.GetAccountBudgetRequest")
}

func init() {
	proto.RegisterFile("google/ads/googleads/v2/services/account_budget_service.proto", fileDescriptor_b0a8f4e7a5a98254)
}

var fileDescriptor_b0a8f4e7a5a98254 = []byte{
	// 387 bytes of a gzipped FileDescriptorProto
	0x1f, 0x8b, 0x08, 0x00, 0x00, 0x00, 0x00, 0x00, 0x02, 0xff, 0x84, 0x92, 0xc1, 0x4a, 0xeb, 0x40,
	0x18, 0x85, 0x49, 0x2e, 0x5c, 0xb8, 0xe1, 0x0a, 0x12, 0x84, 0xd6, 0xe8, 0xa2, 0xd4, 0x2e, 0xa4,
	0x8b, 0x99, 0x12, 0x41, 0x74, 0xa4, 0x42, 0xba, 0xa9, 0x2b, 0x29, 0x15, 0xba, 0x90, 0x40, 0x99,
	0x26, 0x43, 0x08, 0x34, 0x33, 0x35, 0xff, 0xa4, 0x1b, 0x11, 0xc4, 0x57, 0xf0, 0x0d, 0x5c, 0xfa,
	0x06, 0xbe, 0x42, 0xb7, 0xbe, 0x82, 0x2b, 0x37, 0xbe, 0x82, 0xa4, 0x93, 0x49, 0xad, 0x1a, 0xba,
	0x3b, 0xcc, 0xfc, 0xdf, 0x39, 0xf3, 0x9f, 0xc4, 0xea, 0x46, 0x42, 0x44, 0x53, 0x86, 0x69, 0x08,
	0x58, 0xc9, 0x5c, 0xcd, 0x5d, 0x0c, 0x2c, 0x9d, 0xc7, 0x01, 0x03, 0x4c, 0x83, 0x40, 0x64, 0x5c,
	0x8e, 0x27, 0x59, 0x18, 0x31, 0x39, 0x2e, 0xce, 0xd1, 0x2c, 0x15, 0x52, 0xd8, 0x0d, 0xc5, 0x20,
	0x1a, 0x02, 0x2a, 0x71, 0x34, 0x77, 0x91, 0xc6, 0x9d, 0xe3, 0xaa, 0x80, 0x94, 0x81, 0xc8, 0xd2,
	0x9f, 0x09, 0xca, 0xd9, 0xd9, 0xd7, 0xdc, 0x2c, 0xc6, 0x94, 0x73, 0x21, 0xa9, 0x8c, 0x05, 0x87,
	0xe2, 0xb6, 0xf6, 0xe5, 0x36, 0x98, 0xc6, 0x8c, 0x17, 0x58, 0xf3, 0xdc, 0xaa, 0xf5, 0x99, 0xf4,
	0x94, 0x63, 0x6f, 0x69, 0x38, 0x64, 0x37, 0x19, 0x03, 0x69, 0x1f, 0x58, 0x5b, 0x3a, 0x73, 0xcc,
	0x69, 0xc2, 0xea, 0x46, 0xc3, 0x38, 0xfc, 0x37, 0xfc, 0xaf, 0x0f, 0x2f, 0x69, 0xc2, 0xdc, 0x0f,
	0xc3, 0xda, 0x59, 0xa3, 0xaf, 0xd4, 0x22, 0xf6, 0x8b, 0x61, 0x6d, 0x7f, 0x77, 0xb6, 0x4f, 0xd1,
	0xa6, 0xfd, 0x51, 0xc5, 0x6b, 0x9c, 0x4e, 0x25, 0x5a, 0x16, 0x83, 0xd6, 0xc0, 0xe6, 0xc9, 0xc3,
	0xeb, 0xdb, 0xa3, 0xe9, 0xda, 0x9d, 0xbc, 0xbd, 0xdb, 0xb5, 0x55, 0xba, 0x41, 0x06, 0x52, 0x24,
	0x2c, 0x05, 0xdc, 0xd6, 0x75, 0x2a, 0x0a, 0x70, 0xfb, 0xce, 0xd9, 0x5b, 0x78, 0xf5, 0x55, 0x44,
	0xa1, 0x66, 0x31, 0xa0, 0x40, 0x24, 0xbd, 0x7b, 0xd3, 0x6a, 0x05, 0x22, 0xd9, 0xb8, 0x49, 0x6f,
	0xf7, 0xb7, 0x5e, 0x06, 0x79, 0xeb, 0x03, 0xe3, 0xfa, 0xa2, 0xc0, 0x23, 0x31, 0xa5, 0x3c, 0x42,
	0x22, 0x8d, 0x70, 0xc4, 0xf8, 0xf2, 0x9b, 0xe0, 0x55, 0x60, 0xf5, 0x6f, 0x76, 0xa6, 0xc5, 0x93,
	0xf9, 0xa7, 0xef, 0x79, 0xcf, 0x66, 0xa3, 0xaf, 0x0c, 0xbd, 0x10, 0x90, 0x92, 0xb9, 0x1a, 0xb9,
	0xa8, 0x08, 0x86, 0x85, 0x1e, 0xf1, 0xbd, 0x10, 0xfc, 0x72, 0xc4, 0x1f, 0xb9, 0xbe, 0x1e, 0x79,
	0x37, 0x5b, 0xea, 0x9c, 0x10, 0x2f, 0x04, 0x42, 0xca, 0x21, 0x42, 0x46, 0x2e, 0x21, 0x7a, 0x6c,
	0xf2, 0x77, 0xf9, 0xce, 0xa3, 0xcf, 0x00, 0x00, 0x00, 0xff, 0xff, 0xcf, 0x0c, 0x5f, 0x94, 0x0d,
	0x03, 0x00, 0x00,
}

// Reference imports to suppress errors if they are not otherwise used.
var _ context.Context
var _ grpc.ClientConn

// This is a compile-time assertion to ensure that this generated file
// is compatible with the grpc package it is being compiled against.
const _ = grpc.SupportPackageIsVersion4

// AccountBudgetServiceClient is the client API for AccountBudgetService service.
//
// For semantics around ctx use and closing/ending streaming RPCs, please refer to https://godoc.org/google.golang.org/grpc#ClientConn.NewStream.
type AccountBudgetServiceClient interface {
	// Returns an account-level budget in full detail.
	GetAccountBudget(ctx context.Context, in *GetAccountBudgetRequest, opts ...grpc.CallOption) (*resources.AccountBudget, error)
}

type accountBudgetServiceClient struct {
	cc *grpc.ClientConn
}

func NewAccountBudgetServiceClient(cc *grpc.ClientConn) AccountBudgetServiceClient {
	return &accountBudgetServiceClient{cc}
}

func (c *accountBudgetServiceClient) GetAccountBudget(ctx context.Context, in *GetAccountBudgetRequest, opts ...grpc.CallOption) (*resources.AccountBudget, error) {
	out := new(resources.AccountBudget)
	err := c.cc.Invoke(ctx, "/google.ads.googleads.v2.services.AccountBudgetService/GetAccountBudget", in, out, opts...)
	if err != nil {
		return nil, err
	}
	return out, nil
}

// AccountBudgetServiceServer is the server API for AccountBudgetService service.
type AccountBudgetServiceServer interface {
	// Returns an account-level budget in full detail.
	GetAccountBudget(context.Context, *GetAccountBudgetRequest) (*resources.AccountBudget, error)
}

func RegisterAccountBudgetServiceServer(s *grpc.Server, srv AccountBudgetServiceServer) {
	s.RegisterService(&_AccountBudgetService_serviceDesc, srv)
}

func _AccountBudgetService_GetAccountBudget_Handler(srv interface{}, ctx context.Context, dec func(interface{}) error, interceptor grpc.UnaryServerInterceptor) (interface{}, error) {
	in := new(GetAccountBudgetRequest)
	if err := dec(in); err != nil {
		return nil, err
	}
	if interceptor == nil {
		return srv.(AccountBudgetServiceServer).GetAccountBudget(ctx, in)
	}
	info := &grpc.UnaryServerInfo{
		Server:     srv,
		FullMethod: "/google.ads.googleads.v2.services.AccountBudgetService/GetAccountBudget",
	}
	handler := func(ctx context.Context, req interface{}) (interface{}, error) {
		return srv.(AccountBudgetServiceServer).GetAccountBudget(ctx, req.(*GetAccountBudgetRequest))
	}
	return interceptor(ctx, in, info, handler)
}

var _AccountBudgetService_serviceDesc = grpc.ServiceDesc{
	ServiceName: "google.ads.googleads.v2.services.AccountBudgetService",
	HandlerType: (*AccountBudgetServiceServer)(nil),
	Methods: []grpc.MethodDesc{
		{
			MethodName: "GetAccountBudget",
			Handler:    _AccountBudgetService_GetAccountBudget_Handler,
		},
	},
	Streams:  []grpc.StreamDesc{},
	Metadata: "google/ads/googleads/v2/services/account_budget_service.proto",
}
