// Code generated by protoc-gen-go. DO NOT EDIT.
// source: google/ads/googleads/v2/enums/external_conversion_source.proto

package enums

import (
	fmt "fmt"
	math "math"

	proto "github.com/golang/protobuf/proto"
	_ "google.golang.org/genproto/googleapis/api/annotations"
)

// Reference imports to suppress errors if they are not otherwise used.
var _ = proto.Marshal
var _ = fmt.Errorf
var _ = math.Inf

// This is a compile-time assertion to ensure that this generated file
// is compatible with the proto package it is being compiled against.
// A compilation error at this line likely means your copy of the
// proto package needs to be updated.
const _ = proto.ProtoPackageIsVersion3 // please upgrade the proto package

// The external conversion source that is associated with a ConversionAction.
type ExternalConversionSourceEnum_ExternalConversionSource int32

const (
	// Not specified.
	ExternalConversionSourceEnum_UNSPECIFIED ExternalConversionSourceEnum_ExternalConversionSource = 0
	// Represents value unknown in this version.
	ExternalConversionSourceEnum_UNKNOWN ExternalConversionSourceEnum_ExternalConversionSource = 1
	// Conversion that occurs when a user navigates to a particular webpage
	// after viewing an ad; Displayed in Google Ads UI as 'Website'.
	ExternalConversionSourceEnum_WEBPAGE ExternalConversionSourceEnum_ExternalConversionSource = 2
	// Conversion that comes from linked Google Analytics goal or transaction;
	// Displayed in Google Ads UI as 'Analytics'.
	ExternalConversionSourceEnum_ANALYTICS ExternalConversionSourceEnum_ExternalConversionSource = 3
	// Website conversion that is uploaded through ConversionUploadService;
	// Displayed in Google Ads UI as 'Import from clicks'.
	ExternalConversionSourceEnum_UPLOAD ExternalConversionSourceEnum_ExternalConversionSource = 4
	// Conversion that occurs when a user clicks on a call extension directly on
	// an ad; Displayed in Google Ads UI as 'Calls from ads'.
	ExternalConversionSourceEnum_AD_CALL_METRICS ExternalConversionSourceEnum_ExternalConversionSource = 5
	// Conversion that occurs when a user calls a dynamically-generated phone
	// number (by installed javascript) from an advertiser's website after
	// clicking on an ad; Displayed in Google Ads UI as 'Calls from website'.
	ExternalConversionSourceEnum_WEBSITE_CALL_METRICS ExternalConversionSourceEnum_ExternalConversionSource = 6
	// Conversion that occurs when a user visits an advertiser's retail store
	// after clicking on a Google ad;
	// Displayed in Google Ads UI as 'Store visits'.
	ExternalConversionSourceEnum_STORE_VISITS ExternalConversionSourceEnum_ExternalConversionSource = 7
	// Conversion that occurs when a user takes an in-app action such as a
	// purchase in an Android app;
	// Displayed in Google Ads UI as 'Android in-app action'.
	ExternalConversionSourceEnum_ANDROID_IN_APP ExternalConversionSourceEnum_ExternalConversionSource = 8
	// Conversion that occurs when a user takes an in-app action such as a
	// purchase in an iOS app;
	// Displayed in Google Ads UI as 'iOS in-app action'.
	ExternalConversionSourceEnum_IOS_IN_APP ExternalConversionSourceEnum_ExternalConversionSource = 9
	// Conversion that occurs when a user opens an iOS app for the first time;
	// Displayed in Google Ads UI as 'iOS app install (first open)'.
	ExternalConversionSourceEnum_IOS_FIRST_OPEN ExternalConversionSourceEnum_ExternalConversionSource = 10
	// Legacy app conversions that do not have an AppPlatform provided;
	// Displayed in Google Ads UI as 'Mobile app'.
	ExternalConversionSourceEnum_APP_UNSPECIFIED ExternalConversionSourceEnum_ExternalConversionSource = 11
	// Conversion that occurs when a user opens an Android app for the first
	// time; Displayed in Google Ads UI as 'Android app install (first open)'.
	ExternalConversionSourceEnum_ANDROID_FIRST_OPEN ExternalConversionSourceEnum_ExternalConversionSource = 12
	// Call conversion that is uploaded through ConversionUploadService;
	// Displayed in Google Ads UI as 'Import from calls'.
	ExternalConversionSourceEnum_UPLOAD_CALLS ExternalConversionSourceEnum_ExternalConversionSource = 13
	// Conversion that comes from a linked Firebase event;
	// Displayed in Google Ads UI as 'Firebase'.
	ExternalConversionSourceEnum_FIREBASE ExternalConversionSourceEnum_ExternalConversionSource = 14
	// Conversion that occurs when a user clicks on a mobile phone number;
	// Displayed in Google Ads UI as 'Phone number clicks'.
	ExternalConversionSourceEnum_CLICK_TO_CALL ExternalConversionSourceEnum_ExternalConversionSource = 15
	// Conversion that comes from Salesforce;
	// Displayed in Google Ads UI as 'Salesforce.com'.
	ExternalConversionSourceEnum_SALESFORCE ExternalConversionSourceEnum_ExternalConversionSource = 16
	// Conversion that comes from in-store purchases recorded by CRM;
	// Displayed in Google Ads UI as 'Store sales (data partner)'.
	ExternalConversionSourceEnum_STORE_SALES_CRM ExternalConversionSourceEnum_ExternalConversionSource = 17
	// Conversion that comes from in-store purchases from payment network;
	// Displayed in Google Ads UI as 'Store sales (payment network)'.
	ExternalConversionSourceEnum_STORE_SALES_PAYMENT_NETWORK ExternalConversionSourceEnum_ExternalConversionSource = 18
	// Codeless Google Play conversion;
	// Displayed in Google Ads UI as 'Google Play'.
	ExternalConversionSourceEnum_GOOGLE_PLAY ExternalConversionSourceEnum_ExternalConversionSource = 19
	// Conversion that comes from a linked third-party app analytics event;
	// Displayed in Google Ads UI as 'Third-party app analytics'.
	ExternalConversionSourceEnum_THIRD_PARTY_APP_ANALYTICS ExternalConversionSourceEnum_ExternalConversionSource = 20
	// Conversion that is controlled by Google Attribution.
	ExternalConversionSourceEnum_GOOGLE_ATTRIBUTION ExternalConversionSourceEnum_ExternalConversionSource = 21
	// Store Sales conversion based on first-party or third-party merchant data
	// uploads. Displayed in Google Ads UI as 'Store sales (direct)'.
	ExternalConversionSourceEnum_STORE_SALES_DIRECT ExternalConversionSourceEnum_ExternalConversionSource = 22
)

var ExternalConversionSourceEnum_ExternalConversionSource_name = map[int32]string{
	0:  "UNSPECIFIED",
	1:  "UNKNOWN",
	2:  "WEBPAGE",
	3:  "ANALYTICS",
	4:  "UPLOAD",
	5:  "AD_CALL_METRICS",
	6:  "WEBSITE_CALL_METRICS",
	7:  "STORE_VISITS",
	8:  "ANDROID_IN_APP",
	9:  "IOS_IN_APP",
	10: "IOS_FIRST_OPEN",
	11: "APP_UNSPECIFIED",
	12: "ANDROID_FIRST_OPEN",
	13: "UPLOAD_CALLS",
	14: "FIREBASE",
	15: "CLICK_TO_CALL",
	16: "SALESFORCE",
	17: "STORE_SALES_CRM",
	18: "STORE_SALES_PAYMENT_NETWORK",
	19: "GOOGLE_PLAY",
	20: "THIRD_PARTY_APP_ANALYTICS",
	21: "GOOGLE_ATTRIBUTION",
	22: "STORE_SALES_DIRECT",
}

var ExternalConversionSourceEnum_ExternalConversionSource_value = map[string]int32{
	"UNSPECIFIED":                 0,
	"UNKNOWN":                     1,
	"WEBPAGE":                     2,
	"ANALYTICS":                   3,
	"UPLOAD":                      4,
	"AD_CALL_METRICS":             5,
	"WEBSITE_CALL_METRICS":        6,
	"STORE_VISITS":                7,
	"ANDROID_IN_APP":              8,
	"IOS_IN_APP":                  9,
	"IOS_FIRST_OPEN":              10,
	"APP_UNSPECIFIED":             11,
	"ANDROID_FIRST_OPEN":          12,
	"UPLOAD_CALLS":                13,
	"FIREBASE":                    14,
	"CLICK_TO_CALL":               15,
	"SALESFORCE":                  16,
	"STORE_SALES_CRM":             17,
	"STORE_SALES_PAYMENT_NETWORK": 18,
	"GOOGLE_PLAY":                 19,
	"THIRD_PARTY_APP_ANALYTICS":   20,
	"GOOGLE_ATTRIBUTION":          21,
	"STORE_SALES_DIRECT":          22,
}

func (x ExternalConversionSourceEnum_ExternalConversionSource) String() string {
	return proto.EnumName(ExternalConversionSourceEnum_ExternalConversionSource_name, int32(x))
}

func (ExternalConversionSourceEnum_ExternalConversionSource) EnumDescriptor() ([]byte, []int) {
	return fileDescriptor_f6d6b59f230796d9, []int{0, 0}
}

// Container for enum describing the external conversion source that is
// associated with a ConversionAction.
type ExternalConversionSourceEnum struct {
	XXX_NoUnkeyedLiteral struct{} `json:"-"`
	XXX_unrecognized     []byte   `json:"-"`
	XXX_sizecache        int32    `json:"-"`
}

func (m *ExternalConversionSourceEnum) Reset()         { *m = ExternalConversionSourceEnum{} }
func (m *ExternalConversionSourceEnum) String() string { return proto.CompactTextString(m) }
func (*ExternalConversionSourceEnum) ProtoMessage()    {}
func (*ExternalConversionSourceEnum) Descriptor() ([]byte, []int) {
	return fileDescriptor_f6d6b59f230796d9, []int{0}
}

func (m *ExternalConversionSourceEnum) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_ExternalConversionSourceEnum.Unmarshal(m, b)
}
func (m *ExternalConversionSourceEnum) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_ExternalConversionSourceEnum.Marshal(b, m, deterministic)
}
func (m *ExternalConversionSourceEnum) XXX_Merge(src proto.Message) {
	xxx_messageInfo_ExternalConversionSourceEnum.Merge(m, src)
}
func (m *ExternalConversionSourceEnum) XXX_Size() int {
	return xxx_messageInfo_ExternalConversionSourceEnum.Size(m)
}
func (m *ExternalConversionSourceEnum) XXX_DiscardUnknown() {
	xxx_messageInfo_ExternalConversionSourceEnum.DiscardUnknown(m)
}

var xxx_messageInfo_ExternalConversionSourceEnum proto.InternalMessageInfo

func init() {
	proto.RegisterEnum("google.ads.googleads.v2.enums.ExternalConversionSourceEnum_ExternalConversionSource", ExternalConversionSourceEnum_ExternalConversionSource_name, ExternalConversionSourceEnum_ExternalConversionSource_value)
	proto.RegisterType((*ExternalConversionSourceEnum)(nil), "google.ads.googleads.v2.enums.ExternalConversionSourceEnum")
}

func init() {
	proto.RegisterFile("google/ads/googleads/v2/enums/external_conversion_source.proto", fileDescriptor_f6d6b59f230796d9)
}

var fileDescriptor_f6d6b59f230796d9 = []byte{
	// 553 bytes of a gzipped FileDescriptorProto
	0x1f, 0x8b, 0x08, 0x00, 0x00, 0x00, 0x00, 0x00, 0x02, 0xff, 0x7c, 0x52, 0xdd, 0x6e, 0xda, 0x3c,
	0x18, 0xfe, 0x4a, 0xfb, 0xf5, 0xc7, 0xfd, 0x73, 0xdd, 0xae, 0xea, 0xb6, 0xa2, 0xa9, 0xbd, 0x80,
	0x44, 0x62, 0x67, 0x99, 0x34, 0xc9, 0x49, 0x0c, 0xb3, 0x9a, 0xc6, 0x96, 0x6d, 0x40, 0x4c, 0x48,
	0x56, 0x06, 0x51, 0x84, 0x04, 0x31, 0x22, 0x80, 0x76, 0xb8, 0x6b, 0xd9, 0xe1, 0x2e, 0x65, 0x37,
	0xb1, 0xf3, 0x1d, 0xee, 0x0a, 0x26, 0x27, 0xc0, 0xd8, 0x01, 0x3b, 0xb1, 0xde, 0x9f, 0xe7, 0x7d,
	0x9f, 0xe7, 0xb5, 0x1e, 0xf0, 0x3e, 0x33, 0x26, 0x1b, 0xa7, 0x6e, 0x32, 0x2c, 0xdc, 0x2a, 0xb4,
	0xd1, 0xb2, 0xe1, 0xa6, 0xf9, 0x62, 0x52, 0xb8, 0xe9, 0xe7, 0x79, 0x3a, 0xcb, 0x93, 0xb1, 0x1e,
	0x98, 0x7c, 0x99, 0xce, 0x8a, 0x91, 0xc9, 0x75, 0x61, 0x16, 0xb3, 0x41, 0xea, 0x4c, 0x67, 0x66,
	0x6e, 0x50, 0xbd, 0x1a, 0x72, 0x92, 0x61, 0xe1, 0x6c, 0xe6, 0x9d, 0x65, 0xc3, 0x29, 0xe7, 0x5f,
	0xdd, 0xaf, 0xd7, 0x4f, 0x47, 0x6e, 0x92, 0xe7, 0x66, 0x9e, 0xcc, 0x47, 0x26, 0x2f, 0xaa, 0xe1,
	0xc7, 0x2f, 0x07, 0xe0, 0x9e, 0xac, 0x18, 0x82, 0x0d, 0x81, 0x2c, 0xf7, 0x93, 0x7c, 0x31, 0x79,
	0xfc, 0xb1, 0x0f, 0xee, 0x76, 0x01, 0xd0, 0x25, 0x38, 0x6d, 0xc7, 0x92, 0x93, 0x80, 0x36, 0x29,
	0x09, 0xe1, 0x7f, 0xe8, 0x14, 0x1c, 0xb5, 0xe3, 0xa7, 0x98, 0x75, 0x63, 0xb8, 0x67, 0x93, 0x2e,
	0xf1, 0x39, 0x6e, 0x11, 0x58, 0x43, 0xe7, 0xe0, 0x04, 0xc7, 0x38, 0xea, 0x29, 0x1a, 0x48, 0xb8,
	0x8f, 0x00, 0x38, 0x6c, 0xf3, 0x88, 0xe1, 0x10, 0x1e, 0xa0, 0x6b, 0x70, 0x89, 0x43, 0x1d, 0xe0,
	0x28, 0xd2, 0xcf, 0x44, 0x09, 0x0b, 0xf8, 0x1f, 0xdd, 0x81, 0x9b, 0x2e, 0xf1, 0x25, 0x55, 0xe4,
	0xef, 0xce, 0x21, 0x82, 0xe0, 0x4c, 0x2a, 0x26, 0x88, 0xee, 0x50, 0x49, 0x95, 0x84, 0x47, 0x08,
	0x81, 0x0b, 0x1c, 0x87, 0x82, 0xd1, 0x50, 0xd3, 0x58, 0x63, 0xce, 0xe1, 0x31, 0xba, 0x00, 0x80,
	0x32, 0xb9, 0xce, 0x4f, 0x2c, 0xc6, 0xe6, 0x4d, 0x2a, 0xa4, 0xd2, 0x8c, 0x93, 0x18, 0x82, 0x92,
	0x98, 0x73, 0xbd, 0x7d, 0xc2, 0x29, 0xba, 0x05, 0x68, 0xbd, 0x6c, 0x0b, 0x7c, 0x66, 0x69, 0x2b,
	0xc5, 0xa5, 0x1e, 0x09, 0xcf, 0xd1, 0x19, 0x38, 0x6e, 0x52, 0x41, 0x7c, 0x2c, 0x09, 0xbc, 0x40,
	0x57, 0xe0, 0x3c, 0x88, 0x68, 0xf0, 0xa4, 0x15, 0x2b, 0x11, 0xf0, 0xd2, 0x6a, 0x90, 0x38, 0x22,
	0xb2, 0xc9, 0x44, 0x40, 0x20, 0xb4, 0x7c, 0x95, 0xf2, 0xb2, 0xaa, 0x03, 0xf1, 0x0c, 0xaf, 0xd0,
	0x1b, 0xf0, 0x7a, 0xbb, 0xc8, 0x71, 0xef, 0x99, 0xc4, 0x4a, 0xc7, 0x44, 0x75, 0x99, 0x78, 0x82,
	0xc8, 0x7e, 0x72, 0x8b, 0xb1, 0x56, 0x44, 0x34, 0x8f, 0x70, 0x0f, 0x5e, 0xa3, 0x3a, 0x78, 0xa9,
	0x3e, 0x50, 0x11, 0x6a, 0x8e, 0x85, 0xea, 0xd9, 0xfb, 0xf4, 0x9f, 0xaf, 0xbd, 0xb1, 0x07, 0xac,
	0xf0, 0x58, 0x29, 0x41, 0xfd, 0xb6, 0xa2, 0x2c, 0x86, 0x2f, 0x6c, 0x7d, 0x9b, 0x28, 0xa4, 0x82,
	0x04, 0x0a, 0xde, 0xfa, 0xbf, 0xf6, 0xc0, 0xc3, 0xc0, 0x4c, 0x9c, 0x7f, 0xda, 0xc8, 0xaf, 0xef,
	0x32, 0x01, 0xb7, 0x3e, 0xe2, 0x7b, 0x1f, 0xfd, 0xd5, 0x7c, 0x66, 0xc6, 0x49, 0x9e, 0x39, 0x66,
	0x96, 0xb9, 0x59, 0x9a, 0x97, 0x2e, 0x5b, 0xdb, 0x7a, 0x3a, 0x2a, 0x76, 0xb8, 0xfc, 0x5d, 0xf9,
	0x7e, 0xad, 0xed, 0xb7, 0x30, 0xfe, 0x56, 0xab, 0xb7, 0xaa, 0x55, 0x78, 0x58, 0x38, 0x55, 0x68,
	0xa3, 0x4e, 0xc3, 0xb1, 0x8e, 0x2c, 0xbe, 0xaf, 0xfb, 0x7d, 0x3c, 0x2c, 0xfa, 0x9b, 0x7e, 0xbf,
	0xd3, 0xe8, 0x97, 0xfd, 0x9f, 0xb5, 0x87, 0xaa, 0xe8, 0x79, 0x78, 0x58, 0x78, 0xde, 0x06, 0xe1,
	0x79, 0x9d, 0x86, 0xe7, 0x95, 0x98, 0x4f, 0x87, 0xa5, 0xb0, 0xb7, 0xbf, 0x03, 0x00, 0x00, 0xff,
	0xff, 0x93, 0x8a, 0x62, 0xe6, 0x7d, 0x03, 0x00, 0x00,
}
