// Code generated by protoc-gen-go. DO NOT EDIT.
// source: google/cloud/securitycenter/v1beta1/security_marks.proto

package securitycenter

import (
	fmt "fmt"
	math "math"

	proto "github.com/golang/protobuf/proto"
	_ "google.golang.org/genproto/googleapis/api/annotations"
)

// Reference imports to suppress errors if they are not otherwise used.
var _ = proto.Marshal
var _ = fmt.Errorf
var _ = math.Inf

// This is a compile-time assertion to ensure that this generated file
// is compatible with the proto package it is being compiled against.
// A compilation error at this line likely means your copy of the
// proto package needs to be updated.
const _ = proto.ProtoPackageIsVersion3 // please upgrade the proto package

// User specified security marks that are attached to the parent Cloud Security
// Command Center (Cloud SCC) resource. Security marks are scoped within a Cloud
// SCC organization -- they can be modified and viewed by all users who have
// proper permissions on the organization.
type SecurityMarks struct {
	// The relative resource name of the SecurityMarks. See:
	// https://cloud.google.com/apis/design/resource_names#relative_resource_name
	// Examples:
	// "organizations/123/assets/456/securityMarks"
	// "organizations/123/sources/456/findings/789/securityMarks".
	Name string `protobuf:"bytes,1,opt,name=name,proto3" json:"name,omitempty"`
	// Mutable user specified security marks belonging to the parent resource.
	// Constraints are as follows:
	//   - Keys and values are treated as case insensitive
	//   - Keys must be alphanumeric and between 1 - 256 characters (inclusive)
	//   - Values have leading and trailing whitespace trimmed, remaining
	//     characters must be between 1 - 4096 characters (inclusive)
	Marks                map[string]string `protobuf:"bytes,2,rep,name=marks,proto3" json:"marks,omitempty" protobuf_key:"bytes,1,opt,name=key,proto3" protobuf_val:"bytes,2,opt,name=value,proto3"`
	XXX_NoUnkeyedLiteral struct{}          `json:"-"`
	XXX_unrecognized     []byte            `json:"-"`
	XXX_sizecache        int32             `json:"-"`
}

func (m *SecurityMarks) Reset()         { *m = SecurityMarks{} }
func (m *SecurityMarks) String() string { return proto.CompactTextString(m) }
func (*SecurityMarks) ProtoMessage()    {}
func (*SecurityMarks) Descriptor() ([]byte, []int) {
	return fileDescriptor_09d3e42c3896af25, []int{0}
}

func (m *SecurityMarks) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_SecurityMarks.Unmarshal(m, b)
}
func (m *SecurityMarks) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_SecurityMarks.Marshal(b, m, deterministic)
}
func (m *SecurityMarks) XXX_Merge(src proto.Message) {
	xxx_messageInfo_SecurityMarks.Merge(m, src)
}
func (m *SecurityMarks) XXX_Size() int {
	return xxx_messageInfo_SecurityMarks.Size(m)
}
func (m *SecurityMarks) XXX_DiscardUnknown() {
	xxx_messageInfo_SecurityMarks.DiscardUnknown(m)
}

var xxx_messageInfo_SecurityMarks proto.InternalMessageInfo

func (m *SecurityMarks) GetName() string {
	if m != nil {
		return m.Name
	}
	return ""
}

func (m *SecurityMarks) GetMarks() map[string]string {
	if m != nil {
		return m.Marks
	}
	return nil
}

func init() {
	proto.RegisterType((*SecurityMarks)(nil), "google.cloud.securitycenter.v1beta1.SecurityMarks")
	proto.RegisterMapType((map[string]string)(nil), "google.cloud.securitycenter.v1beta1.SecurityMarks.MarksEntry")
}

func init() {
	proto.RegisterFile("google/cloud/securitycenter/v1beta1/security_marks.proto", fileDescriptor_09d3e42c3896af25)
}

var fileDescriptor_09d3e42c3896af25 = []byte{
	// 252 bytes of a gzipped FileDescriptorProto
	0x1f, 0x8b, 0x08, 0x00, 0x00, 0x00, 0x00, 0x00, 0x02, 0xff, 0x8c, 0x90, 0x41, 0x4b, 0xc3, 0x30,
	0x14, 0xc7, 0x49, 0xe7, 0x04, 0x9f, 0x08, 0x12, 0x3c, 0x94, 0xe1, 0x61, 0xe8, 0xc1, 0x9d, 0x12,
	0xa6, 0x97, 0xa2, 0x78, 0x11, 0x3c, 0x0a, 0xba, 0xdd, 0xbc, 0xc8, 0x5b, 0x7d, 0x84, 0xb2, 0x36,
	0xaf, 0xa4, 0xe9, 0xa0, 0x17, 0x3f, 0x94, 0x9f, 0x50, 0x96, 0x04, 0xa5, 0x17, 0xd9, 0xa5, 0xbc,
	0xfe, 0x93, 0xdf, 0xef, 0x9f, 0x04, 0x0a, 0xc3, 0x6c, 0x6a, 0xd2, 0x65, 0xcd, 0xfd, 0xa7, 0xee,
	0xa8, 0xec, 0x5d, 0xe5, 0x87, 0x92, 0xac, 0x27, 0xa7, 0x77, 0xcb, 0x0d, 0x79, 0x5c, 0xfe, 0xc6,
	0x1f, 0x0d, 0xba, 0x6d, 0xa7, 0x5a, 0xc7, 0x9e, 0xe5, 0x75, 0x24, 0x55, 0x20, 0xd5, 0x98, 0x54,
	0x89, 0x9c, 0x5d, 0x26, 0x3d, 0xb6, 0x95, 0x46, 0x6b, 0xd9, 0xa3, 0xaf, 0xd8, 0x26, 0xc5, 0xd5,
	0xb7, 0x80, 0xb3, 0x75, 0x02, 0x5f, 0xf6, 0x6a, 0x29, 0xe1, 0xc8, 0x62, 0x43, 0xb9, 0x98, 0x8b,
	0xc5, 0xc9, 0x2a, 0xcc, 0x72, 0x0d, 0xd3, 0xd0, 0x9b, 0x67, 0xf3, 0xc9, 0xe2, 0xf4, 0xf6, 0x51,
	0x1d, 0x50, 0xac, 0x46, 0x5a, 0x15, 0xbe, 0xcf, 0xd6, 0xbb, 0x61, 0x15, 0x5d, 0xb3, 0x02, 0xe0,
	0x2f, 0x94, 0xe7, 0x30, 0xd9, 0xd2, 0x90, 0x5a, 0xf7, 0xa3, 0xbc, 0x80, 0xe9, 0x0e, 0xeb, 0x9e,
	0xf2, 0x2c, 0x64, 0xf1, 0xe7, 0x3e, 0x2b, 0xc4, 0xd3, 0x17, 0xdc, 0x94, 0xdc, 0x1c, 0x72, 0x88,
	0x57, 0xf1, 0xfe, 0x96, 0xb6, 0x19, 0xae, 0xd1, 0x1a, 0xc5, 0xce, 0x68, 0x43, 0x36, 0xdc, 0x5e,
	0xc7, 0x25, 0x6c, 0xab, 0xee, 0xdf, 0xd7, 0x7f, 0x18, 0xc7, 0x9b, 0xe3, 0x40, 0xdf, 0xfd, 0x04,
	0x00, 0x00, 0xff, 0xff, 0x50, 0x3d, 0x8c, 0xac, 0xba, 0x01, 0x00, 0x00,
}
