// Code generated by protoc-gen-go. DO NOT EDIT.
// source: google/ads/googleads/v1/common/keyword_plan_common.proto

package common

import (
	fmt "fmt"
	math "math"

	proto "github.com/golang/protobuf/proto"
	wrappers "github.com/golang/protobuf/ptypes/wrappers"
	enums "google.golang.org/genproto/googleapis/ads/googleads/v1/enums"
	_ "google.golang.org/genproto/googleapis/api/annotations"
)

// Reference imports to suppress errors if they are not otherwise used.
var _ = proto.Marshal
var _ = fmt.Errorf
var _ = math.Inf

// This is a compile-time assertion to ensure that this generated file
// is compatible with the proto package it is being compiled against.
// A compilation error at this line likely means your copy of the
// proto package needs to be updated.
const _ = proto.ProtoPackageIsVersion3 // please upgrade the proto package

// Historical metrics.
type KeywordPlanHistoricalMetrics struct {
	// Average monthly searches for the past 12 months.
	AvgMonthlySearches *wrappers.Int64Value `protobuf:"bytes,1,opt,name=avg_monthly_searches,json=avgMonthlySearches,proto3" json:"avg_monthly_searches,omitempty"`
	// The competition level for the query.
	Competition          enums.KeywordPlanCompetitionLevelEnum_KeywordPlanCompetitionLevel `protobuf:"varint,2,opt,name=competition,proto3,enum=google.ads.googleads.v1.enums.KeywordPlanCompetitionLevelEnum_KeywordPlanCompetitionLevel" json:"competition,omitempty"`
	XXX_NoUnkeyedLiteral struct{}                                                          `json:"-"`
	XXX_unrecognized     []byte                                                            `json:"-"`
	XXX_sizecache        int32                                                             `json:"-"`
}

func (m *KeywordPlanHistoricalMetrics) Reset()         { *m = KeywordPlanHistoricalMetrics{} }
func (m *KeywordPlanHistoricalMetrics) String() string { return proto.CompactTextString(m) }
func (*KeywordPlanHistoricalMetrics) ProtoMessage()    {}
func (*KeywordPlanHistoricalMetrics) Descriptor() ([]byte, []int) {
	return fileDescriptor_9c4702e792c06e4e, []int{0}
}

func (m *KeywordPlanHistoricalMetrics) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_KeywordPlanHistoricalMetrics.Unmarshal(m, b)
}
func (m *KeywordPlanHistoricalMetrics) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_KeywordPlanHistoricalMetrics.Marshal(b, m, deterministic)
}
func (m *KeywordPlanHistoricalMetrics) XXX_Merge(src proto.Message) {
	xxx_messageInfo_KeywordPlanHistoricalMetrics.Merge(m, src)
}
func (m *KeywordPlanHistoricalMetrics) XXX_Size() int {
	return xxx_messageInfo_KeywordPlanHistoricalMetrics.Size(m)
}
func (m *KeywordPlanHistoricalMetrics) XXX_DiscardUnknown() {
	xxx_messageInfo_KeywordPlanHistoricalMetrics.DiscardUnknown(m)
}

var xxx_messageInfo_KeywordPlanHistoricalMetrics proto.InternalMessageInfo

func (m *KeywordPlanHistoricalMetrics) GetAvgMonthlySearches() *wrappers.Int64Value {
	if m != nil {
		return m.AvgMonthlySearches
	}
	return nil
}

func (m *KeywordPlanHistoricalMetrics) GetCompetition() enums.KeywordPlanCompetitionLevelEnum_KeywordPlanCompetitionLevel {
	if m != nil {
		return m.Competition
	}
	return enums.KeywordPlanCompetitionLevelEnum_UNSPECIFIED
}

func init() {
	proto.RegisterType((*KeywordPlanHistoricalMetrics)(nil), "google.ads.googleads.v1.common.KeywordPlanHistoricalMetrics")
}

func init() {
	proto.RegisterFile("google/ads/googleads/v1/common/keyword_plan_common.proto", fileDescriptor_9c4702e792c06e4e)
}

var fileDescriptor_9c4702e792c06e4e = []byte{
	// 389 bytes of a gzipped FileDescriptorProto
	0x1f, 0x8b, 0x08, 0x00, 0x00, 0x00, 0x00, 0x00, 0x02, 0xff, 0x7c, 0x92, 0x4f, 0x6b, 0xdb, 0x30,
	0x18, 0xc6, 0xb1, 0x07, 0x3b, 0x38, 0xb0, 0x83, 0x19, 0x23, 0x64, 0x21, 0x84, 0x9c, 0x72, 0x92,
	0x70, 0x36, 0xc6, 0xd0, 0x4e, 0xce, 0x5a, 0xd2, 0xd2, 0x06, 0x42, 0x0a, 0x3e, 0x04, 0x83, 0x51,
	0x6c, 0x55, 0x31, 0x95, 0x25, 0x23, 0xc9, 0x0e, 0x81, 0x7e, 0x9a, 0x1e, 0xfb, 0x51, 0xfa, 0x51,
	0xda, 0x53, 0xbf, 0x41, 0xb1, 0x65, 0xa7, 0x29, 0x25, 0x39, 0xf9, 0xb5, 0xde, 0xdf, 0xf3, 0xbc,
	0x7f, 0x24, 0xe7, 0x2f, 0x15, 0x82, 0x32, 0x02, 0x71, 0xa2, 0xa0, 0x09, 0xab, 0xa8, 0xf4, 0x60,
	0x2c, 0xb2, 0x4c, 0x70, 0x78, 0x47, 0x76, 0x5b, 0x21, 0x93, 0x28, 0x67, 0x98, 0x47, 0xe6, 0x0c,
	0xe4, 0x52, 0x68, 0xe1, 0x0e, 0x0c, 0x0e, 0x70, 0xa2, 0xc0, 0x5e, 0x09, 0x4a, 0x0f, 0x18, 0xaa,
	0x37, 0x3d, 0xe6, 0x4c, 0x78, 0x91, 0xa9, 0x4f, 0xc6, 0x39, 0xd1, 0xa9, 0x4e, 0x05, 0x8f, 0x18,
	0x29, 0x09, 0x33, 0x35, 0x7a, 0xfd, 0xd6, 0x23, 0x4f, 0x21, 0xe6, 0x5c, 0x68, 0x5c, 0x21, 0xaa,
	0xc9, 0x36, 0x1d, 0xc0, 0xfa, 0x6f, 0x5d, 0xdc, 0xc2, 0xad, 0xc4, 0x79, 0x4e, 0x64, 0x93, 0x1f,
	0xbd, 0x58, 0x4e, 0xff, 0xca, 0x94, 0x59, 0x30, 0xcc, 0x2f, 0x52, 0xa5, 0x85, 0x4c, 0x63, 0xcc,
	0xe6, 0x44, 0xcb, 0x34, 0x56, 0xee, 0xdc, 0xf9, 0x8e, 0x4b, 0x1a, 0x65, 0x82, 0xeb, 0x0d, 0xdb,
	0x45, 0x8a, 0x60, 0x19, 0x6f, 0x88, 0xea, 0x5a, 0x43, 0x6b, 0xdc, 0x99, 0xfc, 0x6c, 0xc6, 0x02,
	0xad, 0x3f, 0xb8, 0xe4, 0xfa, 0xcf, 0xef, 0x00, 0xb3, 0x82, 0x2c, 0x5d, 0x5c, 0xd2, 0xb9, 0xd1,
	0xdd, 0x34, 0x32, 0xf7, 0xde, 0xe9, 0x1c, 0x0c, 0xd2, 0xb5, 0x87, 0xd6, 0xf8, 0xdb, 0x64, 0x05,
	0x8e, 0xed, 0xa9, 0xde, 0x03, 0x38, 0x68, 0xf0, 0xff, 0xbb, 0xf8, 0xba, 0x5a, 0xc2, 0x39, 0x2f,
	0xb2, 0x53, 0xf9, 0xe5, 0x61, 0xb9, 0xe9, 0xab, 0xe5, 0x8c, 0x62, 0x91, 0x81, 0xd3, 0xd7, 0x32,
	0xfd, 0xf1, 0xd1, 0x30, 0x13, 0x7c, 0x51, 0x8d, 0xb7, 0xb0, 0x56, 0x67, 0x8d, 0x92, 0x0a, 0x86,
	0x39, 0x05, 0x42, 0x52, 0x48, 0x09, 0xaf, 0x87, 0x6f, 0x2f, 0x30, 0x4f, 0xd5, 0xb1, 0x97, 0xf2,
	0xcf, 0x7c, 0x1e, 0xec, 0x2f, 0x33, 0xdf, 0x7f, 0xb4, 0x07, 0x33, 0x63, 0xe6, 0x27, 0x0a, 0x98,
	0xb0, 0x8a, 0x02, 0x0f, 0x98, 0x9a, 0x4f, 0x2d, 0x10, 0xfa, 0x89, 0x0a, 0xf7, 0x40, 0x18, 0x78,
	0xa1, 0x01, 0x9e, 0xed, 0x91, 0x39, 0x45, 0xc8, 0x4f, 0x14, 0x42, 0x7b, 0x04, 0xa1, 0xc0, 0x43,
	0xc8, 0x40, 0xeb, 0xaf, 0x75, 0x77, 0xbf, 0xde, 0x02, 0x00, 0x00, 0xff, 0xff, 0x15, 0x3e, 0x04,
	0x99, 0xc6, 0x02, 0x00, 0x00,
}
