// Code generated by protoc-gen-go. DO NOT EDIT.
// source: google/devtools/containeranalysis/v1alpha1/package_vulnerability.proto

package containeranalysis

import (
	fmt "fmt"
	math "math"

	proto "github.com/golang/protobuf/proto"
	_ "google.golang.org/genproto/googleapis/api/annotations"
)

// Reference imports to suppress errors if they are not otherwise used.
var _ = proto.Marshal
var _ = fmt.Errorf
var _ = math.Inf

// This is a compile-time assertion to ensure that this generated file
// is compatible with the proto package it is being compiled against.
// A compilation error at this line likely means your copy of the
// proto package needs to be updated.
const _ = proto.ProtoPackageIsVersion3 // please upgrade the proto package

// Note provider-assigned severity/impact ranking
type VulnerabilityType_Severity int32

const (
	// Unknown Impact
	VulnerabilityType_SEVERITY_UNSPECIFIED VulnerabilityType_Severity = 0
	// Minimal Impact
	VulnerabilityType_MINIMAL VulnerabilityType_Severity = 1
	// Low Impact
	VulnerabilityType_LOW VulnerabilityType_Severity = 2
	// Medium Impact
	VulnerabilityType_MEDIUM VulnerabilityType_Severity = 3
	// High Impact
	VulnerabilityType_HIGH VulnerabilityType_Severity = 4
	// Critical Impact
	VulnerabilityType_CRITICAL VulnerabilityType_Severity = 5
)

var VulnerabilityType_Severity_name = map[int32]string{
	0: "SEVERITY_UNSPECIFIED",
	1: "MINIMAL",
	2: "LOW",
	3: "MEDIUM",
	4: "HIGH",
	5: "CRITICAL",
}

var VulnerabilityType_Severity_value = map[string]int32{
	"SEVERITY_UNSPECIFIED": 0,
	"MINIMAL":              1,
	"LOW":                  2,
	"MEDIUM":               3,
	"HIGH":                 4,
	"CRITICAL":             5,
}

func (x VulnerabilityType_Severity) String() string {
	return proto.EnumName(VulnerabilityType_Severity_name, int32(x))
}

func (VulnerabilityType_Severity) EnumDescriptor() ([]byte, []int) {
	return fileDescriptor_9c85f6a1c26e0b81, []int{0, 0}
}

// Whether this is an ordinary package version or a
// sentinel MIN/MAX version.
type VulnerabilityType_Version_VersionKind int32

const (
	// A standard package version, defined by the other fields.
	VulnerabilityType_Version_NORMAL VulnerabilityType_Version_VersionKind = 0
	// A special version representing negative infinity,
	// other fields are ignored.
	VulnerabilityType_Version_MINIMUM VulnerabilityType_Version_VersionKind = 1
	// A special version representing positive infinity,
	// other fields are ignored.
	VulnerabilityType_Version_MAXIMUM VulnerabilityType_Version_VersionKind = 2
)

var VulnerabilityType_Version_VersionKind_name = map[int32]string{
	0: "NORMAL",
	1: "MINIMUM",
	2: "MAXIMUM",
}

var VulnerabilityType_Version_VersionKind_value = map[string]int32{
	"NORMAL":  0,
	"MINIMUM": 1,
	"MAXIMUM": 2,
}

func (x VulnerabilityType_Version_VersionKind) String() string {
	return proto.EnumName(VulnerabilityType_Version_VersionKind_name, int32(x))
}

func (VulnerabilityType_Version_VersionKind) EnumDescriptor() ([]byte, []int) {
	return fileDescriptor_9c85f6a1c26e0b81, []int{0, 0, 0}
}

// VulnerabilityType provides metadata about a security vulnerability.
type VulnerabilityType struct {
	// The CVSS score for this Vulnerability.
	CvssScore float32 `protobuf:"fixed32,2,opt,name=cvss_score,json=cvssScore,proto3" json:"cvss_score,omitempty"`
	// Note provider assigned impact of the vulnerability
	Severity VulnerabilityType_Severity `protobuf:"varint,3,opt,name=severity,proto3,enum=google.devtools.containeranalysis.v1alpha1.VulnerabilityType_Severity" json:"severity,omitempty"`
	// All information about the package to specifically identify this
	// vulnerability. One entry per (version range and cpe_uri) the
	// package vulnerability has manifested in.
	Details              []*VulnerabilityType_Detail `protobuf:"bytes,4,rep,name=details,proto3" json:"details,omitempty"`
	XXX_NoUnkeyedLiteral struct{}                    `json:"-"`
	XXX_unrecognized     []byte                      `json:"-"`
	XXX_sizecache        int32                       `json:"-"`
}

func (m *VulnerabilityType) Reset()         { *m = VulnerabilityType{} }
func (m *VulnerabilityType) String() string { return proto.CompactTextString(m) }
func (*VulnerabilityType) ProtoMessage()    {}
func (*VulnerabilityType) Descriptor() ([]byte, []int) {
	return fileDescriptor_9c85f6a1c26e0b81, []int{0}
}

func (m *VulnerabilityType) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_VulnerabilityType.Unmarshal(m, b)
}
func (m *VulnerabilityType) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_VulnerabilityType.Marshal(b, m, deterministic)
}
func (m *VulnerabilityType) XXX_Merge(src proto.Message) {
	xxx_messageInfo_VulnerabilityType.Merge(m, src)
}
func (m *VulnerabilityType) XXX_Size() int {
	return xxx_messageInfo_VulnerabilityType.Size(m)
}
func (m *VulnerabilityType) XXX_DiscardUnknown() {
	xxx_messageInfo_VulnerabilityType.DiscardUnknown(m)
}

var xxx_messageInfo_VulnerabilityType proto.InternalMessageInfo

func (m *VulnerabilityType) GetCvssScore() float32 {
	if m != nil {
		return m.CvssScore
	}
	return 0
}

func (m *VulnerabilityType) GetSeverity() VulnerabilityType_Severity {
	if m != nil {
		return m.Severity
	}
	return VulnerabilityType_SEVERITY_UNSPECIFIED
}

func (m *VulnerabilityType) GetDetails() []*VulnerabilityType_Detail {
	if m != nil {
		return m.Details
	}
	return nil
}

// Version contains structured information about the version of the package.
// For a discussion of this in Debian/Ubuntu:
// http://serverfault.com/questions/604541/debian-packages-version-convention
// For a discussion of this in Redhat/Fedora/Centos:
// http://blog.jasonantman.com/2014/07/how-yum-and-rpm-compare-versions/
type VulnerabilityType_Version struct {
	// Used to correct mistakes in the version numbering scheme.
	Epoch int32 `protobuf:"varint,1,opt,name=epoch,proto3" json:"epoch,omitempty"`
	// The main part of the version name.
	Name string `protobuf:"bytes,2,opt,name=name,proto3" json:"name,omitempty"`
	// The iteration of the package build from the above version.
	Revision string `protobuf:"bytes,3,opt,name=revision,proto3" json:"revision,omitempty"`
	// Distinguish between sentinel MIN/MAX versions and normal versions.
	// If kind is not NORMAL, then the other fields are ignored.
	Kind                 VulnerabilityType_Version_VersionKind `protobuf:"varint,5,opt,name=kind,proto3,enum=google.devtools.containeranalysis.v1alpha1.VulnerabilityType_Version_VersionKind" json:"kind,omitempty"`
	XXX_NoUnkeyedLiteral struct{}                              `json:"-"`
	XXX_unrecognized     []byte                                `json:"-"`
	XXX_sizecache        int32                                 `json:"-"`
}

func (m *VulnerabilityType_Version) Reset()         { *m = VulnerabilityType_Version{} }
func (m *VulnerabilityType_Version) String() string { return proto.CompactTextString(m) }
func (*VulnerabilityType_Version) ProtoMessage()    {}
func (*VulnerabilityType_Version) Descriptor() ([]byte, []int) {
	return fileDescriptor_9c85f6a1c26e0b81, []int{0, 0}
}

func (m *VulnerabilityType_Version) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_VulnerabilityType_Version.Unmarshal(m, b)
}
func (m *VulnerabilityType_Version) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_VulnerabilityType_Version.Marshal(b, m, deterministic)
}
func (m *VulnerabilityType_Version) XXX_Merge(src proto.Message) {
	xxx_messageInfo_VulnerabilityType_Version.Merge(m, src)
}
func (m *VulnerabilityType_Version) XXX_Size() int {
	return xxx_messageInfo_VulnerabilityType_Version.Size(m)
}
func (m *VulnerabilityType_Version) XXX_DiscardUnknown() {
	xxx_messageInfo_VulnerabilityType_Version.DiscardUnknown(m)
}

var xxx_messageInfo_VulnerabilityType_Version proto.InternalMessageInfo

func (m *VulnerabilityType_Version) GetEpoch() int32 {
	if m != nil {
		return m.Epoch
	}
	return 0
}

func (m *VulnerabilityType_Version) GetName() string {
	if m != nil {
		return m.Name
	}
	return ""
}

func (m *VulnerabilityType_Version) GetRevision() string {
	if m != nil {
		return m.Revision
	}
	return ""
}

func (m *VulnerabilityType_Version) GetKind() VulnerabilityType_Version_VersionKind {
	if m != nil {
		return m.Kind
	}
	return VulnerabilityType_Version_NORMAL
}

// Identifies all occurrences of this vulnerability in the package for a
// specific distro/location
// For example: glibc in cpe:/o:debian:debian_linux:8 for versions 2.1 - 2.2
type VulnerabilityType_Detail struct {
	// The cpe_uri in [cpe format] (https://cpe.mitre.org/specification/) in
	// which the vulnerability manifests.  Examples include distro or storage
	// location for vulnerable jar.
	// This field can be used as a filter in list requests.
	CpeUri string `protobuf:"bytes,1,opt,name=cpe_uri,json=cpeUri,proto3" json:"cpe_uri,omitempty"`
	// The name of the package where the vulnerability was found.
	// This field can be used as a filter in list requests.
	Package string `protobuf:"bytes,8,opt,name=package,proto3" json:"package,omitempty"`
	// The min version of the package in which the vulnerability exists.
	MinAffectedVersion *VulnerabilityType_Version `protobuf:"bytes,6,opt,name=min_affected_version,json=minAffectedVersion,proto3" json:"min_affected_version,omitempty"`
	// The max version of the package in which the vulnerability exists.
	// This field can be used as a filter in list requests.
	MaxAffectedVersion *VulnerabilityType_Version `protobuf:"bytes,7,opt,name=max_affected_version,json=maxAffectedVersion,proto3" json:"max_affected_version,omitempty"`
	// The severity (eg: distro assigned severity) for this vulnerability.
	SeverityName string `protobuf:"bytes,4,opt,name=severity_name,json=severityName,proto3" json:"severity_name,omitempty"`
	// A vendor-specific description of this note.
	Description string `protobuf:"bytes,9,opt,name=description,proto3" json:"description,omitempty"`
	// The fix for this specific package version.
	FixedLocation *VulnerabilityType_VulnerabilityLocation `protobuf:"bytes,5,opt,name=fixed_location,json=fixedLocation,proto3" json:"fixed_location,omitempty"`
	// The type of package; whether native or non native(ruby gems,
	// node.js packages etc)
	PackageType string `protobuf:"bytes,10,opt,name=package_type,json=packageType,proto3" json:"package_type,omitempty"`
	// Whether this Detail is obsolete. Occurrences are expected not to point to
	// obsolete details.
	IsObsolete           bool     `protobuf:"varint,11,opt,name=is_obsolete,json=isObsolete,proto3" json:"is_obsolete,omitempty"`
	XXX_NoUnkeyedLiteral struct{} `json:"-"`
	XXX_unrecognized     []byte   `json:"-"`
	XXX_sizecache        int32    `json:"-"`
}

func (m *VulnerabilityType_Detail) Reset()         { *m = VulnerabilityType_Detail{} }
func (m *VulnerabilityType_Detail) String() string { return proto.CompactTextString(m) }
func (*VulnerabilityType_Detail) ProtoMessage()    {}
func (*VulnerabilityType_Detail) Descriptor() ([]byte, []int) {
	return fileDescriptor_9c85f6a1c26e0b81, []int{0, 1}
}

func (m *VulnerabilityType_Detail) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_VulnerabilityType_Detail.Unmarshal(m, b)
}
func (m *VulnerabilityType_Detail) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_VulnerabilityType_Detail.Marshal(b, m, deterministic)
}
func (m *VulnerabilityType_Detail) XXX_Merge(src proto.Message) {
	xxx_messageInfo_VulnerabilityType_Detail.Merge(m, src)
}
func (m *VulnerabilityType_Detail) XXX_Size() int {
	return xxx_messageInfo_VulnerabilityType_Detail.Size(m)
}
func (m *VulnerabilityType_Detail) XXX_DiscardUnknown() {
	xxx_messageInfo_VulnerabilityType_Detail.DiscardUnknown(m)
}

var xxx_messageInfo_VulnerabilityType_Detail proto.InternalMessageInfo

func (m *VulnerabilityType_Detail) GetCpeUri() string {
	if m != nil {
		return m.CpeUri
	}
	return ""
}

func (m *VulnerabilityType_Detail) GetPackage() string {
	if m != nil {
		return m.Package
	}
	return ""
}

func (m *VulnerabilityType_Detail) GetMinAffectedVersion() *VulnerabilityType_Version {
	if m != nil {
		return m.MinAffectedVersion
	}
	return nil
}

func (m *VulnerabilityType_Detail) GetMaxAffectedVersion() *VulnerabilityType_Version {
	if m != nil {
		return m.MaxAffectedVersion
	}
	return nil
}

func (m *VulnerabilityType_Detail) GetSeverityName() string {
	if m != nil {
		return m.SeverityName
	}
	return ""
}

func (m *VulnerabilityType_Detail) GetDescription() string {
	if m != nil {
		return m.Description
	}
	return ""
}

func (m *VulnerabilityType_Detail) GetFixedLocation() *VulnerabilityType_VulnerabilityLocation {
	if m != nil {
		return m.FixedLocation
	}
	return nil
}

func (m *VulnerabilityType_Detail) GetPackageType() string {
	if m != nil {
		return m.PackageType
	}
	return ""
}

func (m *VulnerabilityType_Detail) GetIsObsolete() bool {
	if m != nil {
		return m.IsObsolete
	}
	return false
}

// Used by Occurrence to point to where the vulnerability exists and how
// to fix it.
type VulnerabilityType_VulnerabilityDetails struct {
	// The type of package; whether native or non native(ruby gems,
	// node.js packages etc)
	Type string `protobuf:"bytes,3,opt,name=type,proto3" json:"type,omitempty"`
	// Output only. The note provider assigned Severity of the vulnerability.
	Severity VulnerabilityType_Severity `protobuf:"varint,4,opt,name=severity,proto3,enum=google.devtools.containeranalysis.v1alpha1.VulnerabilityType_Severity" json:"severity,omitempty"`
	// Output only. The CVSS score of this vulnerability. CVSS score is on a
	// scale of 0-10 where 0 indicates low severity and 10 indicates high
	// severity.
	CvssScore float32 `protobuf:"fixed32,5,opt,name=cvss_score,json=cvssScore,proto3" json:"cvss_score,omitempty"`
	// The set of affected locations and their fixes (if available) within
	// the associated resource.
	PackageIssue         []*VulnerabilityType_PackageIssue `protobuf:"bytes,6,rep,name=package_issue,json=packageIssue,proto3" json:"package_issue,omitempty"`
	XXX_NoUnkeyedLiteral struct{}                          `json:"-"`
	XXX_unrecognized     []byte                            `json:"-"`
	XXX_sizecache        int32                             `json:"-"`
}

func (m *VulnerabilityType_VulnerabilityDetails) Reset() {
	*m = VulnerabilityType_VulnerabilityDetails{}
}
func (m *VulnerabilityType_VulnerabilityDetails) String() string { return proto.CompactTextString(m) }
func (*VulnerabilityType_VulnerabilityDetails) ProtoMessage()    {}
func (*VulnerabilityType_VulnerabilityDetails) Descriptor() ([]byte, []int) {
	return fileDescriptor_9c85f6a1c26e0b81, []int{0, 2}
}

func (m *VulnerabilityType_VulnerabilityDetails) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_VulnerabilityType_VulnerabilityDetails.Unmarshal(m, b)
}
func (m *VulnerabilityType_VulnerabilityDetails) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_VulnerabilityType_VulnerabilityDetails.Marshal(b, m, deterministic)
}
func (m *VulnerabilityType_VulnerabilityDetails) XXX_Merge(src proto.Message) {
	xxx_messageInfo_VulnerabilityType_VulnerabilityDetails.Merge(m, src)
}
func (m *VulnerabilityType_VulnerabilityDetails) XXX_Size() int {
	return xxx_messageInfo_VulnerabilityType_VulnerabilityDetails.Size(m)
}
func (m *VulnerabilityType_VulnerabilityDetails) XXX_DiscardUnknown() {
	xxx_messageInfo_VulnerabilityType_VulnerabilityDetails.DiscardUnknown(m)
}

var xxx_messageInfo_VulnerabilityType_VulnerabilityDetails proto.InternalMessageInfo

func (m *VulnerabilityType_VulnerabilityDetails) GetType() string {
	if m != nil {
		return m.Type
	}
	return ""
}

func (m *VulnerabilityType_VulnerabilityDetails) GetSeverity() VulnerabilityType_Severity {
	if m != nil {
		return m.Severity
	}
	return VulnerabilityType_SEVERITY_UNSPECIFIED
}

func (m *VulnerabilityType_VulnerabilityDetails) GetCvssScore() float32 {
	if m != nil {
		return m.CvssScore
	}
	return 0
}

func (m *VulnerabilityType_VulnerabilityDetails) GetPackageIssue() []*VulnerabilityType_PackageIssue {
	if m != nil {
		return m.PackageIssue
	}
	return nil
}

// This message wraps a location affected by a vulnerability and its
// associated fix (if one is available).
type VulnerabilityType_PackageIssue struct {
	// The location of the vulnerability.
	AffectedLocation *VulnerabilityType_VulnerabilityLocation `protobuf:"bytes,1,opt,name=affected_location,json=affectedLocation,proto3" json:"affected_location,omitempty"`
	// The location of the available fix for vulnerability.
	FixedLocation *VulnerabilityType_VulnerabilityLocation `protobuf:"bytes,2,opt,name=fixed_location,json=fixedLocation,proto3" json:"fixed_location,omitempty"`
	// The severity (eg: distro assigned severity) for this vulnerability.
	SeverityName         string   `protobuf:"bytes,3,opt,name=severity_name,json=severityName,proto3" json:"severity_name,omitempty"`
	XXX_NoUnkeyedLiteral struct{} `json:"-"`
	XXX_unrecognized     []byte   `json:"-"`
	XXX_sizecache        int32    `json:"-"`
}

func (m *VulnerabilityType_PackageIssue) Reset()         { *m = VulnerabilityType_PackageIssue{} }
func (m *VulnerabilityType_PackageIssue) String() string { return proto.CompactTextString(m) }
func (*VulnerabilityType_PackageIssue) ProtoMessage()    {}
func (*VulnerabilityType_PackageIssue) Descriptor() ([]byte, []int) {
	return fileDescriptor_9c85f6a1c26e0b81, []int{0, 3}
}

func (m *VulnerabilityType_PackageIssue) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_VulnerabilityType_PackageIssue.Unmarshal(m, b)
}
func (m *VulnerabilityType_PackageIssue) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_VulnerabilityType_PackageIssue.Marshal(b, m, deterministic)
}
func (m *VulnerabilityType_PackageIssue) XXX_Merge(src proto.Message) {
	xxx_messageInfo_VulnerabilityType_PackageIssue.Merge(m, src)
}
func (m *VulnerabilityType_PackageIssue) XXX_Size() int {
	return xxx_messageInfo_VulnerabilityType_PackageIssue.Size(m)
}
func (m *VulnerabilityType_PackageIssue) XXX_DiscardUnknown() {
	xxx_messageInfo_VulnerabilityType_PackageIssue.DiscardUnknown(m)
}

var xxx_messageInfo_VulnerabilityType_PackageIssue proto.InternalMessageInfo

func (m *VulnerabilityType_PackageIssue) GetAffectedLocation() *VulnerabilityType_VulnerabilityLocation {
	if m != nil {
		return m.AffectedLocation
	}
	return nil
}

func (m *VulnerabilityType_PackageIssue) GetFixedLocation() *VulnerabilityType_VulnerabilityLocation {
	if m != nil {
		return m.FixedLocation
	}
	return nil
}

func (m *VulnerabilityType_PackageIssue) GetSeverityName() string {
	if m != nil {
		return m.SeverityName
	}
	return ""
}

// The location of the vulnerability
type VulnerabilityType_VulnerabilityLocation struct {
	// The cpe_uri in [cpe format] (https://cpe.mitre.org/specification/)
	// format. Examples include distro or storage location for vulnerable jar.
	// This field can be used as a filter in list requests.
	CpeUri string `protobuf:"bytes,1,opt,name=cpe_uri,json=cpeUri,proto3" json:"cpe_uri,omitempty"`
	// The package being described.
	Package string `protobuf:"bytes,2,opt,name=package,proto3" json:"package,omitempty"`
	// The version of the package being described.
	// This field can be used as a filter in list requests.
	Version              *VulnerabilityType_Version `protobuf:"bytes,4,opt,name=version,proto3" json:"version,omitempty"`
	XXX_NoUnkeyedLiteral struct{}                   `json:"-"`
	XXX_unrecognized     []byte                     `json:"-"`
	XXX_sizecache        int32                      `json:"-"`
}

func (m *VulnerabilityType_VulnerabilityLocation) Reset() {
	*m = VulnerabilityType_VulnerabilityLocation{}
}
func (m *VulnerabilityType_VulnerabilityLocation) String() string { return proto.CompactTextString(m) }
func (*VulnerabilityType_VulnerabilityLocation) ProtoMessage()    {}
func (*VulnerabilityType_VulnerabilityLocation) Descriptor() ([]byte, []int) {
	return fileDescriptor_9c85f6a1c26e0b81, []int{0, 4}
}

func (m *VulnerabilityType_VulnerabilityLocation) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_VulnerabilityType_VulnerabilityLocation.Unmarshal(m, b)
}
func (m *VulnerabilityType_VulnerabilityLocation) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_VulnerabilityType_VulnerabilityLocation.Marshal(b, m, deterministic)
}
func (m *VulnerabilityType_VulnerabilityLocation) XXX_Merge(src proto.Message) {
	xxx_messageInfo_VulnerabilityType_VulnerabilityLocation.Merge(m, src)
}
func (m *VulnerabilityType_VulnerabilityLocation) XXX_Size() int {
	return xxx_messageInfo_VulnerabilityType_VulnerabilityLocation.Size(m)
}
func (m *VulnerabilityType_VulnerabilityLocation) XXX_DiscardUnknown() {
	xxx_messageInfo_VulnerabilityType_VulnerabilityLocation.DiscardUnknown(m)
}

var xxx_messageInfo_VulnerabilityType_VulnerabilityLocation proto.InternalMessageInfo

func (m *VulnerabilityType_VulnerabilityLocation) GetCpeUri() string {
	if m != nil {
		return m.CpeUri
	}
	return ""
}

func (m *VulnerabilityType_VulnerabilityLocation) GetPackage() string {
	if m != nil {
		return m.Package
	}
	return ""
}

func (m *VulnerabilityType_VulnerabilityLocation) GetVersion() *VulnerabilityType_Version {
	if m != nil {
		return m.Version
	}
	return nil
}

func init() {
	proto.RegisterEnum("google.devtools.containeranalysis.v1alpha1.VulnerabilityType_Severity", VulnerabilityType_Severity_name, VulnerabilityType_Severity_value)
	proto.RegisterEnum("google.devtools.containeranalysis.v1alpha1.VulnerabilityType_Version_VersionKind", VulnerabilityType_Version_VersionKind_name, VulnerabilityType_Version_VersionKind_value)
	proto.RegisterType((*VulnerabilityType)(nil), "google.devtools.containeranalysis.v1alpha1.VulnerabilityType")
	proto.RegisterType((*VulnerabilityType_Version)(nil), "google.devtools.containeranalysis.v1alpha1.VulnerabilityType.Version")
	proto.RegisterType((*VulnerabilityType_Detail)(nil), "google.devtools.containeranalysis.v1alpha1.VulnerabilityType.Detail")
	proto.RegisterType((*VulnerabilityType_VulnerabilityDetails)(nil), "google.devtools.containeranalysis.v1alpha1.VulnerabilityType.VulnerabilityDetails")
	proto.RegisterType((*VulnerabilityType_PackageIssue)(nil), "google.devtools.containeranalysis.v1alpha1.VulnerabilityType.PackageIssue")
	proto.RegisterType((*VulnerabilityType_VulnerabilityLocation)(nil), "google.devtools.containeranalysis.v1alpha1.VulnerabilityType.VulnerabilityLocation")
}

func init() {
	proto.RegisterFile("google/devtools/containeranalysis/v1alpha1/package_vulnerability.proto", fileDescriptor_9c85f6a1c26e0b81)
}

var fileDescriptor_9c85f6a1c26e0b81 = []byte{
	// 769 bytes of a gzipped FileDescriptorProto
	0x1f, 0x8b, 0x08, 0x00, 0x00, 0x00, 0x00, 0x00, 0x02, 0xff, 0xbc, 0x56, 0xcf, 0x6e, 0xfa, 0x46,
	0x10, 0xae, 0x8d, 0xc1, 0x30, 0x26, 0x91, 0xb3, 0xa2, 0xaa, 0x85, 0x5a, 0x95, 0xa6, 0xaa, 0x84,
	0x7a, 0x30, 0x0a, 0x39, 0xf6, 0x44, 0x81, 0x24, 0x6e, 0x81, 0xa4, 0x26, 0xa4, 0xff, 0xa4, 0x58,
	0x8b, 0xd9, 0x90, 0x55, 0x8c, 0xd7, 0xf2, 0x3a, 0x34, 0xf4, 0xd4, 0x07, 0xe8, 0x33, 0xf4, 0xd0,
	0x6b, 0x6f, 0x55, 0xdf, 0xaa, 0x0f, 0xd1, 0xca, 0x6b, 0x2f, 0x82, 0xd0, 0x4a, 0x91, 0x48, 0x7e,
	0x27, 0x3c, 0x33, 0xe6, 0xfb, 0x66, 0x76, 0xbf, 0xf9, 0x00, 0xce, 0xe6, 0x8c, 0xcd, 0x03, 0xd2,
	0x9a, 0x91, 0x65, 0xc2, 0x58, 0xc0, 0x5b, 0x3e, 0x0b, 0x13, 0x4c, 0x43, 0x12, 0xe3, 0x10, 0x07,
	0x2b, 0x4e, 0x79, 0x6b, 0x79, 0x82, 0x83, 0xe8, 0x1e, 0x9f, 0xb4, 0x22, 0xec, 0x3f, 0xe0, 0x39,
	0xf1, 0x96, 0x8f, 0x41, 0x5a, 0x9f, 0xd2, 0x80, 0x26, 0x2b, 0x3b, 0x8a, 0x59, 0xc2, 0xd0, 0xe7,
	0x19, 0x8e, 0x2d, 0x71, 0xec, 0x1d, 0x1c, 0x5b, 0xe2, 0xd4, 0x3f, 0xcc, 0x39, 0x71, 0x44, 0x5b,
	0x38, 0x0c, 0x59, 0x82, 0x13, 0xca, 0x42, 0x9e, 0x21, 0x1d, 0xff, 0x73, 0x08, 0x47, 0x37, 0x9b,
	0x0c, 0xd7, 0xab, 0x88, 0xa0, 0x8f, 0x00, 0xfc, 0x25, 0xe7, 0x1e, 0xf7, 0x59, 0x4c, 0x2c, 0xb5,
	0xa1, 0x34, 0x55, 0xb7, 0x92, 0x66, 0xc6, 0x69, 0x02, 0x4d, 0xa1, 0xcc, 0xc9, 0x92, 0xc4, 0x34,
	0x59, 0x59, 0x85, 0x86, 0xd2, 0x3c, 0x6c, 0x9f, 0xd9, 0x2f, 0xef, 0xc8, 0xde, 0xe1, 0xb3, 0xc7,
	0x39, 0x9a, 0xbb, 0xc6, 0x45, 0xb7, 0xa0, 0xcf, 0x48, 0x82, 0x69, 0xc0, 0x2d, 0xad, 0x51, 0x68,
	0x1a, 0xed, 0xde, 0x7e, 0x14, 0x3d, 0x01, 0xe6, 0x4a, 0xd0, 0xfa, 0xdf, 0x0a, 0xe8, 0x37, 0x24,
	0xe6, 0x94, 0x85, 0xa8, 0x06, 0x45, 0x12, 0x31, 0xff, 0xde, 0x52, 0x1a, 0x4a, 0xb3, 0xe8, 0x66,
	0x01, 0x42, 0xa0, 0x85, 0x78, 0x91, 0x8d, 0x5f, 0x71, 0xc5, 0x33, 0xaa, 0x43, 0x39, 0x26, 0x4b,
	0x9a, 0x7e, 0x4b, 0x4c, 0x5e, 0x71, 0xd7, 0x31, 0x22, 0xa0, 0x3d, 0xd0, 0x70, 0x66, 0x15, 0xc5,
	0x89, 0x7c, 0xb3, 0x5f, 0xbb, 0x79, 0x6b, 0xf2, 0xf3, 0x6b, 0x1a, 0xce, 0x5c, 0x01, 0x7f, 0x7c,
	0x0a, 0xc6, 0x46, 0x12, 0x01, 0x94, 0x46, 0x97, 0xee, 0xb0, 0x33, 0x30, 0xdf, 0x43, 0x06, 0xe8,
	0x43, 0x67, 0xe4, 0x0c, 0x27, 0x43, 0x53, 0x11, 0x41, 0xe7, 0x3b, 0x11, 0xa8, 0xf5, 0xbf, 0x34,
	0x28, 0x65, 0x27, 0x80, 0x3e, 0x00, 0xdd, 0x8f, 0x88, 0xf7, 0x18, 0x53, 0x31, 0x6e, 0xc5, 0x2d,
	0xf9, 0x11, 0x99, 0xc4, 0x14, 0x59, 0xa0, 0xe7, 0x9a, 0xb3, 0xca, 0xa2, 0x20, 0x43, 0xf4, 0x13,
	0xd4, 0x16, 0x34, 0xf4, 0xf0, 0xdd, 0x1d, 0xf1, 0x13, 0x32, 0xf3, 0x96, 0x19, 0xbf, 0x55, 0x6a,
	0x28, 0x4d, 0xa3, 0xdd, 0x7f, 0x95, 0x49, 0x5d, 0xb4, 0xa0, 0x61, 0x27, 0x67, 0x90, 0x17, 0x93,
	0x12, 0xe3, 0xa7, 0x5d, 0x62, 0xfd, 0x75, 0x89, 0xf1, 0xd3, 0x73, 0xe2, 0x4f, 0xe1, 0x40, 0x2a,
	0xd1, 0x13, 0x22, 0xd0, 0xc4, 0x89, 0x54, 0x65, 0x72, 0x94, 0x8a, 0xa1, 0x01, 0xc6, 0x8c, 0x70,
	0x3f, 0xa6, 0x51, 0xba, 0x51, 0x56, 0x45, 0xbc, 0xb2, 0x99, 0x42, 0x3f, 0xc3, 0xe1, 0x1d, 0x7d,
	0x22, 0x33, 0x2f, 0x60, 0xbe, 0x58, 0x3b, 0x21, 0x0e, 0xa3, 0x3d, 0xde, 0xb3, 0xf3, 0xcd, 0xcc,
	0x20, 0x87, 0x76, 0x0f, 0x04, 0x95, 0x0c, 0xd1, 0x27, 0x50, 0x95, 0x16, 0x92, 0xac, 0x22, 0x62,
	0x41, 0xd6, 0x5e, 0x9e, 0x13, 0x6b, 0xfe, 0x31, 0x18, 0x94, 0x7b, 0x6c, 0xca, 0x59, 0x40, 0x12,
	0x62, 0x19, 0x0d, 0xa5, 0x59, 0x76, 0x81, 0xf2, 0xcb, 0x3c, 0x53, 0xff, 0x4d, 0x85, 0xda, 0x16,
	0x59, 0xa6, 0x21, 0x9e, 0xee, 0x86, 0x00, 0xcd, 0x76, 0x40, 0x3c, 0x6f, 0xb9, 0x82, 0xf6, 0x46,
	0xae, 0xb0, 0x6d, 0x4c, 0xc5, 0xe7, 0xc6, 0xc4, 0xe0, 0x40, 0xce, 0x4c, 0x39, 0x7f, 0x24, 0x56,
	0x49, 0x58, 0xc7, 0x57, 0xfb, 0xf5, 0x71, 0x95, 0x41, 0x3a, 0x29, 0xa2, 0x2b, 0x0f, 0x55, 0x44,
	0xf5, 0x3f, 0x55, 0xa8, 0x6e, 0x96, 0xd1, 0x2f, 0x0a, 0x1c, 0xad, 0xe5, 0xba, 0xbe, 0x75, 0xe5,
	0xed, 0x6e, 0xdd, 0x94, 0x6c, 0xeb, 0x8b, 0xdf, 0x15, 0x9d, 0xfa, 0xce, 0x44, 0xb7, 0xb3, 0x37,
	0x85, 0xdd, 0xbd, 0xa9, 0xff, 0xa1, 0xc0, 0xfb, 0xff, 0x89, 0xf6, 0x22, 0x6f, 0x52, 0xb7, 0xbd,
	0xc9, 0x03, 0x5d, 0xba, 0x82, 0xf6, 0x9a, 0xae, 0x20, 0x51, 0x8f, 0x6f, 0xa1, 0x2c, 0x85, 0x88,
	0x2c, 0xa8, 0x8d, 0xfb, 0x37, 0x7d, 0xd7, 0xb9, 0xfe, 0xde, 0x9b, 0x8c, 0xc6, 0x57, 0xfd, 0xae,
	0x73, 0xe6, 0xf4, 0x7b, 0x1b, 0xd6, 0xdb, 0x19, 0x98, 0x0a, 0xd2, 0xa1, 0x30, 0xb8, 0xfc, 0xd6,
	0x54, 0x53, 0x73, 0x1e, 0xf6, 0x7b, 0xce, 0x64, 0x68, 0x16, 0x50, 0x19, 0xb4, 0x0b, 0xe7, 0xfc,
	0xc2, 0xd4, 0x50, 0x15, 0xca, 0x5d, 0xd7, 0xb9, 0x76, 0xba, 0x9d, 0x81, 0x59, 0xfc, 0xf2, 0x57,
	0x05, 0x3e, 0xf3, 0xd9, 0x42, 0x76, 0xfd, 0xff, 0xcd, 0x5e, 0x29, 0x3f, 0xfc, 0x98, 0xbf, 0x34,
	0x67, 0x01, 0x0e, 0xe7, 0x36, 0x8b, 0xe7, 0xad, 0x39, 0x09, 0xc5, 0x2f, 0x79, 0x2b, 0x2b, 0xe1,
	0x88, 0xf2, 0x97, 0xfc, 0xbd, 0xf8, 0x62, 0xa7, 0xf4, 0xbb, 0x5a, 0x38, 0xef, 0x76, 0xa6, 0x25,
	0x81, 0x76, 0xfa, 0x6f, 0x00, 0x00, 0x00, 0xff, 0xff, 0x66, 0xf8, 0xb7, 0x2f, 0xab, 0x08, 0x00,
	0x00,
}
