// Code generated by protoc-gen-go. DO NOT EDIT.
// source: google/ads/googleads/v1/resources/group_placement_view.proto

package resources

import (
	fmt "fmt"
	math "math"

	proto "github.com/golang/protobuf/proto"
	wrappers "github.com/golang/protobuf/ptypes/wrappers"
	enums "google.golang.org/genproto/googleapis/ads/googleads/v1/enums"
	_ "google.golang.org/genproto/googleapis/api/annotations"
)

// Reference imports to suppress errors if they are not otherwise used.
var _ = proto.Marshal
var _ = fmt.Errorf
var _ = math.Inf

// This is a compile-time assertion to ensure that this generated file
// is compatible with the proto package it is being compiled against.
// A compilation error at this line likely means your copy of the
// proto package needs to be updated.
const _ = proto.ProtoPackageIsVersion3 // please upgrade the proto package

// A group placement view.
type GroupPlacementView struct {
	// The resource name of the group placement view.
	// Group placement view resource names have the form:
	//
	//
	// `customers/{customer_id}/groupPlacementViews/{ad_group_id}~{base64_placement}`
	ResourceName string `protobuf:"bytes,1,opt,name=resource_name,json=resourceName,proto3" json:"resource_name,omitempty"`
	// The automatic placement string at group level, e. g. web domain, mobile
	// app ID, or a YouTube channel ID.
	Placement *wrappers.StringValue `protobuf:"bytes,2,opt,name=placement,proto3" json:"placement,omitempty"`
	// Domain name for websites and YouTube channel name for YouTube channels.
	DisplayName *wrappers.StringValue `protobuf:"bytes,3,opt,name=display_name,json=displayName,proto3" json:"display_name,omitempty"`
	// URL of the group placement, e.g. domain, link to the mobile application in
	// app store, or a YouTube channel URL.
	TargetUrl *wrappers.StringValue `protobuf:"bytes,4,opt,name=target_url,json=targetUrl,proto3" json:"target_url,omitempty"`
	// Type of the placement, e.g. Website, YouTube Channel, Mobile Application.
	PlacementType        enums.PlacementTypeEnum_PlacementType `protobuf:"varint,5,opt,name=placement_type,json=placementType,proto3,enum=google.ads.googleads.v1.enums.PlacementTypeEnum_PlacementType" json:"placement_type,omitempty"`
	XXX_NoUnkeyedLiteral struct{}                              `json:"-"`
	XXX_unrecognized     []byte                                `json:"-"`
	XXX_sizecache        int32                                 `json:"-"`
}

func (m *GroupPlacementView) Reset()         { *m = GroupPlacementView{} }
func (m *GroupPlacementView) String() string { return proto.CompactTextString(m) }
func (*GroupPlacementView) ProtoMessage()    {}
func (*GroupPlacementView) Descriptor() ([]byte, []int) {
	return fileDescriptor_40a38bfc66391954, []int{0}
}

func (m *GroupPlacementView) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_GroupPlacementView.Unmarshal(m, b)
}
func (m *GroupPlacementView) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_GroupPlacementView.Marshal(b, m, deterministic)
}
func (m *GroupPlacementView) XXX_Merge(src proto.Message) {
	xxx_messageInfo_GroupPlacementView.Merge(m, src)
}
func (m *GroupPlacementView) XXX_Size() int {
	return xxx_messageInfo_GroupPlacementView.Size(m)
}
func (m *GroupPlacementView) XXX_DiscardUnknown() {
	xxx_messageInfo_GroupPlacementView.DiscardUnknown(m)
}

var xxx_messageInfo_GroupPlacementView proto.InternalMessageInfo

func (m *GroupPlacementView) GetResourceName() string {
	if m != nil {
		return m.ResourceName
	}
	return ""
}

func (m *GroupPlacementView) GetPlacement() *wrappers.StringValue {
	if m != nil {
		return m.Placement
	}
	return nil
}

func (m *GroupPlacementView) GetDisplayName() *wrappers.StringValue {
	if m != nil {
		return m.DisplayName
	}
	return nil
}

func (m *GroupPlacementView) GetTargetUrl() *wrappers.StringValue {
	if m != nil {
		return m.TargetUrl
	}
	return nil
}

func (m *GroupPlacementView) GetPlacementType() enums.PlacementTypeEnum_PlacementType {
	if m != nil {
		return m.PlacementType
	}
	return enums.PlacementTypeEnum_UNSPECIFIED
}

func init() {
	proto.RegisterType((*GroupPlacementView)(nil), "google.ads.googleads.v1.resources.GroupPlacementView")
}

func init() {
	proto.RegisterFile("google/ads/googleads/v1/resources/group_placement_view.proto", fileDescriptor_40a38bfc66391954)
}

var fileDescriptor_40a38bfc66391954 = []byte{
	// 415 bytes of a gzipped FileDescriptorProto
	0x1f, 0x8b, 0x08, 0x00, 0x00, 0x00, 0x00, 0x00, 0x02, 0xff, 0x8c, 0x52, 0xdd, 0x8a, 0xd4, 0x30,
	0x14, 0xa6, 0x5d, 0x15, 0x36, 0xfb, 0x73, 0xd1, 0x1b, 0x87, 0x65, 0x91, 0x59, 0x65, 0x61, 0xae,
	0x12, 0x3a, 0xde, 0x65, 0x45, 0xe9, 0x82, 0x0c, 0x78, 0x21, 0x43, 0xd5, 0x5e, 0x48, 0xa1, 0x64,
	0xa7, 0xc7, 0x50, 0x68, 0x93, 0x90, 0xa4, 0x33, 0xcc, 0xbd, 0x4f, 0xe2, 0xa5, 0x8f, 0xe2, 0x23,
	0xf8, 0x08, 0x3e, 0x85, 0xb4, 0x69, 0xb2, 0x2e, 0xb2, 0xba, 0x77, 0x5f, 0x72, 0xbe, 0xef, 0x3b,
	0xe7, 0xe4, 0x0b, 0x7a, 0xc5, 0xa5, 0xe4, 0x2d, 0x10, 0x56, 0x1b, 0xe2, 0xe0, 0x80, 0xb6, 0x29,
	0xd1, 0x60, 0x64, 0xaf, 0x37, 0x60, 0x08, 0xd7, 0xb2, 0x57, 0x95, 0x6a, 0xd9, 0x06, 0x3a, 0x10,
	0xb6, 0xda, 0x36, 0xb0, 0xc3, 0x4a, 0x4b, 0x2b, 0x93, 0x0b, 0x27, 0xc1, 0xac, 0x36, 0x38, 0xa8,
	0xf1, 0x36, 0xc5, 0x41, 0x7d, 0xb6, 0xbc, 0xaf, 0x01, 0x88, 0xbe, 0x33, 0xe4, 0xd6, 0xd6, 0xee,
	0x15, 0x38, 0xdb, 0xb3, 0x73, 0xaf, 0x51, 0x0d, 0x61, 0x42, 0x48, 0xcb, 0x6c, 0x23, 0x85, 0x99,
	0xaa, 0xcf, 0xa6, 0xea, 0x78, 0xba, 0xe9, 0xbf, 0x90, 0x9d, 0x66, 0x4a, 0x81, 0x9e, 0xea, 0xcf,
	0x7f, 0xc6, 0x28, 0x59, 0x0d, 0x33, 0xaf, 0xbd, 0x77, 0xd1, 0xc0, 0x2e, 0x79, 0x81, 0x4e, 0xfc,
	0x54, 0x95, 0x60, 0x1d, 0xcc, 0xa2, 0x79, 0xb4, 0x38, 0xcc, 0x8f, 0xfd, 0xe5, 0x7b, 0xd6, 0x41,
	0x42, 0xd1, 0x61, 0x98, 0x68, 0x16, 0xcf, 0xa3, 0xc5, 0xd1, 0xf2, 0x7c, 0xda, 0x0c, 0xfb, 0x7e,
	0xf8, 0x83, 0xd5, 0x8d, 0xe0, 0x05, 0x6b, 0x7b, 0xc8, 0x6f, 0xe9, 0xc9, 0x1b, 0x74, 0x5c, 0x37,
	0x46, 0xb5, 0x6c, 0xef, 0xfc, 0x0f, 0x1e, 0x20, 0x3f, 0x9a, 0x14, 0x63, 0xf3, 0x2b, 0x84, 0x2c,
	0xd3, 0x1c, 0x6c, 0xd5, 0xeb, 0x76, 0xf6, 0xe8, 0x21, 0xdd, 0x1d, 0xff, 0x93, 0x6e, 0x13, 0x40,
	0xa7, 0x77, 0xdf, 0x72, 0xf6, 0x78, 0x1e, 0x2d, 0x4e, 0x97, 0xaf, 0xf1, 0x7d, 0x19, 0x8d, 0x01,
	0xe0, 0xf0, 0x48, 0x1f, 0xf7, 0x0a, 0xde, 0x8a, 0xbe, 0xbb, 0x7b, 0x93, 0x9f, 0xa8, 0x3f, 0x8f,
	0xd7, 0x5f, 0x63, 0x74, 0xb9, 0x91, 0x1d, 0xfe, 0x6f, 0xf0, 0xd7, 0x4f, 0xff, 0xce, 0x60, 0x3d,
	0xec, 0xb0, 0x8e, 0x3e, 0xbf, 0x9b, 0xd4, 0x5c, 0xb6, 0x4c, 0x70, 0x2c, 0x35, 0x27, 0x1c, 0xc4,
	0xb8, 0xa1, 0xff, 0x23, 0xaa, 0x31, 0xff, 0xf8, 0x93, 0x57, 0x01, 0x7d, 0x8b, 0x0f, 0x56, 0x59,
	0xf6, 0x3d, 0xbe, 0x58, 0x39, 0xcb, 0xac, 0x36, 0xd8, 0xc1, 0x01, 0x15, 0x29, 0xce, 0x3d, 0xf3,
	0x87, 0xe7, 0x94, 0x59, 0x6d, 0xca, 0xc0, 0x29, 0x8b, 0xb4, 0x0c, 0x9c, 0x5f, 0xf1, 0xa5, 0x2b,
	0x50, 0x9a, 0xd5, 0x86, 0xd2, 0xc0, 0xa2, 0xb4, 0x48, 0x29, 0x0d, 0xbc, 0x9b, 0x27, 0xe3, 0xb0,
	0x2f, 0x7f, 0x07, 0x00, 0x00, 0xff, 0xff, 0xc5, 0xb5, 0xb8, 0xa0, 0x3f, 0x03, 0x00, 0x00,
}
