// Code generated by protoc-gen-go. DO NOT EDIT.
// source: google/ads/googleads/v2/enums/vanity_pharma_text.proto

package enums

import (
	fmt "fmt"
	math "math"

	proto "github.com/golang/protobuf/proto"
	_ "google.golang.org/genproto/googleapis/api/annotations"
)

// Reference imports to suppress errors if they are not otherwise used.
var _ = proto.Marshal
var _ = fmt.Errorf
var _ = math.Inf

// This is a compile-time assertion to ensure that this generated file
// is compatible with the proto package it is being compiled against.
// A compilation error at this line likely means your copy of the
// proto package needs to be updated.
const _ = proto.ProtoPackageIsVersion3 // please upgrade the proto package

// Enum describing possible text.
type VanityPharmaTextEnum_VanityPharmaText int32

const (
	// Not specified.
	VanityPharmaTextEnum_UNSPECIFIED VanityPharmaTextEnum_VanityPharmaText = 0
	// Used for return value only. Represents value unknown in this version.
	VanityPharmaTextEnum_UNKNOWN VanityPharmaTextEnum_VanityPharmaText = 1
	// Prescription treatment website with website content in English.
	VanityPharmaTextEnum_PRESCRIPTION_TREATMENT_WEBSITE_EN VanityPharmaTextEnum_VanityPharmaText = 2
	// Prescription treatment website with website content in Spanish
	// (Sitio de tratamientos con receta).
	VanityPharmaTextEnum_PRESCRIPTION_TREATMENT_WEBSITE_ES VanityPharmaTextEnum_VanityPharmaText = 3
	// Prescription device website with website content in English.
	VanityPharmaTextEnum_PRESCRIPTION_DEVICE_WEBSITE_EN VanityPharmaTextEnum_VanityPharmaText = 4
	// Prescription device website with website content in Spanish (Sitio de
	// dispositivos con receta).
	VanityPharmaTextEnum_PRESCRIPTION_DEVICE_WEBSITE_ES VanityPharmaTextEnum_VanityPharmaText = 5
	// Medical device website with website content in English.
	VanityPharmaTextEnum_MEDICAL_DEVICE_WEBSITE_EN VanityPharmaTextEnum_VanityPharmaText = 6
	// Medical device website with website content in Spanish (Sitio de
	// dispositivos médicos).
	VanityPharmaTextEnum_MEDICAL_DEVICE_WEBSITE_ES VanityPharmaTextEnum_VanityPharmaText = 7
	// Preventative treatment website with website content in English.
	VanityPharmaTextEnum_PREVENTATIVE_TREATMENT_WEBSITE_EN VanityPharmaTextEnum_VanityPharmaText = 8
	// Preventative treatment website with website content in Spanish (Sitio de
	// tratamientos preventivos).
	VanityPharmaTextEnum_PREVENTATIVE_TREATMENT_WEBSITE_ES VanityPharmaTextEnum_VanityPharmaText = 9
	// Prescription contraception website with website content in English.
	VanityPharmaTextEnum_PRESCRIPTION_CONTRACEPTION_WEBSITE_EN VanityPharmaTextEnum_VanityPharmaText = 10
	// Prescription contraception website with website content in Spanish (Sitio
	// de anticonceptivos con receta).
	VanityPharmaTextEnum_PRESCRIPTION_CONTRACEPTION_WEBSITE_ES VanityPharmaTextEnum_VanityPharmaText = 11
	// Prescription vaccine website with website content in English.
	VanityPharmaTextEnum_PRESCRIPTION_VACCINE_WEBSITE_EN VanityPharmaTextEnum_VanityPharmaText = 12
	// Prescription vaccine website with website content in Spanish (Sitio de
	// vacunas con receta).
	VanityPharmaTextEnum_PRESCRIPTION_VACCINE_WEBSITE_ES VanityPharmaTextEnum_VanityPharmaText = 13
)

var VanityPharmaTextEnum_VanityPharmaText_name = map[int32]string{
	0:  "UNSPECIFIED",
	1:  "UNKNOWN",
	2:  "PRESCRIPTION_TREATMENT_WEBSITE_EN",
	3:  "PRESCRIPTION_TREATMENT_WEBSITE_ES",
	4:  "PRESCRIPTION_DEVICE_WEBSITE_EN",
	5:  "PRESCRIPTION_DEVICE_WEBSITE_ES",
	6:  "MEDICAL_DEVICE_WEBSITE_EN",
	7:  "MEDICAL_DEVICE_WEBSITE_ES",
	8:  "PREVENTATIVE_TREATMENT_WEBSITE_EN",
	9:  "PREVENTATIVE_TREATMENT_WEBSITE_ES",
	10: "PRESCRIPTION_CONTRACEPTION_WEBSITE_EN",
	11: "PRESCRIPTION_CONTRACEPTION_WEBSITE_ES",
	12: "PRESCRIPTION_VACCINE_WEBSITE_EN",
	13: "PRESCRIPTION_VACCINE_WEBSITE_ES",
}

var VanityPharmaTextEnum_VanityPharmaText_value = map[string]int32{
	"UNSPECIFIED":                           0,
	"UNKNOWN":                               1,
	"PRESCRIPTION_TREATMENT_WEBSITE_EN":     2,
	"PRESCRIPTION_TREATMENT_WEBSITE_ES":     3,
	"PRESCRIPTION_DEVICE_WEBSITE_EN":        4,
	"PRESCRIPTION_DEVICE_WEBSITE_ES":        5,
	"MEDICAL_DEVICE_WEBSITE_EN":             6,
	"MEDICAL_DEVICE_WEBSITE_ES":             7,
	"PREVENTATIVE_TREATMENT_WEBSITE_EN":     8,
	"PREVENTATIVE_TREATMENT_WEBSITE_ES":     9,
	"PRESCRIPTION_CONTRACEPTION_WEBSITE_EN": 10,
	"PRESCRIPTION_CONTRACEPTION_WEBSITE_ES": 11,
	"PRESCRIPTION_VACCINE_WEBSITE_EN":       12,
	"PRESCRIPTION_VACCINE_WEBSITE_ES":       13,
}

func (x VanityPharmaTextEnum_VanityPharmaText) String() string {
	return proto.EnumName(VanityPharmaTextEnum_VanityPharmaText_name, int32(x))
}

func (VanityPharmaTextEnum_VanityPharmaText) EnumDescriptor() ([]byte, []int) {
	return fileDescriptor_1cee8ebd7fe5a0c2, []int{0, 0}
}

// The text that will be displayed in display URL of the text ad when website
// description is the selected display mode for vanity pharma URLs.
type VanityPharmaTextEnum struct {
	XXX_NoUnkeyedLiteral struct{} `json:"-"`
	XXX_unrecognized     []byte   `json:"-"`
	XXX_sizecache        int32    `json:"-"`
}

func (m *VanityPharmaTextEnum) Reset()         { *m = VanityPharmaTextEnum{} }
func (m *VanityPharmaTextEnum) String() string { return proto.CompactTextString(m) }
func (*VanityPharmaTextEnum) ProtoMessage()    {}
func (*VanityPharmaTextEnum) Descriptor() ([]byte, []int) {
	return fileDescriptor_1cee8ebd7fe5a0c2, []int{0}
}

func (m *VanityPharmaTextEnum) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_VanityPharmaTextEnum.Unmarshal(m, b)
}
func (m *VanityPharmaTextEnum) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_VanityPharmaTextEnum.Marshal(b, m, deterministic)
}
func (m *VanityPharmaTextEnum) XXX_Merge(src proto.Message) {
	xxx_messageInfo_VanityPharmaTextEnum.Merge(m, src)
}
func (m *VanityPharmaTextEnum) XXX_Size() int {
	return xxx_messageInfo_VanityPharmaTextEnum.Size(m)
}
func (m *VanityPharmaTextEnum) XXX_DiscardUnknown() {
	xxx_messageInfo_VanityPharmaTextEnum.DiscardUnknown(m)
}

var xxx_messageInfo_VanityPharmaTextEnum proto.InternalMessageInfo

func init() {
	proto.RegisterEnum("google.ads.googleads.v2.enums.VanityPharmaTextEnum_VanityPharmaText", VanityPharmaTextEnum_VanityPharmaText_name, VanityPharmaTextEnum_VanityPharmaText_value)
	proto.RegisterType((*VanityPharmaTextEnum)(nil), "google.ads.googleads.v2.enums.VanityPharmaTextEnum")
}

func init() {
	proto.RegisterFile("google/ads/googleads/v2/enums/vanity_pharma_text.proto", fileDescriptor_1cee8ebd7fe5a0c2)
}

var fileDescriptor_1cee8ebd7fe5a0c2 = []byte{
	// 429 bytes of a gzipped FileDescriptorProto
	0x1f, 0x8b, 0x08, 0x00, 0x00, 0x00, 0x00, 0x00, 0x02, 0xff, 0x8c, 0x92, 0xc1, 0x8a, 0x13, 0x31,
	0x1c, 0xc6, 0x6d, 0xbb, 0xee, 0x6a, 0xaa, 0x18, 0x06, 0x3d, 0x28, 0x56, 0x69, 0x65, 0x0f, 0x5e,
	0x32, 0x30, 0x82, 0x87, 0x78, 0x4a, 0xd3, 0xb8, 0x04, 0xdd, 0x74, 0x68, 0xb2, 0x59, 0x90, 0xc2,
	0x10, 0x9d, 0x61, 0x2c, 0x6c, 0x93, 0xd2, 0xcc, 0x96, 0xf5, 0x19, 0x7c, 0x0b, 0x8f, 0x3e, 0x8a,
	0x8f, 0xb2, 0x47, 0x9f, 0x40, 0x9a, 0xd9, 0x96, 0xed, 0xb2, 0x6e, 0x7b, 0x19, 0xfe, 0x93, 0xef,
	0xf7, 0x7d, 0xfc, 0xff, 0xf0, 0x81, 0xf7, 0xa5, 0x73, 0xe5, 0x59, 0x11, 0x9b, 0xdc, 0xc7, 0xf5,
	0xb8, 0x9c, 0x16, 0x49, 0x5c, 0xd8, 0xf3, 0xa9, 0x8f, 0x17, 0xc6, 0x4e, 0xaa, 0x1f, 0xd9, 0xec,
	0xbb, 0x99, 0x4f, 0x4d, 0x56, 0x15, 0x17, 0x15, 0x9a, 0xcd, 0x5d, 0xe5, 0xa2, 0x4e, 0x0d, 0x23,
	0x93, 0x7b, 0xb4, 0xf6, 0xa1, 0x45, 0x82, 0x82, 0xef, 0xc5, 0xcb, 0x55, 0xec, 0x6c, 0x12, 0x1b,
	0x6b, 0x5d, 0x65, 0xaa, 0x89, 0xb3, 0xbe, 0x36, 0xf7, 0x7e, 0xee, 0x81, 0xa7, 0x3a, 0x24, 0xa7,
	0x21, 0x58, 0x15, 0x17, 0x15, 0xb3, 0xe7, 0xd3, 0xde, 0xdf, 0x16, 0x80, 0x37, 0x85, 0xe8, 0x09,
	0x68, 0x9f, 0x08, 0x99, 0x32, 0xca, 0x3f, 0x72, 0x36, 0x80, 0xf7, 0xa2, 0x36, 0x38, 0x38, 0x11,
	0x9f, 0xc4, 0xf0, 0x54, 0xc0, 0x46, 0x74, 0x08, 0xba, 0xe9, 0x88, 0x49, 0x3a, 0xe2, 0xa9, 0xe2,
	0x43, 0x91, 0xa9, 0x11, 0x23, 0xea, 0x98, 0x09, 0x95, 0x9d, 0xb2, 0xbe, 0xe4, 0x8a, 0x65, 0x4c,
	0xc0, 0xe6, 0x2e, 0x98, 0x84, 0xad, 0xa8, 0x07, 0x5e, 0x6d, 0x60, 0x03, 0xa6, 0x39, 0x65, 0xd7,
	0xa3, 0xf6, 0xb6, 0x32, 0x12, 0xde, 0x8f, 0x3a, 0xe0, 0xf9, 0x31, 0x1b, 0x70, 0x4a, 0x3e, 0xdf,
	0x12, 0xb1, 0x7f, 0x97, 0x2c, 0xe1, 0xc1, 0xd5, 0xb2, 0x9a, 0x09, 0x45, 0x14, 0xd7, 0xec, 0xf6,
	0x9b, 0x1e, 0xec, 0x82, 0x49, 0xf8, 0x30, 0x7a, 0x0b, 0x0e, 0x37, 0xf6, 0xa5, 0x43, 0xa1, 0x46,
	0x84, 0xb2, 0xfa, 0xef, 0x5a, 0x22, 0xd8, 0x15, 0x95, 0xb0, 0x1d, 0xbd, 0x01, 0xaf, 0x37, 0x50,
	0x4d, 0x28, 0xe5, 0x62, 0xe3, 0xce, 0x47, 0xdb, 0x21, 0x09, 0x1f, 0xf7, 0x2f, 0x1b, 0xa0, 0xfb,
	0xcd, 0x4d, 0xd1, 0x9d, 0x8d, 0xea, 0x3f, 0xbb, 0xd9, 0x8b, 0x74, 0x59, 0xa5, 0xb4, 0xf1, 0xa5,
	0x7f, 0xe5, 0x2b, 0xdd, 0x99, 0xb1, 0x25, 0x72, 0xf3, 0x32, 0x2e, 0x0b, 0x1b, 0x8a, 0xb6, 0x6a,
	0xf4, 0x6c, 0xe2, 0xff, 0x53, 0xf0, 0x0f, 0xe1, 0xfb, 0xab, 0xd9, 0x3a, 0x22, 0xe4, 0x77, 0xb3,
	0x73, 0x54, 0x47, 0x91, 0xdc, 0xa3, 0x7a, 0x5c, 0x4e, 0x3a, 0x41, 0xcb, 0x72, 0xfa, 0x3f, 0x2b,
	0x7d, 0x4c, 0x72, 0x3f, 0x5e, 0xeb, 0x63, 0x9d, 0x8c, 0x83, 0x7e, 0xd9, 0xec, 0xd6, 0x8f, 0x18,
	0x93, 0xdc, 0x63, 0xbc, 0x26, 0x30, 0xd6, 0x09, 0xc6, 0x81, 0xf9, 0xba, 0x1f, 0x16, 0x7b, 0xf7,
	0x2f, 0x00, 0x00, 0xff, 0xff, 0x25, 0xe3, 0xd6, 0x9b, 0x78, 0x03, 0x00, 0x00,
}
