// Code generated by protoc-gen-go. DO NOT EDIT.
// source: google/ads/googleads/v2/resources/keyword_plan_keyword.proto

package resources

import (
	fmt "fmt"
	math "math"

	proto "github.com/golang/protobuf/proto"
	wrappers "github.com/golang/protobuf/ptypes/wrappers"
	enums "google.golang.org/genproto/googleapis/ads/googleads/v2/enums"
	_ "google.golang.org/genproto/googleapis/api/annotations"
)

// Reference imports to suppress errors if they are not otherwise used.
var _ = proto.Marshal
var _ = fmt.Errorf
var _ = math.Inf

// This is a compile-time assertion to ensure that this generated file
// is compatible with the proto package it is being compiled against.
// A compilation error at this line likely means your copy of the
// proto package needs to be updated.
const _ = proto.ProtoPackageIsVersion3 // please upgrade the proto package

// A Keyword Plan ad group keyword.
// Max number of keyword plan keywords per plan: 2500.
type KeywordPlanKeyword struct {
	// The resource name of the Keyword Plan ad group keyword.
	// KeywordPlanKeyword resource names have the form:
	//
	// `customers/{customer_id}/keywordPlanKeywords/{kp_ad_group_keyword_id}`
	ResourceName string `protobuf:"bytes,1,opt,name=resource_name,json=resourceName,proto3" json:"resource_name,omitempty"`
	// The Keyword Plan ad group to which this keyword belongs.
	KeywordPlanAdGroup *wrappers.StringValue `protobuf:"bytes,2,opt,name=keyword_plan_ad_group,json=keywordPlanAdGroup,proto3" json:"keyword_plan_ad_group,omitempty"`
	// The ID of the Keyword Plan keyword.
	Id *wrappers.Int64Value `protobuf:"bytes,3,opt,name=id,proto3" json:"id,omitempty"`
	// The keyword text.
	Text *wrappers.StringValue `protobuf:"bytes,4,opt,name=text,proto3" json:"text,omitempty"`
	// The keyword match type.
	MatchType enums.KeywordMatchTypeEnum_KeywordMatchType `protobuf:"varint,5,opt,name=match_type,json=matchType,proto3,enum=google.ads.googleads.v2.enums.KeywordMatchTypeEnum_KeywordMatchType" json:"match_type,omitempty"`
	// A keyword level max cpc bid in micros, in the account currency, that
	// overrides the keyword plan ad group cpc bid.
	CpcBidMicros         *wrappers.Int64Value `protobuf:"bytes,6,opt,name=cpc_bid_micros,json=cpcBidMicros,proto3" json:"cpc_bid_micros,omitempty"`
	XXX_NoUnkeyedLiteral struct{}             `json:"-"`
	XXX_unrecognized     []byte               `json:"-"`
	XXX_sizecache        int32                `json:"-"`
}

func (m *KeywordPlanKeyword) Reset()         { *m = KeywordPlanKeyword{} }
func (m *KeywordPlanKeyword) String() string { return proto.CompactTextString(m) }
func (*KeywordPlanKeyword) ProtoMessage()    {}
func (*KeywordPlanKeyword) Descriptor() ([]byte, []int) {
	return fileDescriptor_f244ce6e07acf616, []int{0}
}

func (m *KeywordPlanKeyword) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_KeywordPlanKeyword.Unmarshal(m, b)
}
func (m *KeywordPlanKeyword) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_KeywordPlanKeyword.Marshal(b, m, deterministic)
}
func (m *KeywordPlanKeyword) XXX_Merge(src proto.Message) {
	xxx_messageInfo_KeywordPlanKeyword.Merge(m, src)
}
func (m *KeywordPlanKeyword) XXX_Size() int {
	return xxx_messageInfo_KeywordPlanKeyword.Size(m)
}
func (m *KeywordPlanKeyword) XXX_DiscardUnknown() {
	xxx_messageInfo_KeywordPlanKeyword.DiscardUnknown(m)
}

var xxx_messageInfo_KeywordPlanKeyword proto.InternalMessageInfo

func (m *KeywordPlanKeyword) GetResourceName() string {
	if m != nil {
		return m.ResourceName
	}
	return ""
}

func (m *KeywordPlanKeyword) GetKeywordPlanAdGroup() *wrappers.StringValue {
	if m != nil {
		return m.KeywordPlanAdGroup
	}
	return nil
}

func (m *KeywordPlanKeyword) GetId() *wrappers.Int64Value {
	if m != nil {
		return m.Id
	}
	return nil
}

func (m *KeywordPlanKeyword) GetText() *wrappers.StringValue {
	if m != nil {
		return m.Text
	}
	return nil
}

func (m *KeywordPlanKeyword) GetMatchType() enums.KeywordMatchTypeEnum_KeywordMatchType {
	if m != nil {
		return m.MatchType
	}
	return enums.KeywordMatchTypeEnum_UNSPECIFIED
}

func (m *KeywordPlanKeyword) GetCpcBidMicros() *wrappers.Int64Value {
	if m != nil {
		return m.CpcBidMicros
	}
	return nil
}

func init() {
	proto.RegisterType((*KeywordPlanKeyword)(nil), "google.ads.googleads.v2.resources.KeywordPlanKeyword")
}

func init() {
	proto.RegisterFile("google/ads/googleads/v2/resources/keyword_plan_keyword.proto", fileDescriptor_f244ce6e07acf616)
}

var fileDescriptor_f244ce6e07acf616 = []byte{
	// 452 bytes of a gzipped FileDescriptorProto
	0x1f, 0x8b, 0x08, 0x00, 0x00, 0x00, 0x00, 0x00, 0x02, 0xff, 0x8c, 0x92, 0xc1, 0x8a, 0xd4, 0x30,
	0x18, 0xc7, 0x69, 0x67, 0x5d, 0xd8, 0xb8, 0xee, 0x21, 0x20, 0x96, 0x75, 0x91, 0x59, 0x65, 0x61,
	0x40, 0x48, 0xa5, 0xca, 0x1e, 0xaa, 0x97, 0x0e, 0xca, 0xa0, 0xb2, 0x3a, 0x8c, 0x32, 0x07, 0x29,
	0x94, 0x4c, 0x12, 0x6b, 0xd8, 0x36, 0x09, 0x49, 0xba, 0xeb, 0xdc, 0x7d, 0x01, 0x5f, 0xc1, 0xa3,
	0x8f, 0xe2, 0xa3, 0xf8, 0x14, 0xd2, 0x36, 0xe9, 0x20, 0xc3, 0x3a, 0xde, 0xfe, 0x49, 0xfe, 0xbf,
	0xff, 0x97, 0x7c, 0xf9, 0xc0, 0x8b, 0x52, 0xca, 0xb2, 0x62, 0x31, 0xa6, 0x26, 0xee, 0x65, 0xab,
	0xae, 0x92, 0x58, 0x33, 0x23, 0x1b, 0x4d, 0x98, 0x89, 0x2f, 0xd9, 0xfa, 0x5a, 0x6a, 0x5a, 0xa8,
	0x0a, 0x8b, 0xc2, 0x2d, 0x90, 0xd2, 0xd2, 0x4a, 0x78, 0xda, 0x23, 0x08, 0x53, 0x83, 0x06, 0x1a,
	0x5d, 0x25, 0x68, 0xa0, 0x8f, 0xcf, 0x6f, 0x2a, 0xc0, 0x44, 0x53, 0x6f, 0xc2, 0x6b, 0x6c, 0xc9,
	0x97, 0xc2, 0xae, 0x15, 0xeb, 0xa3, 0x8f, 0x1f, 0x38, 0xae, 0x5b, 0xad, 0x9a, 0xcf, 0xf1, 0xb5,
	0xc6, 0x4a, 0x31, 0x6d, 0xdc, 0xf9, 0x89, 0xcf, 0x55, 0x3c, 0xc6, 0x42, 0x48, 0x8b, 0x2d, 0x97,
	0xc2, 0x9d, 0x3e, 0xfc, 0x3e, 0x02, 0xf0, 0x6d, 0x1f, 0x3d, 0xaf, 0xb0, 0x70, 0x12, 0x3e, 0x02,
	0x77, 0xfc, 0xcd, 0x0a, 0x81, 0x6b, 0x16, 0x05, 0xe3, 0x60, 0x72, 0xb0, 0x38, 0xf4, 0x9b, 0xef,
	0x70, 0xcd, 0xe0, 0x7b, 0x70, 0xf7, 0xaf, 0x27, 0x63, 0x5a, 0x94, 0x5a, 0x36, 0x2a, 0x0a, 0xc7,
	0xc1, 0xe4, 0x76, 0x72, 0xe2, 0x5e, 0x8a, 0xfc, 0xcd, 0xd0, 0x07, 0xab, 0xb9, 0x28, 0x97, 0xb8,
	0x6a, 0xd8, 0x02, 0x5e, 0x6e, 0xaa, 0x66, 0x74, 0xd6, 0x72, 0xf0, 0x31, 0x08, 0x39, 0x8d, 0x46,
	0x1d, 0x7d, 0x7f, 0x8b, 0x7e, 0x2d, 0xec, 0xf9, 0xb3, 0x1e, 0x0e, 0x39, 0x85, 0x4f, 0xc0, 0x9e,
	0x65, 0x5f, 0x6d, 0xb4, 0xf7, 0x1f, 0xc5, 0x3a, 0x27, 0x24, 0x00, 0x6c, 0xba, 0x17, 0xdd, 0x1a,
	0x07, 0x93, 0xa3, 0xe4, 0x25, 0xba, 0xe9, 0x67, 0xba, 0xb6, 0x23, 0xd7, 0x90, 0x8b, 0x96, 0xfb,
	0xb8, 0x56, 0xec, 0x95, 0x68, 0xea, 0xad, 0xcd, 0xc5, 0x41, 0xed, 0x25, 0xcc, 0xc0, 0x11, 0x51,
	0xa4, 0x58, 0x71, 0x5a, 0xd4, 0x9c, 0x68, 0x69, 0xa2, 0xfd, 0xdd, 0xef, 0x39, 0x24, 0x8a, 0x4c,
	0x39, 0xbd, 0xe8, 0x80, 0xe9, 0xb7, 0x10, 0x9c, 0x11, 0x59, 0xa3, 0x9d, 0x33, 0x33, 0xbd, 0xb7,
	0xfd, 0x75, 0xf3, 0x36, 0x7e, 0x1e, 0x7c, 0x7a, 0xe3, 0xe8, 0x52, 0x56, 0x58, 0x94, 0x48, 0xea,
	0x32, 0x2e, 0x99, 0xe8, 0x8a, 0xfb, 0xf1, 0x52, 0xdc, 0xfc, 0x63, 0x9c, 0x9f, 0x0f, 0xea, 0x47,
	0x38, 0x9a, 0x65, 0xd9, 0xcf, 0xf0, 0x74, 0xd6, 0x47, 0x66, 0xd4, 0xa0, 0x5e, 0xb6, 0x6a, 0x99,
	0xa0, 0x85, 0x77, 0xfe, 0xf2, 0x9e, 0x3c, 0xa3, 0x26, 0x1f, 0x3c, 0xf9, 0x32, 0xc9, 0x07, 0xcf,
	0xef, 0xf0, 0xac, 0x3f, 0x48, 0xd3, 0x8c, 0x9a, 0x34, 0x1d, 0x5c, 0x69, 0xba, 0x4c, 0xd2, 0x74,
	0xf0, 0xad, 0xf6, 0xbb, 0xcb, 0x3e, 0xfd, 0x13, 0x00, 0x00, 0xff, 0xff, 0x33, 0x39, 0xf5, 0x3d,
	0x7a, 0x03, 0x00, 0x00,
}
