// Code generated by protoc-gen-go. DO NOT EDIT.
// source: google/ads/googleads/v2/resources/extension_feed_item.proto

package resources

import (
	fmt "fmt"
	math "math"

	proto "github.com/golang/protobuf/proto"
	wrappers "github.com/golang/protobuf/ptypes/wrappers"
	common "google.golang.org/genproto/googleapis/ads/googleads/v2/common"
	enums "google.golang.org/genproto/googleapis/ads/googleads/v2/enums"
	_ "google.golang.org/genproto/googleapis/api/annotations"
)

// Reference imports to suppress errors if they are not otherwise used.
var _ = proto.Marshal
var _ = fmt.Errorf
var _ = math.Inf

// This is a compile-time assertion to ensure that this generated file
// is compatible with the proto package it is being compiled against.
// A compilation error at this line likely means your copy of the
// proto package needs to be updated.
const _ = proto.ProtoPackageIsVersion3 // please upgrade the proto package

// An extension feed item.
type ExtensionFeedItem struct {
	// The resource name of the extension feed item.
	// Extension feed item resource names have the form:
	//
	// `customers/{customer_id}/extensionFeedItems/{feed_item_id}`
	ResourceName string `protobuf:"bytes,1,opt,name=resource_name,json=resourceName,proto3" json:"resource_name,omitempty"`
	// The extension type of the extension feed item.
	// This field is read-only.
	ExtensionType enums.ExtensionTypeEnum_ExtensionType `protobuf:"varint,13,opt,name=extension_type,json=extensionType,proto3,enum=google.ads.googleads.v2.enums.ExtensionTypeEnum_ExtensionType" json:"extension_type,omitempty"`
	// Start time in which this feed item is effective and can begin serving. The
	// time is in the customer's time zone.
	// The format is "YYYY-MM-DD HH:MM:SS".
	// Examples: "2018-03-05 09:15:00" or "2018-02-01 14:34:30"
	StartDateTime *wrappers.StringValue `protobuf:"bytes,5,opt,name=start_date_time,json=startDateTime,proto3" json:"start_date_time,omitempty"`
	// End time in which this feed item is no longer effective and will stop
	// serving. The time is in the customer's time zone.
	// The format is "YYYY-MM-DD HH:MM:SS".
	// Examples: "2018-03-05 09:15:00" or "2018-02-01 14:34:30"
	EndDateTime *wrappers.StringValue `protobuf:"bytes,6,opt,name=end_date_time,json=endDateTime,proto3" json:"end_date_time,omitempty"`
	// List of non-overlapping schedules specifying all time intervals
	// for which the feed item may serve. There can be a maximum of 6 schedules
	// per day.
	AdSchedules []*common.AdScheduleInfo `protobuf:"bytes,16,rep,name=ad_schedules,json=adSchedules,proto3" json:"ad_schedules,omitempty"`
	// The targeted device.
	Device enums.FeedItemTargetDeviceEnum_FeedItemTargetDevice `protobuf:"varint,17,opt,name=device,proto3,enum=google.ads.googleads.v2.enums.FeedItemTargetDeviceEnum_FeedItemTargetDevice" json:"device,omitempty"`
	// The targeted geo target constant.
	TargetedGeoTargetConstant *wrappers.StringValue `protobuf:"bytes,20,opt,name=targeted_geo_target_constant,json=targetedGeoTargetConstant,proto3" json:"targeted_geo_target_constant,omitempty"`
	// The targeted keyword.
	TargetedKeyword *common.KeywordInfo `protobuf:"bytes,22,opt,name=targeted_keyword,json=targetedKeyword,proto3" json:"targeted_keyword,omitempty"`
	// Status of the feed item.
	// This field is read-only.
	Status enums.FeedItemStatusEnum_FeedItemStatus `protobuf:"varint,4,opt,name=status,proto3,enum=google.ads.googleads.v2.enums.FeedItemStatusEnum_FeedItemStatus" json:"status,omitempty"`
	// Extension type.
	//
	// Types that are valid to be assigned to Extension:
	//	*ExtensionFeedItem_SitelinkFeedItem
	//	*ExtensionFeedItem_StructuredSnippetFeedItem
	//	*ExtensionFeedItem_AppFeedItem
	//	*ExtensionFeedItem_CallFeedItem
	//	*ExtensionFeedItem_CalloutFeedItem
	//	*ExtensionFeedItem_TextMessageFeedItem
	//	*ExtensionFeedItem_PriceFeedItem
	//	*ExtensionFeedItem_PromotionFeedItem
	//	*ExtensionFeedItem_LocationFeedItem
	//	*ExtensionFeedItem_AffiliateLocationFeedItem
	Extension isExtensionFeedItem_Extension `protobuf_oneof:"extension"`
	// Targeting at either the campaign or ad group level. Feed items that target
	// a campaign or ad group will only serve with that resource.
	//
	// Types that are valid to be assigned to ServingResourceTargeting:
	//	*ExtensionFeedItem_TargetedCampaign
	//	*ExtensionFeedItem_TargetedAdGroup
	ServingResourceTargeting isExtensionFeedItem_ServingResourceTargeting `protobuf_oneof:"serving_resource_targeting"`
	XXX_NoUnkeyedLiteral     struct{}                                     `json:"-"`
	XXX_unrecognized         []byte                                       `json:"-"`
	XXX_sizecache            int32                                        `json:"-"`
}

func (m *ExtensionFeedItem) Reset()         { *m = ExtensionFeedItem{} }
func (m *ExtensionFeedItem) String() string { return proto.CompactTextString(m) }
func (*ExtensionFeedItem) ProtoMessage()    {}
func (*ExtensionFeedItem) Descriptor() ([]byte, []int) {
	return fileDescriptor_84144755971e2200, []int{0}
}

func (m *ExtensionFeedItem) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_ExtensionFeedItem.Unmarshal(m, b)
}
func (m *ExtensionFeedItem) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_ExtensionFeedItem.Marshal(b, m, deterministic)
}
func (m *ExtensionFeedItem) XXX_Merge(src proto.Message) {
	xxx_messageInfo_ExtensionFeedItem.Merge(m, src)
}
func (m *ExtensionFeedItem) XXX_Size() int {
	return xxx_messageInfo_ExtensionFeedItem.Size(m)
}
func (m *ExtensionFeedItem) XXX_DiscardUnknown() {
	xxx_messageInfo_ExtensionFeedItem.DiscardUnknown(m)
}

var xxx_messageInfo_ExtensionFeedItem proto.InternalMessageInfo

func (m *ExtensionFeedItem) GetResourceName() string {
	if m != nil {
		return m.ResourceName
	}
	return ""
}

func (m *ExtensionFeedItem) GetExtensionType() enums.ExtensionTypeEnum_ExtensionType {
	if m != nil {
		return m.ExtensionType
	}
	return enums.ExtensionTypeEnum_UNSPECIFIED
}

func (m *ExtensionFeedItem) GetStartDateTime() *wrappers.StringValue {
	if m != nil {
		return m.StartDateTime
	}
	return nil
}

func (m *ExtensionFeedItem) GetEndDateTime() *wrappers.StringValue {
	if m != nil {
		return m.EndDateTime
	}
	return nil
}

func (m *ExtensionFeedItem) GetAdSchedules() []*common.AdScheduleInfo {
	if m != nil {
		return m.AdSchedules
	}
	return nil
}

func (m *ExtensionFeedItem) GetDevice() enums.FeedItemTargetDeviceEnum_FeedItemTargetDevice {
	if m != nil {
		return m.Device
	}
	return enums.FeedItemTargetDeviceEnum_UNSPECIFIED
}

func (m *ExtensionFeedItem) GetTargetedGeoTargetConstant() *wrappers.StringValue {
	if m != nil {
		return m.TargetedGeoTargetConstant
	}
	return nil
}

func (m *ExtensionFeedItem) GetTargetedKeyword() *common.KeywordInfo {
	if m != nil {
		return m.TargetedKeyword
	}
	return nil
}

func (m *ExtensionFeedItem) GetStatus() enums.FeedItemStatusEnum_FeedItemStatus {
	if m != nil {
		return m.Status
	}
	return enums.FeedItemStatusEnum_UNSPECIFIED
}

type isExtensionFeedItem_Extension interface {
	isExtensionFeedItem_Extension()
}

type ExtensionFeedItem_SitelinkFeedItem struct {
	SitelinkFeedItem *common.SitelinkFeedItem `protobuf:"bytes,2,opt,name=sitelink_feed_item,json=sitelinkFeedItem,proto3,oneof"`
}

type ExtensionFeedItem_StructuredSnippetFeedItem struct {
	StructuredSnippetFeedItem *common.StructuredSnippetFeedItem `protobuf:"bytes,3,opt,name=structured_snippet_feed_item,json=structuredSnippetFeedItem,proto3,oneof"`
}

type ExtensionFeedItem_AppFeedItem struct {
	AppFeedItem *common.AppFeedItem `protobuf:"bytes,7,opt,name=app_feed_item,json=appFeedItem,proto3,oneof"`
}

type ExtensionFeedItem_CallFeedItem struct {
	CallFeedItem *common.CallFeedItem `protobuf:"bytes,8,opt,name=call_feed_item,json=callFeedItem,proto3,oneof"`
}

type ExtensionFeedItem_CalloutFeedItem struct {
	CalloutFeedItem *common.CalloutFeedItem `protobuf:"bytes,9,opt,name=callout_feed_item,json=calloutFeedItem,proto3,oneof"`
}

type ExtensionFeedItem_TextMessageFeedItem struct {
	TextMessageFeedItem *common.TextMessageFeedItem `protobuf:"bytes,10,opt,name=text_message_feed_item,json=textMessageFeedItem,proto3,oneof"`
}

type ExtensionFeedItem_PriceFeedItem struct {
	PriceFeedItem *common.PriceFeedItem `protobuf:"bytes,11,opt,name=price_feed_item,json=priceFeedItem,proto3,oneof"`
}

type ExtensionFeedItem_PromotionFeedItem struct {
	PromotionFeedItem *common.PromotionFeedItem `protobuf:"bytes,12,opt,name=promotion_feed_item,json=promotionFeedItem,proto3,oneof"`
}

type ExtensionFeedItem_LocationFeedItem struct {
	LocationFeedItem *common.LocationFeedItem `protobuf:"bytes,14,opt,name=location_feed_item,json=locationFeedItem,proto3,oneof"`
}

type ExtensionFeedItem_AffiliateLocationFeedItem struct {
	AffiliateLocationFeedItem *common.AffiliateLocationFeedItem `protobuf:"bytes,15,opt,name=affiliate_location_feed_item,json=affiliateLocationFeedItem,proto3,oneof"`
}

func (*ExtensionFeedItem_SitelinkFeedItem) isExtensionFeedItem_Extension() {}

func (*ExtensionFeedItem_StructuredSnippetFeedItem) isExtensionFeedItem_Extension() {}

func (*ExtensionFeedItem_AppFeedItem) isExtensionFeedItem_Extension() {}

func (*ExtensionFeedItem_CallFeedItem) isExtensionFeedItem_Extension() {}

func (*ExtensionFeedItem_CalloutFeedItem) isExtensionFeedItem_Extension() {}

func (*ExtensionFeedItem_TextMessageFeedItem) isExtensionFeedItem_Extension() {}

func (*ExtensionFeedItem_PriceFeedItem) isExtensionFeedItem_Extension() {}

func (*ExtensionFeedItem_PromotionFeedItem) isExtensionFeedItem_Extension() {}

func (*ExtensionFeedItem_LocationFeedItem) isExtensionFeedItem_Extension() {}

func (*ExtensionFeedItem_AffiliateLocationFeedItem) isExtensionFeedItem_Extension() {}

func (m *ExtensionFeedItem) GetExtension() isExtensionFeedItem_Extension {
	if m != nil {
		return m.Extension
	}
	return nil
}

func (m *ExtensionFeedItem) GetSitelinkFeedItem() *common.SitelinkFeedItem {
	if x, ok := m.GetExtension().(*ExtensionFeedItem_SitelinkFeedItem); ok {
		return x.SitelinkFeedItem
	}
	return nil
}

func (m *ExtensionFeedItem) GetStructuredSnippetFeedItem() *common.StructuredSnippetFeedItem {
	if x, ok := m.GetExtension().(*ExtensionFeedItem_StructuredSnippetFeedItem); ok {
		return x.StructuredSnippetFeedItem
	}
	return nil
}

func (m *ExtensionFeedItem) GetAppFeedItem() *common.AppFeedItem {
	if x, ok := m.GetExtension().(*ExtensionFeedItem_AppFeedItem); ok {
		return x.AppFeedItem
	}
	return nil
}

func (m *ExtensionFeedItem) GetCallFeedItem() *common.CallFeedItem {
	if x, ok := m.GetExtension().(*ExtensionFeedItem_CallFeedItem); ok {
		return x.CallFeedItem
	}
	return nil
}

func (m *ExtensionFeedItem) GetCalloutFeedItem() *common.CalloutFeedItem {
	if x, ok := m.GetExtension().(*ExtensionFeedItem_CalloutFeedItem); ok {
		return x.CalloutFeedItem
	}
	return nil
}

func (m *ExtensionFeedItem) GetTextMessageFeedItem() *common.TextMessageFeedItem {
	if x, ok := m.GetExtension().(*ExtensionFeedItem_TextMessageFeedItem); ok {
		return x.TextMessageFeedItem
	}
	return nil
}

func (m *ExtensionFeedItem) GetPriceFeedItem() *common.PriceFeedItem {
	if x, ok := m.GetExtension().(*ExtensionFeedItem_PriceFeedItem); ok {
		return x.PriceFeedItem
	}
	return nil
}

func (m *ExtensionFeedItem) GetPromotionFeedItem() *common.PromotionFeedItem {
	if x, ok := m.GetExtension().(*ExtensionFeedItem_PromotionFeedItem); ok {
		return x.PromotionFeedItem
	}
	return nil
}

func (m *ExtensionFeedItem) GetLocationFeedItem() *common.LocationFeedItem {
	if x, ok := m.GetExtension().(*ExtensionFeedItem_LocationFeedItem); ok {
		return x.LocationFeedItem
	}
	return nil
}

func (m *ExtensionFeedItem) GetAffiliateLocationFeedItem() *common.AffiliateLocationFeedItem {
	if x, ok := m.GetExtension().(*ExtensionFeedItem_AffiliateLocationFeedItem); ok {
		return x.AffiliateLocationFeedItem
	}
	return nil
}

type isExtensionFeedItem_ServingResourceTargeting interface {
	isExtensionFeedItem_ServingResourceTargeting()
}

type ExtensionFeedItem_TargetedCampaign struct {
	TargetedCampaign *wrappers.StringValue `protobuf:"bytes,18,opt,name=targeted_campaign,json=targetedCampaign,proto3,oneof"`
}

type ExtensionFeedItem_TargetedAdGroup struct {
	TargetedAdGroup *wrappers.StringValue `protobuf:"bytes,19,opt,name=targeted_ad_group,json=targetedAdGroup,proto3,oneof"`
}

func (*ExtensionFeedItem_TargetedCampaign) isExtensionFeedItem_ServingResourceTargeting() {}

func (*ExtensionFeedItem_TargetedAdGroup) isExtensionFeedItem_ServingResourceTargeting() {}

func (m *ExtensionFeedItem) GetServingResourceTargeting() isExtensionFeedItem_ServingResourceTargeting {
	if m != nil {
		return m.ServingResourceTargeting
	}
	return nil
}

func (m *ExtensionFeedItem) GetTargetedCampaign() *wrappers.StringValue {
	if x, ok := m.GetServingResourceTargeting().(*ExtensionFeedItem_TargetedCampaign); ok {
		return x.TargetedCampaign
	}
	return nil
}

func (m *ExtensionFeedItem) GetTargetedAdGroup() *wrappers.StringValue {
	if x, ok := m.GetServingResourceTargeting().(*ExtensionFeedItem_TargetedAdGroup); ok {
		return x.TargetedAdGroup
	}
	return nil
}

// XXX_OneofWrappers is for the internal use of the proto package.
func (*ExtensionFeedItem) XXX_OneofWrappers() []interface{} {
	return []interface{}{
		(*ExtensionFeedItem_SitelinkFeedItem)(nil),
		(*ExtensionFeedItem_StructuredSnippetFeedItem)(nil),
		(*ExtensionFeedItem_AppFeedItem)(nil),
		(*ExtensionFeedItem_CallFeedItem)(nil),
		(*ExtensionFeedItem_CalloutFeedItem)(nil),
		(*ExtensionFeedItem_TextMessageFeedItem)(nil),
		(*ExtensionFeedItem_PriceFeedItem)(nil),
		(*ExtensionFeedItem_PromotionFeedItem)(nil),
		(*ExtensionFeedItem_LocationFeedItem)(nil),
		(*ExtensionFeedItem_AffiliateLocationFeedItem)(nil),
		(*ExtensionFeedItem_TargetedCampaign)(nil),
		(*ExtensionFeedItem_TargetedAdGroup)(nil),
	}
}

func init() {
	proto.RegisterType((*ExtensionFeedItem)(nil), "google.ads.googleads.v2.resources.ExtensionFeedItem")
}

func init() {
	proto.RegisterFile("google/ads/googleads/v2/resources/extension_feed_item.proto", fileDescriptor_84144755971e2200)
}

var fileDescriptor_84144755971e2200 = []byte{
	// 920 bytes of a gzipped FileDescriptorProto
	0x1f, 0x8b, 0x08, 0x00, 0x00, 0x00, 0x00, 0x00, 0x02, 0xff, 0x8c, 0x96, 0xdf, 0x6e, 0x23, 0xb5,
	0x17, 0xc7, 0x7f, 0x49, 0x7f, 0x14, 0xea, 0x34, 0x4d, 0xe3, 0xa2, 0x6a, 0x5a, 0x45, 0xa8, 0x0b,
	0x5a, 0xa9, 0x12, 0xec, 0x0c, 0x64, 0xb9, 0x21, 0x95, 0xd0, 0xa6, 0xed, 0xd2, 0xfd, 0x07, 0xea,
	0x26, 0x51, 0x40, 0xa8, 0xab, 0xc1, 0x3b, 0x3e, 0x19, 0xcc, 0xce, 0xd8, 0xd6, 0xd8, 0xd3, 0x6d,
	0x25, 0xee, 0x78, 0x13, 0x6e, 0x90, 0x78, 0x14, 0x1e, 0x85, 0xa7, 0x40, 0xf1, 0xcc, 0xb8, 0x4e,
	0xb7, 0xd9, 0xc9, 0x9d, 0x7d, 0xe6, 0x7c, 0x3f, 0x5f, 0xfb, 0xf8, 0xdf, 0xa0, 0xa3, 0x58, 0x88,
	0x38, 0x81, 0x80, 0x50, 0x15, 0x14, 0xcd, 0x79, 0xeb, 0xb2, 0x1f, 0x64, 0xa0, 0x44, 0x9e, 0x45,
	0xa0, 0x02, 0xb8, 0xd2, 0xc0, 0x15, 0x13, 0x3c, 0x9c, 0x01, 0xd0, 0x90, 0x69, 0x48, 0x7d, 0x99,
	0x09, 0x2d, 0xf0, 0xbd, 0x42, 0xe1, 0x13, 0xaa, 0x7c, 0x2b, 0xf6, 0x2f, 0xfb, 0xbe, 0x15, 0xef,
	0x3f, 0x58, 0xc6, 0x8f, 0x44, 0x9a, 0x0a, 0x1e, 0x44, 0x19, 0xd3, 0x90, 0x31, 0x52, 0x10, 0xf7,
	0x83, 0x9a, 0x74, 0x3b, 0x16, 0x55, 0x0a, 0xfa, 0xcb, 0x04, 0xc0, 0xf3, 0xd4, 0x1d, 0xbb, 0xbe,
	0x96, 0x50, 0x6a, 0xbe, 0x7e, 0xbf, 0xc6, 0xce, 0x32, 0x54, 0x9a, 0xe8, 0xbc, 0x72, 0x3a, 0x5a,
	0x55, 0xa5, 0x49, 0x16, 0x83, 0x0e, 0x29, 0x5c, 0xb2, 0xa8, 0xb2, 0xfc, 0xa4, 0x14, 0x9b, 0xde,
	0xeb, 0x7c, 0x16, 0xbc, 0xcd, 0x88, 0x94, 0x90, 0x55, 0xf0, 0x5e, 0x05, 0x97, 0x2c, 0x20, 0x9c,
	0x0b, 0x4d, 0xf4, 0xcd, 0x24, 0x3f, 0xfd, 0xab, 0x83, 0xba, 0x8f, 0xab, 0x99, 0x7c, 0x07, 0x40,
	0x9f, 0x6a, 0x48, 0xf1, 0x67, 0xa8, 0x5d, 0xd5, 0x39, 0xe4, 0x24, 0x05, 0xaf, 0x71, 0xd0, 0x38,
	0xdc, 0x18, 0x6d, 0x56, 0xc1, 0x1f, 0x48, 0x0a, 0x18, 0xd0, 0xd6, 0x62, 0x0d, 0xbc, 0xf6, 0x41,
	0xe3, 0x70, 0xab, 0xff, 0xad, 0xbf, 0x6c, 0xed, 0xcc, 0x74, 0x7c, 0x6b, 0x37, 0xb9, 0x96, 0xf0,
	0x98, 0xe7, 0xe9, 0x62, 0x64, 0xd4, 0x06, 0xb7, 0x8b, 0x4f, 0x51, 0x47, 0x69, 0x92, 0xe9, 0x90,
	0x12, 0x0d, 0xa1, 0x66, 0x29, 0x78, 0x1f, 0x1c, 0x34, 0x0e, 0x5b, 0xfd, 0x5e, 0xe5, 0x53, 0xcd,
	0xdc, 0x1f, 0xeb, 0x8c, 0xf1, 0x78, 0x4a, 0x92, 0x1c, 0x46, 0x6d, 0x23, 0x3a, 0x25, 0x1a, 0x26,
	0x2c, 0x05, 0xfc, 0x08, 0xb5, 0x81, 0x53, 0x87, 0xb1, 0xbe, 0x02, 0xa3, 0x05, 0x9c, 0x5a, 0xc2,
	0x4b, 0xb4, 0x49, 0x68, 0xa8, 0xa2, 0x5f, 0x81, 0xe6, 0x09, 0x28, 0x6f, 0xfb, 0x60, 0xed, 0xb0,
	0xd5, 0xf7, 0x97, 0x4e, 0xb6, 0xd8, 0x56, 0xfe, 0x90, 0x8e, 0x4b, 0xc9, 0x53, 0x3e, 0x13, 0xa3,
	0x16, 0xb1, 0x7d, 0x85, 0x29, 0x5a, 0x2f, 0x96, 0xd2, 0xeb, 0x9a, 0xca, 0xbd, 0xa8, 0xa9, 0x5c,
	0xb5, 0x3e, 0x13, 0xb3, 0x0d, 0x4e, 0x8d, 0xd4, 0x14, 0xf0, 0xae, 0x0f, 0xa3, 0x92, 0x8d, 0x5f,
	0xa1, 0x5e, 0xb1, 0x6f, 0x80, 0x86, 0x31, 0x88, 0x6a, 0x13, 0x45, 0x82, 0x2b, 0x4d, 0xb8, 0xf6,
	0x3e, 0x5e, 0xa1, 0x12, 0x7b, 0x15, 0xe1, 0x0c, 0x44, 0x61, 0x72, 0x52, 0xca, 0xf1, 0x14, 0x6d,
	0x5b, 0xfc, 0x1b, 0xb8, 0x7e, 0x2b, 0x32, 0xea, 0xed, 0x1a, 0xe4, 0xe7, 0x75, 0xb5, 0x79, 0x5e,
	0xa4, 0x9b, 0xc2, 0x74, 0x2a, 0x48, 0x19, 0xc4, 0x3f, 0xa1, 0xf5, 0xe2, 0x90, 0x78, 0xff, 0x37,
	0xc5, 0x79, 0xb4, 0x62, 0x71, 0xc6, 0x46, 0xb4, 0x50, 0x96, 0x22, 0x34, 0x2a, 0x79, 0xf8, 0x17,
	0x84, 0x15, 0xd3, 0x90, 0x30, 0xfe, 0xe6, 0xe6, 0xde, 0xf1, 0x9a, 0x66, 0xcc, 0x5f, 0xd6, 0x8d,
	0x79, 0x5c, 0x2a, 0x2b, 0xf6, 0x93, 0xff, 0x8d, 0xb6, 0xd5, 0xad, 0x18, 0xfe, 0x1d, 0xf5, 0x94,
	0xce, 0xf2, 0x48, 0xe7, 0x19, 0xd0, 0x50, 0x71, 0x26, 0x25, 0x68, 0xc7, 0x6b, 0xcd, 0x78, 0x7d,
	0x53, 0xeb, 0x65, 0x19, 0xe3, 0x02, 0xe1, 0x98, 0xee, 0xa9, 0x65, 0x1f, 0xf1, 0x4b, 0xd4, 0x26,
	0x52, 0x3a, 0x76, 0x1f, 0xae, 0xb6, 0x1c, 0x43, 0x29, 0x1d, 0x83, 0x16, 0xb9, 0xe9, 0xe2, 0x09,
	0xda, 0x8a, 0x48, 0x92, 0x38, 0xcc, 0x8f, 0x0c, 0xf3, 0x8b, 0x3a, 0xe6, 0x09, 0x49, 0x12, 0x07,
	0xba, 0x19, 0x39, 0x7d, 0xfc, 0x0a, 0x75, 0xe7, 0x7d, 0x91, 0xbb, 0xb5, 0xd9, 0x30, 0xe0, 0x60,
	0x15, 0xb0, 0xc8, 0xdd, 0x8a, 0x74, 0xa2, 0xc5, 0x10, 0xfe, 0x0d, 0xed, 0x6a, 0xb8, 0xd2, 0x61,
	0x0a, 0x4a, 0x91, 0x18, 0x1c, 0x0f, 0x64, 0x3c, 0x1e, 0xd6, 0x79, 0x4c, 0xe0, 0x4a, 0x7f, 0x5f,
	0x88, 0x1d, 0x9f, 0x1d, 0xfd, 0x6e, 0x18, 0xff, 0x88, 0x3a, 0x32, 0x63, 0x91, 0x6b, 0xd2, 0x32,
	0x26, 0x0f, 0xea, 0x4c, 0xce, 0xe7, 0x32, 0x07, 0xdf, 0x96, 0x6e, 0x00, 0x47, 0x68, 0x47, 0x66,
	0x22, 0x15, 0x7a, 0xe1, 0x95, 0xf4, 0x36, 0x0d, 0xfc, 0xab, 0x7a, 0x78, 0x29, 0x75, 0x0c, 0xba,
	0xf2, 0x76, 0x70, 0x7e, 0x22, 0x12, 0x11, 0x91, 0x5b, 0x1e, 0x5b, 0xab, 0x9d, 0x88, 0x17, 0xa5,
	0xd2, 0x3d, 0x11, 0xc9, 0xad, 0xd8, 0xfc, 0x44, 0x90, 0xd9, 0x8c, 0x25, 0x6c, 0x7e, 0x01, 0xdf,
	0xe1, 0xd5, 0x59, 0xed, 0x44, 0x0c, 0x2b, 0xc6, 0x1d, 0xa6, 0x7b, 0x64, 0xd9, 0x47, 0xfc, 0x1c,
	0x75, 0xed, 0x1d, 0x15, 0x91, 0x54, 0x12, 0x16, 0x73, 0x0f, 0xd7, 0xdf, 0x7b, 0x4f, 0x1a, 0x23,
	0x7b, 0xb9, 0x9d, 0x94, 0x3a, 0xfc, 0xcc, 0x81, 0x11, 0x1a, 0xc6, 0x99, 0xc8, 0xa5, 0xb7, 0xb3,
	0x12, 0xcc, 0x5e, 0x72, 0x43, 0x7a, 0x36, 0x97, 0x1d, 0xb7, 0xd0, 0x86, 0x7d, 0xed, 0x8e, 0x7b,
	0x68, 0x5f, 0x41, 0x76, 0xc9, 0x78, 0x1c, 0xda, 0xd7, 0xb7, 0x10, 0x30, 0x1e, 0x1f, 0xff, 0xd1,
	0x44, 0xf7, 0x23, 0x91, 0xfa, 0xb5, 0x3f, 0x46, 0xc7, 0xbb, 0xef, 0x3c, 0xe8, 0xe7, 0xf3, 0xe1,
	0x9c, 0x37, 0x7e, 0x7e, 0x56, 0x8a, 0x63, 0x91, 0x10, 0x1e, 0xfb, 0x22, 0x8b, 0x83, 0x18, 0xb8,
	0x19, 0x6c, 0xf5, 0xe3, 0x21, 0x99, 0x7a, 0xcf, 0x1f, 0xdb, 0x91, 0x6d, 0xfd, 0xd9, 0x5c, 0x3b,
	0x1b, 0x0e, 0xff, 0x6e, 0xde, 0x3b, 0x2b, 0x90, 0x43, 0xaa, 0xfc, 0xa2, 0x39, 0x6f, 0x4d, 0xfb,
	0xfe, 0xa8, 0xca, 0xfc, 0xa7, 0xca, 0xb9, 0x18, 0x52, 0x75, 0x61, 0x73, 0x2e, 0xa6, 0xfd, 0x0b,
	0x9b, 0xf3, 0x6f, 0xf3, 0x7e, 0xf1, 0x61, 0x30, 0x18, 0x52, 0x35, 0x18, 0xd8, 0xac, 0xc1, 0x60,
	0xda, 0x1f, 0x0c, 0x6c, 0xde, 0xeb, 0x75, 0x33, 0xd8, 0x87, 0xff, 0x05, 0x00, 0x00, 0xff, 0xff,
	0x84, 0x42, 0xa8, 0x5d, 0x5d, 0x0a, 0x00, 0x00,
}
