// Code generated by protoc-gen-go. DO NOT EDIT.
// source: google/ads/googleads/v1/services/change_status_service.proto

package services

import (
	context "context"
	fmt "fmt"
	math "math"

	proto "github.com/golang/protobuf/proto"
	resources "google.golang.org/genproto/googleapis/ads/googleads/v1/resources"
	_ "google.golang.org/genproto/googleapis/api/annotations"
	grpc "google.golang.org/grpc"
)

// Reference imports to suppress errors if they are not otherwise used.
var _ = proto.Marshal
var _ = fmt.Errorf
var _ = math.Inf

// This is a compile-time assertion to ensure that this generated file
// is compatible with the proto package it is being compiled against.
// A compilation error at this line likely means your copy of the
// proto package needs to be updated.
const _ = proto.ProtoPackageIsVersion3 // please upgrade the proto package

// Request message for
// '[ChangeStatusService.GetChangeStatus][google.ads.googleads.v1.services.ChangeStatusService.GetChangeStatus]'.
type GetChangeStatusRequest struct {
	// The resource name of the change status to fetch.
	ResourceName         string   `protobuf:"bytes,1,opt,name=resource_name,json=resourceName,proto3" json:"resource_name,omitempty"`
	XXX_NoUnkeyedLiteral struct{} `json:"-"`
	XXX_unrecognized     []byte   `json:"-"`
	XXX_sizecache        int32    `json:"-"`
}

func (m *GetChangeStatusRequest) Reset()         { *m = GetChangeStatusRequest{} }
func (m *GetChangeStatusRequest) String() string { return proto.CompactTextString(m) }
func (*GetChangeStatusRequest) ProtoMessage()    {}
func (*GetChangeStatusRequest) Descriptor() ([]byte, []int) {
	return fileDescriptor_6c59aa7321bb8d53, []int{0}
}

func (m *GetChangeStatusRequest) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_GetChangeStatusRequest.Unmarshal(m, b)
}
func (m *GetChangeStatusRequest) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_GetChangeStatusRequest.Marshal(b, m, deterministic)
}
func (m *GetChangeStatusRequest) XXX_Merge(src proto.Message) {
	xxx_messageInfo_GetChangeStatusRequest.Merge(m, src)
}
func (m *GetChangeStatusRequest) XXX_Size() int {
	return xxx_messageInfo_GetChangeStatusRequest.Size(m)
}
func (m *GetChangeStatusRequest) XXX_DiscardUnknown() {
	xxx_messageInfo_GetChangeStatusRequest.DiscardUnknown(m)
}

var xxx_messageInfo_GetChangeStatusRequest proto.InternalMessageInfo

func (m *GetChangeStatusRequest) GetResourceName() string {
	if m != nil {
		return m.ResourceName
	}
	return ""
}

func init() {
	proto.RegisterType((*GetChangeStatusRequest)(nil), "google.ads.googleads.v1.services.GetChangeStatusRequest")
}

func init() {
	proto.RegisterFile("google/ads/googleads/v1/services/change_status_service.proto", fileDescriptor_6c59aa7321bb8d53)
}

var fileDescriptor_6c59aa7321bb8d53 = []byte{
	// 362 bytes of a gzipped FileDescriptorProto
	0x1f, 0x8b, 0x08, 0x00, 0x00, 0x00, 0x00, 0x00, 0x02, 0xff, 0x84, 0x92, 0xcf, 0x4a, 0xf3, 0x40,
	0x14, 0xc5, 0x49, 0x3e, 0xf8, 0xc0, 0xa0, 0x08, 0x11, 0xa4, 0x14, 0x17, 0xa5, 0x76, 0x21, 0x5d,
	0xcc, 0x18, 0x45, 0x91, 0xd1, 0x2e, 0x52, 0x17, 0x75, 0x25, 0xa5, 0x85, 0x2e, 0x24, 0x50, 0xc6,
	0x64, 0x18, 0x03, 0xcd, 0x4c, 0xcd, 0x9d, 0x74, 0x23, 0x6e, 0x7c, 0x05, 0xdf, 0xc0, 0xa5, 0x6b,
	0x9f, 0x42, 0xdc, 0xf9, 0x0a, 0xae, 0x7c, 0x09, 0x25, 0x99, 0x4c, 0xa8, 0xda, 0xd2, 0xdd, 0xe1,
	0xe6, 0xfc, 0xce, 0xfd, 0x93, 0x71, 0xce, 0xb8, 0x94, 0x7c, 0xc2, 0x30, 0x8d, 0x00, 0x6b, 0x99,
	0xab, 0x99, 0x87, 0x81, 0xa5, 0xb3, 0x38, 0x64, 0x80, 0xc3, 0x1b, 0x2a, 0x38, 0x1b, 0x83, 0xa2,
	0x2a, 0x83, 0x71, 0x59, 0x46, 0xd3, 0x54, 0x2a, 0xe9, 0x36, 0x34, 0x82, 0x68, 0x04, 0xa8, 0xa2,
	0xd1, 0xcc, 0x43, 0x86, 0xae, 0x1f, 0x2d, 0xcb, 0x4f, 0x19, 0xc8, 0x2c, 0xfd, 0xd3, 0x40, 0x07,
	0xd7, 0x77, 0x0c, 0x36, 0x8d, 0x31, 0x15, 0x42, 0x2a, 0xaa, 0x62, 0x29, 0xca, 0xaf, 0xcd, 0x8e,
	0xb3, 0xdd, 0x63, 0xea, 0xbc, 0xe0, 0x86, 0x05, 0x36, 0x60, 0xb7, 0x19, 0x03, 0xe5, 0xee, 0x3a,
	0x1b, 0x26, 0x78, 0x2c, 0x68, 0xc2, 0x6a, 0x56, 0xc3, 0xda, 0x5b, 0x1b, 0xac, 0x9b, 0xe2, 0x25,
	0x4d, 0xd8, 0xc1, 0x9b, 0xe5, 0x6c, 0xcd, 0xc3, 0x43, 0x3d, 0xac, 0xfb, 0x62, 0x39, 0x9b, 0xbf,
	0x72, 0xdd, 0x13, 0xb4, 0x6a, 0x45, 0xb4, 0x78, 0x94, 0x3a, 0x5e, 0x4a, 0x56, 0xab, 0xa3, 0x79,
	0xae, 0x79, 0xfc, 0xf0, 0xfe, 0xf1, 0x68, 0xef, 0xbb, 0x28, 0x3f, 0xcf, 0xdd, 0x8f, 0x35, 0x3a,
	0x61, 0x06, 0x4a, 0x26, 0x2c, 0x05, 0xdc, 0x2e, 0xef, 0xa5, 0x21, 0xdc, 0xbe, 0xef, 0x7e, 0x59,
	0x4e, 0x2b, 0x94, 0xc9, 0xca, 0x41, 0xbb, 0xb5, 0x05, 0x4b, 0xf7, 0xf3, 0x83, 0xf6, 0xad, 0xab,
	0x8b, 0x92, 0xe6, 0x72, 0x42, 0x05, 0x47, 0x32, 0xe5, 0x98, 0x33, 0x51, 0x9c, 0xdb, 0xfc, 0xb7,
	0x69, 0x0c, 0xcb, 0x9f, 0xc9, 0xa9, 0x11, 0x4f, 0xf6, 0xbf, 0x9e, 0xef, 0x3f, 0xdb, 0x8d, 0x9e,
	0x0e, 0xf4, 0x23, 0x40, 0x5a, 0xe6, 0x6a, 0xe4, 0xa1, 0xb2, 0x31, 0xbc, 0x1a, 0x4b, 0xe0, 0x47,
	0x10, 0x54, 0x96, 0x60, 0xe4, 0x05, 0xc6, 0xf2, 0x69, 0xb7, 0x74, 0x9d, 0x10, 0x3f, 0x02, 0x42,
	0x2a, 0x13, 0x21, 0x23, 0x8f, 0x10, 0x63, 0xbb, 0xfe, 0x5f, 0xcc, 0x79, 0xf8, 0x1d, 0x00, 0x00,
	0xff, 0xff, 0xa5, 0x0c, 0x9d, 0x37, 0xcd, 0x02, 0x00, 0x00,
}

// Reference imports to suppress errors if they are not otherwise used.
var _ context.Context
var _ grpc.ClientConn

// This is a compile-time assertion to ensure that this generated file
// is compatible with the grpc package it is being compiled against.
const _ = grpc.SupportPackageIsVersion4

// ChangeStatusServiceClient is the client API for ChangeStatusService service.
//
// For semantics around ctx use and closing/ending streaming RPCs, please refer to https://godoc.org/google.golang.org/grpc#ClientConn.NewStream.
type ChangeStatusServiceClient interface {
	// Returns the requested change status in full detail.
	GetChangeStatus(ctx context.Context, in *GetChangeStatusRequest, opts ...grpc.CallOption) (*resources.ChangeStatus, error)
}

type changeStatusServiceClient struct {
	cc *grpc.ClientConn
}

func NewChangeStatusServiceClient(cc *grpc.ClientConn) ChangeStatusServiceClient {
	return &changeStatusServiceClient{cc}
}

func (c *changeStatusServiceClient) GetChangeStatus(ctx context.Context, in *GetChangeStatusRequest, opts ...grpc.CallOption) (*resources.ChangeStatus, error) {
	out := new(resources.ChangeStatus)
	err := c.cc.Invoke(ctx, "/google.ads.googleads.v1.services.ChangeStatusService/GetChangeStatus", in, out, opts...)
	if err != nil {
		return nil, err
	}
	return out, nil
}

// ChangeStatusServiceServer is the server API for ChangeStatusService service.
type ChangeStatusServiceServer interface {
	// Returns the requested change status in full detail.
	GetChangeStatus(context.Context, *GetChangeStatusRequest) (*resources.ChangeStatus, error)
}

func RegisterChangeStatusServiceServer(s *grpc.Server, srv ChangeStatusServiceServer) {
	s.RegisterService(&_ChangeStatusService_serviceDesc, srv)
}

func _ChangeStatusService_GetChangeStatus_Handler(srv interface{}, ctx context.Context, dec func(interface{}) error, interceptor grpc.UnaryServerInterceptor) (interface{}, error) {
	in := new(GetChangeStatusRequest)
	if err := dec(in); err != nil {
		return nil, err
	}
	if interceptor == nil {
		return srv.(ChangeStatusServiceServer).GetChangeStatus(ctx, in)
	}
	info := &grpc.UnaryServerInfo{
		Server:     srv,
		FullMethod: "/google.ads.googleads.v1.services.ChangeStatusService/GetChangeStatus",
	}
	handler := func(ctx context.Context, req interface{}) (interface{}, error) {
		return srv.(ChangeStatusServiceServer).GetChangeStatus(ctx, req.(*GetChangeStatusRequest))
	}
	return interceptor(ctx, in, info, handler)
}

var _ChangeStatusService_serviceDesc = grpc.ServiceDesc{
	ServiceName: "google.ads.googleads.v1.services.ChangeStatusService",
	HandlerType: (*ChangeStatusServiceServer)(nil),
	Methods: []grpc.MethodDesc{
		{
			MethodName: "GetChangeStatus",
			Handler:    _ChangeStatusService_GetChangeStatus_Handler,
		},
	},
	Streams:  []grpc.StreamDesc{},
	Metadata: "google/ads/googleads/v1/services/change_status_service.proto",
}
