// Code generated by protoc-gen-go. DO NOT EDIT.
// source: google/ads/googleads/v1/services/detail_placement_view_service.proto

package services

import (
	context "context"
	fmt "fmt"
	math "math"

	proto "github.com/golang/protobuf/proto"
	resources "google.golang.org/genproto/googleapis/ads/googleads/v1/resources"
	_ "google.golang.org/genproto/googleapis/api/annotations"
	grpc "google.golang.org/grpc"
)

// Reference imports to suppress errors if they are not otherwise used.
var _ = proto.Marshal
var _ = fmt.Errorf
var _ = math.Inf

// This is a compile-time assertion to ensure that this generated file
// is compatible with the proto package it is being compiled against.
// A compilation error at this line likely means your copy of the
// proto package needs to be updated.
const _ = proto.ProtoPackageIsVersion3 // please upgrade the proto package

// Request message for
// [DetailPlacementViewService.GetDetailPlacementView][google.ads.googleads.v1.services.DetailPlacementViewService.GetDetailPlacementView].
type GetDetailPlacementViewRequest struct {
	// The resource name of the Detail Placement view to fetch.
	ResourceName         string   `protobuf:"bytes,1,opt,name=resource_name,json=resourceName,proto3" json:"resource_name,omitempty"`
	XXX_NoUnkeyedLiteral struct{} `json:"-"`
	XXX_unrecognized     []byte   `json:"-"`
	XXX_sizecache        int32    `json:"-"`
}

func (m *GetDetailPlacementViewRequest) Reset()         { *m = GetDetailPlacementViewRequest{} }
func (m *GetDetailPlacementViewRequest) String() string { return proto.CompactTextString(m) }
func (*GetDetailPlacementViewRequest) ProtoMessage()    {}
func (*GetDetailPlacementViewRequest) Descriptor() ([]byte, []int) {
	return fileDescriptor_9f5548d46c4dece9, []int{0}
}

func (m *GetDetailPlacementViewRequest) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_GetDetailPlacementViewRequest.Unmarshal(m, b)
}
func (m *GetDetailPlacementViewRequest) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_GetDetailPlacementViewRequest.Marshal(b, m, deterministic)
}
func (m *GetDetailPlacementViewRequest) XXX_Merge(src proto.Message) {
	xxx_messageInfo_GetDetailPlacementViewRequest.Merge(m, src)
}
func (m *GetDetailPlacementViewRequest) XXX_Size() int {
	return xxx_messageInfo_GetDetailPlacementViewRequest.Size(m)
}
func (m *GetDetailPlacementViewRequest) XXX_DiscardUnknown() {
	xxx_messageInfo_GetDetailPlacementViewRequest.DiscardUnknown(m)
}

var xxx_messageInfo_GetDetailPlacementViewRequest proto.InternalMessageInfo

func (m *GetDetailPlacementViewRequest) GetResourceName() string {
	if m != nil {
		return m.ResourceName
	}
	return ""
}

func init() {
	proto.RegisterType((*GetDetailPlacementViewRequest)(nil), "google.ads.googleads.v1.services.GetDetailPlacementViewRequest")
}

func init() {
	proto.RegisterFile("google/ads/googleads/v1/services/detail_placement_view_service.proto", fileDescriptor_9f5548d46c4dece9)
}

var fileDescriptor_9f5548d46c4dece9 = []byte{
	// 373 bytes of a gzipped FileDescriptorProto
	0x1f, 0x8b, 0x08, 0x00, 0x00, 0x00, 0x00, 0x00, 0x02, 0xff, 0x84, 0x52, 0xbf, 0x4a, 0xfb, 0x40,
	0x1c, 0x27, 0xf9, 0xc1, 0x0f, 0x0c, 0xba, 0x64, 0x10, 0x09, 0x8a, 0xa5, 0x76, 0x90, 0x0e, 0x77,
	0x44, 0xa1, 0xc8, 0x49, 0x95, 0x94, 0x42, 0x9d, 0xa4, 0x54, 0xc8, 0x20, 0x81, 0x70, 0x26, 0x5f,
	0x42, 0x20, 0xc9, 0xc5, 0xdc, 0x35, 0x1d, 0xc4, 0xc5, 0xc1, 0x17, 0xf0, 0x0d, 0x1c, 0x7d, 0x14,
	0x37, 0xf1, 0x15, 0x9c, 0x9c, 0x7c, 0x04, 0x49, 0x2f, 0x17, 0x28, 0x34, 0x76, 0xfb, 0x70, 0xdf,
	0xcf, 0x9f, 0xef, 0x9f, 0x33, 0xc6, 0x11, 0x63, 0x51, 0x02, 0x98, 0x86, 0x1c, 0x4b, 0x58, 0xa1,
	0xd2, 0xc6, 0x1c, 0x8a, 0x32, 0x0e, 0x80, 0xe3, 0x10, 0x04, 0x8d, 0x13, 0x3f, 0x4f, 0x68, 0x00,
	0x29, 0x64, 0xc2, 0x2f, 0x63, 0x58, 0xf8, 0x75, 0x19, 0xe5, 0x05, 0x13, 0xcc, 0xec, 0x48, 0x29,
	0xa2, 0x21, 0x47, 0x8d, 0x0b, 0x2a, 0x6d, 0xa4, 0x5c, 0xac, 0x61, 0x5b, 0x4e, 0x01, 0x9c, 0xcd,
	0x8b, 0xd6, 0x20, 0x19, 0x60, 0xed, 0x2b, 0x79, 0x1e, 0x63, 0x9a, 0x65, 0x4c, 0x50, 0x11, 0xb3,
	0x8c, 0xcb, 0x6a, 0x77, 0x6c, 0x1c, 0x4c, 0x40, 0x8c, 0x97, 0xfa, 0xa9, 0x92, 0xbb, 0x31, 0x2c,
	0x66, 0x70, 0x3f, 0x07, 0x2e, 0xcc, 0x23, 0x63, 0x47, 0xe5, 0xf8, 0x19, 0x4d, 0x61, 0x4f, 0xeb,
	0x68, 0xc7, 0x5b, 0xb3, 0x6d, 0xf5, 0x78, 0x4d, 0x53, 0x38, 0xf9, 0xd1, 0x0c, 0x6b, 0x8d, 0xc7,
	0x8d, 0x1c, 0xc1, 0xfc, 0xd0, 0x8c, 0xdd, 0xf5, 0x29, 0xe6, 0x25, 0xda, 0x34, 0x3f, 0xfa, 0xb3,
	0x3f, 0x6b, 0xd0, 0x6a, 0xd0, 0xac, 0x07, 0xad, 0x91, 0x77, 0x2f, 0x9e, 0x3e, 0xbf, 0x5e, 0xf4,
	0x33, 0x73, 0x50, 0x6d, 0xf2, 0x61, 0x65, 0xc4, 0x61, 0x30, 0xe7, 0x82, 0xa5, 0x50, 0x70, 0xdc,
	0xaf, 0x57, 0xbb, 0xa2, 0xe5, 0xb8, 0xff, 0x38, 0x7a, 0xd6, 0x8d, 0x5e, 0xc0, 0xd2, 0x8d, 0xed,
	0x8f, 0x0e, 0xdb, 0x17, 0x33, 0xad, 0x4e, 0x30, 0xd5, 0x6e, 0xaf, 0x6a, 0x93, 0x88, 0x25, 0x34,
	0x8b, 0x10, 0x2b, 0x22, 0x1c, 0x41, 0xb6, 0x3c, 0x90, 0xba, 0x78, 0x1e, 0xf3, 0xf6, 0x8f, 0x76,
	0xae, 0xc0, 0xab, 0xfe, 0x6f, 0xe2, 0x38, 0x6f, 0x7a, 0x67, 0x22, 0x0d, 0x9d, 0x90, 0x23, 0x09,
	0x2b, 0xe4, 0xda, 0xa8, 0x0e, 0xe6, 0xef, 0x8a, 0xe2, 0x39, 0x21, 0xf7, 0x1a, 0x8a, 0xe7, 0xda,
	0x9e, 0xa2, 0x7c, 0xeb, 0x3d, 0xf9, 0x4e, 0x88, 0x13, 0x72, 0x42, 0x1a, 0x12, 0x21, 0xae, 0x4d,
	0x88, 0xa2, 0xdd, 0xfd, 0x5f, 0xf6, 0x79, 0xfa, 0x1b, 0x00, 0x00, 0xff, 0xff, 0x3d, 0x02, 0x09,
	0x37, 0x0f, 0x03, 0x00, 0x00,
}

// Reference imports to suppress errors if they are not otherwise used.
var _ context.Context
var _ grpc.ClientConn

// This is a compile-time assertion to ensure that this generated file
// is compatible with the grpc package it is being compiled against.
const _ = grpc.SupportPackageIsVersion4

// DetailPlacementViewServiceClient is the client API for DetailPlacementViewService service.
//
// For semantics around ctx use and closing/ending streaming RPCs, please refer to https://godoc.org/google.golang.org/grpc#ClientConn.NewStream.
type DetailPlacementViewServiceClient interface {
	// Returns the requested Detail Placement view in full detail.
	GetDetailPlacementView(ctx context.Context, in *GetDetailPlacementViewRequest, opts ...grpc.CallOption) (*resources.DetailPlacementView, error)
}

type detailPlacementViewServiceClient struct {
	cc *grpc.ClientConn
}

func NewDetailPlacementViewServiceClient(cc *grpc.ClientConn) DetailPlacementViewServiceClient {
	return &detailPlacementViewServiceClient{cc}
}

func (c *detailPlacementViewServiceClient) GetDetailPlacementView(ctx context.Context, in *GetDetailPlacementViewRequest, opts ...grpc.CallOption) (*resources.DetailPlacementView, error) {
	out := new(resources.DetailPlacementView)
	err := c.cc.Invoke(ctx, "/google.ads.googleads.v1.services.DetailPlacementViewService/GetDetailPlacementView", in, out, opts...)
	if err != nil {
		return nil, err
	}
	return out, nil
}

// DetailPlacementViewServiceServer is the server API for DetailPlacementViewService service.
type DetailPlacementViewServiceServer interface {
	// Returns the requested Detail Placement view in full detail.
	GetDetailPlacementView(context.Context, *GetDetailPlacementViewRequest) (*resources.DetailPlacementView, error)
}

func RegisterDetailPlacementViewServiceServer(s *grpc.Server, srv DetailPlacementViewServiceServer) {
	s.RegisterService(&_DetailPlacementViewService_serviceDesc, srv)
}

func _DetailPlacementViewService_GetDetailPlacementView_Handler(srv interface{}, ctx context.Context, dec func(interface{}) error, interceptor grpc.UnaryServerInterceptor) (interface{}, error) {
	in := new(GetDetailPlacementViewRequest)
	if err := dec(in); err != nil {
		return nil, err
	}
	if interceptor == nil {
		return srv.(DetailPlacementViewServiceServer).GetDetailPlacementView(ctx, in)
	}
	info := &grpc.UnaryServerInfo{
		Server:     srv,
		FullMethod: "/google.ads.googleads.v1.services.DetailPlacementViewService/GetDetailPlacementView",
	}
	handler := func(ctx context.Context, req interface{}) (interface{}, error) {
		return srv.(DetailPlacementViewServiceServer).GetDetailPlacementView(ctx, req.(*GetDetailPlacementViewRequest))
	}
	return interceptor(ctx, in, info, handler)
}

var _DetailPlacementViewService_serviceDesc = grpc.ServiceDesc{
	ServiceName: "google.ads.googleads.v1.services.DetailPlacementViewService",
	HandlerType: (*DetailPlacementViewServiceServer)(nil),
	Methods: []grpc.MethodDesc{
		{
			MethodName: "GetDetailPlacementView",
			Handler:    _DetailPlacementViewService_GetDetailPlacementView_Handler,
		},
	},
	Streams:  []grpc.StreamDesc{},
	Metadata: "google/ads/googleads/v1/services/detail_placement_view_service.proto",
}
