// Code generated by protoc-gen-go. DO NOT EDIT.
// source: google/ads/googleads/v2/enums/budget_period.proto

package enums

import (
	fmt "fmt"
	math "math"

	proto "github.com/golang/protobuf/proto"
	_ "google.golang.org/genproto/googleapis/api/annotations"
)

// Reference imports to suppress errors if they are not otherwise used.
var _ = proto.Marshal
var _ = fmt.Errorf
var _ = math.Inf

// This is a compile-time assertion to ensure that this generated file
// is compatible with the proto package it is being compiled against.
// A compilation error at this line likely means your copy of the
// proto package needs to be updated.
const _ = proto.ProtoPackageIsVersion3 // please upgrade the proto package

// Possible period of a Budget.
type BudgetPeriodEnum_BudgetPeriod int32

const (
	// Not specified.
	BudgetPeriodEnum_UNSPECIFIED BudgetPeriodEnum_BudgetPeriod = 0
	// Used for return value only. Represents value unknown in this version.
	BudgetPeriodEnum_UNKNOWN BudgetPeriodEnum_BudgetPeriod = 1
	// Daily budget.
	BudgetPeriodEnum_DAILY BudgetPeriodEnum_BudgetPeriod = 2
	// Custom budget.
	BudgetPeriodEnum_CUSTOM BudgetPeriodEnum_BudgetPeriod = 3
	// Fixed daily budget.
	BudgetPeriodEnum_FIXED_DAILY BudgetPeriodEnum_BudgetPeriod = 4
)

var BudgetPeriodEnum_BudgetPeriod_name = map[int32]string{
	0: "UNSPECIFIED",
	1: "UNKNOWN",
	2: "DAILY",
	3: "CUSTOM",
	4: "FIXED_DAILY",
}

var BudgetPeriodEnum_BudgetPeriod_value = map[string]int32{
	"UNSPECIFIED": 0,
	"UNKNOWN":     1,
	"DAILY":       2,
	"CUSTOM":      3,
	"FIXED_DAILY": 4,
}

func (x BudgetPeriodEnum_BudgetPeriod) String() string {
	return proto.EnumName(BudgetPeriodEnum_BudgetPeriod_name, int32(x))
}

func (BudgetPeriodEnum_BudgetPeriod) EnumDescriptor() ([]byte, []int) {
	return fileDescriptor_5b320dc9bffbaac3, []int{0, 0}
}

// Message describing Budget period.
type BudgetPeriodEnum struct {
	XXX_NoUnkeyedLiteral struct{} `json:"-"`
	XXX_unrecognized     []byte   `json:"-"`
	XXX_sizecache        int32    `json:"-"`
}

func (m *BudgetPeriodEnum) Reset()         { *m = BudgetPeriodEnum{} }
func (m *BudgetPeriodEnum) String() string { return proto.CompactTextString(m) }
func (*BudgetPeriodEnum) ProtoMessage()    {}
func (*BudgetPeriodEnum) Descriptor() ([]byte, []int) {
	return fileDescriptor_5b320dc9bffbaac3, []int{0}
}

func (m *BudgetPeriodEnum) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_BudgetPeriodEnum.Unmarshal(m, b)
}
func (m *BudgetPeriodEnum) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_BudgetPeriodEnum.Marshal(b, m, deterministic)
}
func (m *BudgetPeriodEnum) XXX_Merge(src proto.Message) {
	xxx_messageInfo_BudgetPeriodEnum.Merge(m, src)
}
func (m *BudgetPeriodEnum) XXX_Size() int {
	return xxx_messageInfo_BudgetPeriodEnum.Size(m)
}
func (m *BudgetPeriodEnum) XXX_DiscardUnknown() {
	xxx_messageInfo_BudgetPeriodEnum.DiscardUnknown(m)
}

var xxx_messageInfo_BudgetPeriodEnum proto.InternalMessageInfo

func init() {
	proto.RegisterEnum("google.ads.googleads.v2.enums.BudgetPeriodEnum_BudgetPeriod", BudgetPeriodEnum_BudgetPeriod_name, BudgetPeriodEnum_BudgetPeriod_value)
	proto.RegisterType((*BudgetPeriodEnum)(nil), "google.ads.googleads.v2.enums.BudgetPeriodEnum")
}

func init() {
	proto.RegisterFile("google/ads/googleads/v2/enums/budget_period.proto", fileDescriptor_5b320dc9bffbaac3)
}

var fileDescriptor_5b320dc9bffbaac3 = []byte{
	// 308 bytes of a gzipped FileDescriptorProto
	0x1f, 0x8b, 0x08, 0x00, 0x00, 0x00, 0x00, 0x00, 0x02, 0xff, 0x7c, 0x50, 0xdd, 0x4e, 0xb3, 0x30,
	0x18, 0xfe, 0xc6, 0x3e, 0x67, 0xec, 0x4c, 0x44, 0x0e, 0x8d, 0x3b, 0xd8, 0x2e, 0xa0, 0x8d, 0x78,
	0x56, 0x8f, 0xca, 0xc6, 0x16, 0xa2, 0x32, 0x92, 0x0d, 0xfc, 0x09, 0xc9, 0xc2, 0x2c, 0xa9, 0x24,
	0xa3, 0x25, 0x14, 0x76, 0x41, 0x1e, 0x7a, 0x29, 0x5e, 0x88, 0x07, 0x5e, 0x85, 0xa1, 0x15, 0xb2,
	0x13, 0x3d, 0x69, 0x9e, 0xbc, 0xcf, 0x4f, 0x9f, 0xf7, 0x05, 0x57, 0x4c, 0x08, 0xb6, 0x4b, 0x51,
	0x42, 0x25, 0xd2, 0xb0, 0x41, 0x7b, 0x1b, 0xa5, 0xbc, 0xce, 0x25, 0xda, 0xd6, 0x94, 0xa5, 0xd5,
	0xa6, 0x48, 0xcb, 0x4c, 0x50, 0x58, 0x94, 0xa2, 0x12, 0xd6, 0x48, 0xeb, 0x60, 0x42, 0x25, 0xec,
	0x2c, 0x70, 0x6f, 0x43, 0x65, 0xb9, 0xb8, 0x6c, 0x13, 0x8b, 0x0c, 0x25, 0x9c, 0x8b, 0x2a, 0xa9,
	0x32, 0xc1, 0xa5, 0x36, 0x4f, 0x5e, 0x81, 0xe9, 0xa8, 0xcc, 0x40, 0x45, 0xba, 0xbc, 0xce, 0x27,
	0x6b, 0x70, 0x7a, 0x38, 0xb3, 0xce, 0xc0, 0x30, 0xf4, 0x57, 0x81, 0x3b, 0xf5, 0xe6, 0x9e, 0x3b,
	0x33, 0xff, 0x59, 0x43, 0x70, 0x1c, 0xfa, 0xb7, 0xfe, 0xf2, 0xc1, 0x37, 0x7b, 0xd6, 0x09, 0x38,
	0x9a, 0x11, 0xef, 0xee, 0xc9, 0x34, 0x2c, 0x00, 0x06, 0xd3, 0x70, 0xb5, 0x5e, 0xde, 0x9b, 0xfd,
	0xc6, 0x34, 0xf7, 0x1e, 0xdd, 0xd9, 0x46, 0x93, 0xff, 0x9d, 0xcf, 0x1e, 0x18, 0xbf, 0x88, 0x1c,
	0xfe, 0xd9, 0xd6, 0x39, 0x3f, 0xfc, 0x39, 0x68, 0x2a, 0x06, 0xbd, 0x67, 0xe7, 0xc7, 0xc3, 0xc4,
	0x2e, 0xe1, 0x0c, 0x8a, 0x92, 0x21, 0x96, 0x72, 0xb5, 0x40, 0x7b, 0xa4, 0x22, 0x93, 0xbf, 0xdc,
	0xec, 0x46, 0xbd, 0x6f, 0x46, 0x7f, 0x41, 0xc8, 0xbb, 0x31, 0x5a, 0xe8, 0x28, 0x42, 0x25, 0xd4,
	0xb0, 0x41, 0x91, 0x0d, 0x9b, 0xcd, 0xe5, 0x47, 0xcb, 0xc7, 0x84, 0xca, 0xb8, 0xe3, 0xe3, 0xc8,
	0x8e, 0x15, 0xff, 0x65, 0x8c, 0xf5, 0x10, 0x63, 0x42, 0x25, 0xc6, 0x9d, 0x02, 0xe3, 0xc8, 0xc6,
	0x58, 0x69, 0xb6, 0x03, 0x55, 0xec, 0xfa, 0x3b, 0x00, 0x00, 0xff, 0xff, 0x0e, 0x77, 0x79, 0x53,
	0xcb, 0x01, 0x00, 0x00,
}
