// Code generated by protoc-gen-go. DO NOT EDIT.
// source: google/ads/googleads/v1/enums/price_extension_price_unit.proto

package enums

import (
	fmt "fmt"
	math "math"

	proto "github.com/golang/protobuf/proto"
	_ "google.golang.org/genproto/googleapis/api/annotations"
)

// Reference imports to suppress errors if they are not otherwise used.
var _ = proto.Marshal
var _ = fmt.Errorf
var _ = math.Inf

// This is a compile-time assertion to ensure that this generated file
// is compatible with the proto package it is being compiled against.
// A compilation error at this line likely means your copy of the
// proto package needs to be updated.
const _ = proto.ProtoPackageIsVersion3 // please upgrade the proto package

// Price extension price unit.
type PriceExtensionPriceUnitEnum_PriceExtensionPriceUnit int32

const (
	// Not specified.
	PriceExtensionPriceUnitEnum_UNSPECIFIED PriceExtensionPriceUnitEnum_PriceExtensionPriceUnit = 0
	// Used for return value only. Represents value unknown in this version.
	PriceExtensionPriceUnitEnum_UNKNOWN PriceExtensionPriceUnitEnum_PriceExtensionPriceUnit = 1
	// Per hour.
	PriceExtensionPriceUnitEnum_PER_HOUR PriceExtensionPriceUnitEnum_PriceExtensionPriceUnit = 2
	// Per day.
	PriceExtensionPriceUnitEnum_PER_DAY PriceExtensionPriceUnitEnum_PriceExtensionPriceUnit = 3
	// Per week.
	PriceExtensionPriceUnitEnum_PER_WEEK PriceExtensionPriceUnitEnum_PriceExtensionPriceUnit = 4
	// Per month.
	PriceExtensionPriceUnitEnum_PER_MONTH PriceExtensionPriceUnitEnum_PriceExtensionPriceUnit = 5
	// Per year.
	PriceExtensionPriceUnitEnum_PER_YEAR PriceExtensionPriceUnitEnum_PriceExtensionPriceUnit = 6
	// Per night.
	PriceExtensionPriceUnitEnum_PER_NIGHT PriceExtensionPriceUnitEnum_PriceExtensionPriceUnit = 7
)

var PriceExtensionPriceUnitEnum_PriceExtensionPriceUnit_name = map[int32]string{
	0: "UNSPECIFIED",
	1: "UNKNOWN",
	2: "PER_HOUR",
	3: "PER_DAY",
	4: "PER_WEEK",
	5: "PER_MONTH",
	6: "PER_YEAR",
	7: "PER_NIGHT",
}

var PriceExtensionPriceUnitEnum_PriceExtensionPriceUnit_value = map[string]int32{
	"UNSPECIFIED": 0,
	"UNKNOWN":     1,
	"PER_HOUR":    2,
	"PER_DAY":     3,
	"PER_WEEK":    4,
	"PER_MONTH":   5,
	"PER_YEAR":    6,
	"PER_NIGHT":   7,
}

func (x PriceExtensionPriceUnitEnum_PriceExtensionPriceUnit) String() string {
	return proto.EnumName(PriceExtensionPriceUnitEnum_PriceExtensionPriceUnit_name, int32(x))
}

func (PriceExtensionPriceUnitEnum_PriceExtensionPriceUnit) EnumDescriptor() ([]byte, []int) {
	return fileDescriptor_1ba476426d1d0390, []int{0, 0}
}

// Container for enum describing price extension price unit.
type PriceExtensionPriceUnitEnum struct {
	XXX_NoUnkeyedLiteral struct{} `json:"-"`
	XXX_unrecognized     []byte   `json:"-"`
	XXX_sizecache        int32    `json:"-"`
}

func (m *PriceExtensionPriceUnitEnum) Reset()         { *m = PriceExtensionPriceUnitEnum{} }
func (m *PriceExtensionPriceUnitEnum) String() string { return proto.CompactTextString(m) }
func (*PriceExtensionPriceUnitEnum) ProtoMessage()    {}
func (*PriceExtensionPriceUnitEnum) Descriptor() ([]byte, []int) {
	return fileDescriptor_1ba476426d1d0390, []int{0}
}

func (m *PriceExtensionPriceUnitEnum) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_PriceExtensionPriceUnitEnum.Unmarshal(m, b)
}
func (m *PriceExtensionPriceUnitEnum) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_PriceExtensionPriceUnitEnum.Marshal(b, m, deterministic)
}
func (m *PriceExtensionPriceUnitEnum) XXX_Merge(src proto.Message) {
	xxx_messageInfo_PriceExtensionPriceUnitEnum.Merge(m, src)
}
func (m *PriceExtensionPriceUnitEnum) XXX_Size() int {
	return xxx_messageInfo_PriceExtensionPriceUnitEnum.Size(m)
}
func (m *PriceExtensionPriceUnitEnum) XXX_DiscardUnknown() {
	xxx_messageInfo_PriceExtensionPriceUnitEnum.DiscardUnknown(m)
}

var xxx_messageInfo_PriceExtensionPriceUnitEnum proto.InternalMessageInfo

func init() {
	proto.RegisterEnum("google.ads.googleads.v1.enums.PriceExtensionPriceUnitEnum_PriceExtensionPriceUnit", PriceExtensionPriceUnitEnum_PriceExtensionPriceUnit_name, PriceExtensionPriceUnitEnum_PriceExtensionPriceUnit_value)
	proto.RegisterType((*PriceExtensionPriceUnitEnum)(nil), "google.ads.googleads.v1.enums.PriceExtensionPriceUnitEnum")
}

func init() {
	proto.RegisterFile("google/ads/googleads/v1/enums/price_extension_price_unit.proto", fileDescriptor_1ba476426d1d0390)
}

var fileDescriptor_1ba476426d1d0390 = []byte{
	// 350 bytes of a gzipped FileDescriptorProto
	0x1f, 0x8b, 0x08, 0x00, 0x00, 0x00, 0x00, 0x00, 0x02, 0xff, 0x7c, 0x91, 0xd1, 0x4e, 0xfa, 0x30,
	0x14, 0xc6, 0xff, 0x1b, 0x7f, 0x41, 0x8b, 0xc6, 0x66, 0x37, 0x26, 0x0a, 0x17, 0xf0, 0x00, 0x5d,
	0x16, 0xef, 0x6a, 0x62, 0x32, 0xa4, 0x02, 0x21, 0x8e, 0x05, 0x19, 0x04, 0xb3, 0x84, 0x4c, 0xb6,
	0x2c, 0x4d, 0xa0, 0x5d, 0xe8, 0x20, 0x3e, 0x84, 0x4f, 0xe1, 0xa5, 0xf1, 0x49, 0x7c, 0x14, 0xef,
	0x7c, 0x03, 0xd3, 0xd6, 0x72, 0x87, 0x37, 0xcb, 0xf7, 0xed, 0xd7, 0xef, 0xb4, 0xe7, 0x1c, 0x70,
	0x9b, 0x73, 0x9e, 0xaf, 0x32, 0x37, 0x49, 0x85, 0xab, 0xa5, 0x54, 0x3b, 0xcf, 0xcd, 0xd8, 0x76,
	0x2d, 0xdc, 0x62, 0x43, 0x97, 0xd9, 0x22, 0x7b, 0x29, 0x33, 0x26, 0x28, 0x67, 0x0b, 0xed, 0xb7,
	0x8c, 0x96, 0xa8, 0xd8, 0xf0, 0x92, 0x3b, 0x4d, 0x1d, 0x42, 0x49, 0x2a, 0xd0, 0x3e, 0x8f, 0x76,
	0x1e, 0x52, 0xf9, 0xcb, 0x86, 0x29, 0x5f, 0x50, 0x37, 0x61, 0x8c, 0x97, 0x49, 0x49, 0x39, 0x13,
	0x3a, 0xdc, 0xfe, 0xb0, 0xc0, 0x55, 0x28, 0x2b, 0x12, 0x73, 0x81, 0x72, 0x11, 0xa3, 0x25, 0x61,
	0xdb, 0x75, 0xfb, 0xd5, 0x02, 0x17, 0x07, 0xb8, 0x73, 0x0e, 0xea, 0x51, 0xf0, 0x18, 0x92, 0xbb,
	0xc1, 0xfd, 0x80, 0x74, 0xe1, 0x3f, 0xa7, 0x0e, 0x6a, 0x51, 0x30, 0x0c, 0x46, 0xb3, 0x00, 0x5a,
	0xce, 0x29, 0x38, 0x0e, 0xc9, 0x78, 0xd1, 0x1f, 0x45, 0x63, 0x68, 0x4b, 0x24, 0x5d, 0xd7, 0x9f,
	0xc3, 0x8a, 0x41, 0x33, 0x42, 0x86, 0xf0, 0xbf, 0x73, 0x06, 0x4e, 0xa4, 0x7b, 0x18, 0x05, 0x93,
	0x3e, 0x3c, 0x32, 0x70, 0x4e, 0xfc, 0x31, 0xac, 0x1a, 0x18, 0x0c, 0x7a, 0xfd, 0x09, 0xac, 0x75,
	0xbe, 0x2d, 0xd0, 0x5a, 0xf2, 0x35, 0xfa, 0xb3, 0xe5, 0x4e, 0xe3, 0xc0, 0x8b, 0x43, 0xd9, 0x72,
	0x68, 0x3d, 0x75, 0x7e, 0xe3, 0x39, 0x5f, 0x25, 0x2c, 0x47, 0x7c, 0x93, 0xbb, 0x79, 0xc6, 0xd4,
	0x40, 0xcc, 0x06, 0x0a, 0x2a, 0x0e, 0x2c, 0xe4, 0x46, 0x7d, 0xdf, 0xec, 0x4a, 0xcf, 0xf7, 0xdf,
	0xed, 0x66, 0x4f, 0x97, 0xf2, 0x53, 0x81, 0xb4, 0x94, 0x6a, 0xea, 0x21, 0x39, 0x3d, 0xf1, 0x69,
	0x78, 0xec, 0xa7, 0x22, 0xde, 0xf3, 0x78, 0xea, 0xc5, 0x8a, 0x7f, 0xd9, 0x2d, 0xfd, 0x13, 0x63,
	0x3f, 0x15, 0x18, 0xef, 0x4f, 0x60, 0x3c, 0xf5, 0x30, 0x56, 0x67, 0x9e, 0xab, 0xea, 0x61, 0xd7,
	0x3f, 0x01, 0x00, 0x00, 0xff, 0xff, 0x32, 0x6a, 0x8d, 0xfb, 0x28, 0x02, 0x00, 0x00,
}
