// Code generated by protoc-gen-go. DO NOT EDIT.
// source: google/ads/googleads/v2/resources/customer_label.proto

package resources

import (
	fmt "fmt"
	math "math"

	proto "github.com/golang/protobuf/proto"
	wrappers "github.com/golang/protobuf/ptypes/wrappers"
	_ "google.golang.org/genproto/googleapis/api/annotations"
)

// Reference imports to suppress errors if they are not otherwise used.
var _ = proto.Marshal
var _ = fmt.Errorf
var _ = math.Inf

// This is a compile-time assertion to ensure that this generated file
// is compatible with the proto package it is being compiled against.
// A compilation error at this line likely means your copy of the
// proto package needs to be updated.
const _ = proto.ProtoPackageIsVersion3 // please upgrade the proto package

// Represents a relationship between a customer and a label. This customer may
// not have access to all the labels attached to it. Additional CustomerLabels
// may be returned by increasing permissions with login-customer-id.
type CustomerLabel struct {
	// Name of the resource.
	// Customer label resource names have the form:
	// `customers/{customer_id}/customerLabels/{label_id}`
	ResourceName string `protobuf:"bytes,1,opt,name=resource_name,json=resourceName,proto3" json:"resource_name,omitempty"`
	// The resource name of the customer to which the label is attached.
	// Read only.
	Customer *wrappers.StringValue `protobuf:"bytes,2,opt,name=customer,proto3" json:"customer,omitempty"`
	// The resource name of the label assigned to the customer.
	//
	// Note: the Customer ID portion of the label resource name is not
	// validated when creating a new CustomerLabel.
	Label                *wrappers.StringValue `protobuf:"bytes,3,opt,name=label,proto3" json:"label,omitempty"`
	XXX_NoUnkeyedLiteral struct{}              `json:"-"`
	XXX_unrecognized     []byte                `json:"-"`
	XXX_sizecache        int32                 `json:"-"`
}

func (m *CustomerLabel) Reset()         { *m = CustomerLabel{} }
func (m *CustomerLabel) String() string { return proto.CompactTextString(m) }
func (*CustomerLabel) ProtoMessage()    {}
func (*CustomerLabel) Descriptor() ([]byte, []int) {
	return fileDescriptor_6fa93913e8013a5b, []int{0}
}

func (m *CustomerLabel) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_CustomerLabel.Unmarshal(m, b)
}
func (m *CustomerLabel) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_CustomerLabel.Marshal(b, m, deterministic)
}
func (m *CustomerLabel) XXX_Merge(src proto.Message) {
	xxx_messageInfo_CustomerLabel.Merge(m, src)
}
func (m *CustomerLabel) XXX_Size() int {
	return xxx_messageInfo_CustomerLabel.Size(m)
}
func (m *CustomerLabel) XXX_DiscardUnknown() {
	xxx_messageInfo_CustomerLabel.DiscardUnknown(m)
}

var xxx_messageInfo_CustomerLabel proto.InternalMessageInfo

func (m *CustomerLabel) GetResourceName() string {
	if m != nil {
		return m.ResourceName
	}
	return ""
}

func (m *CustomerLabel) GetCustomer() *wrappers.StringValue {
	if m != nil {
		return m.Customer
	}
	return nil
}

func (m *CustomerLabel) GetLabel() *wrappers.StringValue {
	if m != nil {
		return m.Label
	}
	return nil
}

func init() {
	proto.RegisterType((*CustomerLabel)(nil), "google.ads.googleads.v2.resources.CustomerLabel")
}

func init() {
	proto.RegisterFile("google/ads/googleads/v2/resources/customer_label.proto", fileDescriptor_6fa93913e8013a5b)
}

var fileDescriptor_6fa93913e8013a5b = []byte{
	// 321 bytes of a gzipped FileDescriptorProto
	0x1f, 0x8b, 0x08, 0x00, 0x00, 0x00, 0x00, 0x00, 0x02, 0xff, 0x8c, 0x91, 0xcf, 0x4a, 0xc3, 0x30,
	0x00, 0xc6, 0x49, 0x87, 0xa2, 0xd1, 0x5d, 0x7a, 0x1a, 0x63, 0xc8, 0xa6, 0x0c, 0x76, 0x4a, 0x20,
	0x82, 0x48, 0x3c, 0x75, 0x1e, 0x06, 0x22, 0x32, 0x26, 0xf4, 0x20, 0x85, 0x91, 0xb5, 0x31, 0x14,
	0xda, 0xa4, 0x24, 0xed, 0x7c, 0x9f, 0x1d, 0x7d, 0x14, 0x1f, 0xc5, 0x97, 0x50, 0xda, 0x34, 0x01,
	0x2f, 0xea, 0xed, 0xa3, 0xf9, 0x7d, 0x7f, 0xd2, 0xc0, 0x1b, 0xa1, 0x94, 0x28, 0x38, 0x66, 0x99,
	0xc1, 0x56, 0xb6, 0x6a, 0x4f, 0xb0, 0xe6, 0x46, 0x35, 0x3a, 0xe5, 0x06, 0xa7, 0x8d, 0xa9, 0x55,
	0xc9, 0xf5, 0xb6, 0x60, 0x3b, 0x5e, 0xa0, 0x4a, 0xab, 0x5a, 0x85, 0x33, 0x0b, 0x23, 0x96, 0x19,
	0xe4, 0x7d, 0x68, 0x4f, 0x90, 0xf7, 0x8d, 0x2f, 0xfa, 0xe8, 0xce, 0xb0, 0x6b, 0x5e, 0xf1, 0x9b,
	0x66, 0x55, 0xc5, 0xb5, 0xb1, 0x11, 0xe3, 0x89, 0xab, 0xae, 0x72, 0xcc, 0xa4, 0x54, 0x35, 0xab,
	0x73, 0x25, 0xfb, 0xd3, 0xcb, 0x03, 0x80, 0xc3, 0xfb, 0xbe, 0xf9, 0xb1, 0x2d, 0x0e, 0xaf, 0xe0,
	0xd0, 0x85, 0x6f, 0x25, 0x2b, 0xf9, 0x08, 0x4c, 0xc1, 0xe2, 0x74, 0x73, 0xee, 0x3e, 0x3e, 0xb1,
	0x92, 0x87, 0xb7, 0xf0, 0xc4, 0xed, 0x1d, 0x05, 0x53, 0xb0, 0x38, 0x23, 0x93, 0x7e, 0x1f, 0x72,
	0x3b, 0xd0, 0x73, 0xad, 0x73, 0x29, 0x62, 0x56, 0x34, 0x7c, 0xe3, 0xe9, 0x90, 0xc0, 0xa3, 0xee,
	0x82, 0xa3, 0xc1, 0x3f, 0x6c, 0x16, 0x5d, 0x7e, 0x01, 0x38, 0x4f, 0x55, 0x89, 0xfe, 0xfc, 0x19,
	0xcb, 0xf0, 0xc7, 0x5d, 0xd6, 0x6d, 0xe6, 0x1a, 0xbc, 0x3c, 0xf4, 0x46, 0xa1, 0x0a, 0x26, 0x05,
	0x52, 0x5a, 0x60, 0xc1, 0x65, 0xd7, 0xe8, 0x5e, 0xa3, 0xca, 0xcd, 0x2f, 0x8f, 0x73, 0xe7, 0xd5,
	0x21, 0x18, 0xac, 0xa2, 0xe8, 0x3d, 0x98, 0xad, 0x6c, 0x64, 0x94, 0x19, 0x64, 0x65, 0xab, 0x62,
	0x82, 0x36, 0x8e, 0xfc, 0x70, 0x4c, 0x12, 0x65, 0x26, 0xf1, 0x4c, 0x12, 0x93, 0xc4, 0x33, 0x9f,
	0xc1, 0xdc, 0x1e, 0x50, 0x1a, 0x65, 0x86, 0x52, 0x4f, 0x51, 0x1a, 0x13, 0x4a, 0x3d, 0xb7, 0x3b,
	0xee, 0xc6, 0x5e, 0x7f, 0x07, 0x00, 0x00, 0xff, 0xff, 0xc7, 0x9d, 0x7c, 0x44, 0x48, 0x02, 0x00,
	0x00,
}
