// Code generated by protoc-gen-go. DO NOT EDIT.
// source: google/ads/googleads/v2/errors/mutate_job_error.proto

package errors

import (
	fmt "fmt"
	math "math"

	proto "github.com/golang/protobuf/proto"
	_ "google.golang.org/genproto/googleapis/api/annotations"
)

// Reference imports to suppress errors if they are not otherwise used.
var _ = proto.Marshal
var _ = fmt.Errorf
var _ = math.Inf

// This is a compile-time assertion to ensure that this generated file
// is compatible with the proto package it is being compiled against.
// A compilation error at this line likely means your copy of the
// proto package needs to be updated.
const _ = proto.ProtoPackageIsVersion3 // please upgrade the proto package

// Enum describing possible request errors.
type MutateJobErrorEnum_MutateJobError int32

const (
	// Enum unspecified.
	MutateJobErrorEnum_UNSPECIFIED MutateJobErrorEnum_MutateJobError = 0
	// The received error code is not known in this version.
	MutateJobErrorEnum_UNKNOWN MutateJobErrorEnum_MutateJobError = 1
	// The mutate job cannot add more operations or run after it has started
	// running.
	MutateJobErrorEnum_CANNOT_MODIFY_JOB_AFTER_JOB_STARTS_RUNNING MutateJobErrorEnum_MutateJobError = 2
	// The operations for an AddMutateJobOperations request were empty.
	MutateJobErrorEnum_EMPTY_OPERATIONS MutateJobErrorEnum_MutateJobError = 3
	// The sequence token for an AddMutateJobOperations request was invalid.
	MutateJobErrorEnum_INVALID_SEQUENCE_TOKEN MutateJobErrorEnum_MutateJobError = 4
	// Mutate Job Results can only be retrieved once the job is finished.
	MutateJobErrorEnum_RESULTS_NOT_READY MutateJobErrorEnum_MutateJobError = 5
	// The page size for ListMutateJobResults was invalid.
	MutateJobErrorEnum_INVALID_PAGE_SIZE MutateJobErrorEnum_MutateJobError = 6
)

var MutateJobErrorEnum_MutateJobError_name = map[int32]string{
	0: "UNSPECIFIED",
	1: "UNKNOWN",
	2: "CANNOT_MODIFY_JOB_AFTER_JOB_STARTS_RUNNING",
	3: "EMPTY_OPERATIONS",
	4: "INVALID_SEQUENCE_TOKEN",
	5: "RESULTS_NOT_READY",
	6: "INVALID_PAGE_SIZE",
}

var MutateJobErrorEnum_MutateJobError_value = map[string]int32{
	"UNSPECIFIED": 0,
	"UNKNOWN":     1,
	"CANNOT_MODIFY_JOB_AFTER_JOB_STARTS_RUNNING": 2,
	"EMPTY_OPERATIONS":                           3,
	"INVALID_SEQUENCE_TOKEN":                     4,
	"RESULTS_NOT_READY":                          5,
	"INVALID_PAGE_SIZE":                          6,
}

func (x MutateJobErrorEnum_MutateJobError) String() string {
	return proto.EnumName(MutateJobErrorEnum_MutateJobError_name, int32(x))
}

func (MutateJobErrorEnum_MutateJobError) EnumDescriptor() ([]byte, []int) {
	return fileDescriptor_dd1d9fac35776029, []int{0, 0}
}

// Container for enum describing possible mutate job errors.
type MutateJobErrorEnum struct {
	XXX_NoUnkeyedLiteral struct{} `json:"-"`
	XXX_unrecognized     []byte   `json:"-"`
	XXX_sizecache        int32    `json:"-"`
}

func (m *MutateJobErrorEnum) Reset()         { *m = MutateJobErrorEnum{} }
func (m *MutateJobErrorEnum) String() string { return proto.CompactTextString(m) }
func (*MutateJobErrorEnum) ProtoMessage()    {}
func (*MutateJobErrorEnum) Descriptor() ([]byte, []int) {
	return fileDescriptor_dd1d9fac35776029, []int{0}
}

func (m *MutateJobErrorEnum) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_MutateJobErrorEnum.Unmarshal(m, b)
}
func (m *MutateJobErrorEnum) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_MutateJobErrorEnum.Marshal(b, m, deterministic)
}
func (m *MutateJobErrorEnum) XXX_Merge(src proto.Message) {
	xxx_messageInfo_MutateJobErrorEnum.Merge(m, src)
}
func (m *MutateJobErrorEnum) XXX_Size() int {
	return xxx_messageInfo_MutateJobErrorEnum.Size(m)
}
func (m *MutateJobErrorEnum) XXX_DiscardUnknown() {
	xxx_messageInfo_MutateJobErrorEnum.DiscardUnknown(m)
}

var xxx_messageInfo_MutateJobErrorEnum proto.InternalMessageInfo

func init() {
	proto.RegisterEnum("google.ads.googleads.v2.errors.MutateJobErrorEnum_MutateJobError", MutateJobErrorEnum_MutateJobError_name, MutateJobErrorEnum_MutateJobError_value)
	proto.RegisterType((*MutateJobErrorEnum)(nil), "google.ads.googleads.v2.errors.MutateJobErrorEnum")
}

func init() {
	proto.RegisterFile("google/ads/googleads/v2/errors/mutate_job_error.proto", fileDescriptor_dd1d9fac35776029)
}

var fileDescriptor_dd1d9fac35776029 = []byte{
	// 399 bytes of a gzipped FileDescriptorProto
	0x1f, 0x8b, 0x08, 0x00, 0x00, 0x00, 0x00, 0x00, 0x02, 0xff, 0x7c, 0x91, 0x4f, 0x8e, 0xd3, 0x30,
	0x18, 0xc5, 0x49, 0x07, 0x06, 0xc9, 0x23, 0x81, 0x31, 0x7f, 0x16, 0x23, 0x34, 0x8b, 0x2e, 0x59,
	0x38, 0x52, 0x10, 0x1b, 0xb3, 0x72, 0x1b, 0xb7, 0xf2, 0xcc, 0xd4, 0x09, 0xb1, 0x13, 0xd4, 0x51,
	0x24, 0x2b, 0x25, 0x51, 0x54, 0x34, 0x8d, 0xab, 0x38, 0x33, 0x07, 0x62, 0xc9, 0x21, 0x38, 0x00,
	0x7b, 0x2e, 0xc1, 0x82, 0x33, 0xa0, 0xc4, 0xa4, 0x52, 0x17, 0xcc, 0x2a, 0x4f, 0x4f, 0xef, 0xf7,
	0x7d, 0xf1, 0xfb, 0xc0, 0x87, 0xda, 0x98, 0xfa, 0xb6, 0xf2, 0x8b, 0xd2, 0xfa, 0x4e, 0xf6, 0xea,
	0x3e, 0xf0, 0xab, 0xb6, 0x35, 0xad, 0xf5, 0x77, 0x77, 0x5d, 0xd1, 0x55, 0xfa, 0xab, 0xd9, 0xe8,
	0xc1, 0xc1, 0xfb, 0xd6, 0x74, 0x06, 0x5d, 0xb8, 0x2c, 0x2e, 0x4a, 0x8b, 0x0f, 0x18, 0xbe, 0x0f,
	0xb0, 0xc3, 0xce, 0xdf, 0x8e, 0x63, 0xf7, 0x5b, 0xbf, 0x68, 0x1a, 0xd3, 0x15, 0xdd, 0xd6, 0x34,
	0xd6, 0xd1, 0xd3, 0x5f, 0x1e, 0x40, 0xab, 0x61, 0xf0, 0xa5, 0xd9, 0xb0, 0x9e, 0x60, 0xcd, 0xdd,
	0x6e, 0xfa, 0xc3, 0x03, 0xcf, 0x8e, 0x6d, 0xf4, 0x1c, 0x9c, 0xa5, 0x42, 0xc6, 0x6c, 0xce, 0x17,
	0x9c, 0x85, 0xf0, 0x11, 0x3a, 0x03, 0x4f, 0x53, 0x71, 0x25, 0xa2, 0xcf, 0x02, 0x7a, 0x08, 0x83,
	0x77, 0x73, 0x2a, 0x44, 0xa4, 0xf4, 0x2a, 0x0a, 0xf9, 0x62, 0xad, 0x2f, 0xa3, 0x99, 0xa6, 0x0b,
	0xc5, 0x92, 0x41, 0x49, 0x45, 0x13, 0x25, 0x75, 0x92, 0x0a, 0xc1, 0xc5, 0x12, 0x4e, 0xd0, 0x2b,
	0x00, 0xd9, 0x2a, 0x56, 0x6b, 0x1d, 0xc5, 0x2c, 0xa1, 0x8a, 0x47, 0x42, 0xc2, 0x13, 0x74, 0x0e,
	0xde, 0x70, 0x91, 0xd1, 0x6b, 0x1e, 0x6a, 0xc9, 0x3e, 0xa5, 0x4c, 0xcc, 0x99, 0x56, 0xd1, 0x15,
	0x13, 0xf0, 0x31, 0x7a, 0x0d, 0x5e, 0x24, 0x4c, 0xa6, 0xd7, 0x4a, 0xea, 0x7e, 0x4d, 0xc2, 0x68,
	0xb8, 0x86, 0x4f, 0x7a, 0x7b, 0x44, 0x62, 0xba, 0x64, 0x5a, 0xf2, 0x1b, 0x06, 0x4f, 0x67, 0x7f,
	0x3c, 0x30, 0xfd, 0x62, 0x76, 0xf8, 0xe1, 0x72, 0x66, 0x2f, 0x8f, 0x1f, 0x19, 0xf7, 0x9d, 0xc4,
	0xde, 0x4d, 0xf8, 0x0f, 0xab, 0xcd, 0x6d, 0xd1, 0xd4, 0xd8, 0xb4, 0xb5, 0x5f, 0x57, 0xcd, 0xd0,
	0xd8, 0x78, 0x9a, 0xfd, 0xd6, 0xfe, 0xef, 0x52, 0x1f, 0xdd, 0xe7, 0xdb, 0xe4, 0x64, 0x49, 0xe9,
	0xf7, 0xc9, 0xc5, 0xd2, 0x0d, 0xa3, 0xa5, 0xc5, 0x4e, 0xf6, 0x2a, 0x0b, 0xf0, 0xb0, 0xd2, 0xfe,
	0x1c, 0x03, 0x39, 0x2d, 0x6d, 0x7e, 0x08, 0xe4, 0x59, 0x90, 0xbb, 0xc0, 0xef, 0xc9, 0xd4, 0xb9,
	0x84, 0xd0, 0xd2, 0x12, 0x72, 0x88, 0x10, 0x92, 0x05, 0x84, 0xb8, 0xd0, 0xe6, 0x74, 0xf8, 0xbb,
	0xf7, 0x7f, 0x03, 0x00, 0x00, 0xff, 0xff, 0xcc, 0xdb, 0x03, 0x0a, 0x46, 0x02, 0x00, 0x00,
}
