// Code generated by protoc-gen-go. DO NOT EDIT.
// source: google/ads/googleads/v1/resources/language_constant.proto

package resources

import (
	fmt "fmt"
	math "math"

	proto "github.com/golang/protobuf/proto"
	wrappers "github.com/golang/protobuf/ptypes/wrappers"
	_ "google.golang.org/genproto/googleapis/api/annotations"
)

// Reference imports to suppress errors if they are not otherwise used.
var _ = proto.Marshal
var _ = fmt.Errorf
var _ = math.Inf

// This is a compile-time assertion to ensure that this generated file
// is compatible with the proto package it is being compiled against.
// A compilation error at this line likely means your copy of the
// proto package needs to be updated.
const _ = proto.ProtoPackageIsVersion3 // please upgrade the proto package

// A language.
type LanguageConstant struct {
	// The resource name of the language constant.
	// Language constant resource names have the form:
	//
	// `languageConstants/{criterion_id}`
	ResourceName string `protobuf:"bytes,1,opt,name=resource_name,json=resourceName,proto3" json:"resource_name,omitempty"`
	// The ID of the language constant.
	Id *wrappers.Int64Value `protobuf:"bytes,2,opt,name=id,proto3" json:"id,omitempty"`
	// The language code, e.g. "en_US", "en_AU", "es", "fr", etc.
	Code *wrappers.StringValue `protobuf:"bytes,3,opt,name=code,proto3" json:"code,omitempty"`
	// The full name of the language in English, e.g., "English (US)", "Spanish",
	// etc.
	Name *wrappers.StringValue `protobuf:"bytes,4,opt,name=name,proto3" json:"name,omitempty"`
	// Whether the language is targetable.
	Targetable           *wrappers.BoolValue `protobuf:"bytes,5,opt,name=targetable,proto3" json:"targetable,omitempty"`
	XXX_NoUnkeyedLiteral struct{}            `json:"-"`
	XXX_unrecognized     []byte              `json:"-"`
	XXX_sizecache        int32               `json:"-"`
}

func (m *LanguageConstant) Reset()         { *m = LanguageConstant{} }
func (m *LanguageConstant) String() string { return proto.CompactTextString(m) }
func (*LanguageConstant) ProtoMessage()    {}
func (*LanguageConstant) Descriptor() ([]byte, []int) {
	return fileDescriptor_74e5fb6fb55865cb, []int{0}
}

func (m *LanguageConstant) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_LanguageConstant.Unmarshal(m, b)
}
func (m *LanguageConstant) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_LanguageConstant.Marshal(b, m, deterministic)
}
func (m *LanguageConstant) XXX_Merge(src proto.Message) {
	xxx_messageInfo_LanguageConstant.Merge(m, src)
}
func (m *LanguageConstant) XXX_Size() int {
	return xxx_messageInfo_LanguageConstant.Size(m)
}
func (m *LanguageConstant) XXX_DiscardUnknown() {
	xxx_messageInfo_LanguageConstant.DiscardUnknown(m)
}

var xxx_messageInfo_LanguageConstant proto.InternalMessageInfo

func (m *LanguageConstant) GetResourceName() string {
	if m != nil {
		return m.ResourceName
	}
	return ""
}

func (m *LanguageConstant) GetId() *wrappers.Int64Value {
	if m != nil {
		return m.Id
	}
	return nil
}

func (m *LanguageConstant) GetCode() *wrappers.StringValue {
	if m != nil {
		return m.Code
	}
	return nil
}

func (m *LanguageConstant) GetName() *wrappers.StringValue {
	if m != nil {
		return m.Name
	}
	return nil
}

func (m *LanguageConstant) GetTargetable() *wrappers.BoolValue {
	if m != nil {
		return m.Targetable
	}
	return nil
}

func init() {
	proto.RegisterType((*LanguageConstant)(nil), "google.ads.googleads.v1.resources.LanguageConstant")
}

func init() {
	proto.RegisterFile("google/ads/googleads/v1/resources/language_constant.proto", fileDescriptor_74e5fb6fb55865cb)
}

var fileDescriptor_74e5fb6fb55865cb = []byte{
	// 371 bytes of a gzipped FileDescriptorProto
	0x1f, 0x8b, 0x08, 0x00, 0x00, 0x00, 0x00, 0x00, 0x02, 0xff, 0x8c, 0x92, 0xd1, 0x4a, 0xeb, 0x30,
	0x1c, 0xc6, 0x69, 0xb6, 0x73, 0xe0, 0xe4, 0x9c, 0x03, 0x52, 0x10, 0xca, 0x1c, 0xb2, 0x29, 0x83,
	0x81, 0x90, 0x5a, 0x15, 0xc1, 0x78, 0xd5, 0x79, 0x31, 0x14, 0x91, 0x31, 0xa1, 0x17, 0x52, 0x18,
	0x59, 0x13, 0x43, 0xa1, 0x4b, 0x4a, 0x92, 0xce, 0x7b, 0xf1, 0x49, 0xbc, 0xf4, 0x51, 0x7c, 0x14,
	0x9f, 0x42, 0xda, 0xb4, 0x45, 0x1c, 0xa8, 0x77, 0x5f, 0xfb, 0xff, 0x7d, 0xdf, 0x17, 0xf2, 0x0f,
	0x3c, 0xe3, 0x52, 0xf2, 0x8c, 0xf9, 0x84, 0x6a, 0xdf, 0xca, 0x52, 0xad, 0x03, 0x5f, 0x31, 0x2d,
	0x0b, 0x95, 0x30, 0xed, 0x67, 0x44, 0xf0, 0x82, 0x70, 0xb6, 0x48, 0xa4, 0xd0, 0x86, 0x08, 0x83,
	0x72, 0x25, 0x8d, 0x74, 0x87, 0x96, 0x47, 0x84, 0x6a, 0xd4, 0x5a, 0xd1, 0x3a, 0x40, 0xad, 0xb5,
	0xd7, 0x6f, 0xd2, 0xf3, 0xd4, 0x27, 0x42, 0x48, 0x43, 0x4c, 0x2a, 0x85, 0xb6, 0x01, 0xbd, 0xdd,
	0x7a, 0x5a, 0x7d, 0x2d, 0x8b, 0x7b, 0xff, 0x41, 0x91, 0x3c, 0x67, 0xaa, 0x9e, 0xef, 0x3d, 0x01,
	0xb8, 0x75, 0x5d, 0x97, 0x5f, 0xd4, 0xdd, 0xee, 0x3e, 0xfc, 0xdf, 0xe4, 0x2f, 0x04, 0x59, 0x31,
	0xcf, 0x19, 0x38, 0xe3, 0x3f, 0xf3, 0x7f, 0xcd, 0xcf, 0x1b, 0xb2, 0x62, 0xee, 0x01, 0x04, 0x29,
	0xf5, 0xc0, 0xc0, 0x19, 0xff, 0x3d, 0xda, 0xa9, 0x0f, 0x87, 0x9a, 0x1a, 0x74, 0x29, 0xcc, 0xe9,
	0x49, 0x44, 0xb2, 0x82, 0xcd, 0x41, 0x4a, 0xdd, 0x43, 0xd8, 0x4d, 0x24, 0x65, 0x5e, 0xa7, 0xc2,
	0xfb, 0x1b, 0xf8, 0xad, 0x51, 0xa9, 0xe0, 0x96, 0xaf, 0xc8, 0xd2, 0x51, 0x55, 0x77, 0x7f, 0xe2,
	0x28, 0x49, 0x17, 0x43, 0x68, 0x88, 0xe2, 0xcc, 0x90, 0x65, 0xc6, 0xbc, 0x5f, 0x95, 0xaf, 0xb7,
	0xe1, 0x9b, 0x48, 0x99, 0x59, 0xd7, 0x07, 0x7a, 0xf2, 0x08, 0xe0, 0x28, 0x91, 0x2b, 0xf4, 0xed,
	0x75, 0x4f, 0xb6, 0x3f, 0xdf, 0xd6, 0xac, 0x4c, 0x9e, 0x39, 0x77, 0x57, 0xb5, 0x97, 0xcb, 0x72,
	0x99, 0x48, 0x2a, 0xee, 0x73, 0x26, 0xaa, 0xde, 0x66, 0xeb, 0x79, 0xaa, 0xbf, 0x78, 0x04, 0xe7,
	0xad, 0x7a, 0x06, 0x9d, 0x69, 0x18, 0xbe, 0x80, 0xe1, 0xd4, 0x46, 0x86, 0x54, 0x23, 0x2b, 0x4b,
	0x15, 0x05, 0x68, 0xde, 0x90, 0xaf, 0x0d, 0x13, 0x87, 0x54, 0xc7, 0x2d, 0x13, 0x47, 0x41, 0xdc,
	0x32, 0x6f, 0x60, 0x64, 0x07, 0x18, 0x87, 0x54, 0x63, 0xdc, 0x52, 0x18, 0x47, 0x01, 0xc6, 0x2d,
	0xb7, 0xfc, 0x5d, 0x1d, 0xf6, 0xf8, 0x3d, 0x00, 0x00, 0xff, 0xff, 0xe2, 0xa3, 0xed, 0xf7, 0xb0,
	0x02, 0x00, 0x00,
}
