// Code generated by protoc-gen-go. DO NOT EDIT.
// source: google/ads/googleads/v1/services/ad_group_criterion_simulation_service.proto

package services

import (
	context "context"
	fmt "fmt"
	math "math"

	proto "github.com/golang/protobuf/proto"
	resources "google.golang.org/genproto/googleapis/ads/googleads/v1/resources"
	_ "google.golang.org/genproto/googleapis/api/annotations"
	grpc "google.golang.org/grpc"
)

// Reference imports to suppress errors if they are not otherwise used.
var _ = proto.Marshal
var _ = fmt.Errorf
var _ = math.Inf

// This is a compile-time assertion to ensure that this generated file
// is compatible with the proto package it is being compiled against.
// A compilation error at this line likely means your copy of the
// proto package needs to be updated.
const _ = proto.ProtoPackageIsVersion3 // please upgrade the proto package

// Request message for
// [AdGroupCriterionSimulationService.GetAdGroupCriterionSimulation][google.ads.googleads.v1.services.AdGroupCriterionSimulationService.GetAdGroupCriterionSimulation].
type GetAdGroupCriterionSimulationRequest struct {
	// The resource name of the ad group criterion simulation to fetch.
	ResourceName         string   `protobuf:"bytes,1,opt,name=resource_name,json=resourceName,proto3" json:"resource_name,omitempty"`
	XXX_NoUnkeyedLiteral struct{} `json:"-"`
	XXX_unrecognized     []byte   `json:"-"`
	XXX_sizecache        int32    `json:"-"`
}

func (m *GetAdGroupCriterionSimulationRequest) Reset()         { *m = GetAdGroupCriterionSimulationRequest{} }
func (m *GetAdGroupCriterionSimulationRequest) String() string { return proto.CompactTextString(m) }
func (*GetAdGroupCriterionSimulationRequest) ProtoMessage()    {}
func (*GetAdGroupCriterionSimulationRequest) Descriptor() ([]byte, []int) {
	return fileDescriptor_1f03d9711149e38c, []int{0}
}

func (m *GetAdGroupCriterionSimulationRequest) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_GetAdGroupCriterionSimulationRequest.Unmarshal(m, b)
}
func (m *GetAdGroupCriterionSimulationRequest) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_GetAdGroupCriterionSimulationRequest.Marshal(b, m, deterministic)
}
func (m *GetAdGroupCriterionSimulationRequest) XXX_Merge(src proto.Message) {
	xxx_messageInfo_GetAdGroupCriterionSimulationRequest.Merge(m, src)
}
func (m *GetAdGroupCriterionSimulationRequest) XXX_Size() int {
	return xxx_messageInfo_GetAdGroupCriterionSimulationRequest.Size(m)
}
func (m *GetAdGroupCriterionSimulationRequest) XXX_DiscardUnknown() {
	xxx_messageInfo_GetAdGroupCriterionSimulationRequest.DiscardUnknown(m)
}

var xxx_messageInfo_GetAdGroupCriterionSimulationRequest proto.InternalMessageInfo

func (m *GetAdGroupCriterionSimulationRequest) GetResourceName() string {
	if m != nil {
		return m.ResourceName
	}
	return ""
}

func init() {
	proto.RegisterType((*GetAdGroupCriterionSimulationRequest)(nil), "google.ads.googleads.v1.services.GetAdGroupCriterionSimulationRequest")
}

func init() {
	proto.RegisterFile("google/ads/googleads/v1/services/ad_group_criterion_simulation_service.proto", fileDescriptor_1f03d9711149e38c)
}

var fileDescriptor_1f03d9711149e38c = []byte{
	// 373 bytes of a gzipped FileDescriptorProto
	0x1f, 0x8b, 0x08, 0x00, 0x00, 0x00, 0x00, 0x00, 0x02, 0xff, 0x8c, 0x92, 0xb1, 0x4a, 0xc3, 0x40,
	0x1c, 0xc6, 0x49, 0x04, 0xc1, 0xa0, 0x4b, 0x26, 0x29, 0x0a, 0xb5, 0x16, 0x91, 0x0e, 0x77, 0x44,
	0xb7, 0x93, 0x22, 0xa9, 0xd4, 0x08, 0x8a, 0x94, 0x16, 0x3a, 0x48, 0x20, 0x9c, 0xc9, 0x11, 0x02,
	0x4d, 0x2e, 0xde, 0xff, 0xd2, 0x45, 0x5c, 0xdc, 0x9d, 0xfa, 0x06, 0x8e, 0x3e, 0x8a, 0xab, 0xaf,
	0xe0, 0x24, 0xf8, 0x0e, 0x92, 0x5c, 0x2f, 0xe0, 0x10, 0xe3, 0xf6, 0x71, 0xf7, 0xf1, 0xfb, 0xee,
	0xff, 0xdd, 0xdf, 0xba, 0x89, 0x39, 0x8f, 0x17, 0x0c, 0xd3, 0x08, 0xb0, 0x92, 0xa5, 0x5a, 0x3a,
	0x18, 0x98, 0x58, 0x26, 0x21, 0x03, 0x4c, 0xa3, 0x20, 0x16, 0xbc, 0xc8, 0x83, 0x50, 0x24, 0x92,
	0x89, 0x84, 0x67, 0x01, 0x24, 0x69, 0xb1, 0xa0, 0xb2, 0x92, 0xca, 0x86, 0x72, 0xc1, 0x25, 0xb7,
	0xbb, 0x0a, 0x81, 0x68, 0x04, 0xa8, 0xa6, 0xa1, 0xa5, 0x83, 0x34, 0xad, 0x33, 0x6e, 0xca, 0x13,
	0x0c, 0x78, 0x21, 0x5a, 0x03, 0x55, 0x50, 0x67, 0x4f, 0x63, 0xf2, 0x04, 0xd3, 0x2c, 0xe3, 0xb2,
	0xba, 0x04, 0x75, 0xdb, 0xbb, 0xb6, 0xfa, 0x1e, 0x93, 0x6e, 0xe4, 0x95, 0x98, 0x0b, 0x4d, 0x99,
	0xd5, 0x90, 0x29, 0x7b, 0x28, 0x18, 0x48, 0xfb, 0xd0, 0xda, 0xd1, 0xb1, 0x41, 0x46, 0x53, 0xb6,
	0x6b, 0x74, 0x8d, 0xe3, 0xad, 0xe9, 0xb6, 0x3e, 0xbc, 0xa5, 0x29, 0x3b, 0x59, 0x99, 0xd6, 0x41,
	0x33, 0x6a, 0xa6, 0x06, 0xb3, 0xbf, 0x0d, 0x6b, 0xff, 0xcf, 0x4c, 0xfb, 0x12, 0xb5, 0x95, 0x83,
	0xfe, 0xf3, 0xe8, 0xce, 0xb0, 0x91, 0x53, 0x57, 0x88, 0x9a, 0x29, 0xbd, 0xf1, 0xf3, 0xc7, 0xe7,
	0xca, 0x3c, 0xb7, 0x87, 0x65, 0xe9, 0x8f, 0xbf, 0xc6, 0x1f, 0x86, 0x05, 0x48, 0x9e, 0x32, 0x01,
	0x78, 0x80, 0x69, 0x23, 0x02, 0xf0, 0xe0, 0x69, 0xf4, 0x62, 0x5a, 0xfd, 0x90, 0xa7, 0xad, 0x33,
	0x8d, 0x8e, 0x5a, 0xbb, 0x9b, 0x94, 0x7f, 0x36, 0x31, 0xee, 0xae, 0xd6, 0xac, 0x98, 0x2f, 0x68,
	0x16, 0x23, 0x2e, 0x62, 0x1c, 0xb3, 0xac, 0xfa, 0x51, 0xbd, 0x2a, 0x79, 0x02, 0xcd, 0x9b, 0x7a,
	0xa6, 0xc5, 0xab, 0xb9, 0xe1, 0xb9, 0xee, 0x9b, 0xd9, 0xf5, 0x14, 0xd0, 0x8d, 0x00, 0x29, 0x59,
	0xaa, 0xb9, 0x83, 0xd6, 0xc1, 0xf0, 0xae, 0x2d, 0xbe, 0x1b, 0x81, 0x5f, 0x5b, 0xfc, 0xb9, 0xe3,
	0x6b, 0xcb, 0x97, 0xd9, 0x57, 0xe7, 0x84, 0xb8, 0x11, 0x10, 0x52, 0x9b, 0x08, 0x99, 0x3b, 0x84,
	0x68, 0xdb, 0xfd, 0x66, 0xf5, 0xce, 0xd3, 0x9f, 0x00, 0x00, 0x00, 0xff, 0xff, 0xbd, 0x43, 0x68,
	0x5b, 0x50, 0x03, 0x00, 0x00,
}

// Reference imports to suppress errors if they are not otherwise used.
var _ context.Context
var _ grpc.ClientConn

// This is a compile-time assertion to ensure that this generated file
// is compatible with the grpc package it is being compiled against.
const _ = grpc.SupportPackageIsVersion4

// AdGroupCriterionSimulationServiceClient is the client API for AdGroupCriterionSimulationService service.
//
// For semantics around ctx use and closing/ending streaming RPCs, please refer to https://godoc.org/google.golang.org/grpc#ClientConn.NewStream.
type AdGroupCriterionSimulationServiceClient interface {
	// Returns the requested ad group criterion simulation in full detail.
	GetAdGroupCriterionSimulation(ctx context.Context, in *GetAdGroupCriterionSimulationRequest, opts ...grpc.CallOption) (*resources.AdGroupCriterionSimulation, error)
}

type adGroupCriterionSimulationServiceClient struct {
	cc *grpc.ClientConn
}

func NewAdGroupCriterionSimulationServiceClient(cc *grpc.ClientConn) AdGroupCriterionSimulationServiceClient {
	return &adGroupCriterionSimulationServiceClient{cc}
}

func (c *adGroupCriterionSimulationServiceClient) GetAdGroupCriterionSimulation(ctx context.Context, in *GetAdGroupCriterionSimulationRequest, opts ...grpc.CallOption) (*resources.AdGroupCriterionSimulation, error) {
	out := new(resources.AdGroupCriterionSimulation)
	err := c.cc.Invoke(ctx, "/google.ads.googleads.v1.services.AdGroupCriterionSimulationService/GetAdGroupCriterionSimulation", in, out, opts...)
	if err != nil {
		return nil, err
	}
	return out, nil
}

// AdGroupCriterionSimulationServiceServer is the server API for AdGroupCriterionSimulationService service.
type AdGroupCriterionSimulationServiceServer interface {
	// Returns the requested ad group criterion simulation in full detail.
	GetAdGroupCriterionSimulation(context.Context, *GetAdGroupCriterionSimulationRequest) (*resources.AdGroupCriterionSimulation, error)
}

func RegisterAdGroupCriterionSimulationServiceServer(s *grpc.Server, srv AdGroupCriterionSimulationServiceServer) {
	s.RegisterService(&_AdGroupCriterionSimulationService_serviceDesc, srv)
}

func _AdGroupCriterionSimulationService_GetAdGroupCriterionSimulation_Handler(srv interface{}, ctx context.Context, dec func(interface{}) error, interceptor grpc.UnaryServerInterceptor) (interface{}, error) {
	in := new(GetAdGroupCriterionSimulationRequest)
	if err := dec(in); err != nil {
		return nil, err
	}
	if interceptor == nil {
		return srv.(AdGroupCriterionSimulationServiceServer).GetAdGroupCriterionSimulation(ctx, in)
	}
	info := &grpc.UnaryServerInfo{
		Server:     srv,
		FullMethod: "/google.ads.googleads.v1.services.AdGroupCriterionSimulationService/GetAdGroupCriterionSimulation",
	}
	handler := func(ctx context.Context, req interface{}) (interface{}, error) {
		return srv.(AdGroupCriterionSimulationServiceServer).GetAdGroupCriterionSimulation(ctx, req.(*GetAdGroupCriterionSimulationRequest))
	}
	return interceptor(ctx, in, info, handler)
}

var _AdGroupCriterionSimulationService_serviceDesc = grpc.ServiceDesc{
	ServiceName: "google.ads.googleads.v1.services.AdGroupCriterionSimulationService",
	HandlerType: (*AdGroupCriterionSimulationServiceServer)(nil),
	Methods: []grpc.MethodDesc{
		{
			MethodName: "GetAdGroupCriterionSimulation",
			Handler:    _AdGroupCriterionSimulationService_GetAdGroupCriterionSimulation_Handler,
		},
	},
	Streams:  []grpc.StreamDesc{},
	Metadata: "google/ads/googleads/v1/services/ad_group_criterion_simulation_service.proto",
}
