// Code generated by protoc-gen-go. DO NOT EDIT.
// source: google/ads/googleads/v2/services/campaign_audience_view_service.proto

package services

import (
	context "context"
	fmt "fmt"
	math "math"

	proto "github.com/golang/protobuf/proto"
	resources "google.golang.org/genproto/googleapis/ads/googleads/v2/resources"
	_ "google.golang.org/genproto/googleapis/api/annotations"
	grpc "google.golang.org/grpc"
)

// Reference imports to suppress errors if they are not otherwise used.
var _ = proto.Marshal
var _ = fmt.Errorf
var _ = math.Inf

// This is a compile-time assertion to ensure that this generated file
// is compatible with the proto package it is being compiled against.
// A compilation error at this line likely means your copy of the
// proto package needs to be updated.
const _ = proto.ProtoPackageIsVersion3 // please upgrade the proto package

// Request message for [CampaignAudienceViewService.GetCampaignAudienceView][google.ads.googleads.v2.services.CampaignAudienceViewService.GetCampaignAudienceView].
type GetCampaignAudienceViewRequest struct {
	// The resource name of the campaign audience view to fetch.
	ResourceName         string   `protobuf:"bytes,1,opt,name=resource_name,json=resourceName,proto3" json:"resource_name,omitempty"`
	XXX_NoUnkeyedLiteral struct{} `json:"-"`
	XXX_unrecognized     []byte   `json:"-"`
	XXX_sizecache        int32    `json:"-"`
}

func (m *GetCampaignAudienceViewRequest) Reset()         { *m = GetCampaignAudienceViewRequest{} }
func (m *GetCampaignAudienceViewRequest) String() string { return proto.CompactTextString(m) }
func (*GetCampaignAudienceViewRequest) ProtoMessage()    {}
func (*GetCampaignAudienceViewRequest) Descriptor() ([]byte, []int) {
	return fileDescriptor_b8ae39646e976956, []int{0}
}

func (m *GetCampaignAudienceViewRequest) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_GetCampaignAudienceViewRequest.Unmarshal(m, b)
}
func (m *GetCampaignAudienceViewRequest) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_GetCampaignAudienceViewRequest.Marshal(b, m, deterministic)
}
func (m *GetCampaignAudienceViewRequest) XXX_Merge(src proto.Message) {
	xxx_messageInfo_GetCampaignAudienceViewRequest.Merge(m, src)
}
func (m *GetCampaignAudienceViewRequest) XXX_Size() int {
	return xxx_messageInfo_GetCampaignAudienceViewRequest.Size(m)
}
func (m *GetCampaignAudienceViewRequest) XXX_DiscardUnknown() {
	xxx_messageInfo_GetCampaignAudienceViewRequest.DiscardUnknown(m)
}

var xxx_messageInfo_GetCampaignAudienceViewRequest proto.InternalMessageInfo

func (m *GetCampaignAudienceViewRequest) GetResourceName() string {
	if m != nil {
		return m.ResourceName
	}
	return ""
}

func init() {
	proto.RegisterType((*GetCampaignAudienceViewRequest)(nil), "google.ads.googleads.v2.services.GetCampaignAudienceViewRequest")
}

func init() {
	proto.RegisterFile("google/ads/googleads/v2/services/campaign_audience_view_service.proto", fileDescriptor_b8ae39646e976956)
}

var fileDescriptor_b8ae39646e976956 = []byte{
	// 398 bytes of a gzipped FileDescriptorProto
	0x1f, 0x8b, 0x08, 0x00, 0x00, 0x00, 0x00, 0x00, 0x02, 0xff, 0x84, 0x52, 0x3d, 0x8b, 0xdb, 0x40,
	0x10, 0x45, 0x0a, 0x04, 0x22, 0x92, 0x46, 0x8d, 0x8d, 0x1c, 0x82, 0x70, 0x5c, 0x04, 0x17, 0xbb,
	0xa0, 0x14, 0x26, 0x1b, 0xf2, 0x21, 0x07, 0xe3, 0x54, 0xc1, 0x38, 0xa0, 0x22, 0x08, 0xc4, 0x46,
	0x1a, 0xc4, 0x82, 0xb5, 0xab, 0x68, 0x25, 0xb9, 0x08, 0x69, 0xd2, 0xa4, 0x4f, 0xfe, 0x41, 0xca,
	0xfb, 0x29, 0x6e, 0x8f, 0xfb, 0x07, 0x57, 0xdd, 0xaf, 0x38, 0xe4, 0xd5, 0xca, 0x3e, 0xb0, 0xec,
	0xee, 0xb1, 0xf3, 0xe6, 0xbd, 0x99, 0x37, 0x6b, 0x2d, 0x52, 0x21, 0xd2, 0x0d, 0x60, 0x9a, 0x48,
	0xac, 0x60, 0x83, 0x6a, 0x0f, 0x4b, 0x28, 0x6a, 0x16, 0x83, 0xc4, 0x31, 0xcd, 0x72, 0xca, 0x52,
	0x1e, 0xd1, 0x2a, 0x61, 0xc0, 0x63, 0x88, 0x6a, 0x06, 0xdb, 0xa8, 0xad, 0xa3, 0xbc, 0x10, 0xa5,
	0xb0, 0x5d, 0xd5, 0x8b, 0x68, 0x22, 0x51, 0x27, 0x83, 0x6a, 0x0f, 0x69, 0x19, 0xe7, 0x7d, 0x9f,
	0x51, 0x01, 0x52, 0x54, 0x45, 0xbf, 0x93, 0x72, 0x70, 0x9e, 0xeb, 0xfe, 0x9c, 0x61, 0xca, 0xb9,
	0x28, 0x69, 0xc9, 0x04, 0x97, 0x6d, 0x75, 0x70, 0x54, 0x8d, 0x37, 0x0c, 0x78, 0xa9, 0x0a, 0xe3,
	0x85, 0xf5, 0x62, 0x09, 0xe5, 0xa7, 0x56, 0xd9, 0x6f, 0x85, 0x03, 0x06, 0xdb, 0x35, 0xfc, 0xa8,
	0x40, 0x96, 0xf6, 0x4b, 0xeb, 0x99, 0x1e, 0x21, 0xe2, 0x34, 0x83, 0xa1, 0xe1, 0x1a, 0xaf, 0x9e,
	0xac, 0x9f, 0xea, 0xc7, 0x2f, 0x34, 0x03, 0xef, 0xaf, 0x69, 0x8d, 0x4e, 0x89, 0x7c, 0x55, 0xeb,
	0xd9, 0x37, 0x86, 0x35, 0xe8, 0xf1, 0xb1, 0x3f, 0xa2, 0x4b, 0xe1, 0xa0, 0xf3, 0x23, 0x3a, 0xb3,
	0x5e, 0x85, 0x2e, 0x3c, 0x74, 0xaa, 0x7f, 0xfc, 0xe1, 0xf7, 0xf5, 0xed, 0x3f, 0xf3, 0x8d, 0x3d,
	0x6b, 0x82, 0xfe, 0xf9, 0x60, 0xcd, 0x77, 0x71, 0x25, 0x4b, 0x91, 0x41, 0x21, 0xf1, 0xb4, 0x4b,
	0xfe, 0xb8, 0x59, 0xe2, 0xe9, 0x2f, 0x67, 0xb4, 0xf3, 0x87, 0x07, 0xc3, 0x16, 0xe5, 0x4c, 0xa2,
	0x58, 0x64, 0xf3, 0x3f, 0xa6, 0x35, 0x89, 0x45, 0x76, 0x71, 0xbd, 0xb9, 0x7b, 0x26, 0xba, 0x55,
	0x73, 0xa6, 0x95, 0xf1, 0xed, 0x73, 0xab, 0x92, 0x8a, 0x0d, 0xe5, 0x29, 0x12, 0x45, 0x8a, 0x53,
	0xe0, 0xfb, 0x23, 0xe2, 0x83, 0x6f, 0xff, 0x3f, 0x7d, 0xab, 0xc1, 0x7f, 0xf3, 0xd1, 0xd2, 0xf7,
	0xaf, 0x4c, 0x77, 0xa9, 0x04, 0xfd, 0x44, 0x22, 0x05, 0x1b, 0x14, 0x78, 0xa8, 0x35, 0x96, 0x3b,
	0x4d, 0x09, 0xfd, 0x44, 0x86, 0x1d, 0x25, 0x0c, 0xbc, 0x50, 0x53, 0xee, 0xcc, 0x89, 0x7a, 0x27,
	0xc4, 0x4f, 0x24, 0x21, 0x1d, 0x89, 0x90, 0xc0, 0x23, 0x44, 0xd3, 0xbe, 0x3f, 0xde, 0xcf, 0xf9,
	0xfa, 0x3e, 0x00, 0x00, 0xff, 0xff, 0x48, 0x0d, 0x45, 0xd0, 0x4e, 0x03, 0x00, 0x00,
}

// Reference imports to suppress errors if they are not otherwise used.
var _ context.Context
var _ grpc.ClientConn

// This is a compile-time assertion to ensure that this generated file
// is compatible with the grpc package it is being compiled against.
const _ = grpc.SupportPackageIsVersion4

// CampaignAudienceViewServiceClient is the client API for CampaignAudienceViewService service.
//
// For semantics around ctx use and closing/ending streaming RPCs, please refer to https://godoc.org/google.golang.org/grpc#ClientConn.NewStream.
type CampaignAudienceViewServiceClient interface {
	// Returns the requested campaign audience view in full detail.
	GetCampaignAudienceView(ctx context.Context, in *GetCampaignAudienceViewRequest, opts ...grpc.CallOption) (*resources.CampaignAudienceView, error)
}

type campaignAudienceViewServiceClient struct {
	cc *grpc.ClientConn
}

func NewCampaignAudienceViewServiceClient(cc *grpc.ClientConn) CampaignAudienceViewServiceClient {
	return &campaignAudienceViewServiceClient{cc}
}

func (c *campaignAudienceViewServiceClient) GetCampaignAudienceView(ctx context.Context, in *GetCampaignAudienceViewRequest, opts ...grpc.CallOption) (*resources.CampaignAudienceView, error) {
	out := new(resources.CampaignAudienceView)
	err := c.cc.Invoke(ctx, "/google.ads.googleads.v2.services.CampaignAudienceViewService/GetCampaignAudienceView", in, out, opts...)
	if err != nil {
		return nil, err
	}
	return out, nil
}

// CampaignAudienceViewServiceServer is the server API for CampaignAudienceViewService service.
type CampaignAudienceViewServiceServer interface {
	// Returns the requested campaign audience view in full detail.
	GetCampaignAudienceView(context.Context, *GetCampaignAudienceViewRequest) (*resources.CampaignAudienceView, error)
}

func RegisterCampaignAudienceViewServiceServer(s *grpc.Server, srv CampaignAudienceViewServiceServer) {
	s.RegisterService(&_CampaignAudienceViewService_serviceDesc, srv)
}

func _CampaignAudienceViewService_GetCampaignAudienceView_Handler(srv interface{}, ctx context.Context, dec func(interface{}) error, interceptor grpc.UnaryServerInterceptor) (interface{}, error) {
	in := new(GetCampaignAudienceViewRequest)
	if err := dec(in); err != nil {
		return nil, err
	}
	if interceptor == nil {
		return srv.(CampaignAudienceViewServiceServer).GetCampaignAudienceView(ctx, in)
	}
	info := &grpc.UnaryServerInfo{
		Server:     srv,
		FullMethod: "/google.ads.googleads.v2.services.CampaignAudienceViewService/GetCampaignAudienceView",
	}
	handler := func(ctx context.Context, req interface{}) (interface{}, error) {
		return srv.(CampaignAudienceViewServiceServer).GetCampaignAudienceView(ctx, req.(*GetCampaignAudienceViewRequest))
	}
	return interceptor(ctx, in, info, handler)
}

var _CampaignAudienceViewService_serviceDesc = grpc.ServiceDesc{
	ServiceName: "google.ads.googleads.v2.services.CampaignAudienceViewService",
	HandlerType: (*CampaignAudienceViewServiceServer)(nil),
	Methods: []grpc.MethodDesc{
		{
			MethodName: "GetCampaignAudienceView",
			Handler:    _CampaignAudienceViewService_GetCampaignAudienceView_Handler,
		},
	},
	Streams:  []grpc.StreamDesc{},
	Metadata: "google/ads/googleads/v2/services/campaign_audience_view_service.proto",
}
