// Code generated by protoc-gen-go. DO NOT EDIT.
// source: google/ads/googleads/v2/resources/search_term_view.proto

package resources

import (
	fmt "fmt"
	math "math"

	proto "github.com/golang/protobuf/proto"
	wrappers "github.com/golang/protobuf/ptypes/wrappers"
	enums "google.golang.org/genproto/googleapis/ads/googleads/v2/enums"
	_ "google.golang.org/genproto/googleapis/api/annotations"
)

// Reference imports to suppress errors if they are not otherwise used.
var _ = proto.Marshal
var _ = fmt.Errorf
var _ = math.Inf

// This is a compile-time assertion to ensure that this generated file
// is compatible with the proto package it is being compiled against.
// A compilation error at this line likely means your copy of the
// proto package needs to be updated.
const _ = proto.ProtoPackageIsVersion3 // please upgrade the proto package

// A search term view with metrics aggregated by search term at the ad group
// level.
type SearchTermView struct {
	// The resource name of the search term view.
	// Search term view resource names have the form:
	//
	// `customers/{customer_id}/searchTermViews/{campaign_id}~{ad_group_id}~{URL-base64_search_term}`
	ResourceName string `protobuf:"bytes,1,opt,name=resource_name,json=resourceName,proto3" json:"resource_name,omitempty"`
	// The search term.
	SearchTerm *wrappers.StringValue `protobuf:"bytes,2,opt,name=search_term,json=searchTerm,proto3" json:"search_term,omitempty"`
	// The ad group the search term served in.
	AdGroup *wrappers.StringValue `protobuf:"bytes,3,opt,name=ad_group,json=adGroup,proto3" json:"ad_group,omitempty"`
	// Indicates whether the search term is currently one of your
	// targeted or excluded keywords.
	Status               enums.SearchTermTargetingStatusEnum_SearchTermTargetingStatus `protobuf:"varint,4,opt,name=status,proto3,enum=google.ads.googleads.v2.enums.SearchTermTargetingStatusEnum_SearchTermTargetingStatus" json:"status,omitempty"`
	XXX_NoUnkeyedLiteral struct{}                                                      `json:"-"`
	XXX_unrecognized     []byte                                                        `json:"-"`
	XXX_sizecache        int32                                                         `json:"-"`
}

func (m *SearchTermView) Reset()         { *m = SearchTermView{} }
func (m *SearchTermView) String() string { return proto.CompactTextString(m) }
func (*SearchTermView) ProtoMessage()    {}
func (*SearchTermView) Descriptor() ([]byte, []int) {
	return fileDescriptor_c10e074d81af5129, []int{0}
}

func (m *SearchTermView) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_SearchTermView.Unmarshal(m, b)
}
func (m *SearchTermView) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_SearchTermView.Marshal(b, m, deterministic)
}
func (m *SearchTermView) XXX_Merge(src proto.Message) {
	xxx_messageInfo_SearchTermView.Merge(m, src)
}
func (m *SearchTermView) XXX_Size() int {
	return xxx_messageInfo_SearchTermView.Size(m)
}
func (m *SearchTermView) XXX_DiscardUnknown() {
	xxx_messageInfo_SearchTermView.DiscardUnknown(m)
}

var xxx_messageInfo_SearchTermView proto.InternalMessageInfo

func (m *SearchTermView) GetResourceName() string {
	if m != nil {
		return m.ResourceName
	}
	return ""
}

func (m *SearchTermView) GetSearchTerm() *wrappers.StringValue {
	if m != nil {
		return m.SearchTerm
	}
	return nil
}

func (m *SearchTermView) GetAdGroup() *wrappers.StringValue {
	if m != nil {
		return m.AdGroup
	}
	return nil
}

func (m *SearchTermView) GetStatus() enums.SearchTermTargetingStatusEnum_SearchTermTargetingStatus {
	if m != nil {
		return m.Status
	}
	return enums.SearchTermTargetingStatusEnum_UNSPECIFIED
}

func init() {
	proto.RegisterType((*SearchTermView)(nil), "google.ads.googleads.v2.resources.SearchTermView")
}

func init() {
	proto.RegisterFile("google/ads/googleads/v2/resources/search_term_view.proto", fileDescriptor_c10e074d81af5129)
}

var fileDescriptor_c10e074d81af5129 = []byte{
	// 403 bytes of a gzipped FileDescriptorProto
	0x1f, 0x8b, 0x08, 0x00, 0x00, 0x00, 0x00, 0x00, 0x02, 0xff, 0x8c, 0x52, 0x4d, 0x6b, 0xe3, 0x30,
	0x10, 0xc5, 0xce, 0x92, 0xdd, 0x55, 0x76, 0x73, 0xf0, 0x5e, 0x4c, 0x08, 0x4b, 0xb2, 0x4b, 0x20,
	0x27, 0x19, 0xbc, 0x87, 0x2d, 0x2a, 0x85, 0x3a, 0x50, 0x02, 0x3d, 0x94, 0xe0, 0x04, 0x1f, 0x8a,
	0xc1, 0x28, 0xb1, 0xaa, 0x1a, 0x62, 0xc9, 0x48, 0x72, 0x72, 0xed, 0x1f, 0xe9, 0xa5, 0xc7, 0xfe,
	0x94, 0xfe, 0x94, 0xfe, 0x8a, 0xe2, 0x0f, 0xa9, 0xcd, 0x21, 0x6d, 0x6f, 0xcf, 0x9e, 0xf7, 0xe6,
	0xcd, 0x9b, 0x11, 0x38, 0xa1, 0x9c, 0xd3, 0x2d, 0xf1, 0x70, 0x2a, 0xbd, 0x06, 0x56, 0x68, 0xe7,
	0x7b, 0x82, 0x48, 0x5e, 0x8a, 0x0d, 0x91, 0x9e, 0x24, 0x58, 0x6c, 0x6e, 0x13, 0x45, 0x44, 0x9e,
	0xec, 0x32, 0xb2, 0x87, 0x85, 0xe0, 0x8a, 0x3b, 0xe3, 0x86, 0x0e, 0x71, 0x2a, 0xa1, 0x51, 0xc2,
	0x9d, 0x0f, 0x8d, 0x72, 0x70, 0x7e, 0xac, 0x39, 0x61, 0x65, 0x7e, 0xd8, 0x58, 0x61, 0x41, 0x89,
	0xca, 0x18, 0x4d, 0xa4, 0xc2, 0xaa, 0x94, 0x8d, 0xc9, 0xe0, 0x77, 0xdb, 0xa1, 0xfe, 0x5a, 0x97,
	0x37, 0xde, 0x5e, 0xe0, 0xa2, 0x20, 0x42, 0xd7, 0x87, 0xda, 0xa1, 0xc8, 0x3c, 0xcc, 0x18, 0x57,
	0x58, 0x65, 0x9c, 0xb5, 0xd5, 0x3f, 0xf7, 0x36, 0xe8, 0x2f, 0x6b, 0x93, 0x15, 0x11, 0x79, 0x94,
	0x91, 0xbd, 0xf3, 0x17, 0xfc, 0xd4, 0xf3, 0x25, 0x0c, 0xe7, 0xc4, 0xb5, 0x46, 0xd6, 0xf4, 0x7b,
	0xf8, 0x43, 0xff, 0xbc, 0xc2, 0x39, 0x71, 0xce, 0x40, 0xef, 0xcd, 0x6c, 0xae, 0x3d, 0xb2, 0xa6,
	0x3d, 0x7f, 0xd8, 0xa6, 0x84, 0x7a, 0x16, 0xb8, 0x54, 0x22, 0x63, 0x34, 0xc2, 0xdb, 0x92, 0x84,
	0x40, 0x1a, 0x1f, 0xe7, 0x3f, 0xf8, 0x86, 0xd3, 0x84, 0x0a, 0x5e, 0x16, 0x6e, 0xe7, 0x13, 0xda,
	0xaf, 0x38, 0x9d, 0x57, 0x64, 0x87, 0x81, 0x6e, 0x93, 0xde, 0xfd, 0x32, 0xb2, 0xa6, 0x7d, 0x3f,
	0x82, 0xc7, 0x76, 0x5c, 0x2f, 0x10, 0xbe, 0x66, 0x5b, 0xe9, 0xf5, 0x2d, 0x6b, 0xfd, 0x05, 0x2b,
	0xf3, 0xe3, 0xd5, 0xb0, 0x75, 0x99, 0xdd, 0xd9, 0x60, 0xb2, 0xe1, 0x39, 0xfc, 0xf0, 0x92, 0xb3,
	0x5f, 0x87, 0x6b, 0x5c, 0x54, 0x31, 0x16, 0xd6, 0xf5, 0x65, 0xab, 0xa4, 0x7c, 0x8b, 0x19, 0x85,
	0x5c, 0x50, 0x8f, 0x12, 0x56, 0x87, 0xd4, 0x07, 0x2f, 0x32, 0xf9, 0xce, 0xe3, 0x3a, 0x35, 0xe8,
	0xc1, 0xee, 0xcc, 0x83, 0xe0, 0xd1, 0x1e, 0xcf, 0x9b, 0x96, 0x41, 0x2a, 0x61, 0x03, 0x2b, 0x14,
	0xf9, 0x30, 0xd4, 0xcc, 0x27, 0xcd, 0x89, 0x83, 0x54, 0xc6, 0x86, 0x13, 0x47, 0x7e, 0x6c, 0x38,
	0xcf, 0xf6, 0xa4, 0x29, 0x20, 0x14, 0xa4, 0x12, 0x21, 0xc3, 0x42, 0x28, 0xf2, 0x11, 0x32, 0xbc,
	0x75, 0xb7, 0x1e, 0xf6, 0xdf, 0x4b, 0x00, 0x00, 0x00, 0xff, 0xff, 0x3c, 0xf7, 0x2e, 0x43, 0x08,
	0x03, 0x00, 0x00,
}
