// Code generated by protoc-gen-go. DO NOT EDIT.
// source: google/ads/googleads/v1/errors/string_format_error.proto

package errors

import (
	fmt "fmt"
	math "math"

	proto "github.com/golang/protobuf/proto"
	_ "google.golang.org/genproto/googleapis/api/annotations"
)

// Reference imports to suppress errors if they are not otherwise used.
var _ = proto.Marshal
var _ = fmt.Errorf
var _ = math.Inf

// This is a compile-time assertion to ensure that this generated file
// is compatible with the proto package it is being compiled against.
// A compilation error at this line likely means your copy of the
// proto package needs to be updated.
const _ = proto.ProtoPackageIsVersion3 // please upgrade the proto package

// Enum describing possible string format errors.
type StringFormatErrorEnum_StringFormatError int32

const (
	// Enum unspecified.
	StringFormatErrorEnum_UNSPECIFIED StringFormatErrorEnum_StringFormatError = 0
	// The received error code is not known in this version.
	StringFormatErrorEnum_UNKNOWN StringFormatErrorEnum_StringFormatError = 1
	// The input string value contains disallowed characters.
	StringFormatErrorEnum_ILLEGAL_CHARS StringFormatErrorEnum_StringFormatError = 2
	// The input string value is invalid for the associated field.
	StringFormatErrorEnum_INVALID_FORMAT StringFormatErrorEnum_StringFormatError = 3
)

var StringFormatErrorEnum_StringFormatError_name = map[int32]string{
	0: "UNSPECIFIED",
	1: "UNKNOWN",
	2: "ILLEGAL_CHARS",
	3: "INVALID_FORMAT",
}

var StringFormatErrorEnum_StringFormatError_value = map[string]int32{
	"UNSPECIFIED":    0,
	"UNKNOWN":        1,
	"ILLEGAL_CHARS":  2,
	"INVALID_FORMAT": 3,
}

func (x StringFormatErrorEnum_StringFormatError) String() string {
	return proto.EnumName(StringFormatErrorEnum_StringFormatError_name, int32(x))
}

func (StringFormatErrorEnum_StringFormatError) EnumDescriptor() ([]byte, []int) {
	return fileDescriptor_8ce65d4b86eec262, []int{0, 0}
}

// Container for enum describing possible string format errors.
type StringFormatErrorEnum struct {
	XXX_NoUnkeyedLiteral struct{} `json:"-"`
	XXX_unrecognized     []byte   `json:"-"`
	XXX_sizecache        int32    `json:"-"`
}

func (m *StringFormatErrorEnum) Reset()         { *m = StringFormatErrorEnum{} }
func (m *StringFormatErrorEnum) String() string { return proto.CompactTextString(m) }
func (*StringFormatErrorEnum) ProtoMessage()    {}
func (*StringFormatErrorEnum) Descriptor() ([]byte, []int) {
	return fileDescriptor_8ce65d4b86eec262, []int{0}
}

func (m *StringFormatErrorEnum) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_StringFormatErrorEnum.Unmarshal(m, b)
}
func (m *StringFormatErrorEnum) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_StringFormatErrorEnum.Marshal(b, m, deterministic)
}
func (m *StringFormatErrorEnum) XXX_Merge(src proto.Message) {
	xxx_messageInfo_StringFormatErrorEnum.Merge(m, src)
}
func (m *StringFormatErrorEnum) XXX_Size() int {
	return xxx_messageInfo_StringFormatErrorEnum.Size(m)
}
func (m *StringFormatErrorEnum) XXX_DiscardUnknown() {
	xxx_messageInfo_StringFormatErrorEnum.DiscardUnknown(m)
}

var xxx_messageInfo_StringFormatErrorEnum proto.InternalMessageInfo

func init() {
	proto.RegisterEnum("google.ads.googleads.v1.errors.StringFormatErrorEnum_StringFormatError", StringFormatErrorEnum_StringFormatError_name, StringFormatErrorEnum_StringFormatError_value)
	proto.RegisterType((*StringFormatErrorEnum)(nil), "google.ads.googleads.v1.errors.StringFormatErrorEnum")
}

func init() {
	proto.RegisterFile("google/ads/googleads/v1/errors/string_format_error.proto", fileDescriptor_8ce65d4b86eec262)
}

var fileDescriptor_8ce65d4b86eec262 = []byte{
	// 318 bytes of a gzipped FileDescriptorProto
	0x1f, 0x8b, 0x08, 0x00, 0x00, 0x00, 0x00, 0x00, 0x02, 0xff, 0x7c, 0x90, 0xc1, 0x4a, 0xc3, 0x30,
	0x1c, 0xc6, 0x5d, 0x07, 0x0a, 0x19, 0x6a, 0x17, 0xd0, 0x83, 0xc8, 0x0e, 0x7d, 0x80, 0x84, 0xe2,
	0x45, 0xe2, 0x29, 0xdb, 0xba, 0x59, 0xac, 0xdd, 0xd8, 0x5c, 0x15, 0x29, 0x94, 0x68, 0x67, 0x28,
	0x6c, 0xc9, 0x4c, 0xea, 0x1e, 0xc8, 0xa3, 0x8f, 0xe2, 0xa3, 0x78, 0xf3, 0x0d, 0xa4, 0x89, 0xed,
	0x65, 0xe8, 0xa9, 0x1f, 0xff, 0xfe, 0xbe, 0xef, 0xff, 0xe5, 0x0f, 0x2e, 0xb9, 0x94, 0x7c, 0xb5,
	0xc4, 0x2c, 0xd7, 0xd8, 0xca, 0x4a, 0x6d, 0x7d, 0xbc, 0x54, 0x4a, 0x2a, 0x8d, 0x75, 0xa9, 0x0a,
	0xc1, 0xb3, 0x17, 0xa9, 0xd6, 0xac, 0xcc, 0xcc, 0x10, 0x6d, 0x94, 0x2c, 0x25, 0xec, 0x59, 0x1c,
	0xb1, 0x5c, 0xa3, 0xc6, 0x89, 0xb6, 0x3e, 0xb2, 0xce, 0xb3, 0xf3, 0x3a, 0x79, 0x53, 0x60, 0x26,
	0x84, 0x2c, 0x59, 0x59, 0x48, 0xa1, 0xad, 0xdb, 0x7b, 0x05, 0x27, 0x73, 0x13, 0x3d, 0x32, 0xc9,
	0x41, 0xe5, 0x09, 0xc4, 0xdb, 0xda, 0x7b, 0x00, 0xdd, 0x9d, 0x1f, 0xf0, 0x18, 0x74, 0x16, 0xf1,
	0x7c, 0x1a, 0x0c, 0xc2, 0x51, 0x18, 0x0c, 0xdd, 0x3d, 0xd8, 0x01, 0x07, 0x8b, 0xf8, 0x26, 0x9e,
	0xdc, 0xc7, 0x6e, 0x0b, 0x76, 0xc1, 0x61, 0x18, 0x45, 0xc1, 0x98, 0x46, 0xd9, 0xe0, 0x9a, 0xce,
	0xe6, 0xae, 0x03, 0x21, 0x38, 0x0a, 0xe3, 0x84, 0x46, 0xe1, 0x30, 0x1b, 0x4d, 0x66, 0xb7, 0xf4,
	0xce, 0x6d, 0xf7, 0xbf, 0x5b, 0xc0, 0x7b, 0x96, 0x6b, 0xf4, 0x7f, 0xef, 0xfe, 0xe9, 0xce, 0xfa,
	0x69, 0xd5, 0x78, 0xda, 0x7a, 0x1c, 0xfe, 0x3a, 0xb9, 0x5c, 0x31, 0xc1, 0x91, 0x54, 0x1c, 0xf3,
	0xa5, 0x30, 0xef, 0xa9, 0x6f, 0xb7, 0x29, 0xf4, 0x5f, 0xa7, 0xbc, 0xb2, 0x9f, 0x77, 0xa7, 0x3d,
	0xa6, 0xf4, 0xc3, 0xe9, 0x8d, 0x6d, 0x18, 0xcd, 0x35, 0xb2, 0xb2, 0x52, 0x89, 0x8f, 0xcc, 0x4a,
	0xfd, 0x59, 0x03, 0x29, 0xcd, 0x75, 0xda, 0x00, 0x69, 0xe2, 0xa7, 0x16, 0xf8, 0x72, 0x3c, 0x3b,
	0x25, 0x84, 0xe6, 0x9a, 0x90, 0x06, 0x21, 0x24, 0xf1, 0x09, 0xb1, 0xd0, 0xd3, 0xbe, 0x69, 0x77,
	0xf1, 0x13, 0x00, 0x00, 0xff, 0xff, 0xb4, 0x40, 0x90, 0x0d, 0xe7, 0x01, 0x00, 0x00,
}
