// Code generated by protoc-gen-go. DO NOT EDIT.
// source: google/ads/googleads/v2/enums/time_type.proto

package enums

import (
	fmt "fmt"
	math "math"

	proto "github.com/golang/protobuf/proto"
	_ "google.golang.org/genproto/googleapis/api/annotations"
)

// Reference imports to suppress errors if they are not otherwise used.
var _ = proto.Marshal
var _ = fmt.Errorf
var _ = math.Inf

// This is a compile-time assertion to ensure that this generated file
// is compatible with the proto package it is being compiled against.
// A compilation error at this line likely means your copy of the
// proto package needs to be updated.
const _ = proto.ProtoPackageIsVersion3 // please upgrade the proto package

// The possible time types used by certain resources as an alternative to
// absolute timestamps.
type TimeTypeEnum_TimeType int32

const (
	// Not specified.
	TimeTypeEnum_UNSPECIFIED TimeTypeEnum_TimeType = 0
	// Used for return value only. Represents value unknown in this version.
	TimeTypeEnum_UNKNOWN TimeTypeEnum_TimeType = 1
	// As soon as possible.
	TimeTypeEnum_NOW TimeTypeEnum_TimeType = 2
	// An infinite point in the future.
	TimeTypeEnum_FOREVER TimeTypeEnum_TimeType = 3
)

var TimeTypeEnum_TimeType_name = map[int32]string{
	0: "UNSPECIFIED",
	1: "UNKNOWN",
	2: "NOW",
	3: "FOREVER",
}

var TimeTypeEnum_TimeType_value = map[string]int32{
	"UNSPECIFIED": 0,
	"UNKNOWN":     1,
	"NOW":         2,
	"FOREVER":     3,
}

func (x TimeTypeEnum_TimeType) String() string {
	return proto.EnumName(TimeTypeEnum_TimeType_name, int32(x))
}

func (TimeTypeEnum_TimeType) EnumDescriptor() ([]byte, []int) {
	return fileDescriptor_e72f15c04c2348fd, []int{0, 0}
}

// Message describing time types.
type TimeTypeEnum struct {
	XXX_NoUnkeyedLiteral struct{} `json:"-"`
	XXX_unrecognized     []byte   `json:"-"`
	XXX_sizecache        int32    `json:"-"`
}

func (m *TimeTypeEnum) Reset()         { *m = TimeTypeEnum{} }
func (m *TimeTypeEnum) String() string { return proto.CompactTextString(m) }
func (*TimeTypeEnum) ProtoMessage()    {}
func (*TimeTypeEnum) Descriptor() ([]byte, []int) {
	return fileDescriptor_e72f15c04c2348fd, []int{0}
}

func (m *TimeTypeEnum) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_TimeTypeEnum.Unmarshal(m, b)
}
func (m *TimeTypeEnum) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_TimeTypeEnum.Marshal(b, m, deterministic)
}
func (m *TimeTypeEnum) XXX_Merge(src proto.Message) {
	xxx_messageInfo_TimeTypeEnum.Merge(m, src)
}
func (m *TimeTypeEnum) XXX_Size() int {
	return xxx_messageInfo_TimeTypeEnum.Size(m)
}
func (m *TimeTypeEnum) XXX_DiscardUnknown() {
	xxx_messageInfo_TimeTypeEnum.DiscardUnknown(m)
}

var xxx_messageInfo_TimeTypeEnum proto.InternalMessageInfo

func init() {
	proto.RegisterEnum("google.ads.googleads.v2.enums.TimeTypeEnum_TimeType", TimeTypeEnum_TimeType_name, TimeTypeEnum_TimeType_value)
	proto.RegisterType((*TimeTypeEnum)(nil), "google.ads.googleads.v2.enums.TimeTypeEnum")
}

func init() {
	proto.RegisterFile("google/ads/googleads/v2/enums/time_type.proto", fileDescriptor_e72f15c04c2348fd)
}

var fileDescriptor_e72f15c04c2348fd = []byte{
	// 294 bytes of a gzipped FileDescriptorProto
	0x1f, 0x8b, 0x08, 0x00, 0x00, 0x00, 0x00, 0x00, 0x02, 0xff, 0x7c, 0x90, 0xc1, 0x4a, 0xc3, 0x30,
	0x18, 0xc7, 0x6d, 0x0b, 0x4e, 0x32, 0xc5, 0xd2, 0xa3, 0xb8, 0xc3, 0x76, 0x37, 0x81, 0x7a, 0x8b,
	0x20, 0xb4, 0xda, 0x8d, 0x21, 0xa4, 0x65, 0x6e, 0x1d, 0x48, 0x41, 0xaa, 0x0d, 0xa1, 0xb0, 0x26,
	0x65, 0xe9, 0x06, 0x7b, 0x1d, 0x8f, 0x3e, 0x8a, 0x8f, 0xe1, 0xd1, 0xa7, 0x90, 0x24, 0xa6, 0x37,
	0x77, 0x09, 0xff, 0x7c, 0xff, 0x5f, 0xbe, 0xfc, 0xbf, 0x0f, 0xdc, 0x30, 0x21, 0xd8, 0x86, 0xa2,
	0xb2, 0x92, 0xc8, 0x48, 0xa5, 0xf6, 0x21, 0xa2, 0x7c, 0xd7, 0x48, 0xd4, 0xd5, 0x0d, 0x7d, 0xed,
	0x0e, 0x2d, 0x85, 0xed, 0x56, 0x74, 0x22, 0x18, 0x19, 0x06, 0x96, 0x95, 0x84, 0x3d, 0x0e, 0xf7,
	0x21, 0xd4, 0xf8, 0xd5, 0xb5, 0xed, 0xd6, 0xd6, 0xa8, 0xe4, 0x5c, 0x74, 0x65, 0x57, 0x0b, 0x2e,
	0xcd, 0xe3, 0x09, 0x01, 0xe7, 0xcb, 0xba, 0xa1, 0xcb, 0x43, 0x4b, 0x13, 0xbe, 0x6b, 0x26, 0xf7,
	0xe0, 0xcc, 0xde, 0x83, 0x4b, 0x30, 0x5c, 0x91, 0xe7, 0x2c, 0x79, 0x98, 0x4f, 0xe7, 0xc9, 0xa3,
	0x7f, 0x12, 0x0c, 0xc1, 0x60, 0x45, 0x9e, 0x48, 0xba, 0x26, 0xbe, 0x13, 0x0c, 0x80, 0x47, 0xd2,
	0xb5, 0xef, 0xaa, 0xea, 0x34, 0x5d, 0x24, 0x79, 0xb2, 0xf0, 0xbd, 0xf8, 0xdb, 0x01, 0xe3, 0x77,
	0xd1, 0xc0, 0xa3, 0x99, 0xe2, 0x0b, 0xfb, 0x47, 0xa6, 0x42, 0x64, 0xce, 0x4b, 0xfc, 0xc7, 0x33,
	0xb1, 0x29, 0x39, 0x83, 0x62, 0xcb, 0x10, 0xa3, 0x5c, 0x47, 0xb4, 0x2b, 0x68, 0x6b, 0xf9, 0xcf,
	0x46, 0xee, 0xf4, 0xf9, 0xe1, 0x7a, 0xb3, 0x28, 0xfa, 0x74, 0x47, 0x33, 0xd3, 0x2a, 0xaa, 0x24,
	0x34, 0x52, 0xa9, 0x3c, 0x84, 0x6a, 0x3e, 0xf9, 0x65, 0xfd, 0x22, 0xaa, 0x64, 0xd1, 0xfb, 0x45,
	0x1e, 0x16, 0xda, 0xff, 0x71, 0xc7, 0xa6, 0x88, 0x71, 0x54, 0x49, 0x8c, 0x7b, 0x02, 0xe3, 0x3c,
	0xc4, 0x58, 0x33, 0x6f, 0xa7, 0x3a, 0xd8, 0xed, 0x6f, 0x00, 0x00, 0x00, 0xff, 0xff, 0x01, 0x6e,
	0x0a, 0x9a, 0xa9, 0x01, 0x00, 0x00,
}
