// Code generated by protoc-gen-go. DO NOT EDIT.
// source: google/cloud/automl/v1beta1/annotation_payload.proto

package automl

import (
	fmt "fmt"
	math "math"

	proto "github.com/golang/protobuf/proto"
	_ "github.com/golang/protobuf/ptypes/any"
	_ "google.golang.org/genproto/googleapis/api/annotations"
)

// Reference imports to suppress errors if they are not otherwise used.
var _ = proto.Marshal
var _ = fmt.Errorf
var _ = math.Inf

// This is a compile-time assertion to ensure that this generated file
// is compatible with the proto package it is being compiled against.
// A compilation error at this line likely means your copy of the
// proto package needs to be updated.
const _ = proto.ProtoPackageIsVersion3 // please upgrade the proto package

// Contains annotation information that is relevant to AutoML.
type AnnotationPayload struct {
	// Output only . Additional information about the annotation
	// specific to the AutoML domain.
	//
	// Types that are valid to be assigned to Detail:
	//	*AnnotationPayload_Translation
	//	*AnnotationPayload_Classification
	//	*AnnotationPayload_ImageObjectDetection
	//	*AnnotationPayload_VideoClassification
	//	*AnnotationPayload_VideoObjectTracking
	//	*AnnotationPayload_TextExtraction
	//	*AnnotationPayload_TextSentiment
	//	*AnnotationPayload_Tables
	Detail isAnnotationPayload_Detail `protobuf_oneof:"detail"`
	// Output only . The resource ID of the annotation spec that
	// this annotation pertains to. The annotation spec comes from either an
	// ancestor dataset, or the dataset that was used to train the model in use.
	AnnotationSpecId string `protobuf:"bytes,1,opt,name=annotation_spec_id,json=annotationSpecId,proto3" json:"annotation_spec_id,omitempty"`
	// Output only. The value of
	// [display_name][google.cloud.automl.v1beta1.AnnotationSpec.display_name]
	// when the model was trained. Because this field returns a value at model
	// training time, for different models trained using the same dataset, the
	// returned value could be different as model owner could update the
	// `display_name` between any two model training.
	DisplayName          string   `protobuf:"bytes,5,opt,name=display_name,json=displayName,proto3" json:"display_name,omitempty"`
	XXX_NoUnkeyedLiteral struct{} `json:"-"`
	XXX_unrecognized     []byte   `json:"-"`
	XXX_sizecache        int32    `json:"-"`
}

func (m *AnnotationPayload) Reset()         { *m = AnnotationPayload{} }
func (m *AnnotationPayload) String() string { return proto.CompactTextString(m) }
func (*AnnotationPayload) ProtoMessage()    {}
func (*AnnotationPayload) Descriptor() ([]byte, []int) {
	return fileDescriptor_cb8fb684261d0460, []int{0}
}

func (m *AnnotationPayload) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_AnnotationPayload.Unmarshal(m, b)
}
func (m *AnnotationPayload) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_AnnotationPayload.Marshal(b, m, deterministic)
}
func (m *AnnotationPayload) XXX_Merge(src proto.Message) {
	xxx_messageInfo_AnnotationPayload.Merge(m, src)
}
func (m *AnnotationPayload) XXX_Size() int {
	return xxx_messageInfo_AnnotationPayload.Size(m)
}
func (m *AnnotationPayload) XXX_DiscardUnknown() {
	xxx_messageInfo_AnnotationPayload.DiscardUnknown(m)
}

var xxx_messageInfo_AnnotationPayload proto.InternalMessageInfo

type isAnnotationPayload_Detail interface {
	isAnnotationPayload_Detail()
}

type AnnotationPayload_Translation struct {
	Translation *TranslationAnnotation `protobuf:"bytes,2,opt,name=translation,proto3,oneof"`
}

type AnnotationPayload_Classification struct {
	Classification *ClassificationAnnotation `protobuf:"bytes,3,opt,name=classification,proto3,oneof"`
}

type AnnotationPayload_ImageObjectDetection struct {
	ImageObjectDetection *ImageObjectDetectionAnnotation `protobuf:"bytes,4,opt,name=image_object_detection,json=imageObjectDetection,proto3,oneof"`
}

type AnnotationPayload_VideoClassification struct {
	VideoClassification *VideoClassificationAnnotation `protobuf:"bytes,9,opt,name=video_classification,json=videoClassification,proto3,oneof"`
}

type AnnotationPayload_VideoObjectTracking struct {
	VideoObjectTracking *VideoObjectTrackingAnnotation `protobuf:"bytes,8,opt,name=video_object_tracking,json=videoObjectTracking,proto3,oneof"`
}

type AnnotationPayload_TextExtraction struct {
	TextExtraction *TextExtractionAnnotation `protobuf:"bytes,6,opt,name=text_extraction,json=textExtraction,proto3,oneof"`
}

type AnnotationPayload_TextSentiment struct {
	TextSentiment *TextSentimentAnnotation `protobuf:"bytes,7,opt,name=text_sentiment,json=textSentiment,proto3,oneof"`
}

type AnnotationPayload_Tables struct {
	Tables *TablesAnnotation `protobuf:"bytes,10,opt,name=tables,proto3,oneof"`
}

func (*AnnotationPayload_Translation) isAnnotationPayload_Detail() {}

func (*AnnotationPayload_Classification) isAnnotationPayload_Detail() {}

func (*AnnotationPayload_ImageObjectDetection) isAnnotationPayload_Detail() {}

func (*AnnotationPayload_VideoClassification) isAnnotationPayload_Detail() {}

func (*AnnotationPayload_VideoObjectTracking) isAnnotationPayload_Detail() {}

func (*AnnotationPayload_TextExtraction) isAnnotationPayload_Detail() {}

func (*AnnotationPayload_TextSentiment) isAnnotationPayload_Detail() {}

func (*AnnotationPayload_Tables) isAnnotationPayload_Detail() {}

func (m *AnnotationPayload) GetDetail() isAnnotationPayload_Detail {
	if m != nil {
		return m.Detail
	}
	return nil
}

func (m *AnnotationPayload) GetTranslation() *TranslationAnnotation {
	if x, ok := m.GetDetail().(*AnnotationPayload_Translation); ok {
		return x.Translation
	}
	return nil
}

func (m *AnnotationPayload) GetClassification() *ClassificationAnnotation {
	if x, ok := m.GetDetail().(*AnnotationPayload_Classification); ok {
		return x.Classification
	}
	return nil
}

func (m *AnnotationPayload) GetImageObjectDetection() *ImageObjectDetectionAnnotation {
	if x, ok := m.GetDetail().(*AnnotationPayload_ImageObjectDetection); ok {
		return x.ImageObjectDetection
	}
	return nil
}

func (m *AnnotationPayload) GetVideoClassification() *VideoClassificationAnnotation {
	if x, ok := m.GetDetail().(*AnnotationPayload_VideoClassification); ok {
		return x.VideoClassification
	}
	return nil
}

func (m *AnnotationPayload) GetVideoObjectTracking() *VideoObjectTrackingAnnotation {
	if x, ok := m.GetDetail().(*AnnotationPayload_VideoObjectTracking); ok {
		return x.VideoObjectTracking
	}
	return nil
}

func (m *AnnotationPayload) GetTextExtraction() *TextExtractionAnnotation {
	if x, ok := m.GetDetail().(*AnnotationPayload_TextExtraction); ok {
		return x.TextExtraction
	}
	return nil
}

func (m *AnnotationPayload) GetTextSentiment() *TextSentimentAnnotation {
	if x, ok := m.GetDetail().(*AnnotationPayload_TextSentiment); ok {
		return x.TextSentiment
	}
	return nil
}

func (m *AnnotationPayload) GetTables() *TablesAnnotation {
	if x, ok := m.GetDetail().(*AnnotationPayload_Tables); ok {
		return x.Tables
	}
	return nil
}

func (m *AnnotationPayload) GetAnnotationSpecId() string {
	if m != nil {
		return m.AnnotationSpecId
	}
	return ""
}

func (m *AnnotationPayload) GetDisplayName() string {
	if m != nil {
		return m.DisplayName
	}
	return ""
}

// XXX_OneofWrappers is for the internal use of the proto package.
func (*AnnotationPayload) XXX_OneofWrappers() []interface{} {
	return []interface{}{
		(*AnnotationPayload_Translation)(nil),
		(*AnnotationPayload_Classification)(nil),
		(*AnnotationPayload_ImageObjectDetection)(nil),
		(*AnnotationPayload_VideoClassification)(nil),
		(*AnnotationPayload_VideoObjectTracking)(nil),
		(*AnnotationPayload_TextExtraction)(nil),
		(*AnnotationPayload_TextSentiment)(nil),
		(*AnnotationPayload_Tables)(nil),
	}
}

func init() {
	proto.RegisterType((*AnnotationPayload)(nil), "google.cloud.automl.v1beta1.AnnotationPayload")
}

func init() {
	proto.RegisterFile("google/cloud/automl/v1beta1/annotation_payload.proto", fileDescriptor_cb8fb684261d0460)
}

var fileDescriptor_cb8fb684261d0460 = []byte{
	// 540 bytes of a gzipped FileDescriptorProto
	0x1f, 0x8b, 0x08, 0x00, 0x00, 0x00, 0x00, 0x00, 0x02, 0xff, 0x8c, 0x94, 0xdf, 0x6e, 0xd3, 0x30,
	0x18, 0xc5, 0x69, 0x81, 0x6e, 0x73, 0x61, 0x80, 0x19, 0x28, 0x6c, 0x08, 0x06, 0x57, 0x95, 0x60,
	0xc9, 0x3a, 0xc6, 0x4d, 0x76, 0xd5, 0x0d, 0x34, 0x26, 0xf1, 0x67, 0xda, 0xaa, 0x5e, 0xa0, 0xa2,
	0xe0, 0x24, 0xdf, 0x22, 0x83, 0x63, 0x47, 0x8d, 0x5b, 0xb5, 0x8f, 0xc0, 0x83, 0xf0, 0x32, 0x3c,
	0x0a, 0x4f, 0x81, 0x6a, 0x7b, 0x6d, 0x5c, 0x2a, 0x6f, 0x97, 0xc9, 0x39, 0xbf, 0x73, 0xfa, 0xf5,
	0x8b, 0x8d, 0xf6, 0x33, 0x21, 0x32, 0x06, 0x41, 0xc2, 0xc4, 0x30, 0x0d, 0xc8, 0x50, 0x8a, 0x9c,
	0x05, 0xa3, 0x76, 0x0c, 0x92, 0xb4, 0x03, 0xc2, 0xb9, 0x90, 0x44, 0x52, 0xc1, 0xa3, 0x82, 0x4c,
	0x98, 0x20, 0xa9, 0x5f, 0x0c, 0x84, 0x14, 0x78, 0x4b, 0x53, 0xbe, 0xa2, 0x7c, 0x4d, 0xf9, 0x86,
	0xda, 0xdc, 0x75, 0x45, 0x26, 0x8c, 0x94, 0x25, 0xbd, 0xa0, 0x89, 0x8a, 0xd5, 0x71, 0x9b, 0xaf,
	0x5c, 0x44, 0x0a, 0x12, 0x92, 0x8a, 0xb9, 0xe5, 0x32, 0x4b, 0x12, 0x33, 0x28, 0x8d, 0xb3, 0xed,
	0x74, 0xc2, 0x58, 0x46, 0x30, 0x96, 0x03, 0x52, 0x0d, 0xdf, 0xbd, 0x12, 0x29, 0x81, 0x4b, 0x9a,
	0x03, 0x97, 0x86, 0xd8, 0x71, 0x12, 0x03, 0xc2, 0x4b, 0x56, 0x1d, 0xf5, 0x89, 0xb1, 0xab, 0xa7,
	0x78, 0x78, 0x11, 0x10, 0x3e, 0x31, 0xd2, 0x53, 0x23, 0x91, 0x82, 0x56, 0xfe, 0x79, 0x33, 0xcc,
	0xcb, 0x5f, 0x2b, 0xe8, 0x41, 0x67, 0xf6, 0xf6, 0x54, 0xaf, 0x03, 0xf7, 0x50, 0xb3, 0xd2, 0xe1,
	0xd5, 0xb7, 0x6b, 0xad, 0xe6, 0xde, 0x9e, 0xef, 0x58, 0x8f, 0xdf, 0x9d, 0xfb, 0xe7, 0x79, 0x1f,
	0x6e, 0x9c, 0x55, 0x83, 0x70, 0x84, 0xd6, 0xed, 0x4d, 0x79, 0x37, 0x55, 0xf4, 0x5b, 0x67, 0xf4,
	0x91, 0x85, 0x58, 0xe9, 0x0b, 0x71, 0xb8, 0x44, 0x8f, 0x69, 0x4e, 0x32, 0x88, 0x44, 0xfc, 0x03,
	0x12, 0x19, 0xcd, 0xb6, 0xec, 0xdd, 0x52, 0x45, 0x07, 0xce, 0xa2, 0x93, 0x29, 0xfa, 0x45, 0x91,
	0xef, 0x2e, 0x41, 0xab, 0x6e, 0x83, 0x2e, 0x71, 0x60, 0x81, 0x36, 0x46, 0x34, 0x05, 0x11, 0x2d,
	0xcc, 0xb6, 0xa6, 0x2a, 0x43, 0x67, 0x65, 0x6f, 0x0a, 0x3a, 0x06, 0x7c, 0x38, 0xfa, 0xdf, 0x80,
	0x0b, 0xf4, 0x48, 0x17, 0x9a, 0x29, 0xa7, 0x5f, 0xdb, 0x4f, 0xca, 0x33, 0x6f, 0xf5, 0xba, 0x8d,
	0x7a, 0x84, 0xae, 0xe1, 0x96, 0x34, 0xda, 0x06, 0xfc, 0x1d, 0xdd, 0x5b, 0xf8, 0xb2, 0xbd, 0xc6,
	0x35, 0x36, 0xd7, 0x85, 0xb1, 0x7c, 0x3f, 0x43, 0xec, 0xcd, 0x49, 0x4b, 0xc3, 0xdf, 0xd0, 0xba,
	0x7d, 0x10, 0xbc, 0x15, 0x55, 0xb0, 0x7f, 0x65, 0xc1, 0xf9, 0x25, 0x61, 0xe5, 0xdf, 0x95, 0x55,
	0x09, 0x1f, 0xa3, 0x86, 0x3e, 0xc4, 0x1e, 0x52, 0xb1, 0x3b, 0xee, 0x58, 0x65, 0xb5, 0xf2, 0x0c,
	0x8e, 0x5f, 0x23, 0x5c, 0xb9, 0xbf, 0xca, 0x02, 0x92, 0x88, 0xa6, 0x5e, 0x6d, 0xbb, 0xd6, 0x5a,
	0x3b, 0xbb, 0x3f, 0x57, 0xce, 0x0b, 0x48, 0x4e, 0x52, 0xfc, 0x02, 0xdd, 0x49, 0x69, 0x59, 0x30,
	0x32, 0x89, 0x38, 0xc9, 0xc1, 0xbb, 0xad, 0x7c, 0x4d, 0xf3, 0xee, 0x33, 0xc9, 0xe1, 0x70, 0x15,
	0x35, 0x52, 0x90, 0x84, 0xb2, 0xc3, 0xdf, 0x35, 0xf4, 0x3c, 0x11, 0xb9, 0xeb, 0x97, 0x9d, 0xd6,
	0xbe, 0x76, 0x8c, 0x9c, 0x09, 0x46, 0x78, 0xe6, 0x8b, 0x41, 0x16, 0x64, 0xc0, 0xd5, 0x69, 0x0e,
	0xb4, 0x44, 0x0a, 0x5a, 0x2e, 0xbd, 0x38, 0x0e, 0xf4, 0xe3, 0x9f, 0xfa, 0xd6, 0xb1, 0x32, 0xf6,
	0x8f, 0xa6, 0xa6, 0x7e, 0x67, 0x28, 0xc5, 0x27, 0xd6, 0xef, 0x69, 0xd3, 0xdf, 0xfa, 0x33, 0xad,
	0x86, 0xa1, 0x92, 0xc3, 0x50, 0xe9, 0x1f, 0xc3, 0xd0, 0x18, 0xe2, 0x86, 0x2a, 0x7b, 0xf3, 0x2f,
	0x00, 0x00, 0xff, 0xff, 0xc1, 0xf1, 0x53, 0xbb, 0xe5, 0x05, 0x00, 0x00,
}
