// Code generated by protoc-gen-go. DO NOT EDIT.
// source: google/ads/googleads/v1/resources/bidding_strategy.proto

package resources

import (
	fmt "fmt"
	math "math"

	proto "github.com/golang/protobuf/proto"
	wrappers "github.com/golang/protobuf/ptypes/wrappers"
	common "google.golang.org/genproto/googleapis/ads/googleads/v1/common"
	enums "google.golang.org/genproto/googleapis/ads/googleads/v1/enums"
	_ "google.golang.org/genproto/googleapis/api/annotations"
)

// Reference imports to suppress errors if they are not otherwise used.
var _ = proto.Marshal
var _ = fmt.Errorf
var _ = math.Inf

// This is a compile-time assertion to ensure that this generated file
// is compatible with the proto package it is being compiled against.
// A compilation error at this line likely means your copy of the
// proto package needs to be updated.
const _ = proto.ProtoPackageIsVersion3 // please upgrade the proto package

// A bidding strategy.
type BiddingStrategy struct {
	// The resource name of the bidding strategy.
	// Bidding strategy resource names have the form:
	//
	// `customers/{customer_id}/biddingStrategies/{bidding_strategy_id}`
	ResourceName string `protobuf:"bytes,1,opt,name=resource_name,json=resourceName,proto3" json:"resource_name,omitempty"`
	// The ID of the bidding strategy.
	Id *wrappers.Int64Value `protobuf:"bytes,3,opt,name=id,proto3" json:"id,omitempty"`
	// The name of the bidding strategy.
	// All bidding strategies within an account must be named distinctly.
	//
	// The length of this string should be between 1 and 255, inclusive,
	// in UTF-8 bytes, (trimmed).
	Name *wrappers.StringValue `protobuf:"bytes,4,opt,name=name,proto3" json:"name,omitempty"`
	// The status of the bidding strategy.
	//
	// This field is read-only.
	Status enums.BiddingStrategyStatusEnum_BiddingStrategyStatus `protobuf:"varint,15,opt,name=status,proto3,enum=google.ads.googleads.v1.enums.BiddingStrategyStatusEnum_BiddingStrategyStatus" json:"status,omitempty"`
	// The type of the bidding strategy.
	// Create a bidding strategy by setting the bidding scheme.
	//
	// This field is read-only.
	Type enums.BiddingStrategyTypeEnum_BiddingStrategyType `protobuf:"varint,5,opt,name=type,proto3,enum=google.ads.googleads.v1.enums.BiddingStrategyTypeEnum_BiddingStrategyType" json:"type,omitempty"`
	// The number of campaigns attached to this bidding strategy.
	//
	// This field is read-only.
	CampaignCount *wrappers.Int64Value `protobuf:"bytes,13,opt,name=campaign_count,json=campaignCount,proto3" json:"campaign_count,omitempty"`
	// The number of non-removed campaigns attached to this bidding strategy.
	//
	// This field is read-only.
	NonRemovedCampaignCount *wrappers.Int64Value `protobuf:"bytes,14,opt,name=non_removed_campaign_count,json=nonRemovedCampaignCount,proto3" json:"non_removed_campaign_count,omitempty"`
	// The bidding scheme.
	//
	// Only one can be set.
	//
	// Types that are valid to be assigned to Scheme:
	//	*BiddingStrategy_EnhancedCpc
	//	*BiddingStrategy_PageOnePromoted
	//	*BiddingStrategy_TargetCpa
	//	*BiddingStrategy_TargetImpressionShare
	//	*BiddingStrategy_TargetOutrankShare
	//	*BiddingStrategy_TargetRoas
	//	*BiddingStrategy_TargetSpend
	Scheme               isBiddingStrategy_Scheme `protobuf_oneof:"scheme"`
	XXX_NoUnkeyedLiteral struct{}                 `json:"-"`
	XXX_unrecognized     []byte                   `json:"-"`
	XXX_sizecache        int32                    `json:"-"`
}

func (m *BiddingStrategy) Reset()         { *m = BiddingStrategy{} }
func (m *BiddingStrategy) String() string { return proto.CompactTextString(m) }
func (*BiddingStrategy) ProtoMessage()    {}
func (*BiddingStrategy) Descriptor() ([]byte, []int) {
	return fileDescriptor_45db3d8386a3943d, []int{0}
}

func (m *BiddingStrategy) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_BiddingStrategy.Unmarshal(m, b)
}
func (m *BiddingStrategy) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_BiddingStrategy.Marshal(b, m, deterministic)
}
func (m *BiddingStrategy) XXX_Merge(src proto.Message) {
	xxx_messageInfo_BiddingStrategy.Merge(m, src)
}
func (m *BiddingStrategy) XXX_Size() int {
	return xxx_messageInfo_BiddingStrategy.Size(m)
}
func (m *BiddingStrategy) XXX_DiscardUnknown() {
	xxx_messageInfo_BiddingStrategy.DiscardUnknown(m)
}

var xxx_messageInfo_BiddingStrategy proto.InternalMessageInfo

func (m *BiddingStrategy) GetResourceName() string {
	if m != nil {
		return m.ResourceName
	}
	return ""
}

func (m *BiddingStrategy) GetId() *wrappers.Int64Value {
	if m != nil {
		return m.Id
	}
	return nil
}

func (m *BiddingStrategy) GetName() *wrappers.StringValue {
	if m != nil {
		return m.Name
	}
	return nil
}

func (m *BiddingStrategy) GetStatus() enums.BiddingStrategyStatusEnum_BiddingStrategyStatus {
	if m != nil {
		return m.Status
	}
	return enums.BiddingStrategyStatusEnum_UNSPECIFIED
}

func (m *BiddingStrategy) GetType() enums.BiddingStrategyTypeEnum_BiddingStrategyType {
	if m != nil {
		return m.Type
	}
	return enums.BiddingStrategyTypeEnum_UNSPECIFIED
}

func (m *BiddingStrategy) GetCampaignCount() *wrappers.Int64Value {
	if m != nil {
		return m.CampaignCount
	}
	return nil
}

func (m *BiddingStrategy) GetNonRemovedCampaignCount() *wrappers.Int64Value {
	if m != nil {
		return m.NonRemovedCampaignCount
	}
	return nil
}

type isBiddingStrategy_Scheme interface {
	isBiddingStrategy_Scheme()
}

type BiddingStrategy_EnhancedCpc struct {
	EnhancedCpc *common.EnhancedCpc `protobuf:"bytes,7,opt,name=enhanced_cpc,json=enhancedCpc,proto3,oneof"`
}

type BiddingStrategy_PageOnePromoted struct {
	PageOnePromoted *common.PageOnePromoted `protobuf:"bytes,8,opt,name=page_one_promoted,json=pageOnePromoted,proto3,oneof"`
}

type BiddingStrategy_TargetCpa struct {
	TargetCpa *common.TargetCpa `protobuf:"bytes,9,opt,name=target_cpa,json=targetCpa,proto3,oneof"`
}

type BiddingStrategy_TargetImpressionShare struct {
	TargetImpressionShare *common.TargetImpressionShare `protobuf:"bytes,48,opt,name=target_impression_share,json=targetImpressionShare,proto3,oneof"`
}

type BiddingStrategy_TargetOutrankShare struct {
	TargetOutrankShare *common.TargetOutrankShare `protobuf:"bytes,10,opt,name=target_outrank_share,json=targetOutrankShare,proto3,oneof"`
}

type BiddingStrategy_TargetRoas struct {
	TargetRoas *common.TargetRoas `protobuf:"bytes,11,opt,name=target_roas,json=targetRoas,proto3,oneof"`
}

type BiddingStrategy_TargetSpend struct {
	TargetSpend *common.TargetSpend `protobuf:"bytes,12,opt,name=target_spend,json=targetSpend,proto3,oneof"`
}

func (*BiddingStrategy_EnhancedCpc) isBiddingStrategy_Scheme() {}

func (*BiddingStrategy_PageOnePromoted) isBiddingStrategy_Scheme() {}

func (*BiddingStrategy_TargetCpa) isBiddingStrategy_Scheme() {}

func (*BiddingStrategy_TargetImpressionShare) isBiddingStrategy_Scheme() {}

func (*BiddingStrategy_TargetOutrankShare) isBiddingStrategy_Scheme() {}

func (*BiddingStrategy_TargetRoas) isBiddingStrategy_Scheme() {}

func (*BiddingStrategy_TargetSpend) isBiddingStrategy_Scheme() {}

func (m *BiddingStrategy) GetScheme() isBiddingStrategy_Scheme {
	if m != nil {
		return m.Scheme
	}
	return nil
}

func (m *BiddingStrategy) GetEnhancedCpc() *common.EnhancedCpc {
	if x, ok := m.GetScheme().(*BiddingStrategy_EnhancedCpc); ok {
		return x.EnhancedCpc
	}
	return nil
}

func (m *BiddingStrategy) GetPageOnePromoted() *common.PageOnePromoted {
	if x, ok := m.GetScheme().(*BiddingStrategy_PageOnePromoted); ok {
		return x.PageOnePromoted
	}
	return nil
}

func (m *BiddingStrategy) GetTargetCpa() *common.TargetCpa {
	if x, ok := m.GetScheme().(*BiddingStrategy_TargetCpa); ok {
		return x.TargetCpa
	}
	return nil
}

func (m *BiddingStrategy) GetTargetImpressionShare() *common.TargetImpressionShare {
	if x, ok := m.GetScheme().(*BiddingStrategy_TargetImpressionShare); ok {
		return x.TargetImpressionShare
	}
	return nil
}

func (m *BiddingStrategy) GetTargetOutrankShare() *common.TargetOutrankShare {
	if x, ok := m.GetScheme().(*BiddingStrategy_TargetOutrankShare); ok {
		return x.TargetOutrankShare
	}
	return nil
}

func (m *BiddingStrategy) GetTargetRoas() *common.TargetRoas {
	if x, ok := m.GetScheme().(*BiddingStrategy_TargetRoas); ok {
		return x.TargetRoas
	}
	return nil
}

func (m *BiddingStrategy) GetTargetSpend() *common.TargetSpend {
	if x, ok := m.GetScheme().(*BiddingStrategy_TargetSpend); ok {
		return x.TargetSpend
	}
	return nil
}

// XXX_OneofWrappers is for the internal use of the proto package.
func (*BiddingStrategy) XXX_OneofWrappers() []interface{} {
	return []interface{}{
		(*BiddingStrategy_EnhancedCpc)(nil),
		(*BiddingStrategy_PageOnePromoted)(nil),
		(*BiddingStrategy_TargetCpa)(nil),
		(*BiddingStrategy_TargetImpressionShare)(nil),
		(*BiddingStrategy_TargetOutrankShare)(nil),
		(*BiddingStrategy_TargetRoas)(nil),
		(*BiddingStrategy_TargetSpend)(nil),
	}
}

func init() {
	proto.RegisterType((*BiddingStrategy)(nil), "google.ads.googleads.v1.resources.BiddingStrategy")
}

func init() {
	proto.RegisterFile("google/ads/googleads/v1/resources/bidding_strategy.proto", fileDescriptor_45db3d8386a3943d)
}

var fileDescriptor_45db3d8386a3943d = []byte{
	// 693 bytes of a gzipped FileDescriptorProto
	0x1f, 0x8b, 0x08, 0x00, 0x00, 0x00, 0x00, 0x00, 0x02, 0xff, 0x94, 0x95, 0xdd, 0x4e, 0xdb, 0x30,
	0x14, 0xc7, 0xdb, 0xc2, 0x18, 0xb8, 0x7c, 0x68, 0x11, 0x13, 0x11, 0x43, 0x13, 0x6c, 0x42, 0x62,
	0x63, 0x72, 0x28, 0xfb, 0xd0, 0x16, 0xae, 0xda, 0x0a, 0x51, 0x90, 0x06, 0x55, 0x8a, 0xaa, 0x69,
	0xea, 0x16, 0x99, 0xe4, 0x10, 0xa2, 0x11, 0xdb, 0xb2, 0x1d, 0x26, 0x2e, 0xf7, 0x2a, 0xbb, 0xdc,
	0xa3, 0xec, 0x51, 0xf6, 0x0c, 0xbb, 0x98, 0xe2, 0x38, 0x41, 0x7c, 0x74, 0x2d, 0x77, 0x3e, 0x3e,
	0xff, 0xff, 0xef, 0x1f, 0x0e, 0x27, 0x29, 0x7a, 0x1f, 0x31, 0x16, 0x9d, 0x83, 0x43, 0x42, 0xe9,
	0xe4, 0xc7, 0xec, 0x74, 0xd1, 0x70, 0x04, 0x48, 0x96, 0x8a, 0x00, 0xa4, 0x73, 0x12, 0x87, 0x61,
	0x4c, 0x23, 0x5f, 0x2a, 0x41, 0x14, 0x44, 0x97, 0x98, 0x0b, 0xa6, 0x98, 0xb5, 0x96, 0xcb, 0x31,
	0x09, 0x25, 0x2e, 0x9d, 0xf8, 0xa2, 0x81, 0x4b, 0xe7, 0xf2, 0xab, 0x61, 0xf0, 0x80, 0x25, 0x09,
	0xa3, 0x05, 0x39, 0x07, 0x2e, 0xef, 0x0c, 0x53, 0x03, 0x4d, 0x93, 0xdb, 0x8f, 0xe1, 0x4b, 0x45,
	0x54, 0x2a, 0x8d, 0xf9, 0xc3, 0x3d, 0xcd, 0xea, 0x92, 0x83, 0xb1, 0xae, 0x14, 0x56, 0x1e, 0x3b,
	0x84, 0x52, 0xa6, 0x88, 0x8a, 0x19, 0x2d, 0xc0, 0x4f, 0x4d, 0x57, 0x57, 0x27, 0xe9, 0xa9, 0xf3,
	0x5d, 0x10, 0xce, 0x41, 0x98, 0xfe, 0xb3, 0xbf, 0xd3, 0x68, 0xa1, 0x95, 0xd3, 0x7b, 0x06, 0x6e,
	0x3d, 0x47, 0x73, 0xc5, 0x10, 0x7c, 0x4a, 0x12, 0xb0, 0xab, 0xab, 0xd5, 0x8d, 0x19, 0x6f, 0xb6,
	0xb8, 0x3c, 0x24, 0x09, 0x58, 0x9b, 0xa8, 0x16, 0x87, 0xf6, 0xc4, 0x6a, 0x75, 0xa3, 0xbe, 0xfd,
	0xc4, 0x4c, 0x10, 0x17, 0x29, 0x78, 0x9f, 0xaa, 0x77, 0x6f, 0xfa, 0xe4, 0x3c, 0x05, 0xaf, 0x16,
	0x87, 0xd6, 0x16, 0x9a, 0xd4, 0xa0, 0x49, 0x2d, 0x5f, 0xb9, 0x25, 0xef, 0x29, 0x11, 0xd3, 0x28,
	0xd7, 0x6b, 0xa5, 0x75, 0x8a, 0xa6, 0xf2, 0x01, 0xd9, 0x0b, 0xab, 0xd5, 0x8d, 0xf9, 0xed, 0x43,
	0x3c, 0xec, 0xff, 0xa5, 0x27, 0x84, 0x6f, 0xfc, 0x0d, 0x3d, 0xed, 0xdd, 0xa5, 0x69, 0x72, 0x77,
	0xc7, 0x33, 0x74, 0xeb, 0x2b, 0x9a, 0xcc, 0x66, 0x69, 0x3f, 0xd0, 0x29, 0x07, 0xf7, 0x4b, 0x39,
	0xbe, 0xe4, 0x70, 0x57, 0x46, 0x76, 0xef, 0x69, 0xae, 0xd5, 0x42, 0xf3, 0x01, 0x49, 0x38, 0x89,
	0x23, 0xea, 0x07, 0x2c, 0xa5, 0xca, 0x9e, 0x1b, 0x3d, 0xb2, 0xb9, 0xc2, 0xd2, 0xce, 0x1c, 0xd6,
	0x27, 0xb4, 0x4c, 0x19, 0xf5, 0x05, 0x24, 0xec, 0x02, 0x42, 0xff, 0x06, 0x6f, 0x7e, 0x34, 0x6f,
	0x89, 0x32, 0xea, 0xe5, 0xee, 0xf6, 0x35, 0x72, 0x17, 0xcd, 0x02, 0x3d, 0x23, 0x34, 0xc8, 0xb0,
	0x3c, 0xb0, 0x1f, 0x6a, 0xd6, 0xe6, 0xd0, 0x29, 0xe4, 0x8b, 0x8f, 0x77, 0x8d, 0xa7, 0xcd, 0x83,
	0x4e, 0xc5, 0xab, 0xc3, 0x55, 0x69, 0x7d, 0x41, 0x8f, 0x38, 0x89, 0xc0, 0x67, 0x14, 0x7c, 0x2e,
	0x58, 0xc2, 0x14, 0x84, 0xf6, 0xb4, 0xc6, 0x3a, 0xa3, 0xb0, 0x5d, 0x12, 0xc1, 0x11, 0x85, 0xae,
	0xb1, 0x75, 0x2a, 0xde, 0x02, 0xbf, 0x7e, 0x65, 0x1d, 0x20, 0xa4, 0x88, 0x88, 0x40, 0xf9, 0x01,
	0x27, 0xf6, 0x8c, 0xe6, 0xbe, 0x18, 0xc5, 0x3d, 0xd6, 0x8e, 0x36, 0x27, 0x9d, 0x8a, 0x37, 0xa3,
	0x8a, 0xc2, 0x62, 0x68, 0xc9, 0xb0, 0xe2, 0x84, 0x0b, 0x90, 0x32, 0x66, 0xd4, 0x97, 0x67, 0x44,
	0x80, 0xbd, 0xa5, 0xc1, 0x6f, 0xc7, 0x03, 0xef, 0x97, 0xee, 0x5e, 0x66, 0xee, 0x54, 0xbc, 0xc7,
	0xea, 0xae, 0x86, 0x75, 0x8a, 0x16, 0x4d, 0x20, 0x4b, 0x95, 0x20, 0xf4, 0x9b, 0x49, 0x43, 0x3a,
	0x6d, 0x7b, 0xbc, 0xb4, 0xa3, 0xdc, 0x5a, 0x44, 0x59, 0xea, 0xd6, 0xad, 0xf5, 0x11, 0xd5, 0x4d,
	0x8e, 0x60, 0x44, 0xda, 0x75, 0x8d, 0x7f, 0x39, 0x1e, 0xde, 0x63, 0x44, 0x76, 0x2a, 0x9e, 0x99,
	0x72, 0x56, 0x65, 0x4b, 0x62, 0x70, 0x92, 0x03, 0x0d, 0xed, 0xd9, 0xf1, 0x96, 0x24, 0xe7, 0xf5,
	0x32, 0x4b, 0xb6, 0x24, 0xea, 0xaa, 0x6c, 0x4d, 0xa3, 0x29, 0x19, 0x9c, 0x41, 0x02, 0xad, 0x1f,
	0x35, 0xb4, 0x1e, 0xb0, 0x04, 0x8f, 0xfc, 0x18, 0xb7, 0x16, 0x6f, 0xbc, 0x63, 0xdd, 0x6c, 0xcf,
	0xbb, 0xd5, 0xcf, 0x07, 0xc6, 0x1a, 0xb1, 0x73, 0x42, 0x23, 0xcc, 0x44, 0xe4, 0x44, 0x40, 0xf5,
	0x5b, 0x50, 0x7c, 0x49, 0x79, 0x2c, 0xff, 0xf3, 0x03, 0xb1, 0x53, 0x9e, 0x7e, 0xd6, 0x26, 0xf6,
	0x9a, 0xcd, 0x5f, 0xb5, 0xb5, 0xbd, 0x1c, 0xd9, 0x0c, 0x25, 0xce, 0x8f, 0xd9, 0xa9, 0xdf, 0xc0,
	0x5e, 0xa1, 0xfc, 0x5d, 0x68, 0x06, 0xcd, 0x50, 0x0e, 0x4a, 0xcd, 0xa0, 0xdf, 0x18, 0x94, 0x9a,
	0x3f, 0xb5, 0xf5, 0xbc, 0xe1, 0xba, 0xcd, 0x50, 0xba, 0x6e, 0xa9, 0x72, 0xdd, 0x7e, 0xc3, 0x75,
	0x4b, 0xdd, 0xc9, 0x94, 0x7e, 0xd8, 0xd7, 0xff, 0x02, 0x00, 0x00, 0xff, 0xff, 0xe8, 0x8b, 0xa0,
	0x46, 0xcc, 0x06, 0x00, 0x00,
}
