// Code generated by protoc-gen-go. DO NOT EDIT.
// source: google/ads/googleads/v2/enums/access_role.proto

package enums

import (
	fmt "fmt"
	math "math"

	proto "github.com/golang/protobuf/proto"
	_ "google.golang.org/genproto/googleapis/api/annotations"
)

// Reference imports to suppress errors if they are not otherwise used.
var _ = proto.Marshal
var _ = fmt.Errorf
var _ = math.Inf

// This is a compile-time assertion to ensure that this generated file
// is compatible with the proto package it is being compiled against.
// A compilation error at this line likely means your copy of the
// proto package needs to be updated.
const _ = proto.ProtoPackageIsVersion3 // please upgrade the proto package

// Possible access role of a user.
type AccessRoleEnum_AccessRole int32

const (
	// Not specified.
	AccessRoleEnum_UNSPECIFIED AccessRoleEnum_AccessRole = 0
	// Used for return value only. Represents value unknown in this version.
	AccessRoleEnum_UNKNOWN AccessRoleEnum_AccessRole = 1
	// Owns its account and can control the addition of other users.
	AccessRoleEnum_ADMIN AccessRoleEnum_AccessRole = 2
	// Can modify campaigns, but can't affect other users.
	AccessRoleEnum_STANDARD AccessRoleEnum_AccessRole = 3
	// Can view campaigns and account changes, but cannot make edits.
	AccessRoleEnum_READ_ONLY AccessRoleEnum_AccessRole = 4
)

var AccessRoleEnum_AccessRole_name = map[int32]string{
	0: "UNSPECIFIED",
	1: "UNKNOWN",
	2: "ADMIN",
	3: "STANDARD",
	4: "READ_ONLY",
}

var AccessRoleEnum_AccessRole_value = map[string]int32{
	"UNSPECIFIED": 0,
	"UNKNOWN":     1,
	"ADMIN":       2,
	"STANDARD":    3,
	"READ_ONLY":   4,
}

func (x AccessRoleEnum_AccessRole) String() string {
	return proto.EnumName(AccessRoleEnum_AccessRole_name, int32(x))
}

func (AccessRoleEnum_AccessRole) EnumDescriptor() ([]byte, []int) {
	return fileDescriptor_5240257b7a04740a, []int{0, 0}
}

// Container for enum describing possible access role for user.
type AccessRoleEnum struct {
	XXX_NoUnkeyedLiteral struct{} `json:"-"`
	XXX_unrecognized     []byte   `json:"-"`
	XXX_sizecache        int32    `json:"-"`
}

func (m *AccessRoleEnum) Reset()         { *m = AccessRoleEnum{} }
func (m *AccessRoleEnum) String() string { return proto.CompactTextString(m) }
func (*AccessRoleEnum) ProtoMessage()    {}
func (*AccessRoleEnum) Descriptor() ([]byte, []int) {
	return fileDescriptor_5240257b7a04740a, []int{0}
}

func (m *AccessRoleEnum) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_AccessRoleEnum.Unmarshal(m, b)
}
func (m *AccessRoleEnum) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_AccessRoleEnum.Marshal(b, m, deterministic)
}
func (m *AccessRoleEnum) XXX_Merge(src proto.Message) {
	xxx_messageInfo_AccessRoleEnum.Merge(m, src)
}
func (m *AccessRoleEnum) XXX_Size() int {
	return xxx_messageInfo_AccessRoleEnum.Size(m)
}
func (m *AccessRoleEnum) XXX_DiscardUnknown() {
	xxx_messageInfo_AccessRoleEnum.DiscardUnknown(m)
}

var xxx_messageInfo_AccessRoleEnum proto.InternalMessageInfo

func init() {
	proto.RegisterEnum("google.ads.googleads.v2.enums.AccessRoleEnum_AccessRole", AccessRoleEnum_AccessRole_name, AccessRoleEnum_AccessRole_value)
	proto.RegisterType((*AccessRoleEnum)(nil), "google.ads.googleads.v2.enums.AccessRoleEnum")
}

func init() {
	proto.RegisterFile("google/ads/googleads/v2/enums/access_role.proto", fileDescriptor_5240257b7a04740a)
}

var fileDescriptor_5240257b7a04740a = []byte{
	// 310 bytes of a gzipped FileDescriptorProto
	0x1f, 0x8b, 0x08, 0x00, 0x00, 0x00, 0x00, 0x00, 0x02, 0xff, 0x7c, 0x50, 0xdd, 0x4e, 0xf2, 0x30,
	0x18, 0xfe, 0x18, 0x9f, 0x3f, 0x14, 0x95, 0xa5, 0x87, 0x46, 0x0e, 0xe0, 0x02, 0xda, 0x64, 0x9e,
	0xd5, 0xa3, 0xe2, 0x26, 0x21, 0x6a, 0x21, 0x43, 0x30, 0x9a, 0x25, 0xa4, 0xd2, 0xa6, 0x21, 0x19,
	0x2d, 0x59, 0x07, 0x17, 0xe4, 0xa1, 0x97, 0xe2, 0x75, 0x78, 0xe4, 0x55, 0x98, 0x75, 0x6c, 0x1c,
	0xe9, 0x49, 0xf3, 0xe4, 0x7d, 0x7e, 0xfa, 0xbc, 0x2f, 0xc0, 0xca, 0x18, 0x95, 0x4a, 0xcc, 0x85,
	0xdd, 0xc3, 0x02, 0xed, 0x02, 0x2c, 0xf5, 0x76, 0x6d, 0x31, 0x5f, 0x2e, 0xa5, 0xb5, 0x8b, 0xcc,
	0xa4, 0x12, 0x6d, 0x32, 0x93, 0x1b, 0xd8, 0x2d, 0x55, 0x88, 0x0b, 0x8b, 0x6a, 0x03, 0xda, 0x05,
	0xc8, 0x19, 0x2e, 0xaf, 0xaa, 0xbc, 0xcd, 0x0a, 0x73, 0xad, 0x4d, 0xce, 0xf3, 0x95, 0xd1, 0xb6,
	0x34, 0xf7, 0x05, 0xb8, 0xa0, 0x2e, 0x31, 0x36, 0xa9, 0x8c, 0xf4, 0x76, 0xdd, 0x8f, 0x01, 0x38,
	0x4c, 0x60, 0x07, 0xb4, 0x67, 0x6c, 0x3a, 0x89, 0x6e, 0x47, 0x77, 0xa3, 0x28, 0xf4, 0xff, 0xc1,
	0x36, 0x38, 0x99, 0xb1, 0x7b, 0x36, 0x7e, 0x66, 0x7e, 0x03, 0xb6, 0xc0, 0x11, 0x0d, 0x1f, 0x47,
	0xcc, 0xf7, 0xe0, 0x19, 0x38, 0x9d, 0x3e, 0x51, 0x16, 0xd2, 0x38, 0xf4, 0x9b, 0xf0, 0x1c, 0xb4,
	0xe2, 0x88, 0x86, 0x8b, 0x31, 0x7b, 0x78, 0xf1, 0xff, 0x0f, 0xbe, 0x1a, 0xa0, 0xb7, 0x34, 0x6b,
	0xf4, 0x67, 0xd3, 0x41, 0xe7, 0xf0, 0xef, 0xa4, 0x28, 0x37, 0x69, 0xbc, 0x0e, 0xf6, 0x0e, 0x65,
	0x52, 0xae, 0x15, 0x32, 0x99, 0xc2, 0x4a, 0x6a, 0x57, 0xbd, 0x3a, 0xce, 0x66, 0x65, 0x7f, 0xb9,
	0xd5, 0x8d, 0x7b, 0xdf, 0xbd, 0xe6, 0x90, 0xd2, 0x0f, 0xaf, 0x3b, 0x2c, 0xa3, 0xa8, 0xb0, 0xa8,
	0x84, 0x05, 0x9a, 0x07, 0xa8, 0xd8, 0xda, 0x7e, 0x56, 0x7c, 0x42, 0x85, 0x4d, 0x6a, 0x3e, 0x99,
	0x07, 0x89, 0xe3, 0xbf, 0xbd, 0x5e, 0x39, 0x24, 0x84, 0x0a, 0x4b, 0x48, 0xad, 0x20, 0x64, 0x1e,
	0x10, 0xe2, 0x34, 0x6f, 0xc7, 0xae, 0xd8, 0xf5, 0x4f, 0x00, 0x00, 0x00, 0xff, 0xff, 0x3d, 0x07,
	0x60, 0xbe, 0xc3, 0x01, 0x00, 0x00,
}
