// Code generated by protoc-gen-go. DO NOT EDIT.
// source: google/ads/googleads/v2/services/ad_group_ad_asset_view_service.proto

package services

import (
	context "context"
	fmt "fmt"
	math "math"

	proto "github.com/golang/protobuf/proto"
	resources "google.golang.org/genproto/googleapis/ads/googleads/v2/resources"
	_ "google.golang.org/genproto/googleapis/api/annotations"
	grpc "google.golang.org/grpc"
)

// Reference imports to suppress errors if they are not otherwise used.
var _ = proto.Marshal
var _ = fmt.Errorf
var _ = math.Inf

// This is a compile-time assertion to ensure that this generated file
// is compatible with the proto package it is being compiled against.
// A compilation error at this line likely means your copy of the
// proto package needs to be updated.
const _ = proto.ProtoPackageIsVersion3 // please upgrade the proto package

// Request message for [AdGroupAdAssetViewService.GetAdGroupAdAssetView][google.ads.googleads.v2.services.AdGroupAdAssetViewService.GetAdGroupAdAssetView].
type GetAdGroupAdAssetViewRequest struct {
	// The resource name of the ad group ad asset view to fetch.
	ResourceName         string   `protobuf:"bytes,1,opt,name=resource_name,json=resourceName,proto3" json:"resource_name,omitempty"`
	XXX_NoUnkeyedLiteral struct{} `json:"-"`
	XXX_unrecognized     []byte   `json:"-"`
	XXX_sizecache        int32    `json:"-"`
}

func (m *GetAdGroupAdAssetViewRequest) Reset()         { *m = GetAdGroupAdAssetViewRequest{} }
func (m *GetAdGroupAdAssetViewRequest) String() string { return proto.CompactTextString(m) }
func (*GetAdGroupAdAssetViewRequest) ProtoMessage()    {}
func (*GetAdGroupAdAssetViewRequest) Descriptor() ([]byte, []int) {
	return fileDescriptor_1330b0e2ddef9dd5, []int{0}
}

func (m *GetAdGroupAdAssetViewRequest) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_GetAdGroupAdAssetViewRequest.Unmarshal(m, b)
}
func (m *GetAdGroupAdAssetViewRequest) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_GetAdGroupAdAssetViewRequest.Marshal(b, m, deterministic)
}
func (m *GetAdGroupAdAssetViewRequest) XXX_Merge(src proto.Message) {
	xxx_messageInfo_GetAdGroupAdAssetViewRequest.Merge(m, src)
}
func (m *GetAdGroupAdAssetViewRequest) XXX_Size() int {
	return xxx_messageInfo_GetAdGroupAdAssetViewRequest.Size(m)
}
func (m *GetAdGroupAdAssetViewRequest) XXX_DiscardUnknown() {
	xxx_messageInfo_GetAdGroupAdAssetViewRequest.DiscardUnknown(m)
}

var xxx_messageInfo_GetAdGroupAdAssetViewRequest proto.InternalMessageInfo

func (m *GetAdGroupAdAssetViewRequest) GetResourceName() string {
	if m != nil {
		return m.ResourceName
	}
	return ""
}

func init() {
	proto.RegisterType((*GetAdGroupAdAssetViewRequest)(nil), "google.ads.googleads.v2.services.GetAdGroupAdAssetViewRequest")
}

func init() {
	proto.RegisterFile("google/ads/googleads/v2/services/ad_group_ad_asset_view_service.proto", fileDescriptor_1330b0e2ddef9dd5)
}

var fileDescriptor_1330b0e2ddef9dd5 = []byte{
	// 397 bytes of a gzipped FileDescriptorProto
	0x1f, 0x8b, 0x08, 0x00, 0x00, 0x00, 0x00, 0x00, 0x02, 0xff, 0x84, 0x52, 0xcd, 0xaa, 0xd3, 0x40,
	0x14, 0x26, 0x11, 0x04, 0x83, 0x6e, 0x02, 0x62, 0x8d, 0x45, 0x4a, 0xed, 0x42, 0xba, 0x98, 0x81,
	0x48, 0x11, 0x46, 0x5a, 0x98, 0x8a, 0xc4, 0x95, 0x94, 0x0a, 0x59, 0x48, 0x20, 0x8c, 0x99, 0x21,
	0x04, 0x9a, 0x4c, 0xcc, 0x99, 0xa4, 0x0b, 0x71, 0x23, 0x08, 0xee, 0x7d, 0x03, 0x97, 0x3e, 0x4a,
	0xc1, 0x95, 0xaf, 0xe0, 0xca, 0xa7, 0x90, 0x74, 0x32, 0xe9, 0xbd, 0xf4, 0xe6, 0x76, 0xf7, 0x31,
	0xe7, 0xfb, 0x39, 0x3f, 0xe3, 0xbc, 0x49, 0xa5, 0x4c, 0x77, 0x02, 0x33, 0x0e, 0x58, 0xc3, 0x16,
	0x35, 0x3e, 0x06, 0x51, 0x35, 0x59, 0x22, 0x00, 0x33, 0x1e, 0xa7, 0x95, 0xac, 0xcb, 0x98, 0xf1,
	0x98, 0x01, 0x08, 0x15, 0x37, 0x99, 0xd8, 0xc7, 0x5d, 0x1d, 0x95, 0x95, 0x54, 0xd2, 0x9d, 0x68,
	0x2d, 0x62, 0x1c, 0x50, 0x6f, 0x83, 0x1a, 0x1f, 0x19, 0x1b, 0x6f, 0x35, 0x14, 0x54, 0x09, 0x90,
	0x75, 0x35, 0x9c, 0xa4, 0x13, 0xbc, 0xb1, 0xd1, 0x97, 0x19, 0x66, 0x45, 0x21, 0x15, 0x53, 0x99,
	0x2c, 0xa0, 0xab, 0x3e, 0xba, 0x52, 0x4d, 0x76, 0x99, 0x28, 0x94, 0x2e, 0x4c, 0x5f, 0x3b, 0xe3,
	0x40, 0x28, 0xca, 0x83, 0xd6, 0x98, 0x72, 0xda, 0xda, 0x86, 0x99, 0xd8, 0x6f, 0xc5, 0xa7, 0x5a,
	0x80, 0x72, 0x9f, 0x39, 0x0f, 0x4c, 0x03, 0x71, 0xc1, 0x72, 0x31, 0xb2, 0x26, 0xd6, 0xf3, 0x7b,
	0xdb, 0xfb, 0xe6, 0xf1, 0x1d, 0xcb, 0x85, 0xff, 0xdd, 0x76, 0x1e, 0x9f, 0x5b, 0xbc, 0xd7, 0xa3,
	0xb9, 0xbf, 0x2d, 0xe7, 0xe1, 0x8d, 0x19, 0xee, 0x0a, 0x5d, 0x5a, 0x0b, 0xba, 0xad, 0x39, 0x6f,
	0x31, 0xa8, 0xef, 0x97, 0x86, 0xce, 0xd5, 0xd3, 0xe5, 0xd7, 0x3f, 0x7f, 0x7f, 0xd8, 0x2f, 0xdd,
	0x45, 0xbb, 0xde, 0xcf, 0xd7, 0xc6, 0x5b, 0x26, 0x35, 0x28, 0x99, 0x8b, 0x0a, 0xf0, 0x1c, 0xb3,
	0x33, 0x29, 0xe0, 0xf9, 0x17, 0xef, 0xc9, 0x81, 0x8e, 0x4e, 0x61, 0x1d, 0x2a, 0x33, 0x40, 0x89,
	0xcc, 0xd7, 0xdf, 0x6c, 0x67, 0x96, 0xc8, 0xfc, 0xe2, 0x60, 0xeb, 0xa7, 0x83, 0x0b, 0xdb, 0xb4,
	0x87, 0xd9, 0x58, 0x1f, 0xde, 0x76, 0x1e, 0xa9, 0xdc, 0xb1, 0x22, 0x45, 0xb2, 0x4a, 0x71, 0x2a,
	0x8a, 0xe3, 0xd9, 0xf0, 0x29, 0x75, 0xf8, 0x67, 0xbe, 0x32, 0xe0, 0xa7, 0x7d, 0x27, 0xa0, 0xf4,
	0x97, 0x3d, 0x09, 0xb4, 0x21, 0xe5, 0x80, 0x34, 0x6c, 0x51, 0xe8, 0xa3, 0x2e, 0x18, 0x0e, 0x86,
	0x12, 0x51, 0x0e, 0x51, 0x4f, 0x89, 0x42, 0x3f, 0x32, 0x94, 0x7f, 0xf6, 0x4c, 0xbf, 0x13, 0x42,
	0x39, 0x10, 0xd2, 0x93, 0x08, 0x09, 0x7d, 0x42, 0x0c, 0xed, 0xe3, 0xdd, 0x63, 0x9f, 0x2f, 0xfe,
	0x07, 0x00, 0x00, 0xff, 0xff, 0x21, 0x62, 0x1f, 0xc3, 0x40, 0x03, 0x00, 0x00,
}

// Reference imports to suppress errors if they are not otherwise used.
var _ context.Context
var _ grpc.ClientConn

// This is a compile-time assertion to ensure that this generated file
// is compatible with the grpc package it is being compiled against.
const _ = grpc.SupportPackageIsVersion4

// AdGroupAdAssetViewServiceClient is the client API for AdGroupAdAssetViewService service.
//
// For semantics around ctx use and closing/ending streaming RPCs, please refer to https://godoc.org/google.golang.org/grpc#ClientConn.NewStream.
type AdGroupAdAssetViewServiceClient interface {
	// Returns the requested ad group ad asset view in full detail.
	GetAdGroupAdAssetView(ctx context.Context, in *GetAdGroupAdAssetViewRequest, opts ...grpc.CallOption) (*resources.AdGroupAdAssetView, error)
}

type adGroupAdAssetViewServiceClient struct {
	cc *grpc.ClientConn
}

func NewAdGroupAdAssetViewServiceClient(cc *grpc.ClientConn) AdGroupAdAssetViewServiceClient {
	return &adGroupAdAssetViewServiceClient{cc}
}

func (c *adGroupAdAssetViewServiceClient) GetAdGroupAdAssetView(ctx context.Context, in *GetAdGroupAdAssetViewRequest, opts ...grpc.CallOption) (*resources.AdGroupAdAssetView, error) {
	out := new(resources.AdGroupAdAssetView)
	err := c.cc.Invoke(ctx, "/google.ads.googleads.v2.services.AdGroupAdAssetViewService/GetAdGroupAdAssetView", in, out, opts...)
	if err != nil {
		return nil, err
	}
	return out, nil
}

// AdGroupAdAssetViewServiceServer is the server API for AdGroupAdAssetViewService service.
type AdGroupAdAssetViewServiceServer interface {
	// Returns the requested ad group ad asset view in full detail.
	GetAdGroupAdAssetView(context.Context, *GetAdGroupAdAssetViewRequest) (*resources.AdGroupAdAssetView, error)
}

func RegisterAdGroupAdAssetViewServiceServer(s *grpc.Server, srv AdGroupAdAssetViewServiceServer) {
	s.RegisterService(&_AdGroupAdAssetViewService_serviceDesc, srv)
}

func _AdGroupAdAssetViewService_GetAdGroupAdAssetView_Handler(srv interface{}, ctx context.Context, dec func(interface{}) error, interceptor grpc.UnaryServerInterceptor) (interface{}, error) {
	in := new(GetAdGroupAdAssetViewRequest)
	if err := dec(in); err != nil {
		return nil, err
	}
	if interceptor == nil {
		return srv.(AdGroupAdAssetViewServiceServer).GetAdGroupAdAssetView(ctx, in)
	}
	info := &grpc.UnaryServerInfo{
		Server:     srv,
		FullMethod: "/google.ads.googleads.v2.services.AdGroupAdAssetViewService/GetAdGroupAdAssetView",
	}
	handler := func(ctx context.Context, req interface{}) (interface{}, error) {
		return srv.(AdGroupAdAssetViewServiceServer).GetAdGroupAdAssetView(ctx, req.(*GetAdGroupAdAssetViewRequest))
	}
	return interceptor(ctx, in, info, handler)
}

var _AdGroupAdAssetViewService_serviceDesc = grpc.ServiceDesc{
	ServiceName: "google.ads.googleads.v2.services.AdGroupAdAssetViewService",
	HandlerType: (*AdGroupAdAssetViewServiceServer)(nil),
	Methods: []grpc.MethodDesc{
		{
			MethodName: "GetAdGroupAdAssetView",
			Handler:    _AdGroupAdAssetViewService_GetAdGroupAdAssetView_Handler,
		},
	},
	Streams:  []grpc.StreamDesc{},
	Metadata: "google/ads/googleads/v2/services/ad_group_ad_asset_view_service.proto",
}
