// Code generated by protoc-gen-go. DO NOT EDIT.
// source: google/ads/googleads/v1/enums/criterion_category_channel_availability_mode.proto

package enums

import (
	fmt "fmt"
	math "math"

	proto "github.com/golang/protobuf/proto"
	_ "google.golang.org/genproto/googleapis/api/annotations"
)

// Reference imports to suppress errors if they are not otherwise used.
var _ = proto.Marshal
var _ = fmt.Errorf
var _ = math.Inf

// This is a compile-time assertion to ensure that this generated file
// is compatible with the proto package it is being compiled against.
// A compilation error at this line likely means your copy of the
// proto package needs to be updated.
const _ = proto.ProtoPackageIsVersion3 // please upgrade the proto package

// Enum containing the possible CriterionCategoryChannelAvailabilityMode.
type CriterionCategoryChannelAvailabilityModeEnum_CriterionCategoryChannelAvailabilityMode int32

const (
	// Not specified.
	CriterionCategoryChannelAvailabilityModeEnum_UNSPECIFIED CriterionCategoryChannelAvailabilityModeEnum_CriterionCategoryChannelAvailabilityMode = 0
	// Used for return value only. Represents value unknown in this version.
	CriterionCategoryChannelAvailabilityModeEnum_UNKNOWN CriterionCategoryChannelAvailabilityModeEnum_CriterionCategoryChannelAvailabilityMode = 1
	// The category is available to campaigns of all channel types and subtypes.
	CriterionCategoryChannelAvailabilityModeEnum_ALL_CHANNELS CriterionCategoryChannelAvailabilityModeEnum_CriterionCategoryChannelAvailabilityMode = 2
	// The category is available to campaigns of a specific channel type,
	// including all subtypes under it.
	CriterionCategoryChannelAvailabilityModeEnum_CHANNEL_TYPE_AND_ALL_SUBTYPES CriterionCategoryChannelAvailabilityModeEnum_CriterionCategoryChannelAvailabilityMode = 3
	// The category is available to campaigns of a specific channel type and
	// subtype(s).
	CriterionCategoryChannelAvailabilityModeEnum_CHANNEL_TYPE_AND_SUBSET_SUBTYPES CriterionCategoryChannelAvailabilityModeEnum_CriterionCategoryChannelAvailabilityMode = 4
)

var CriterionCategoryChannelAvailabilityModeEnum_CriterionCategoryChannelAvailabilityMode_name = map[int32]string{
	0: "UNSPECIFIED",
	1: "UNKNOWN",
	2: "ALL_CHANNELS",
	3: "CHANNEL_TYPE_AND_ALL_SUBTYPES",
	4: "CHANNEL_TYPE_AND_SUBSET_SUBTYPES",
}

var CriterionCategoryChannelAvailabilityModeEnum_CriterionCategoryChannelAvailabilityMode_value = map[string]int32{
	"UNSPECIFIED":                      0,
	"UNKNOWN":                          1,
	"ALL_CHANNELS":                     2,
	"CHANNEL_TYPE_AND_ALL_SUBTYPES":    3,
	"CHANNEL_TYPE_AND_SUBSET_SUBTYPES": 4,
}

func (x CriterionCategoryChannelAvailabilityModeEnum_CriterionCategoryChannelAvailabilityMode) String() string {
	return proto.EnumName(CriterionCategoryChannelAvailabilityModeEnum_CriterionCategoryChannelAvailabilityMode_name, int32(x))
}

func (CriterionCategoryChannelAvailabilityModeEnum_CriterionCategoryChannelAvailabilityMode) EnumDescriptor() ([]byte, []int) {
	return fileDescriptor_193a0f2dff78de0b, []int{0, 0}
}

// Describes channel availability mode for a criterion availability - whether
// the availability is meant to include all advertising channels, or a
// particular channel with all its channel subtypes, or a channel with a certain
// subset of channel subtypes.
type CriterionCategoryChannelAvailabilityModeEnum struct {
	XXX_NoUnkeyedLiteral struct{} `json:"-"`
	XXX_unrecognized     []byte   `json:"-"`
	XXX_sizecache        int32    `json:"-"`
}

func (m *CriterionCategoryChannelAvailabilityModeEnum) Reset() {
	*m = CriterionCategoryChannelAvailabilityModeEnum{}
}
func (m *CriterionCategoryChannelAvailabilityModeEnum) String() string {
	return proto.CompactTextString(m)
}
func (*CriterionCategoryChannelAvailabilityModeEnum) ProtoMessage() {}
func (*CriterionCategoryChannelAvailabilityModeEnum) Descriptor() ([]byte, []int) {
	return fileDescriptor_193a0f2dff78de0b, []int{0}
}

func (m *CriterionCategoryChannelAvailabilityModeEnum) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_CriterionCategoryChannelAvailabilityModeEnum.Unmarshal(m, b)
}
func (m *CriterionCategoryChannelAvailabilityModeEnum) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_CriterionCategoryChannelAvailabilityModeEnum.Marshal(b, m, deterministic)
}
func (m *CriterionCategoryChannelAvailabilityModeEnum) XXX_Merge(src proto.Message) {
	xxx_messageInfo_CriterionCategoryChannelAvailabilityModeEnum.Merge(m, src)
}
func (m *CriterionCategoryChannelAvailabilityModeEnum) XXX_Size() int {
	return xxx_messageInfo_CriterionCategoryChannelAvailabilityModeEnum.Size(m)
}
func (m *CriterionCategoryChannelAvailabilityModeEnum) XXX_DiscardUnknown() {
	xxx_messageInfo_CriterionCategoryChannelAvailabilityModeEnum.DiscardUnknown(m)
}

var xxx_messageInfo_CriterionCategoryChannelAvailabilityModeEnum proto.InternalMessageInfo

func init() {
	proto.RegisterEnum("google.ads.googleads.v1.enums.CriterionCategoryChannelAvailabilityModeEnum_CriterionCategoryChannelAvailabilityMode", CriterionCategoryChannelAvailabilityModeEnum_CriterionCategoryChannelAvailabilityMode_name, CriterionCategoryChannelAvailabilityModeEnum_CriterionCategoryChannelAvailabilityMode_value)
	proto.RegisterType((*CriterionCategoryChannelAvailabilityModeEnum)(nil), "google.ads.googleads.v1.enums.CriterionCategoryChannelAvailabilityModeEnum")
}

func init() {
	proto.RegisterFile("google/ads/googleads/v1/enums/criterion_category_channel_availability_mode.proto", fileDescriptor_193a0f2dff78de0b)
}

var fileDescriptor_193a0f2dff78de0b = []byte{
	// 374 bytes of a gzipped FileDescriptorProto
	0x1f, 0x8b, 0x08, 0x00, 0x00, 0x00, 0x00, 0x00, 0x02, 0xff, 0x8c, 0x51, 0x41, 0x6b, 0xdb, 0x30,
	0x18, 0x9d, 0x9d, 0xb1, 0x81, 0x32, 0x98, 0xf1, 0x71, 0x2c, 0xb0, 0x84, 0x1d, 0x76, 0xd8, 0x64,
	0xcc, 0x6e, 0xea, 0x49, 0x76, 0xdc, 0x34, 0x34, 0x75, 0x0d, 0x8e, 0x53, 0x5a, 0x0c, 0x42, 0xb1,
	0x85, 0x2b, 0xb0, 0xa5, 0x60, 0x39, 0x81, 0x5c, 0xfb, 0x53, 0xda, 0x5b, 0x7f, 0x4a, 0xcf, 0xfd,
	0x15, 0xfd, 0x15, 0xc5, 0x76, 0x9c, 0x16, 0x4a, 0x4b, 0x2e, 0xe2, 0x7d, 0xfa, 0xde, 0xf7, 0x9e,
	0xf4, 0x3e, 0x10, 0x64, 0x52, 0x66, 0x39, 0xb3, 0x68, 0xaa, 0xac, 0x16, 0xd6, 0x68, 0x63, 0x5b,
	0x4c, 0xac, 0x0b, 0x65, 0x25, 0x25, 0xaf, 0x58, 0xc9, 0xa5, 0x20, 0x09, 0xad, 0x58, 0x26, 0xcb,
	0x2d, 0x49, 0xae, 0xa9, 0x10, 0x2c, 0x27, 0x74, 0x43, 0x79, 0x4e, 0x97, 0x3c, 0xe7, 0xd5, 0x96,
	0x14, 0x32, 0x65, 0x70, 0x55, 0xca, 0x4a, 0x9a, 0x83, 0x56, 0x06, 0xd2, 0x54, 0xc1, 0xbd, 0x22,
	0xdc, 0xd8, 0xb0, 0x51, 0xfc, 0xf1, 0xb3, 0x33, 0x5c, 0x71, 0x8b, 0x0a, 0x21, 0x2b, 0x5a, 0x71,
	0x29, 0x54, 0x3b, 0x3c, 0x7a, 0xd4, 0xc0, 0x5f, 0xb7, 0xf3, 0x74, 0x77, 0x96, 0x6e, 0xeb, 0x88,
	0x5f, 0x19, 0x9e, 0xc9, 0x94, 0x79, 0x62, 0x5d, 0x8c, 0xee, 0x34, 0xf0, 0xe7, 0xd0, 0x01, 0xf3,
	0x3b, 0xe8, 0x47, 0x7e, 0x18, 0x78, 0xee, 0xf4, 0x78, 0xea, 0x8d, 0x8d, 0x4f, 0x66, 0x1f, 0x7c,
	0x8d, 0xfc, 0x53, 0xff, 0xfc, 0xc2, 0x37, 0x34, 0xd3, 0x00, 0xdf, 0xf0, 0x6c, 0x46, 0xdc, 0x13,
	0xec, 0xfb, 0xde, 0x2c, 0x34, 0x74, 0x73, 0x08, 0x06, 0xbb, 0x8a, 0xcc, 0x2f, 0x03, 0x8f, 0x60,
	0x7f, 0x4c, 0x6a, 0x4a, 0x18, 0x39, 0x75, 0x1d, 0x1a, 0x3d, 0xf3, 0x37, 0xf8, 0xf5, 0x86, 0x12,
	0x46, 0x4e, 0xe8, 0xcd, 0x5f, 0x58, 0x9f, 0x9d, 0x1b, 0x1d, 0x0c, 0x13, 0x59, 0xc0, 0x0f, 0xa3,
	0x71, 0xfe, 0x1d, 0xfa, 0x91, 0xa0, 0xce, 0x2a, 0xd0, 0xae, 0x9c, 0x9d, 0x5e, 0x26, 0x73, 0x2a,
	0x32, 0x28, 0xcb, 0xcc, 0xca, 0x98, 0x68, 0x92, 0xec, 0x96, 0xb9, 0xe2, 0xea, 0x9d, 0xdd, 0x1e,
	0x35, 0xe7, 0xad, 0xde, 0x9b, 0x60, 0x7c, 0xaf, 0x0f, 0x26, 0xad, 0x14, 0x4e, 0x15, 0x6c, 0x61,
	0x8d, 0x16, 0x36, 0xac, 0x53, 0x56, 0x0f, 0x5d, 0x3f, 0xc6, 0xa9, 0x8a, 0xf7, 0xfd, 0x78, 0x61,
	0xc7, 0x4d, 0xff, 0x49, 0x1f, 0xb6, 0x97, 0x08, 0xe1, 0x54, 0x21, 0xb4, 0x67, 0x20, 0xb4, 0xb0,
	0x11, 0x6a, 0x38, 0xcb, 0x2f, 0xcd, 0xc3, 0xfe, 0x3f, 0x07, 0x00, 0x00, 0xff, 0xff, 0x69, 0x2b,
	0x2e, 0x1a, 0x73, 0x02, 0x00, 0x00,
}
