// Code generated by protoc-gen-go. DO NOT EDIT.
// source: google/ads/googleads/v1/enums/page_one_promoted_strategy_goal.proto

package enums

import (
	fmt "fmt"
	math "math"

	proto "github.com/golang/protobuf/proto"
	_ "google.golang.org/genproto/googleapis/api/annotations"
)

// Reference imports to suppress errors if they are not otherwise used.
var _ = proto.Marshal
var _ = fmt.Errorf
var _ = math.Inf

// This is a compile-time assertion to ensure that this generated file
// is compatible with the proto package it is being compiled against.
// A compilation error at this line likely means your copy of the
// proto package needs to be updated.
const _ = proto.ProtoPackageIsVersion3 // please upgrade the proto package

// Enum describing possible strategy goals.
type PageOnePromotedStrategyGoalEnum_PageOnePromotedStrategyGoal int32

const (
	// Not specified.
	PageOnePromotedStrategyGoalEnum_UNSPECIFIED PageOnePromotedStrategyGoalEnum_PageOnePromotedStrategyGoal = 0
	// Used for return value only. Represents value unknown in this version.
	PageOnePromotedStrategyGoalEnum_UNKNOWN PageOnePromotedStrategyGoalEnum_PageOnePromotedStrategyGoal = 1
	// First page on google.com.
	PageOnePromotedStrategyGoalEnum_FIRST_PAGE PageOnePromotedStrategyGoalEnum_PageOnePromotedStrategyGoal = 2
	// Top slots of the first page on google.com.
	PageOnePromotedStrategyGoalEnum_FIRST_PAGE_PROMOTED PageOnePromotedStrategyGoalEnum_PageOnePromotedStrategyGoal = 3
)

var PageOnePromotedStrategyGoalEnum_PageOnePromotedStrategyGoal_name = map[int32]string{
	0: "UNSPECIFIED",
	1: "UNKNOWN",
	2: "FIRST_PAGE",
	3: "FIRST_PAGE_PROMOTED",
}

var PageOnePromotedStrategyGoalEnum_PageOnePromotedStrategyGoal_value = map[string]int32{
	"UNSPECIFIED":         0,
	"UNKNOWN":             1,
	"FIRST_PAGE":          2,
	"FIRST_PAGE_PROMOTED": 3,
}

func (x PageOnePromotedStrategyGoalEnum_PageOnePromotedStrategyGoal) String() string {
	return proto.EnumName(PageOnePromotedStrategyGoalEnum_PageOnePromotedStrategyGoal_name, int32(x))
}

func (PageOnePromotedStrategyGoalEnum_PageOnePromotedStrategyGoal) EnumDescriptor() ([]byte, []int) {
	return fileDescriptor_a14ec166d42f2f9d, []int{0, 0}
}

// Container for enum describing possible strategy goals: where impressions are
// desired to be shown on search result pages.
type PageOnePromotedStrategyGoalEnum struct {
	XXX_NoUnkeyedLiteral struct{} `json:"-"`
	XXX_unrecognized     []byte   `json:"-"`
	XXX_sizecache        int32    `json:"-"`
}

func (m *PageOnePromotedStrategyGoalEnum) Reset()         { *m = PageOnePromotedStrategyGoalEnum{} }
func (m *PageOnePromotedStrategyGoalEnum) String() string { return proto.CompactTextString(m) }
func (*PageOnePromotedStrategyGoalEnum) ProtoMessage()    {}
func (*PageOnePromotedStrategyGoalEnum) Descriptor() ([]byte, []int) {
	return fileDescriptor_a14ec166d42f2f9d, []int{0}
}

func (m *PageOnePromotedStrategyGoalEnum) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_PageOnePromotedStrategyGoalEnum.Unmarshal(m, b)
}
func (m *PageOnePromotedStrategyGoalEnum) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_PageOnePromotedStrategyGoalEnum.Marshal(b, m, deterministic)
}
func (m *PageOnePromotedStrategyGoalEnum) XXX_Merge(src proto.Message) {
	xxx_messageInfo_PageOnePromotedStrategyGoalEnum.Merge(m, src)
}
func (m *PageOnePromotedStrategyGoalEnum) XXX_Size() int {
	return xxx_messageInfo_PageOnePromotedStrategyGoalEnum.Size(m)
}
func (m *PageOnePromotedStrategyGoalEnum) XXX_DiscardUnknown() {
	xxx_messageInfo_PageOnePromotedStrategyGoalEnum.DiscardUnknown(m)
}

var xxx_messageInfo_PageOnePromotedStrategyGoalEnum proto.InternalMessageInfo

func init() {
	proto.RegisterEnum("google.ads.googleads.v1.enums.PageOnePromotedStrategyGoalEnum_PageOnePromotedStrategyGoal", PageOnePromotedStrategyGoalEnum_PageOnePromotedStrategyGoal_name, PageOnePromotedStrategyGoalEnum_PageOnePromotedStrategyGoal_value)
	proto.RegisterType((*PageOnePromotedStrategyGoalEnum)(nil), "google.ads.googleads.v1.enums.PageOnePromotedStrategyGoalEnum")
}

func init() {
	proto.RegisterFile("google/ads/googleads/v1/enums/page_one_promoted_strategy_goal.proto", fileDescriptor_a14ec166d42f2f9d)
}

var fileDescriptor_a14ec166d42f2f9d = []byte{
	// 331 bytes of a gzipped FileDescriptorProto
	0x1f, 0x8b, 0x08, 0x00, 0x00, 0x00, 0x00, 0x00, 0x02, 0xff, 0x7c, 0x50, 0xcd, 0x4a, 0xc3, 0x40,
	0x18, 0x34, 0x29, 0x28, 0x6c, 0x41, 0x43, 0x3c, 0x08, 0x6a, 0xd1, 0xf6, 0x01, 0x36, 0x04, 0x6f,
	0xeb, 0x29, 0x6d, 0xd3, 0x50, 0xc4, 0x64, 0xe9, 0x9f, 0x20, 0x81, 0xb0, 0xba, 0xcb, 0x52, 0x48,
	0xf6, 0x0b, 0xd9, 0xb4, 0xe0, 0x13, 0xf8, 0x1e, 0x1e, 0x7d, 0x14, 0x1f, 0xc5, 0xbb, 0x77, 0x49,
	0xd2, 0xd6, 0x93, 0xb9, 0x84, 0xc9, 0x7e, 0xf3, 0xcd, 0x7c, 0x33, 0x68, 0x24, 0x01, 0x64, 0x2a,
	0x1c, 0xc6, 0xb5, 0xd3, 0xc0, 0x0a, 0x6d, 0x5d, 0x47, 0xa8, 0x4d, 0xa6, 0x9d, 0x9c, 0x49, 0x91,
	0x80, 0x12, 0x49, 0x5e, 0x40, 0x06, 0xa5, 0xe0, 0x89, 0x2e, 0x0b, 0x56, 0x0a, 0xf9, 0x96, 0x48,
	0x60, 0x29, 0xce, 0x0b, 0x28, 0xc1, 0xee, 0x35, 0x9b, 0x98, 0x71, 0x8d, 0x0f, 0x22, 0x78, 0xeb,
	0xe2, 0x5a, 0xe4, 0xf2, 0x7a, 0xef, 0x91, 0xaf, 0x1d, 0xa6, 0x14, 0x94, 0xac, 0x5c, 0x83, 0xd2,
	0xcd, 0xf2, 0xe0, 0xdd, 0x40, 0x37, 0x94, 0x49, 0x11, 0x29, 0x41, 0x77, 0x26, 0xf3, 0x9d, 0x47,
	0x00, 0x2c, 0xf5, 0xd5, 0x26, 0x1b, 0x70, 0x74, 0xd5, 0x42, 0xb1, 0xcf, 0x50, 0x77, 0x19, 0xce,
	0xa9, 0x3f, 0x9a, 0x4e, 0xa6, 0xfe, 0xd8, 0x3a, 0xb2, 0xbb, 0xe8, 0x64, 0x19, 0x3e, 0x84, 0xd1,
	0x53, 0x68, 0x19, 0xf6, 0x29, 0x42, 0x93, 0xe9, 0x6c, 0xbe, 0x48, 0xa8, 0x17, 0xf8, 0x96, 0x69,
	0x5f, 0xa0, 0xf3, 0xbf, 0xff, 0x84, 0xce, 0xa2, 0xc7, 0x68, 0xe1, 0x8f, 0xad, 0xce, 0xf0, 0xc7,
	0x40, 0xfd, 0x57, 0xc8, 0x70, 0x6b, 0x9a, 0xe1, 0x6d, 0xcb, 0x25, 0xb4, 0x4a, 0x44, 0x8d, 0xe7,
	0xe1, 0x4e, 0x42, 0x42, 0xca, 0x94, 0xc4, 0x50, 0x48, 0x47, 0x0a, 0x55, 0xe7, 0xdd, 0xb7, 0x9c,
	0xaf, 0xf5, 0x3f, 0xa5, 0xdf, 0xd7, 0xdf, 0x0f, 0xb3, 0x13, 0x78, 0xde, 0xa7, 0xd9, 0x0b, 0x1a,
	0x29, 0x8f, 0x6b, 0xdc, 0xc0, 0x0a, 0xad, 0x5c, 0x5c, 0x15, 0xa3, 0xbf, 0xf6, 0xf3, 0xd8, 0xe3,
	0x3a, 0x3e, 0xcc, 0xe3, 0x95, 0x1b, 0xd7, 0xf3, 0x6f, 0xb3, 0xdf, 0x3c, 0x12, 0xe2, 0x71, 0x4d,
	0xc8, 0x81, 0x41, 0xc8, 0xca, 0x25, 0xa4, 0xe6, 0xbc, 0x1c, 0xd7, 0x87, 0xdd, 0xfd, 0x06, 0x00,
	0x00, 0xff, 0xff, 0x14, 0xde, 0x68, 0xf5, 0x0c, 0x02, 0x00, 0x00,
}
