// Code generated by protoc-gen-go. DO NOT EDIT.
// source: google/cloud/websecurityscanner/v1alpha/web_security_scanner.proto

package websecurityscanner

import (
	context "context"
	fmt "fmt"
	math "math"

	proto "github.com/golang/protobuf/proto"
	empty "github.com/golang/protobuf/ptypes/empty"
	_ "google.golang.org/genproto/googleapis/api/annotations"
	field_mask "google.golang.org/genproto/protobuf/field_mask"
	grpc "google.golang.org/grpc"
)

// Reference imports to suppress errors if they are not otherwise used.
var _ = proto.Marshal
var _ = fmt.Errorf
var _ = math.Inf

// This is a compile-time assertion to ensure that this generated file
// is compatible with the proto package it is being compiled against.
// A compilation error at this line likely means your copy of the
// proto package needs to be updated.
const _ = proto.ProtoPackageIsVersion3 // please upgrade the proto package

// Request for the `CreateScanConfig` method.
type CreateScanConfigRequest struct {
	// Required.
	// The parent resource name where the scan is created, which should be a
	// project resource name in the format 'projects/{projectId}'.
	Parent string `protobuf:"bytes,1,opt,name=parent,proto3" json:"parent,omitempty"`
	// Required.
	// The ScanConfig to be created.
	ScanConfig           *ScanConfig `protobuf:"bytes,2,opt,name=scan_config,json=scanConfig,proto3" json:"scan_config,omitempty"`
	XXX_NoUnkeyedLiteral struct{}    `json:"-"`
	XXX_unrecognized     []byte      `json:"-"`
	XXX_sizecache        int32       `json:"-"`
}

func (m *CreateScanConfigRequest) Reset()         { *m = CreateScanConfigRequest{} }
func (m *CreateScanConfigRequest) String() string { return proto.CompactTextString(m) }
func (*CreateScanConfigRequest) ProtoMessage()    {}
func (*CreateScanConfigRequest) Descriptor() ([]byte, []int) {
	return fileDescriptor_23d01882da6eef5f, []int{0}
}

func (m *CreateScanConfigRequest) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_CreateScanConfigRequest.Unmarshal(m, b)
}
func (m *CreateScanConfigRequest) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_CreateScanConfigRequest.Marshal(b, m, deterministic)
}
func (m *CreateScanConfigRequest) XXX_Merge(src proto.Message) {
	xxx_messageInfo_CreateScanConfigRequest.Merge(m, src)
}
func (m *CreateScanConfigRequest) XXX_Size() int {
	return xxx_messageInfo_CreateScanConfigRequest.Size(m)
}
func (m *CreateScanConfigRequest) XXX_DiscardUnknown() {
	xxx_messageInfo_CreateScanConfigRequest.DiscardUnknown(m)
}

var xxx_messageInfo_CreateScanConfigRequest proto.InternalMessageInfo

func (m *CreateScanConfigRequest) GetParent() string {
	if m != nil {
		return m.Parent
	}
	return ""
}

func (m *CreateScanConfigRequest) GetScanConfig() *ScanConfig {
	if m != nil {
		return m.ScanConfig
	}
	return nil
}

// Request for the `DeleteScanConfig` method.
type DeleteScanConfigRequest struct {
	// Required.
	// The resource name of the ScanConfig to be deleted. The name follows the
	// format of 'projects/{projectId}/scanConfigs/{scanConfigId}'.
	Name                 string   `protobuf:"bytes,1,opt,name=name,proto3" json:"name,omitempty"`
	XXX_NoUnkeyedLiteral struct{} `json:"-"`
	XXX_unrecognized     []byte   `json:"-"`
	XXX_sizecache        int32    `json:"-"`
}

func (m *DeleteScanConfigRequest) Reset()         { *m = DeleteScanConfigRequest{} }
func (m *DeleteScanConfigRequest) String() string { return proto.CompactTextString(m) }
func (*DeleteScanConfigRequest) ProtoMessage()    {}
func (*DeleteScanConfigRequest) Descriptor() ([]byte, []int) {
	return fileDescriptor_23d01882da6eef5f, []int{1}
}

func (m *DeleteScanConfigRequest) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_DeleteScanConfigRequest.Unmarshal(m, b)
}
func (m *DeleteScanConfigRequest) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_DeleteScanConfigRequest.Marshal(b, m, deterministic)
}
func (m *DeleteScanConfigRequest) XXX_Merge(src proto.Message) {
	xxx_messageInfo_DeleteScanConfigRequest.Merge(m, src)
}
func (m *DeleteScanConfigRequest) XXX_Size() int {
	return xxx_messageInfo_DeleteScanConfigRequest.Size(m)
}
func (m *DeleteScanConfigRequest) XXX_DiscardUnknown() {
	xxx_messageInfo_DeleteScanConfigRequest.DiscardUnknown(m)
}

var xxx_messageInfo_DeleteScanConfigRequest proto.InternalMessageInfo

func (m *DeleteScanConfigRequest) GetName() string {
	if m != nil {
		return m.Name
	}
	return ""
}

// Request for the `GetScanConfig` method.
type GetScanConfigRequest struct {
	// Required.
	// The resource name of the ScanConfig to be returned. The name follows the
	// format of 'projects/{projectId}/scanConfigs/{scanConfigId}'.
	Name                 string   `protobuf:"bytes,1,opt,name=name,proto3" json:"name,omitempty"`
	XXX_NoUnkeyedLiteral struct{} `json:"-"`
	XXX_unrecognized     []byte   `json:"-"`
	XXX_sizecache        int32    `json:"-"`
}

func (m *GetScanConfigRequest) Reset()         { *m = GetScanConfigRequest{} }
func (m *GetScanConfigRequest) String() string { return proto.CompactTextString(m) }
func (*GetScanConfigRequest) ProtoMessage()    {}
func (*GetScanConfigRequest) Descriptor() ([]byte, []int) {
	return fileDescriptor_23d01882da6eef5f, []int{2}
}

func (m *GetScanConfigRequest) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_GetScanConfigRequest.Unmarshal(m, b)
}
func (m *GetScanConfigRequest) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_GetScanConfigRequest.Marshal(b, m, deterministic)
}
func (m *GetScanConfigRequest) XXX_Merge(src proto.Message) {
	xxx_messageInfo_GetScanConfigRequest.Merge(m, src)
}
func (m *GetScanConfigRequest) XXX_Size() int {
	return xxx_messageInfo_GetScanConfigRequest.Size(m)
}
func (m *GetScanConfigRequest) XXX_DiscardUnknown() {
	xxx_messageInfo_GetScanConfigRequest.DiscardUnknown(m)
}

var xxx_messageInfo_GetScanConfigRequest proto.InternalMessageInfo

func (m *GetScanConfigRequest) GetName() string {
	if m != nil {
		return m.Name
	}
	return ""
}

// Request for the `ListScanConfigs` method.
type ListScanConfigsRequest struct {
	// Required.
	// The parent resource name, which should be a project resource name in the
	// format 'projects/{projectId}'.
	Parent string `protobuf:"bytes,1,opt,name=parent,proto3" json:"parent,omitempty"`
	// A token identifying a page of results to be returned. This should be a
	// `next_page_token` value returned from a previous List request.
	// If unspecified, the first page of results is returned.
	PageToken string `protobuf:"bytes,2,opt,name=page_token,json=pageToken,proto3" json:"page_token,omitempty"`
	// The maximum number of ScanConfigs to return, can be limited by server.
	// If not specified or not positive, the implementation will select a
	// reasonable value.
	PageSize             int32    `protobuf:"varint,3,opt,name=page_size,json=pageSize,proto3" json:"page_size,omitempty"`
	XXX_NoUnkeyedLiteral struct{} `json:"-"`
	XXX_unrecognized     []byte   `json:"-"`
	XXX_sizecache        int32    `json:"-"`
}

func (m *ListScanConfigsRequest) Reset()         { *m = ListScanConfigsRequest{} }
func (m *ListScanConfigsRequest) String() string { return proto.CompactTextString(m) }
func (*ListScanConfigsRequest) ProtoMessage()    {}
func (*ListScanConfigsRequest) Descriptor() ([]byte, []int) {
	return fileDescriptor_23d01882da6eef5f, []int{3}
}

func (m *ListScanConfigsRequest) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_ListScanConfigsRequest.Unmarshal(m, b)
}
func (m *ListScanConfigsRequest) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_ListScanConfigsRequest.Marshal(b, m, deterministic)
}
func (m *ListScanConfigsRequest) XXX_Merge(src proto.Message) {
	xxx_messageInfo_ListScanConfigsRequest.Merge(m, src)
}
func (m *ListScanConfigsRequest) XXX_Size() int {
	return xxx_messageInfo_ListScanConfigsRequest.Size(m)
}
func (m *ListScanConfigsRequest) XXX_DiscardUnknown() {
	xxx_messageInfo_ListScanConfigsRequest.DiscardUnknown(m)
}

var xxx_messageInfo_ListScanConfigsRequest proto.InternalMessageInfo

func (m *ListScanConfigsRequest) GetParent() string {
	if m != nil {
		return m.Parent
	}
	return ""
}

func (m *ListScanConfigsRequest) GetPageToken() string {
	if m != nil {
		return m.PageToken
	}
	return ""
}

func (m *ListScanConfigsRequest) GetPageSize() int32 {
	if m != nil {
		return m.PageSize
	}
	return 0
}

// Request for the `UpdateScanConfigRequest` method.
type UpdateScanConfigRequest struct {
	// Required.
	// The ScanConfig to be updated. The name field must be set to identify the
	// resource to be updated. The values of fields not covered by the mask
	// will be ignored.
	ScanConfig *ScanConfig `protobuf:"bytes,2,opt,name=scan_config,json=scanConfig,proto3" json:"scan_config,omitempty"`
	// Required.
	// The update mask applies to the resource. For the `FieldMask` definition,
	// see
	// https://developers.google.com/protocol-buffers/docs/reference/google.protobuf#fieldmask
	UpdateMask           *field_mask.FieldMask `protobuf:"bytes,3,opt,name=update_mask,json=updateMask,proto3" json:"update_mask,omitempty"`
	XXX_NoUnkeyedLiteral struct{}              `json:"-"`
	XXX_unrecognized     []byte                `json:"-"`
	XXX_sizecache        int32                 `json:"-"`
}

func (m *UpdateScanConfigRequest) Reset()         { *m = UpdateScanConfigRequest{} }
func (m *UpdateScanConfigRequest) String() string { return proto.CompactTextString(m) }
func (*UpdateScanConfigRequest) ProtoMessage()    {}
func (*UpdateScanConfigRequest) Descriptor() ([]byte, []int) {
	return fileDescriptor_23d01882da6eef5f, []int{4}
}

func (m *UpdateScanConfigRequest) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_UpdateScanConfigRequest.Unmarshal(m, b)
}
func (m *UpdateScanConfigRequest) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_UpdateScanConfigRequest.Marshal(b, m, deterministic)
}
func (m *UpdateScanConfigRequest) XXX_Merge(src proto.Message) {
	xxx_messageInfo_UpdateScanConfigRequest.Merge(m, src)
}
func (m *UpdateScanConfigRequest) XXX_Size() int {
	return xxx_messageInfo_UpdateScanConfigRequest.Size(m)
}
func (m *UpdateScanConfigRequest) XXX_DiscardUnknown() {
	xxx_messageInfo_UpdateScanConfigRequest.DiscardUnknown(m)
}

var xxx_messageInfo_UpdateScanConfigRequest proto.InternalMessageInfo

func (m *UpdateScanConfigRequest) GetScanConfig() *ScanConfig {
	if m != nil {
		return m.ScanConfig
	}
	return nil
}

func (m *UpdateScanConfigRequest) GetUpdateMask() *field_mask.FieldMask {
	if m != nil {
		return m.UpdateMask
	}
	return nil
}

// Response for the `ListScanConfigs` method.
type ListScanConfigsResponse struct {
	// The list of ScanConfigs returned.
	ScanConfigs []*ScanConfig `protobuf:"bytes,1,rep,name=scan_configs,json=scanConfigs,proto3" json:"scan_configs,omitempty"`
	// Token to retrieve the next page of results, or empty if there are no
	// more results in the list.
	NextPageToken        string   `protobuf:"bytes,2,opt,name=next_page_token,json=nextPageToken,proto3" json:"next_page_token,omitempty"`
	XXX_NoUnkeyedLiteral struct{} `json:"-"`
	XXX_unrecognized     []byte   `json:"-"`
	XXX_sizecache        int32    `json:"-"`
}

func (m *ListScanConfigsResponse) Reset()         { *m = ListScanConfigsResponse{} }
func (m *ListScanConfigsResponse) String() string { return proto.CompactTextString(m) }
func (*ListScanConfigsResponse) ProtoMessage()    {}
func (*ListScanConfigsResponse) Descriptor() ([]byte, []int) {
	return fileDescriptor_23d01882da6eef5f, []int{5}
}

func (m *ListScanConfigsResponse) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_ListScanConfigsResponse.Unmarshal(m, b)
}
func (m *ListScanConfigsResponse) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_ListScanConfigsResponse.Marshal(b, m, deterministic)
}
func (m *ListScanConfigsResponse) XXX_Merge(src proto.Message) {
	xxx_messageInfo_ListScanConfigsResponse.Merge(m, src)
}
func (m *ListScanConfigsResponse) XXX_Size() int {
	return xxx_messageInfo_ListScanConfigsResponse.Size(m)
}
func (m *ListScanConfigsResponse) XXX_DiscardUnknown() {
	xxx_messageInfo_ListScanConfigsResponse.DiscardUnknown(m)
}

var xxx_messageInfo_ListScanConfigsResponse proto.InternalMessageInfo

func (m *ListScanConfigsResponse) GetScanConfigs() []*ScanConfig {
	if m != nil {
		return m.ScanConfigs
	}
	return nil
}

func (m *ListScanConfigsResponse) GetNextPageToken() string {
	if m != nil {
		return m.NextPageToken
	}
	return ""
}

// Request for the `StartScanRun` method.
type StartScanRunRequest struct {
	// Required.
	// The resource name of the ScanConfig to be used. The name follows the
	// format of 'projects/{projectId}/scanConfigs/{scanConfigId}'.
	Name                 string   `protobuf:"bytes,1,opt,name=name,proto3" json:"name,omitempty"`
	XXX_NoUnkeyedLiteral struct{} `json:"-"`
	XXX_unrecognized     []byte   `json:"-"`
	XXX_sizecache        int32    `json:"-"`
}

func (m *StartScanRunRequest) Reset()         { *m = StartScanRunRequest{} }
func (m *StartScanRunRequest) String() string { return proto.CompactTextString(m) }
func (*StartScanRunRequest) ProtoMessage()    {}
func (*StartScanRunRequest) Descriptor() ([]byte, []int) {
	return fileDescriptor_23d01882da6eef5f, []int{6}
}

func (m *StartScanRunRequest) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_StartScanRunRequest.Unmarshal(m, b)
}
func (m *StartScanRunRequest) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_StartScanRunRequest.Marshal(b, m, deterministic)
}
func (m *StartScanRunRequest) XXX_Merge(src proto.Message) {
	xxx_messageInfo_StartScanRunRequest.Merge(m, src)
}
func (m *StartScanRunRequest) XXX_Size() int {
	return xxx_messageInfo_StartScanRunRequest.Size(m)
}
func (m *StartScanRunRequest) XXX_DiscardUnknown() {
	xxx_messageInfo_StartScanRunRequest.DiscardUnknown(m)
}

var xxx_messageInfo_StartScanRunRequest proto.InternalMessageInfo

func (m *StartScanRunRequest) GetName() string {
	if m != nil {
		return m.Name
	}
	return ""
}

// Request for the `GetScanRun` method.
type GetScanRunRequest struct {
	// Required.
	// The resource name of the ScanRun to be returned. The name follows the
	// format of
	// 'projects/{projectId}/scanConfigs/{scanConfigId}/scanRuns/{scanRunId}'.
	Name                 string   `protobuf:"bytes,1,opt,name=name,proto3" json:"name,omitempty"`
	XXX_NoUnkeyedLiteral struct{} `json:"-"`
	XXX_unrecognized     []byte   `json:"-"`
	XXX_sizecache        int32    `json:"-"`
}

func (m *GetScanRunRequest) Reset()         { *m = GetScanRunRequest{} }
func (m *GetScanRunRequest) String() string { return proto.CompactTextString(m) }
func (*GetScanRunRequest) ProtoMessage()    {}
func (*GetScanRunRequest) Descriptor() ([]byte, []int) {
	return fileDescriptor_23d01882da6eef5f, []int{7}
}

func (m *GetScanRunRequest) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_GetScanRunRequest.Unmarshal(m, b)
}
func (m *GetScanRunRequest) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_GetScanRunRequest.Marshal(b, m, deterministic)
}
func (m *GetScanRunRequest) XXX_Merge(src proto.Message) {
	xxx_messageInfo_GetScanRunRequest.Merge(m, src)
}
func (m *GetScanRunRequest) XXX_Size() int {
	return xxx_messageInfo_GetScanRunRequest.Size(m)
}
func (m *GetScanRunRequest) XXX_DiscardUnknown() {
	xxx_messageInfo_GetScanRunRequest.DiscardUnknown(m)
}

var xxx_messageInfo_GetScanRunRequest proto.InternalMessageInfo

func (m *GetScanRunRequest) GetName() string {
	if m != nil {
		return m.Name
	}
	return ""
}

// Request for the `ListScanRuns` method.
type ListScanRunsRequest struct {
	// Required.
	// The parent resource name, which should be a scan resource name in the
	// format 'projects/{projectId}/scanConfigs/{scanConfigId}'.
	Parent string `protobuf:"bytes,1,opt,name=parent,proto3" json:"parent,omitempty"`
	// A token identifying a page of results to be returned. This should be a
	// `next_page_token` value returned from a previous List request.
	// If unspecified, the first page of results is returned.
	PageToken string `protobuf:"bytes,2,opt,name=page_token,json=pageToken,proto3" json:"page_token,omitempty"`
	// The maximum number of ScanRuns to return, can be limited by server.
	// If not specified or not positive, the implementation will select a
	// reasonable value.
	PageSize             int32    `protobuf:"varint,3,opt,name=page_size,json=pageSize,proto3" json:"page_size,omitempty"`
	XXX_NoUnkeyedLiteral struct{} `json:"-"`
	XXX_unrecognized     []byte   `json:"-"`
	XXX_sizecache        int32    `json:"-"`
}

func (m *ListScanRunsRequest) Reset()         { *m = ListScanRunsRequest{} }
func (m *ListScanRunsRequest) String() string { return proto.CompactTextString(m) }
func (*ListScanRunsRequest) ProtoMessage()    {}
func (*ListScanRunsRequest) Descriptor() ([]byte, []int) {
	return fileDescriptor_23d01882da6eef5f, []int{8}
}

func (m *ListScanRunsRequest) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_ListScanRunsRequest.Unmarshal(m, b)
}
func (m *ListScanRunsRequest) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_ListScanRunsRequest.Marshal(b, m, deterministic)
}
func (m *ListScanRunsRequest) XXX_Merge(src proto.Message) {
	xxx_messageInfo_ListScanRunsRequest.Merge(m, src)
}
func (m *ListScanRunsRequest) XXX_Size() int {
	return xxx_messageInfo_ListScanRunsRequest.Size(m)
}
func (m *ListScanRunsRequest) XXX_DiscardUnknown() {
	xxx_messageInfo_ListScanRunsRequest.DiscardUnknown(m)
}

var xxx_messageInfo_ListScanRunsRequest proto.InternalMessageInfo

func (m *ListScanRunsRequest) GetParent() string {
	if m != nil {
		return m.Parent
	}
	return ""
}

func (m *ListScanRunsRequest) GetPageToken() string {
	if m != nil {
		return m.PageToken
	}
	return ""
}

func (m *ListScanRunsRequest) GetPageSize() int32 {
	if m != nil {
		return m.PageSize
	}
	return 0
}

// Response for the `ListScanRuns` method.
type ListScanRunsResponse struct {
	// The list of ScanRuns returned.
	ScanRuns []*ScanRun `protobuf:"bytes,1,rep,name=scan_runs,json=scanRuns,proto3" json:"scan_runs,omitempty"`
	// Token to retrieve the next page of results, or empty if there are no
	// more results in the list.
	NextPageToken        string   `protobuf:"bytes,2,opt,name=next_page_token,json=nextPageToken,proto3" json:"next_page_token,omitempty"`
	XXX_NoUnkeyedLiteral struct{} `json:"-"`
	XXX_unrecognized     []byte   `json:"-"`
	XXX_sizecache        int32    `json:"-"`
}

func (m *ListScanRunsResponse) Reset()         { *m = ListScanRunsResponse{} }
func (m *ListScanRunsResponse) String() string { return proto.CompactTextString(m) }
func (*ListScanRunsResponse) ProtoMessage()    {}
func (*ListScanRunsResponse) Descriptor() ([]byte, []int) {
	return fileDescriptor_23d01882da6eef5f, []int{9}
}

func (m *ListScanRunsResponse) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_ListScanRunsResponse.Unmarshal(m, b)
}
func (m *ListScanRunsResponse) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_ListScanRunsResponse.Marshal(b, m, deterministic)
}
func (m *ListScanRunsResponse) XXX_Merge(src proto.Message) {
	xxx_messageInfo_ListScanRunsResponse.Merge(m, src)
}
func (m *ListScanRunsResponse) XXX_Size() int {
	return xxx_messageInfo_ListScanRunsResponse.Size(m)
}
func (m *ListScanRunsResponse) XXX_DiscardUnknown() {
	xxx_messageInfo_ListScanRunsResponse.DiscardUnknown(m)
}

var xxx_messageInfo_ListScanRunsResponse proto.InternalMessageInfo

func (m *ListScanRunsResponse) GetScanRuns() []*ScanRun {
	if m != nil {
		return m.ScanRuns
	}
	return nil
}

func (m *ListScanRunsResponse) GetNextPageToken() string {
	if m != nil {
		return m.NextPageToken
	}
	return ""
}

// Request for the `StopScanRun` method.
type StopScanRunRequest struct {
	// Required.
	// The resource name of the ScanRun to be stopped. The name follows the
	// format of
	// 'projects/{projectId}/scanConfigs/{scanConfigId}/scanRuns/{scanRunId}'.
	Name                 string   `protobuf:"bytes,1,opt,name=name,proto3" json:"name,omitempty"`
	XXX_NoUnkeyedLiteral struct{} `json:"-"`
	XXX_unrecognized     []byte   `json:"-"`
	XXX_sizecache        int32    `json:"-"`
}

func (m *StopScanRunRequest) Reset()         { *m = StopScanRunRequest{} }
func (m *StopScanRunRequest) String() string { return proto.CompactTextString(m) }
func (*StopScanRunRequest) ProtoMessage()    {}
func (*StopScanRunRequest) Descriptor() ([]byte, []int) {
	return fileDescriptor_23d01882da6eef5f, []int{10}
}

func (m *StopScanRunRequest) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_StopScanRunRequest.Unmarshal(m, b)
}
func (m *StopScanRunRequest) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_StopScanRunRequest.Marshal(b, m, deterministic)
}
func (m *StopScanRunRequest) XXX_Merge(src proto.Message) {
	xxx_messageInfo_StopScanRunRequest.Merge(m, src)
}
func (m *StopScanRunRequest) XXX_Size() int {
	return xxx_messageInfo_StopScanRunRequest.Size(m)
}
func (m *StopScanRunRequest) XXX_DiscardUnknown() {
	xxx_messageInfo_StopScanRunRequest.DiscardUnknown(m)
}

var xxx_messageInfo_StopScanRunRequest proto.InternalMessageInfo

func (m *StopScanRunRequest) GetName() string {
	if m != nil {
		return m.Name
	}
	return ""
}

// Request for the `ListCrawledUrls` method.
type ListCrawledUrlsRequest struct {
	// Required.
	// The parent resource name, which should be a scan run resource name in the
	// format
	// 'projects/{projectId}/scanConfigs/{scanConfigId}/scanRuns/{scanRunId}'.
	Parent string `protobuf:"bytes,1,opt,name=parent,proto3" json:"parent,omitempty"`
	// A token identifying a page of results to be returned. This should be a
	// `next_page_token` value returned from a previous List request.
	// If unspecified, the first page of results is returned.
	PageToken string `protobuf:"bytes,2,opt,name=page_token,json=pageToken,proto3" json:"page_token,omitempty"`
	// The maximum number of CrawledUrls to return, can be limited by server.
	// If not specified or not positive, the implementation will select a
	// reasonable value.
	PageSize             int32    `protobuf:"varint,3,opt,name=page_size,json=pageSize,proto3" json:"page_size,omitempty"`
	XXX_NoUnkeyedLiteral struct{} `json:"-"`
	XXX_unrecognized     []byte   `json:"-"`
	XXX_sizecache        int32    `json:"-"`
}

func (m *ListCrawledUrlsRequest) Reset()         { *m = ListCrawledUrlsRequest{} }
func (m *ListCrawledUrlsRequest) String() string { return proto.CompactTextString(m) }
func (*ListCrawledUrlsRequest) ProtoMessage()    {}
func (*ListCrawledUrlsRequest) Descriptor() ([]byte, []int) {
	return fileDescriptor_23d01882da6eef5f, []int{11}
}

func (m *ListCrawledUrlsRequest) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_ListCrawledUrlsRequest.Unmarshal(m, b)
}
func (m *ListCrawledUrlsRequest) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_ListCrawledUrlsRequest.Marshal(b, m, deterministic)
}
func (m *ListCrawledUrlsRequest) XXX_Merge(src proto.Message) {
	xxx_messageInfo_ListCrawledUrlsRequest.Merge(m, src)
}
func (m *ListCrawledUrlsRequest) XXX_Size() int {
	return xxx_messageInfo_ListCrawledUrlsRequest.Size(m)
}
func (m *ListCrawledUrlsRequest) XXX_DiscardUnknown() {
	xxx_messageInfo_ListCrawledUrlsRequest.DiscardUnknown(m)
}

var xxx_messageInfo_ListCrawledUrlsRequest proto.InternalMessageInfo

func (m *ListCrawledUrlsRequest) GetParent() string {
	if m != nil {
		return m.Parent
	}
	return ""
}

func (m *ListCrawledUrlsRequest) GetPageToken() string {
	if m != nil {
		return m.PageToken
	}
	return ""
}

func (m *ListCrawledUrlsRequest) GetPageSize() int32 {
	if m != nil {
		return m.PageSize
	}
	return 0
}

// Response for the `ListCrawledUrls` method.
type ListCrawledUrlsResponse struct {
	// The list of CrawledUrls returned.
	CrawledUrls []*CrawledUrl `protobuf:"bytes,1,rep,name=crawled_urls,json=crawledUrls,proto3" json:"crawled_urls,omitempty"`
	// Token to retrieve the next page of results, or empty if there are no
	// more results in the list.
	NextPageToken        string   `protobuf:"bytes,2,opt,name=next_page_token,json=nextPageToken,proto3" json:"next_page_token,omitempty"`
	XXX_NoUnkeyedLiteral struct{} `json:"-"`
	XXX_unrecognized     []byte   `json:"-"`
	XXX_sizecache        int32    `json:"-"`
}

func (m *ListCrawledUrlsResponse) Reset()         { *m = ListCrawledUrlsResponse{} }
func (m *ListCrawledUrlsResponse) String() string { return proto.CompactTextString(m) }
func (*ListCrawledUrlsResponse) ProtoMessage()    {}
func (*ListCrawledUrlsResponse) Descriptor() ([]byte, []int) {
	return fileDescriptor_23d01882da6eef5f, []int{12}
}

func (m *ListCrawledUrlsResponse) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_ListCrawledUrlsResponse.Unmarshal(m, b)
}
func (m *ListCrawledUrlsResponse) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_ListCrawledUrlsResponse.Marshal(b, m, deterministic)
}
func (m *ListCrawledUrlsResponse) XXX_Merge(src proto.Message) {
	xxx_messageInfo_ListCrawledUrlsResponse.Merge(m, src)
}
func (m *ListCrawledUrlsResponse) XXX_Size() int {
	return xxx_messageInfo_ListCrawledUrlsResponse.Size(m)
}
func (m *ListCrawledUrlsResponse) XXX_DiscardUnknown() {
	xxx_messageInfo_ListCrawledUrlsResponse.DiscardUnknown(m)
}

var xxx_messageInfo_ListCrawledUrlsResponse proto.InternalMessageInfo

func (m *ListCrawledUrlsResponse) GetCrawledUrls() []*CrawledUrl {
	if m != nil {
		return m.CrawledUrls
	}
	return nil
}

func (m *ListCrawledUrlsResponse) GetNextPageToken() string {
	if m != nil {
		return m.NextPageToken
	}
	return ""
}

// Request for the `GetFinding` method.
type GetFindingRequest struct {
	// Required.
	// The resource name of the Finding to be returned. The name follows the
	// format of
	// 'projects/{projectId}/scanConfigs/{scanConfigId}/scanRuns/{scanRunId}/findings/{findingId}'.
	Name                 string   `protobuf:"bytes,1,opt,name=name,proto3" json:"name,omitempty"`
	XXX_NoUnkeyedLiteral struct{} `json:"-"`
	XXX_unrecognized     []byte   `json:"-"`
	XXX_sizecache        int32    `json:"-"`
}

func (m *GetFindingRequest) Reset()         { *m = GetFindingRequest{} }
func (m *GetFindingRequest) String() string { return proto.CompactTextString(m) }
func (*GetFindingRequest) ProtoMessage()    {}
func (*GetFindingRequest) Descriptor() ([]byte, []int) {
	return fileDescriptor_23d01882da6eef5f, []int{13}
}

func (m *GetFindingRequest) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_GetFindingRequest.Unmarshal(m, b)
}
func (m *GetFindingRequest) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_GetFindingRequest.Marshal(b, m, deterministic)
}
func (m *GetFindingRequest) XXX_Merge(src proto.Message) {
	xxx_messageInfo_GetFindingRequest.Merge(m, src)
}
func (m *GetFindingRequest) XXX_Size() int {
	return xxx_messageInfo_GetFindingRequest.Size(m)
}
func (m *GetFindingRequest) XXX_DiscardUnknown() {
	xxx_messageInfo_GetFindingRequest.DiscardUnknown(m)
}

var xxx_messageInfo_GetFindingRequest proto.InternalMessageInfo

func (m *GetFindingRequest) GetName() string {
	if m != nil {
		return m.Name
	}
	return ""
}

// Request for the `ListFindings` method.
type ListFindingsRequest struct {
	// Required.
	// The parent resource name, which should be a scan run resource name in the
	// format
	// 'projects/{projectId}/scanConfigs/{scanConfigId}/scanRuns/{scanRunId}'.
	Parent string `protobuf:"bytes,1,opt,name=parent,proto3" json:"parent,omitempty"`
	// The filter expression. The expression must be in the format: <field>
	// <operator> <value>.
	// Supported field: 'finding_type'.
	// Supported operator: '='.
	Filter string `protobuf:"bytes,2,opt,name=filter,proto3" json:"filter,omitempty"`
	// A token identifying a page of results to be returned. This should be a
	// `next_page_token` value returned from a previous List request.
	// If unspecified, the first page of results is returned.
	PageToken string `protobuf:"bytes,3,opt,name=page_token,json=pageToken,proto3" json:"page_token,omitempty"`
	// The maximum number of Findings to return, can be limited by server.
	// If not specified or not positive, the implementation will select a
	// reasonable value.
	PageSize             int32    `protobuf:"varint,4,opt,name=page_size,json=pageSize,proto3" json:"page_size,omitempty"`
	XXX_NoUnkeyedLiteral struct{} `json:"-"`
	XXX_unrecognized     []byte   `json:"-"`
	XXX_sizecache        int32    `json:"-"`
}

func (m *ListFindingsRequest) Reset()         { *m = ListFindingsRequest{} }
func (m *ListFindingsRequest) String() string { return proto.CompactTextString(m) }
func (*ListFindingsRequest) ProtoMessage()    {}
func (*ListFindingsRequest) Descriptor() ([]byte, []int) {
	return fileDescriptor_23d01882da6eef5f, []int{14}
}

func (m *ListFindingsRequest) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_ListFindingsRequest.Unmarshal(m, b)
}
func (m *ListFindingsRequest) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_ListFindingsRequest.Marshal(b, m, deterministic)
}
func (m *ListFindingsRequest) XXX_Merge(src proto.Message) {
	xxx_messageInfo_ListFindingsRequest.Merge(m, src)
}
func (m *ListFindingsRequest) XXX_Size() int {
	return xxx_messageInfo_ListFindingsRequest.Size(m)
}
func (m *ListFindingsRequest) XXX_DiscardUnknown() {
	xxx_messageInfo_ListFindingsRequest.DiscardUnknown(m)
}

var xxx_messageInfo_ListFindingsRequest proto.InternalMessageInfo

func (m *ListFindingsRequest) GetParent() string {
	if m != nil {
		return m.Parent
	}
	return ""
}

func (m *ListFindingsRequest) GetFilter() string {
	if m != nil {
		return m.Filter
	}
	return ""
}

func (m *ListFindingsRequest) GetPageToken() string {
	if m != nil {
		return m.PageToken
	}
	return ""
}

func (m *ListFindingsRequest) GetPageSize() int32 {
	if m != nil {
		return m.PageSize
	}
	return 0
}

// Response for the `ListFindings` method.
type ListFindingsResponse struct {
	// The list of Findings returned.
	Findings []*Finding `protobuf:"bytes,1,rep,name=findings,proto3" json:"findings,omitempty"`
	// Token to retrieve the next page of results, or empty if there are no
	// more results in the list.
	NextPageToken        string   `protobuf:"bytes,2,opt,name=next_page_token,json=nextPageToken,proto3" json:"next_page_token,omitempty"`
	XXX_NoUnkeyedLiteral struct{} `json:"-"`
	XXX_unrecognized     []byte   `json:"-"`
	XXX_sizecache        int32    `json:"-"`
}

func (m *ListFindingsResponse) Reset()         { *m = ListFindingsResponse{} }
func (m *ListFindingsResponse) String() string { return proto.CompactTextString(m) }
func (*ListFindingsResponse) ProtoMessage()    {}
func (*ListFindingsResponse) Descriptor() ([]byte, []int) {
	return fileDescriptor_23d01882da6eef5f, []int{15}
}

func (m *ListFindingsResponse) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_ListFindingsResponse.Unmarshal(m, b)
}
func (m *ListFindingsResponse) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_ListFindingsResponse.Marshal(b, m, deterministic)
}
func (m *ListFindingsResponse) XXX_Merge(src proto.Message) {
	xxx_messageInfo_ListFindingsResponse.Merge(m, src)
}
func (m *ListFindingsResponse) XXX_Size() int {
	return xxx_messageInfo_ListFindingsResponse.Size(m)
}
func (m *ListFindingsResponse) XXX_DiscardUnknown() {
	xxx_messageInfo_ListFindingsResponse.DiscardUnknown(m)
}

var xxx_messageInfo_ListFindingsResponse proto.InternalMessageInfo

func (m *ListFindingsResponse) GetFindings() []*Finding {
	if m != nil {
		return m.Findings
	}
	return nil
}

func (m *ListFindingsResponse) GetNextPageToken() string {
	if m != nil {
		return m.NextPageToken
	}
	return ""
}

// Request for the `ListFindingTypeStats` method.
type ListFindingTypeStatsRequest struct {
	// Required.
	// The parent resource name, which should be a scan run resource name in the
	// format
	// 'projects/{projectId}/scanConfigs/{scanConfigId}/scanRuns/{scanRunId}'.
	Parent               string   `protobuf:"bytes,1,opt,name=parent,proto3" json:"parent,omitempty"`
	XXX_NoUnkeyedLiteral struct{} `json:"-"`
	XXX_unrecognized     []byte   `json:"-"`
	XXX_sizecache        int32    `json:"-"`
}

func (m *ListFindingTypeStatsRequest) Reset()         { *m = ListFindingTypeStatsRequest{} }
func (m *ListFindingTypeStatsRequest) String() string { return proto.CompactTextString(m) }
func (*ListFindingTypeStatsRequest) ProtoMessage()    {}
func (*ListFindingTypeStatsRequest) Descriptor() ([]byte, []int) {
	return fileDescriptor_23d01882da6eef5f, []int{16}
}

func (m *ListFindingTypeStatsRequest) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_ListFindingTypeStatsRequest.Unmarshal(m, b)
}
func (m *ListFindingTypeStatsRequest) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_ListFindingTypeStatsRequest.Marshal(b, m, deterministic)
}
func (m *ListFindingTypeStatsRequest) XXX_Merge(src proto.Message) {
	xxx_messageInfo_ListFindingTypeStatsRequest.Merge(m, src)
}
func (m *ListFindingTypeStatsRequest) XXX_Size() int {
	return xxx_messageInfo_ListFindingTypeStatsRequest.Size(m)
}
func (m *ListFindingTypeStatsRequest) XXX_DiscardUnknown() {
	xxx_messageInfo_ListFindingTypeStatsRequest.DiscardUnknown(m)
}

var xxx_messageInfo_ListFindingTypeStatsRequest proto.InternalMessageInfo

func (m *ListFindingTypeStatsRequest) GetParent() string {
	if m != nil {
		return m.Parent
	}
	return ""
}

// Response for the `ListFindingTypeStats` method.
type ListFindingTypeStatsResponse struct {
	// The list of FindingTypeStats returned.
	FindingTypeStats     []*FindingTypeStats `protobuf:"bytes,1,rep,name=finding_type_stats,json=findingTypeStats,proto3" json:"finding_type_stats,omitempty"`
	XXX_NoUnkeyedLiteral struct{}            `json:"-"`
	XXX_unrecognized     []byte              `json:"-"`
	XXX_sizecache        int32               `json:"-"`
}

func (m *ListFindingTypeStatsResponse) Reset()         { *m = ListFindingTypeStatsResponse{} }
func (m *ListFindingTypeStatsResponse) String() string { return proto.CompactTextString(m) }
func (*ListFindingTypeStatsResponse) ProtoMessage()    {}
func (*ListFindingTypeStatsResponse) Descriptor() ([]byte, []int) {
	return fileDescriptor_23d01882da6eef5f, []int{17}
}

func (m *ListFindingTypeStatsResponse) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_ListFindingTypeStatsResponse.Unmarshal(m, b)
}
func (m *ListFindingTypeStatsResponse) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_ListFindingTypeStatsResponse.Marshal(b, m, deterministic)
}
func (m *ListFindingTypeStatsResponse) XXX_Merge(src proto.Message) {
	xxx_messageInfo_ListFindingTypeStatsResponse.Merge(m, src)
}
func (m *ListFindingTypeStatsResponse) XXX_Size() int {
	return xxx_messageInfo_ListFindingTypeStatsResponse.Size(m)
}
func (m *ListFindingTypeStatsResponse) XXX_DiscardUnknown() {
	xxx_messageInfo_ListFindingTypeStatsResponse.DiscardUnknown(m)
}

var xxx_messageInfo_ListFindingTypeStatsResponse proto.InternalMessageInfo

func (m *ListFindingTypeStatsResponse) GetFindingTypeStats() []*FindingTypeStats {
	if m != nil {
		return m.FindingTypeStats
	}
	return nil
}

func init() {
	proto.RegisterType((*CreateScanConfigRequest)(nil), "google.cloud.websecurityscanner.v1alpha.CreateScanConfigRequest")
	proto.RegisterType((*DeleteScanConfigRequest)(nil), "google.cloud.websecurityscanner.v1alpha.DeleteScanConfigRequest")
	proto.RegisterType((*GetScanConfigRequest)(nil), "google.cloud.websecurityscanner.v1alpha.GetScanConfigRequest")
	proto.RegisterType((*ListScanConfigsRequest)(nil), "google.cloud.websecurityscanner.v1alpha.ListScanConfigsRequest")
	proto.RegisterType((*UpdateScanConfigRequest)(nil), "google.cloud.websecurityscanner.v1alpha.UpdateScanConfigRequest")
	proto.RegisterType((*ListScanConfigsResponse)(nil), "google.cloud.websecurityscanner.v1alpha.ListScanConfigsResponse")
	proto.RegisterType((*StartScanRunRequest)(nil), "google.cloud.websecurityscanner.v1alpha.StartScanRunRequest")
	proto.RegisterType((*GetScanRunRequest)(nil), "google.cloud.websecurityscanner.v1alpha.GetScanRunRequest")
	proto.RegisterType((*ListScanRunsRequest)(nil), "google.cloud.websecurityscanner.v1alpha.ListScanRunsRequest")
	proto.RegisterType((*ListScanRunsResponse)(nil), "google.cloud.websecurityscanner.v1alpha.ListScanRunsResponse")
	proto.RegisterType((*StopScanRunRequest)(nil), "google.cloud.websecurityscanner.v1alpha.StopScanRunRequest")
	proto.RegisterType((*ListCrawledUrlsRequest)(nil), "google.cloud.websecurityscanner.v1alpha.ListCrawledUrlsRequest")
	proto.RegisterType((*ListCrawledUrlsResponse)(nil), "google.cloud.websecurityscanner.v1alpha.ListCrawledUrlsResponse")
	proto.RegisterType((*GetFindingRequest)(nil), "google.cloud.websecurityscanner.v1alpha.GetFindingRequest")
	proto.RegisterType((*ListFindingsRequest)(nil), "google.cloud.websecurityscanner.v1alpha.ListFindingsRequest")
	proto.RegisterType((*ListFindingsResponse)(nil), "google.cloud.websecurityscanner.v1alpha.ListFindingsResponse")
	proto.RegisterType((*ListFindingTypeStatsRequest)(nil), "google.cloud.websecurityscanner.v1alpha.ListFindingTypeStatsRequest")
	proto.RegisterType((*ListFindingTypeStatsResponse)(nil), "google.cloud.websecurityscanner.v1alpha.ListFindingTypeStatsResponse")
}

func init() {
	proto.RegisterFile("google/cloud/websecurityscanner/v1alpha/web_security_scanner.proto", fileDescriptor_23d01882da6eef5f)
}

var fileDescriptor_23d01882da6eef5f = []byte{
	// 1115 bytes of a gzipped FileDescriptorProto
	0x1f, 0x8b, 0x08, 0x00, 0x00, 0x00, 0x00, 0x00, 0x02, 0xff, 0xb4, 0x58, 0xcf, 0x6f, 0x1b, 0x45,
	0x14, 0xd6, 0xb4, 0x25, 0x4a, 0x9e, 0x53, 0x35, 0x4c, 0xa3, 0x38, 0xda, 0x14, 0xc9, 0xda, 0x03,
	0x35, 0x46, 0x78, 0x4b, 0x42, 0x80, 0x38, 0x18, 0x42, 0xdc, 0x06, 0x90, 0x5a, 0x14, 0xd9, 0x29,
	0x08, 0x2e, 0xab, 0x8d, 0x3d, 0x36, 0x4b, 0x36, 0xb3, 0xcb, 0xce, 0x98, 0x92, 0xa2, 0x1e, 0xe0,
	0xc2, 0x05, 0x4e, 0x9c, 0xb8, 0x70, 0xe1, 0xca, 0x15, 0x21, 0x8e, 0x70, 0x40, 0x3d, 0x22, 0x95,
	0x3b, 0x17, 0xfe, 0x03, 0xfe, 0x01, 0xb4, 0xb3, 0xb3, 0xf6, 0x78, 0x77, 0x6b, 0xef, 0x38, 0xca,
	0x6d, 0xe7, 0xd7, 0x9b, 0xef, 0x7d, 0xef, 0xbd, 0x79, 0x9f, 0x16, 0xf6, 0x07, 0xbe, 0x3f, 0xf0,
	0x88, 0xd5, 0xf5, 0xfc, 0x61, 0xcf, 0x7a, 0x40, 0x8e, 0x19, 0xe9, 0x0e, 0x43, 0x97, 0x9f, 0xb1,
	0xae, 0x43, 0x29, 0x09, 0xad, 0xcf, 0x5f, 0x76, 0xbc, 0xe0, 0x13, 0x27, 0x5a, 0xb2, 0x93, 0x35,
	0x5b, 0x2e, 0xd6, 0x83, 0xd0, 0xe7, 0x3e, 0xbe, 0x19, 0xdb, 0xa8, 0x0b, 0x1b, 0xf5, 0xac, 0x8d,
	0xba, 0xb4, 0x61, 0xdc, 0x90, 0x97, 0x39, 0x81, 0x6b, 0x39, 0x94, 0xfa, 0xdc, 0xe1, 0xae, 0x4f,
	0x59, 0x6c, 0xc6, 0xd8, 0x29, 0x0a, 0xa5, 0x1b, 0x3a, 0x0f, 0x3c, 0xd2, 0xb3, 0x87, 0xa1, 0x27,
	0x8f, 0x6e, 0x17, 0x3d, 0xda, 0x77, 0x69, 0xcf, 0xa5, 0x03, 0x79, 0x6c, 0x4f, 0xf3, 0x98, 0xcd,
	0xcf, 0x02, 0x62, 0x33, 0xee, 0x70, 0x6d, 0xcc, 0xd1, 0xd8, 0xee, 0xfa, 0xb4, 0xef, 0x26, 0x97,
	0xbf, 0xaa, 0x75, 0x34, 0x1c, 0x52, 0x79, 0x6e, 0x43, 0x9e, 0x13, 0xa3, 0xe3, 0x61, 0xdf, 0x22,
	0xa7, 0x01, 0x3f, 0x93, 0x8b, 0x95, 0xf4, 0x62, 0xdf, 0x25, 0x5e, 0xcf, 0x3e, 0x75, 0xd8, 0x49,
	0xbc, 0xc3, 0xfc, 0x06, 0x41, 0xb9, 0x15, 0x12, 0x87, 0x93, 0x4e, 0xd7, 0xa1, 0x2d, 0x81, 0xa8,
	0x4d, 0x3e, 0x1b, 0x12, 0xc6, 0xf1, 0x1a, 0x2c, 0x04, 0x4e, 0x48, 0x28, 0x5f, 0x47, 0x15, 0x54,
	0x5d, 0x6a, 0xcb, 0x11, 0x3e, 0x82, 0x92, 0x82, 0x7f, 0xfd, 0x52, 0x05, 0x55, 0x4b, 0x9b, 0x5b,
	0xf5, 0x82, 0x61, 0xaf, 0x2b, 0x17, 0x01, 0x1b, 0x7d, 0x9b, 0x2f, 0x41, 0xf9, 0x36, 0xf1, 0x48,
	0x1e, 0x10, 0x0c, 0x57, 0xa8, 0x73, 0x4a, 0x24, 0x0c, 0xf1, 0x6d, 0xd6, 0x60, 0xf5, 0x1d, 0xc2,
	0x8b, 0xed, 0xf5, 0x60, 0xed, 0xae, 0xcb, 0x94, 0xcd, 0x6c, 0x96, 0x8b, 0xcf, 0x01, 0x04, 0xce,
	0x80, 0xd8, 0xdc, 0x3f, 0x21, 0x54, 0x78, 0xb8, 0xd4, 0x5e, 0x8a, 0x66, 0x8e, 0xa2, 0x09, 0xbc,
	0x01, 0x62, 0x60, 0x33, 0xf7, 0x21, 0x59, 0xbf, 0x5c, 0x41, 0xd5, 0x67, 0xda, 0x8b, 0xd1, 0x44,
	0xc7, 0x7d, 0x48, 0xcc, 0x9f, 0x11, 0x94, 0xef, 0x07, 0xbd, 0x5c, 0x4a, 0x2f, 0x84, 0x3a, 0xbc,
	0x0b, 0xa5, 0xa1, 0xb8, 0x50, 0x44, 0x56, 0x00, 0x2a, 0x6d, 0x1a, 0x89, 0xd5, 0x24, 0xf8, 0xf5,
	0x83, 0x28, 0xf8, 0xf7, 0x1c, 0x76, 0xd2, 0x86, 0x78, 0x7b, 0xf4, 0x6d, 0xfe, 0x80, 0xa0, 0x9c,
	0x61, 0x87, 0x05, 0x3e, 0x65, 0x04, 0x7f, 0x00, 0xcb, 0x0a, 0x5c, 0xb6, 0x8e, 0x2a, 0x97, 0xe7,
	0xc5, 0x5b, 0x1a, 0xe3, 0x65, 0xf8, 0x79, 0xb8, 0x46, 0xc9, 0x17, 0xdc, 0xce, 0x70, 0x7c, 0x35,
	0x9a, 0x3e, 0x4c, 0x78, 0x36, 0x5f, 0x80, 0xeb, 0x1d, 0xee, 0x84, 0x02, 0x5b, 0x7b, 0x48, 0xa7,
	0xc5, 0xf8, 0x26, 0x3c, 0x2b, 0xf3, 0x61, 0xc6, 0x46, 0x17, 0xae, 0x27, 0xee, 0xb6, 0x87, 0xf4,
	0x42, 0x33, 0xe1, 0x3b, 0x04, 0xab, 0x93, 0x77, 0x49, 0x5e, 0xef, 0xc1, 0x52, 0x52, 0xc6, 0x09,
	0xa9, 0xb7, 0xb4, 0x48, 0x8d, 0x7c, 0x5c, 0x64, 0xd2, 0x6c, 0x61, 0x3a, 0xab, 0x80, 0x3b, 0xdc,
	0x0f, 0x0a, 0x90, 0x24, 0x2b, 0xa6, 0x15, 0x3f, 0xad, 0xf7, 0x43, 0xef, 0x42, 0x79, 0x4a, 0x52,
	0x70, 0xe2, 0xba, 0x71, 0x0a, 0x2a, 0x0f, 0xbc, 0x7e, 0x0a, 0x8e, 0x6d, 0xb6, 0x4b, 0xdd, 0xb1,
	0xfd, 0xc2, 0x9c, 0xc5, 0x79, 0x75, 0x10, 0xbf, 0xf8, 0xd3, 0x28, 0xfb, 0x0a, 0xc5, 0x89, 0x25,
	0xb7, 0xce, 0x24, 0x6c, 0x0d, 0x16, 0xfa, 0xae, 0xc7, 0x49, 0x28, 0xef, 0x95, 0xa3, 0x14, 0x91,
	0x97, 0xa7, 0x12, 0x79, 0x25, 0x45, 0xe4, 0xb7, 0x32, 0xe1, 0xc6, 0x18, 0x24, 0x8b, 0x77, 0x61,
	0x51, 0x36, 0x2d, 0xfd, 0x7c, 0x4b, 0x7c, 0x1f, 0x59, 0x28, 0xcc, 0xdd, 0x36, 0x6c, 0x28, 0x68,
	0x8e, 0xce, 0x02, 0xd2, 0x89, 0x9a, 0xe5, 0x0c, 0x66, 0xa2, 0x9e, 0x74, 0x23, 0xff, 0x9c, 0xf4,
	0x66, 0x00, 0x38, 0xdb, 0x82, 0xa5, 0x5f, 0x3b, 0xba, 0x7e, 0x8d, 0xcd, 0xaf, 0xf4, 0x53, 0x33,
	0x9b, 0x7f, 0xad, 0x02, 0xfe, 0x90, 0x1c, 0x77, 0xa4, 0x85, 0x4e, 0x6c, 0x01, 0x3f, 0x46, 0xb0,
	0x92, 0x6e, 0x9a, 0x78, 0x4f, 0x23, 0x25, 0x73, 0xfb, 0xad, 0x31, 0xcf, 0xbb, 0x6a, 0x36, 0xbf,
	0x7e, 0xf2, 0xef, 0xf7, 0x97, 0x5e, 0x33, 0xab, 0x23, 0x81, 0xf0, 0x65, 0x4c, 0x63, 0x33, 0x08,
	0xfd, 0x4f, 0x49, 0x97, 0x33, 0xab, 0xf6, 0xc8, 0x52, 0x1e, 0xdf, 0x86, 0xda, 0x81, 0xf0, 0x8f,
	0x08, 0x56, 0xd2, 0x6d, 0x57, 0xc3, 0x95, 0xa7, 0x74, 0x6c, 0x63, 0x2d, 0xd3, 0x7c, 0xee, 0x44,
	0xb2, 0xc4, 0xbc, 0x25, 0xd0, 0xd6, 0x6a, 0x0a, 0xda, 0xa8, 0x78, 0x14, 0xac, 0x2a, 0x54, 0xab,
	0xf6, 0x08, 0xff, 0x82, 0xe0, 0xea, 0x44, 0xa3, 0xc7, 0xcd, 0xc2, 0xe8, 0xf2, 0x04, 0xc2, 0x7c,
	0x2c, 0x4b, 0xdc, 0xb8, 0x38, 0xee, 0x3f, 0x11, 0x5c, 0x4b, 0xb5, 0x55, 0xfc, 0x56, 0xe1, 0xab,
	0xf3, 0xe5, 0x8a, 0xb1, 0x37, 0xbf, 0x81, 0xb8, 0x74, 0xf2, 0x1c, 0x99, 0x9e, 0x2e, 0xf8, 0x6f,
	0x04, 0x2b, 0x69, 0x39, 0xa3, 0x91, 0x21, 0x4f, 0x51, 0x42, 0xf3, 0x85, 0xe1, 0x3d, 0x81, 0xbe,
	0xb5, 0xf9, 0xca, 0x18, 0xbd, 0xaa, 0xa4, 0xa7, 0x87, 0x64, 0x32, 0xf1, 0x7f, 0x43, 0xb0, 0xac,
	0x6a, 0x0b, 0xfc, 0x46, 0x71, 0x40, 0x59, 0x49, 0x62, 0x68, 0xb7, 0x6f, 0x73, 0x47, 0xf8, 0xb2,
	0x65, 0xd6, 0x8b, 0xa6, 0x54, 0x83, 0x45, 0xf7, 0x36, 0x50, 0x0d, 0xff, 0x8a, 0x00, 0xc6, 0x62,
	0x07, 0x37, 0x74, 0x0b, 0xe2, 0x5c, 0xb8, 0x77, 0x05, 0xee, 0x6d, 0xbc, 0x55, 0x10, 0xb7, 0x95,
	0xc8, 0x94, 0xa8, 0x2a, 0x1e, 0x23, 0x58, 0x56, 0x15, 0x91, 0x06, 0xeb, 0x39, 0xa2, 0xcd, 0x68,
	0xce, 0x79, 0x5a, 0x16, 0x43, 0x8e, 0x2b, 0x99, 0x62, 0x48, 0x05, 0x61, 0xe4, 0x0d, 0xfe, 0x1d,
	0x41, 0x49, 0x51, 0x53, 0x78, 0x57, 0x23, 0x7f, 0xd2, 0x1a, 0x6c, 0x8e, 0x30, 0xb4, 0x04, 0xf6,
	0xa6, 0xf9, 0xfa, 0x1c, 0x61, 0x68, 0x30, 0xee, 0x07, 0x51, 0x22, 0xfd, 0x23, 0x1f, 0x29, 0x45,
	0x78, 0x69, 0x3e, 0x52, 0x59, 0x85, 0xa8, 0xf9, 0x48, 0xe5, 0x68, 0xbe, 0xa4, 0xcc, 0xf1, 0xdb,
	0x85, 0xe3, 0xa2, 0x7a, 0x67, 0xa9, 0x32, 0xef, 0x8f, 0xb8, 0x54, 0x64, 0xaf, 0xd7, 0x2b, 0x95,
	0x49, 0xd1, 0x67, 0x68, 0x2b, 0x26, 0xf3, 0x40, 0xf8, 0xb1, 0x87, 0xdf, 0xd4, 0x8f, 0x51, 0xf2,
	0x8f, 0x41, 0x54, 0xcd, 0x13, 0x59, 0x35, 0x89, 0xac, 0xd3, 0xac, 0x9a, 0x94, 0x22, 0xd5, 0xac,
	0x9a, 0xb4, 0x96, 0xcc, 0xf3, 0x4a, 0x27, 0x3a, 0x23, 0x15, 0xf9, 0xdf, 0xa4, 0x58, 0x1d, 0xa9,
	0x2e, 0x7c, 0x7b, 0x1e, 0x7c, 0x69, 0x75, 0x69, 0xdc, 0x39, 0xa7, 0x15, 0xe9, 0xed, 0xfb, 0xc2,
	0xdb, 0x77, 0xf1, 0xc1, 0xb9, 0xbc, 0x1d, 0xd9, 0xdd, 0xff, 0x09, 0xc1, 0x8b, 0x5d, 0xff, 0xb4,
	0x28, 0xb8, 0xfd, 0x72, 0x56, 0x7f, 0x1e, 0x46, 0x9a, 0xea, 0x10, 0x7d, 0xfc, 0x91, 0xb4, 0x31,
	0xf0, 0x3d, 0x87, 0x0e, 0xea, 0x7e, 0x38, 0xb0, 0x06, 0x84, 0x0a, 0xc5, 0x65, 0xc5, 0x4b, 0x4e,
	0xe0, 0xb2, 0x99, 0x7f, 0x94, 0x76, 0xb3, 0x4b, 0xc7, 0x0b, 0xc2, 0xca, 0xd6, 0xff, 0x01, 0x00,
	0x00, 0xff, 0xff, 0x32, 0x00, 0x5e, 0x95, 0x10, 0x14, 0x00, 0x00,
}

// Reference imports to suppress errors if they are not otherwise used.
var _ context.Context
var _ grpc.ClientConn

// This is a compile-time assertion to ensure that this generated file
// is compatible with the grpc package it is being compiled against.
const _ = grpc.SupportPackageIsVersion4

// WebSecurityScannerClient is the client API for WebSecurityScanner service.
//
// For semantics around ctx use and closing/ending streaming RPCs, please refer to https://godoc.org/google.golang.org/grpc#ClientConn.NewStream.
type WebSecurityScannerClient interface {
	// Creates a new ScanConfig.
	CreateScanConfig(ctx context.Context, in *CreateScanConfigRequest, opts ...grpc.CallOption) (*ScanConfig, error)
	// Deletes an existing ScanConfig and its child resources.
	DeleteScanConfig(ctx context.Context, in *DeleteScanConfigRequest, opts ...grpc.CallOption) (*empty.Empty, error)
	// Gets a ScanConfig.
	GetScanConfig(ctx context.Context, in *GetScanConfigRequest, opts ...grpc.CallOption) (*ScanConfig, error)
	// Lists ScanConfigs under a given project.
	ListScanConfigs(ctx context.Context, in *ListScanConfigsRequest, opts ...grpc.CallOption) (*ListScanConfigsResponse, error)
	// Updates a ScanConfig. This method support partial update of a ScanConfig.
	UpdateScanConfig(ctx context.Context, in *UpdateScanConfigRequest, opts ...grpc.CallOption) (*ScanConfig, error)
	// Start a ScanRun according to the given ScanConfig.
	StartScanRun(ctx context.Context, in *StartScanRunRequest, opts ...grpc.CallOption) (*ScanRun, error)
	// Gets a ScanRun.
	GetScanRun(ctx context.Context, in *GetScanRunRequest, opts ...grpc.CallOption) (*ScanRun, error)
	// Lists ScanRuns under a given ScanConfig, in descending order of ScanRun
	// stop time.
	ListScanRuns(ctx context.Context, in *ListScanRunsRequest, opts ...grpc.CallOption) (*ListScanRunsResponse, error)
	// Stops a ScanRun. The stopped ScanRun is returned.
	StopScanRun(ctx context.Context, in *StopScanRunRequest, opts ...grpc.CallOption) (*ScanRun, error)
	// List CrawledUrls under a given ScanRun.
	ListCrawledUrls(ctx context.Context, in *ListCrawledUrlsRequest, opts ...grpc.CallOption) (*ListCrawledUrlsResponse, error)
	// Gets a Finding.
	GetFinding(ctx context.Context, in *GetFindingRequest, opts ...grpc.CallOption) (*Finding, error)
	// List Findings under a given ScanRun.
	ListFindings(ctx context.Context, in *ListFindingsRequest, opts ...grpc.CallOption) (*ListFindingsResponse, error)
	// List all FindingTypeStats under a given ScanRun.
	ListFindingTypeStats(ctx context.Context, in *ListFindingTypeStatsRequest, opts ...grpc.CallOption) (*ListFindingTypeStatsResponse, error)
}

type webSecurityScannerClient struct {
	cc *grpc.ClientConn
}

func NewWebSecurityScannerClient(cc *grpc.ClientConn) WebSecurityScannerClient {
	return &webSecurityScannerClient{cc}
}

func (c *webSecurityScannerClient) CreateScanConfig(ctx context.Context, in *CreateScanConfigRequest, opts ...grpc.CallOption) (*ScanConfig, error) {
	out := new(ScanConfig)
	err := c.cc.Invoke(ctx, "/google.cloud.websecurityscanner.v1alpha.WebSecurityScanner/CreateScanConfig", in, out, opts...)
	if err != nil {
		return nil, err
	}
	return out, nil
}

func (c *webSecurityScannerClient) DeleteScanConfig(ctx context.Context, in *DeleteScanConfigRequest, opts ...grpc.CallOption) (*empty.Empty, error) {
	out := new(empty.Empty)
	err := c.cc.Invoke(ctx, "/google.cloud.websecurityscanner.v1alpha.WebSecurityScanner/DeleteScanConfig", in, out, opts...)
	if err != nil {
		return nil, err
	}
	return out, nil
}

func (c *webSecurityScannerClient) GetScanConfig(ctx context.Context, in *GetScanConfigRequest, opts ...grpc.CallOption) (*ScanConfig, error) {
	out := new(ScanConfig)
	err := c.cc.Invoke(ctx, "/google.cloud.websecurityscanner.v1alpha.WebSecurityScanner/GetScanConfig", in, out, opts...)
	if err != nil {
		return nil, err
	}
	return out, nil
}

func (c *webSecurityScannerClient) ListScanConfigs(ctx context.Context, in *ListScanConfigsRequest, opts ...grpc.CallOption) (*ListScanConfigsResponse, error) {
	out := new(ListScanConfigsResponse)
	err := c.cc.Invoke(ctx, "/google.cloud.websecurityscanner.v1alpha.WebSecurityScanner/ListScanConfigs", in, out, opts...)
	if err != nil {
		return nil, err
	}
	return out, nil
}

func (c *webSecurityScannerClient) UpdateScanConfig(ctx context.Context, in *UpdateScanConfigRequest, opts ...grpc.CallOption) (*ScanConfig, error) {
	out := new(ScanConfig)
	err := c.cc.Invoke(ctx, "/google.cloud.websecurityscanner.v1alpha.WebSecurityScanner/UpdateScanConfig", in, out, opts...)
	if err != nil {
		return nil, err
	}
	return out, nil
}

func (c *webSecurityScannerClient) StartScanRun(ctx context.Context, in *StartScanRunRequest, opts ...grpc.CallOption) (*ScanRun, error) {
	out := new(ScanRun)
	err := c.cc.Invoke(ctx, "/google.cloud.websecurityscanner.v1alpha.WebSecurityScanner/StartScanRun", in, out, opts...)
	if err != nil {
		return nil, err
	}
	return out, nil
}

func (c *webSecurityScannerClient) GetScanRun(ctx context.Context, in *GetScanRunRequest, opts ...grpc.CallOption) (*ScanRun, error) {
	out := new(ScanRun)
	err := c.cc.Invoke(ctx, "/google.cloud.websecurityscanner.v1alpha.WebSecurityScanner/GetScanRun", in, out, opts...)
	if err != nil {
		return nil, err
	}
	return out, nil
}

func (c *webSecurityScannerClient) ListScanRuns(ctx context.Context, in *ListScanRunsRequest, opts ...grpc.CallOption) (*ListScanRunsResponse, error) {
	out := new(ListScanRunsResponse)
	err := c.cc.Invoke(ctx, "/google.cloud.websecurityscanner.v1alpha.WebSecurityScanner/ListScanRuns", in, out, opts...)
	if err != nil {
		return nil, err
	}
	return out, nil
}

func (c *webSecurityScannerClient) StopScanRun(ctx context.Context, in *StopScanRunRequest, opts ...grpc.CallOption) (*ScanRun, error) {
	out := new(ScanRun)
	err := c.cc.Invoke(ctx, "/google.cloud.websecurityscanner.v1alpha.WebSecurityScanner/StopScanRun", in, out, opts...)
	if err != nil {
		return nil, err
	}
	return out, nil
}

func (c *webSecurityScannerClient) ListCrawledUrls(ctx context.Context, in *ListCrawledUrlsRequest, opts ...grpc.CallOption) (*ListCrawledUrlsResponse, error) {
	out := new(ListCrawledUrlsResponse)
	err := c.cc.Invoke(ctx, "/google.cloud.websecurityscanner.v1alpha.WebSecurityScanner/ListCrawledUrls", in, out, opts...)
	if err != nil {
		return nil, err
	}
	return out, nil
}

func (c *webSecurityScannerClient) GetFinding(ctx context.Context, in *GetFindingRequest, opts ...grpc.CallOption) (*Finding, error) {
	out := new(Finding)
	err := c.cc.Invoke(ctx, "/google.cloud.websecurityscanner.v1alpha.WebSecurityScanner/GetFinding", in, out, opts...)
	if err != nil {
		return nil, err
	}
	return out, nil
}

func (c *webSecurityScannerClient) ListFindings(ctx context.Context, in *ListFindingsRequest, opts ...grpc.CallOption) (*ListFindingsResponse, error) {
	out := new(ListFindingsResponse)
	err := c.cc.Invoke(ctx, "/google.cloud.websecurityscanner.v1alpha.WebSecurityScanner/ListFindings", in, out, opts...)
	if err != nil {
		return nil, err
	}
	return out, nil
}

func (c *webSecurityScannerClient) ListFindingTypeStats(ctx context.Context, in *ListFindingTypeStatsRequest, opts ...grpc.CallOption) (*ListFindingTypeStatsResponse, error) {
	out := new(ListFindingTypeStatsResponse)
	err := c.cc.Invoke(ctx, "/google.cloud.websecurityscanner.v1alpha.WebSecurityScanner/ListFindingTypeStats", in, out, opts...)
	if err != nil {
		return nil, err
	}
	return out, nil
}

// WebSecurityScannerServer is the server API for WebSecurityScanner service.
type WebSecurityScannerServer interface {
	// Creates a new ScanConfig.
	CreateScanConfig(context.Context, *CreateScanConfigRequest) (*ScanConfig, error)
	// Deletes an existing ScanConfig and its child resources.
	DeleteScanConfig(context.Context, *DeleteScanConfigRequest) (*empty.Empty, error)
	// Gets a ScanConfig.
	GetScanConfig(context.Context, *GetScanConfigRequest) (*ScanConfig, error)
	// Lists ScanConfigs under a given project.
	ListScanConfigs(context.Context, *ListScanConfigsRequest) (*ListScanConfigsResponse, error)
	// Updates a ScanConfig. This method support partial update of a ScanConfig.
	UpdateScanConfig(context.Context, *UpdateScanConfigRequest) (*ScanConfig, error)
	// Start a ScanRun according to the given ScanConfig.
	StartScanRun(context.Context, *StartScanRunRequest) (*ScanRun, error)
	// Gets a ScanRun.
	GetScanRun(context.Context, *GetScanRunRequest) (*ScanRun, error)
	// Lists ScanRuns under a given ScanConfig, in descending order of ScanRun
	// stop time.
	ListScanRuns(context.Context, *ListScanRunsRequest) (*ListScanRunsResponse, error)
	// Stops a ScanRun. The stopped ScanRun is returned.
	StopScanRun(context.Context, *StopScanRunRequest) (*ScanRun, error)
	// List CrawledUrls under a given ScanRun.
	ListCrawledUrls(context.Context, *ListCrawledUrlsRequest) (*ListCrawledUrlsResponse, error)
	// Gets a Finding.
	GetFinding(context.Context, *GetFindingRequest) (*Finding, error)
	// List Findings under a given ScanRun.
	ListFindings(context.Context, *ListFindingsRequest) (*ListFindingsResponse, error)
	// List all FindingTypeStats under a given ScanRun.
	ListFindingTypeStats(context.Context, *ListFindingTypeStatsRequest) (*ListFindingTypeStatsResponse, error)
}

func RegisterWebSecurityScannerServer(s *grpc.Server, srv WebSecurityScannerServer) {
	s.RegisterService(&_WebSecurityScanner_serviceDesc, srv)
}

func _WebSecurityScanner_CreateScanConfig_Handler(srv interface{}, ctx context.Context, dec func(interface{}) error, interceptor grpc.UnaryServerInterceptor) (interface{}, error) {
	in := new(CreateScanConfigRequest)
	if err := dec(in); err != nil {
		return nil, err
	}
	if interceptor == nil {
		return srv.(WebSecurityScannerServer).CreateScanConfig(ctx, in)
	}
	info := &grpc.UnaryServerInfo{
		Server:     srv,
		FullMethod: "/google.cloud.websecurityscanner.v1alpha.WebSecurityScanner/CreateScanConfig",
	}
	handler := func(ctx context.Context, req interface{}) (interface{}, error) {
		return srv.(WebSecurityScannerServer).CreateScanConfig(ctx, req.(*CreateScanConfigRequest))
	}
	return interceptor(ctx, in, info, handler)
}

func _WebSecurityScanner_DeleteScanConfig_Handler(srv interface{}, ctx context.Context, dec func(interface{}) error, interceptor grpc.UnaryServerInterceptor) (interface{}, error) {
	in := new(DeleteScanConfigRequest)
	if err := dec(in); err != nil {
		return nil, err
	}
	if interceptor == nil {
		return srv.(WebSecurityScannerServer).DeleteScanConfig(ctx, in)
	}
	info := &grpc.UnaryServerInfo{
		Server:     srv,
		FullMethod: "/google.cloud.websecurityscanner.v1alpha.WebSecurityScanner/DeleteScanConfig",
	}
	handler := func(ctx context.Context, req interface{}) (interface{}, error) {
		return srv.(WebSecurityScannerServer).DeleteScanConfig(ctx, req.(*DeleteScanConfigRequest))
	}
	return interceptor(ctx, in, info, handler)
}

func _WebSecurityScanner_GetScanConfig_Handler(srv interface{}, ctx context.Context, dec func(interface{}) error, interceptor grpc.UnaryServerInterceptor) (interface{}, error) {
	in := new(GetScanConfigRequest)
	if err := dec(in); err != nil {
		return nil, err
	}
	if interceptor == nil {
		return srv.(WebSecurityScannerServer).GetScanConfig(ctx, in)
	}
	info := &grpc.UnaryServerInfo{
		Server:     srv,
		FullMethod: "/google.cloud.websecurityscanner.v1alpha.WebSecurityScanner/GetScanConfig",
	}
	handler := func(ctx context.Context, req interface{}) (interface{}, error) {
		return srv.(WebSecurityScannerServer).GetScanConfig(ctx, req.(*GetScanConfigRequest))
	}
	return interceptor(ctx, in, info, handler)
}

func _WebSecurityScanner_ListScanConfigs_Handler(srv interface{}, ctx context.Context, dec func(interface{}) error, interceptor grpc.UnaryServerInterceptor) (interface{}, error) {
	in := new(ListScanConfigsRequest)
	if err := dec(in); err != nil {
		return nil, err
	}
	if interceptor == nil {
		return srv.(WebSecurityScannerServer).ListScanConfigs(ctx, in)
	}
	info := &grpc.UnaryServerInfo{
		Server:     srv,
		FullMethod: "/google.cloud.websecurityscanner.v1alpha.WebSecurityScanner/ListScanConfigs",
	}
	handler := func(ctx context.Context, req interface{}) (interface{}, error) {
		return srv.(WebSecurityScannerServer).ListScanConfigs(ctx, req.(*ListScanConfigsRequest))
	}
	return interceptor(ctx, in, info, handler)
}

func _WebSecurityScanner_UpdateScanConfig_Handler(srv interface{}, ctx context.Context, dec func(interface{}) error, interceptor grpc.UnaryServerInterceptor) (interface{}, error) {
	in := new(UpdateScanConfigRequest)
	if err := dec(in); err != nil {
		return nil, err
	}
	if interceptor == nil {
		return srv.(WebSecurityScannerServer).UpdateScanConfig(ctx, in)
	}
	info := &grpc.UnaryServerInfo{
		Server:     srv,
		FullMethod: "/google.cloud.websecurityscanner.v1alpha.WebSecurityScanner/UpdateScanConfig",
	}
	handler := func(ctx context.Context, req interface{}) (interface{}, error) {
		return srv.(WebSecurityScannerServer).UpdateScanConfig(ctx, req.(*UpdateScanConfigRequest))
	}
	return interceptor(ctx, in, info, handler)
}

func _WebSecurityScanner_StartScanRun_Handler(srv interface{}, ctx context.Context, dec func(interface{}) error, interceptor grpc.UnaryServerInterceptor) (interface{}, error) {
	in := new(StartScanRunRequest)
	if err := dec(in); err != nil {
		return nil, err
	}
	if interceptor == nil {
		return srv.(WebSecurityScannerServer).StartScanRun(ctx, in)
	}
	info := &grpc.UnaryServerInfo{
		Server:     srv,
		FullMethod: "/google.cloud.websecurityscanner.v1alpha.WebSecurityScanner/StartScanRun",
	}
	handler := func(ctx context.Context, req interface{}) (interface{}, error) {
		return srv.(WebSecurityScannerServer).StartScanRun(ctx, req.(*StartScanRunRequest))
	}
	return interceptor(ctx, in, info, handler)
}

func _WebSecurityScanner_GetScanRun_Handler(srv interface{}, ctx context.Context, dec func(interface{}) error, interceptor grpc.UnaryServerInterceptor) (interface{}, error) {
	in := new(GetScanRunRequest)
	if err := dec(in); err != nil {
		return nil, err
	}
	if interceptor == nil {
		return srv.(WebSecurityScannerServer).GetScanRun(ctx, in)
	}
	info := &grpc.UnaryServerInfo{
		Server:     srv,
		FullMethod: "/google.cloud.websecurityscanner.v1alpha.WebSecurityScanner/GetScanRun",
	}
	handler := func(ctx context.Context, req interface{}) (interface{}, error) {
		return srv.(WebSecurityScannerServer).GetScanRun(ctx, req.(*GetScanRunRequest))
	}
	return interceptor(ctx, in, info, handler)
}

func _WebSecurityScanner_ListScanRuns_Handler(srv interface{}, ctx context.Context, dec func(interface{}) error, interceptor grpc.UnaryServerInterceptor) (interface{}, error) {
	in := new(ListScanRunsRequest)
	if err := dec(in); err != nil {
		return nil, err
	}
	if interceptor == nil {
		return srv.(WebSecurityScannerServer).ListScanRuns(ctx, in)
	}
	info := &grpc.UnaryServerInfo{
		Server:     srv,
		FullMethod: "/google.cloud.websecurityscanner.v1alpha.WebSecurityScanner/ListScanRuns",
	}
	handler := func(ctx context.Context, req interface{}) (interface{}, error) {
		return srv.(WebSecurityScannerServer).ListScanRuns(ctx, req.(*ListScanRunsRequest))
	}
	return interceptor(ctx, in, info, handler)
}

func _WebSecurityScanner_StopScanRun_Handler(srv interface{}, ctx context.Context, dec func(interface{}) error, interceptor grpc.UnaryServerInterceptor) (interface{}, error) {
	in := new(StopScanRunRequest)
	if err := dec(in); err != nil {
		return nil, err
	}
	if interceptor == nil {
		return srv.(WebSecurityScannerServer).StopScanRun(ctx, in)
	}
	info := &grpc.UnaryServerInfo{
		Server:     srv,
		FullMethod: "/google.cloud.websecurityscanner.v1alpha.WebSecurityScanner/StopScanRun",
	}
	handler := func(ctx context.Context, req interface{}) (interface{}, error) {
		return srv.(WebSecurityScannerServer).StopScanRun(ctx, req.(*StopScanRunRequest))
	}
	return interceptor(ctx, in, info, handler)
}

func _WebSecurityScanner_ListCrawledUrls_Handler(srv interface{}, ctx context.Context, dec func(interface{}) error, interceptor grpc.UnaryServerInterceptor) (interface{}, error) {
	in := new(ListCrawledUrlsRequest)
	if err := dec(in); err != nil {
		return nil, err
	}
	if interceptor == nil {
		return srv.(WebSecurityScannerServer).ListCrawledUrls(ctx, in)
	}
	info := &grpc.UnaryServerInfo{
		Server:     srv,
		FullMethod: "/google.cloud.websecurityscanner.v1alpha.WebSecurityScanner/ListCrawledUrls",
	}
	handler := func(ctx context.Context, req interface{}) (interface{}, error) {
		return srv.(WebSecurityScannerServer).ListCrawledUrls(ctx, req.(*ListCrawledUrlsRequest))
	}
	return interceptor(ctx, in, info, handler)
}

func _WebSecurityScanner_GetFinding_Handler(srv interface{}, ctx context.Context, dec func(interface{}) error, interceptor grpc.UnaryServerInterceptor) (interface{}, error) {
	in := new(GetFindingRequest)
	if err := dec(in); err != nil {
		return nil, err
	}
	if interceptor == nil {
		return srv.(WebSecurityScannerServer).GetFinding(ctx, in)
	}
	info := &grpc.UnaryServerInfo{
		Server:     srv,
		FullMethod: "/google.cloud.websecurityscanner.v1alpha.WebSecurityScanner/GetFinding",
	}
	handler := func(ctx context.Context, req interface{}) (interface{}, error) {
		return srv.(WebSecurityScannerServer).GetFinding(ctx, req.(*GetFindingRequest))
	}
	return interceptor(ctx, in, info, handler)
}

func _WebSecurityScanner_ListFindings_Handler(srv interface{}, ctx context.Context, dec func(interface{}) error, interceptor grpc.UnaryServerInterceptor) (interface{}, error) {
	in := new(ListFindingsRequest)
	if err := dec(in); err != nil {
		return nil, err
	}
	if interceptor == nil {
		return srv.(WebSecurityScannerServer).ListFindings(ctx, in)
	}
	info := &grpc.UnaryServerInfo{
		Server:     srv,
		FullMethod: "/google.cloud.websecurityscanner.v1alpha.WebSecurityScanner/ListFindings",
	}
	handler := func(ctx context.Context, req interface{}) (interface{}, error) {
		return srv.(WebSecurityScannerServer).ListFindings(ctx, req.(*ListFindingsRequest))
	}
	return interceptor(ctx, in, info, handler)
}

func _WebSecurityScanner_ListFindingTypeStats_Handler(srv interface{}, ctx context.Context, dec func(interface{}) error, interceptor grpc.UnaryServerInterceptor) (interface{}, error) {
	in := new(ListFindingTypeStatsRequest)
	if err := dec(in); err != nil {
		return nil, err
	}
	if interceptor == nil {
		return srv.(WebSecurityScannerServer).ListFindingTypeStats(ctx, in)
	}
	info := &grpc.UnaryServerInfo{
		Server:     srv,
		FullMethod: "/google.cloud.websecurityscanner.v1alpha.WebSecurityScanner/ListFindingTypeStats",
	}
	handler := func(ctx context.Context, req interface{}) (interface{}, error) {
		return srv.(WebSecurityScannerServer).ListFindingTypeStats(ctx, req.(*ListFindingTypeStatsRequest))
	}
	return interceptor(ctx, in, info, handler)
}

var _WebSecurityScanner_serviceDesc = grpc.ServiceDesc{
	ServiceName: "google.cloud.websecurityscanner.v1alpha.WebSecurityScanner",
	HandlerType: (*WebSecurityScannerServer)(nil),
	Methods: []grpc.MethodDesc{
		{
			MethodName: "CreateScanConfig",
			Handler:    _WebSecurityScanner_CreateScanConfig_Handler,
		},
		{
			MethodName: "DeleteScanConfig",
			Handler:    _WebSecurityScanner_DeleteScanConfig_Handler,
		},
		{
			MethodName: "GetScanConfig",
			Handler:    _WebSecurityScanner_GetScanConfig_Handler,
		},
		{
			MethodName: "ListScanConfigs",
			Handler:    _WebSecurityScanner_ListScanConfigs_Handler,
		},
		{
			MethodName: "UpdateScanConfig",
			Handler:    _WebSecurityScanner_UpdateScanConfig_Handler,
		},
		{
			MethodName: "StartScanRun",
			Handler:    _WebSecurityScanner_StartScanRun_Handler,
		},
		{
			MethodName: "GetScanRun",
			Handler:    _WebSecurityScanner_GetScanRun_Handler,
		},
		{
			MethodName: "ListScanRuns",
			Handler:    _WebSecurityScanner_ListScanRuns_Handler,
		},
		{
			MethodName: "StopScanRun",
			Handler:    _WebSecurityScanner_StopScanRun_Handler,
		},
		{
			MethodName: "ListCrawledUrls",
			Handler:    _WebSecurityScanner_ListCrawledUrls_Handler,
		},
		{
			MethodName: "GetFinding",
			Handler:    _WebSecurityScanner_GetFinding_Handler,
		},
		{
			MethodName: "ListFindings",
			Handler:    _WebSecurityScanner_ListFindings_Handler,
		},
		{
			MethodName: "ListFindingTypeStats",
			Handler:    _WebSecurityScanner_ListFindingTypeStats_Handler,
		},
	},
	Streams:  []grpc.StreamDesc{},
	Metadata: "google/cloud/websecurityscanner/v1alpha/web_security_scanner.proto",
}
