// Code generated by protoc-gen-go. DO NOT EDIT.
// source: google/ads/googleads/v2/enums/preferred_content_type.proto

package enums

import (
	fmt "fmt"
	math "math"

	proto "github.com/golang/protobuf/proto"
	_ "google.golang.org/genproto/googleapis/api/annotations"
)

// Reference imports to suppress errors if they are not otherwise used.
var _ = proto.Marshal
var _ = fmt.Errorf
var _ = math.Inf

// This is a compile-time assertion to ensure that this generated file
// is compatible with the proto package it is being compiled against.
// A compilation error at this line likely means your copy of the
// proto package needs to be updated.
const _ = proto.ProtoPackageIsVersion3 // please upgrade the proto package

// Enumerates preferred content criterion type.
type PreferredContentTypeEnum_PreferredContentType int32

const (
	// Not specified.
	PreferredContentTypeEnum_UNSPECIFIED PreferredContentTypeEnum_PreferredContentType = 0
	// The value is unknown in this version.
	PreferredContentTypeEnum_UNKNOWN PreferredContentTypeEnum_PreferredContentType = 1
	// Represents top content on YouTube.
	PreferredContentTypeEnum_YOUTUBE_TOP_CONTENT PreferredContentTypeEnum_PreferredContentType = 400
)

var PreferredContentTypeEnum_PreferredContentType_name = map[int32]string{
	0:   "UNSPECIFIED",
	1:   "UNKNOWN",
	400: "YOUTUBE_TOP_CONTENT",
}

var PreferredContentTypeEnum_PreferredContentType_value = map[string]int32{
	"UNSPECIFIED":         0,
	"UNKNOWN":             1,
	"YOUTUBE_TOP_CONTENT": 400,
}

func (x PreferredContentTypeEnum_PreferredContentType) String() string {
	return proto.EnumName(PreferredContentTypeEnum_PreferredContentType_name, int32(x))
}

func (PreferredContentTypeEnum_PreferredContentType) EnumDescriptor() ([]byte, []int) {
	return fileDescriptor_7010073384f9785b, []int{0, 0}
}

// Container for enumeration of preferred content criterion type.
type PreferredContentTypeEnum struct {
	XXX_NoUnkeyedLiteral struct{} `json:"-"`
	XXX_unrecognized     []byte   `json:"-"`
	XXX_sizecache        int32    `json:"-"`
}

func (m *PreferredContentTypeEnum) Reset()         { *m = PreferredContentTypeEnum{} }
func (m *PreferredContentTypeEnum) String() string { return proto.CompactTextString(m) }
func (*PreferredContentTypeEnum) ProtoMessage()    {}
func (*PreferredContentTypeEnum) Descriptor() ([]byte, []int) {
	return fileDescriptor_7010073384f9785b, []int{0}
}

func (m *PreferredContentTypeEnum) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_PreferredContentTypeEnum.Unmarshal(m, b)
}
func (m *PreferredContentTypeEnum) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_PreferredContentTypeEnum.Marshal(b, m, deterministic)
}
func (m *PreferredContentTypeEnum) XXX_Merge(src proto.Message) {
	xxx_messageInfo_PreferredContentTypeEnum.Merge(m, src)
}
func (m *PreferredContentTypeEnum) XXX_Size() int {
	return xxx_messageInfo_PreferredContentTypeEnum.Size(m)
}
func (m *PreferredContentTypeEnum) XXX_DiscardUnknown() {
	xxx_messageInfo_PreferredContentTypeEnum.DiscardUnknown(m)
}

var xxx_messageInfo_PreferredContentTypeEnum proto.InternalMessageInfo

func init() {
	proto.RegisterEnum("google.ads.googleads.v2.enums.PreferredContentTypeEnum_PreferredContentType", PreferredContentTypeEnum_PreferredContentType_name, PreferredContentTypeEnum_PreferredContentType_value)
	proto.RegisterType((*PreferredContentTypeEnum)(nil), "google.ads.googleads.v2.enums.PreferredContentTypeEnum")
}

func init() {
	proto.RegisterFile("google/ads/googleads/v2/enums/preferred_content_type.proto", fileDescriptor_7010073384f9785b)
}

var fileDescriptor_7010073384f9785b = []byte{
	// 316 bytes of a gzipped FileDescriptorProto
	0x1f, 0x8b, 0x08, 0x00, 0x00, 0x00, 0x00, 0x00, 0x02, 0xff, 0x7c, 0x90, 0xd1, 0x4a, 0xfb, 0x30,
	0x18, 0xc5, 0xff, 0xdb, 0xe0, 0x2f, 0x64, 0x17, 0x8e, 0xea, 0xc5, 0x14, 0x77, 0xb1, 0x3d, 0x40,
	0x02, 0xf5, 0x2e, 0x5e, 0xb5, 0xb3, 0x8e, 0x21, 0xa4, 0x05, 0xdb, 0x89, 0x52, 0x28, 0x75, 0x89,
	0x61, 0xb2, 0x25, 0xa1, 0xc9, 0x06, 0x7b, 0x0b, 0x9f, 0xc1, 0x4b, 0x1f, 0xc5, 0x47, 0xf1, 0xc2,
	0x67, 0x90, 0x26, 0xb6, 0x57, 0xd3, 0x9b, 0x72, 0xe8, 0xf9, 0x7e, 0x27, 0xe7, 0xfb, 0x00, 0xe6,
	0x52, 0xf2, 0x35, 0x43, 0x25, 0xd5, 0xc8, 0xc9, 0x5a, 0xed, 0x7c, 0xc4, 0xc4, 0x76, 0xa3, 0x91,
	0xaa, 0xd8, 0x33, 0xab, 0x2a, 0x46, 0x8b, 0xa5, 0x14, 0x86, 0x09, 0x53, 0x98, 0xbd, 0x62, 0x50,
	0x55, 0xd2, 0x48, 0x6f, 0xe4, 0x00, 0x58, 0x52, 0x0d, 0x5b, 0x16, 0xee, 0x7c, 0x68, 0xd9, 0xf3,
	0x8b, 0x26, 0x5a, 0xad, 0x50, 0x29, 0x84, 0x34, 0xa5, 0x59, 0x49, 0xa1, 0x1d, 0x3c, 0x79, 0x01,
	0xc3, 0xa4, 0x09, 0x9f, 0xba, 0xec, 0x74, 0xaf, 0x58, 0x24, 0xb6, 0x9b, 0x09, 0x01, 0xa7, 0x87,
	0x3c, 0xef, 0x18, 0xf4, 0x33, 0x72, 0x97, 0x44, 0xd3, 0xf9, 0xcd, 0x3c, 0xba, 0x1e, 0xfc, 0xf3,
	0xfa, 0xe0, 0x28, 0x23, 0xb7, 0x24, 0xbe, 0x27, 0x83, 0x8e, 0x37, 0x04, 0x27, 0x0f, 0x71, 0x96,
	0x66, 0x61, 0x54, 0xa4, 0x71, 0x52, 0x4c, 0x63, 0x92, 0x46, 0x24, 0x1d, 0xbc, 0xf6, 0xc2, 0xaf,
	0x0e, 0x18, 0x2f, 0xe5, 0x06, 0xfe, 0xd9, 0x37, 0x3c, 0x3b, 0xf4, 0x66, 0x52, 0x97, 0x4d, 0x3a,
	0x8f, 0xe1, 0x0f, 0xcb, 0xe5, 0xba, 0x14, 0x1c, 0xca, 0x8a, 0x23, 0xce, 0x84, 0x5d, 0xa5, 0xb9,
	0x9b, 0x5a, 0xe9, 0x5f, 0xce, 0x78, 0x65, 0xbf, 0x6f, 0xdd, 0xde, 0x2c, 0x08, 0xde, 0xbb, 0xa3,
	0x99, 0x8b, 0x0a, 0xa8, 0x86, 0x4e, 0xd6, 0x6a, 0xe1, 0xc3, 0x7a, 0x77, 0xfd, 0xd1, 0xf8, 0x79,
	0x40, 0x75, 0xde, 0xfa, 0xf9, 0xc2, 0xcf, 0xad, 0xff, 0xd9, 0x1d, 0xbb, 0x9f, 0x18, 0x07, 0x54,
	0x63, 0xdc, 0x4e, 0x60, 0xbc, 0xf0, 0x31, 0xb6, 0x33, 0x4f, 0xff, 0x6d, 0xb1, 0xcb, 0xef, 0x00,
	0x00, 0x00, 0xff, 0xff, 0x47, 0x48, 0x98, 0xc7, 0xde, 0x01, 0x00, 0x00,
}
