// Code generated by protoc-gen-go. DO NOT EDIT.
// source: google/ads/googleads/v2/services/search_term_view_service.proto

package services

import (
	context "context"
	fmt "fmt"
	math "math"

	proto "github.com/golang/protobuf/proto"
	resources "google.golang.org/genproto/googleapis/ads/googleads/v2/resources"
	_ "google.golang.org/genproto/googleapis/api/annotations"
	grpc "google.golang.org/grpc"
)

// Reference imports to suppress errors if they are not otherwise used.
var _ = proto.Marshal
var _ = fmt.Errorf
var _ = math.Inf

// This is a compile-time assertion to ensure that this generated file
// is compatible with the proto package it is being compiled against.
// A compilation error at this line likely means your copy of the
// proto package needs to be updated.
const _ = proto.ProtoPackageIsVersion3 // please upgrade the proto package

// Request message for [SearchTermViewService.GetSearchTermView][google.ads.googleads.v2.services.SearchTermViewService.GetSearchTermView].
type GetSearchTermViewRequest struct {
	// The resource name of the search term view to fetch.
	ResourceName         string   `protobuf:"bytes,1,opt,name=resource_name,json=resourceName,proto3" json:"resource_name,omitempty"`
	XXX_NoUnkeyedLiteral struct{} `json:"-"`
	XXX_unrecognized     []byte   `json:"-"`
	XXX_sizecache        int32    `json:"-"`
}

func (m *GetSearchTermViewRequest) Reset()         { *m = GetSearchTermViewRequest{} }
func (m *GetSearchTermViewRequest) String() string { return proto.CompactTextString(m) }
func (*GetSearchTermViewRequest) ProtoMessage()    {}
func (*GetSearchTermViewRequest) Descriptor() ([]byte, []int) {
	return fileDescriptor_1e88e47a718a69f1, []int{0}
}

func (m *GetSearchTermViewRequest) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_GetSearchTermViewRequest.Unmarshal(m, b)
}
func (m *GetSearchTermViewRequest) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_GetSearchTermViewRequest.Marshal(b, m, deterministic)
}
func (m *GetSearchTermViewRequest) XXX_Merge(src proto.Message) {
	xxx_messageInfo_GetSearchTermViewRequest.Merge(m, src)
}
func (m *GetSearchTermViewRequest) XXX_Size() int {
	return xxx_messageInfo_GetSearchTermViewRequest.Size(m)
}
func (m *GetSearchTermViewRequest) XXX_DiscardUnknown() {
	xxx_messageInfo_GetSearchTermViewRequest.DiscardUnknown(m)
}

var xxx_messageInfo_GetSearchTermViewRequest proto.InternalMessageInfo

func (m *GetSearchTermViewRequest) GetResourceName() string {
	if m != nil {
		return m.ResourceName
	}
	return ""
}

func init() {
	proto.RegisterType((*GetSearchTermViewRequest)(nil), "google.ads.googleads.v2.services.GetSearchTermViewRequest")
}

func init() {
	proto.RegisterFile("google/ads/googleads/v2/services/search_term_view_service.proto", fileDescriptor_1e88e47a718a69f1)
}

var fileDescriptor_1e88e47a718a69f1 = []byte{
	// 393 bytes of a gzipped FileDescriptorProto
	0x1f, 0x8b, 0x08, 0x00, 0x00, 0x00, 0x00, 0x00, 0x02, 0xff, 0x84, 0x52, 0xcd, 0xaa, 0xd3, 0x40,
	0x14, 0x26, 0x11, 0x04, 0x83, 0x2e, 0x0c, 0x88, 0x25, 0xba, 0x28, 0xb5, 0x0b, 0xe9, 0x62, 0x86,
	0xa6, 0x1b, 0x1d, 0x91, 0x92, 0x6e, 0xea, 0x4a, 0x4a, 0x2b, 0x59, 0x48, 0x20, 0x8c, 0xc9, 0x21,
	0x06, 0x9a, 0x4c, 0x9d, 0x33, 0x4d, 0x17, 0xe2, 0x42, 0x5f, 0xc1, 0x37, 0x70, 0xe9, 0x3b, 0xf8,
	0x02, 0xdd, 0xfa, 0x0a, 0x77, 0x75, 0xd7, 0xf7, 0x01, 0x2e, 0xe9, 0x64, 0xd2, 0x5b, 0x6e, 0x43,
	0x77, 0x1f, 0x73, 0xbe, 0x9f, 0x73, 0xbe, 0xc4, 0x99, 0x66, 0x42, 0x64, 0x6b, 0xa0, 0x3c, 0x45,
	0xaa, 0x61, 0x8d, 0x2a, 0x9f, 0x22, 0xc8, 0x2a, 0x4f, 0x00, 0x29, 0x02, 0x97, 0xc9, 0xd7, 0x58,
	0x81, 0x2c, 0xe2, 0x2a, 0x87, 0x5d, 0xdc, 0x4c, 0xc8, 0x46, 0x0a, 0x25, 0xdc, 0xbe, 0x56, 0x11,
	0x9e, 0x22, 0x69, 0x0d, 0x48, 0xe5, 0x13, 0x63, 0xe0, 0xbd, 0xe9, 0x8a, 0x90, 0x80, 0x62, 0x2b,
	0xcf, 0x65, 0x68, 0x6f, 0xef, 0xa5, 0x51, 0x6e, 0x72, 0xca, 0xcb, 0x52, 0x28, 0xae, 0x72, 0x51,
	0x62, 0x33, 0x7d, 0x7e, 0x67, 0x9a, 0xac, 0x73, 0x28, 0x95, 0x1e, 0x0c, 0xa6, 0x4e, 0x6f, 0x0e,
	0x6a, 0x75, 0xf0, 0xfc, 0x04, 0xb2, 0x08, 0x73, 0xd8, 0x2d, 0xe1, 0xdb, 0x16, 0x50, 0xb9, 0xaf,
	0x9c, 0x27, 0x26, 0x36, 0x2e, 0x79, 0x01, 0x3d, 0xab, 0x6f, 0xbd, 0x7e, 0xb4, 0x7c, 0x6c, 0x1e,
	0x3f, 0xf2, 0x02, 0xfc, 0x1b, 0xcb, 0x79, 0x76, 0x2a, 0x5f, 0xe9, 0x63, 0xdc, 0x7f, 0x96, 0xf3,
	0xf4, 0x9e, 0xb7, 0xcb, 0xc8, 0xa5, 0x12, 0x48, 0xd7, 0x42, 0xde, 0xb8, 0x53, 0xdb, 0xd6, 0x43,
	0x4e, 0x95, 0x83, 0xb7, 0xbf, 0xfe, 0x5f, 0xfd, 0xb6, 0x27, 0xee, 0xb8, 0x2e, 0xf1, 0xfb, 0xc9,
	0x39, 0xef, 0x93, 0x2d, 0x2a, 0x51, 0x80, 0x44, 0x3a, 0x6a, 0x5a, 0x35, 0x32, 0xa4, 0xa3, 0x1f,
	0xde, 0x8b, 0x7d, 0xd0, 0x3b, 0x86, 0x34, 0x68, 0x93, 0x23, 0x49, 0x44, 0x31, 0xfb, 0x69, 0x3b,
	0xc3, 0x44, 0x14, 0x17, 0x8f, 0x99, 0x79, 0x67, 0xcb, 0x59, 0xd4, 0xe5, 0x2f, 0xac, 0xcf, 0x1f,
	0x1a, 0x7d, 0x26, 0xd6, 0xbc, 0xcc, 0x88, 0x90, 0x19, 0xcd, 0xa0, 0x3c, 0x7c, 0x1a, 0x7a, 0x4c,
	0xec, 0xfe, 0xe3, 0xde, 0x19, 0xf0, 0xc7, 0x7e, 0x30, 0x0f, 0x82, 0xbf, 0x76, 0x7f, 0xae, 0x0d,
	0x83, 0x14, 0x89, 0x86, 0x35, 0x0a, 0x7d, 0xd2, 0x04, 0xe3, 0xde, 0x50, 0xa2, 0x20, 0xc5, 0xa8,
	0xa5, 0x44, 0xa1, 0x1f, 0x19, 0xca, 0xb5, 0x3d, 0xd4, 0xef, 0x8c, 0x05, 0x29, 0x32, 0xd6, 0x92,
	0x18, 0x0b, 0x7d, 0xc6, 0x0c, 0xed, 0xcb, 0xc3, 0xc3, 0x9e, 0x93, 0xdb, 0x00, 0x00, 0x00, 0xff,
	0xff, 0xce, 0xe1, 0x7e, 0xc0, 0x18, 0x03, 0x00, 0x00,
}

// Reference imports to suppress errors if they are not otherwise used.
var _ context.Context
var _ grpc.ClientConn

// This is a compile-time assertion to ensure that this generated file
// is compatible with the grpc package it is being compiled against.
const _ = grpc.SupportPackageIsVersion4

// SearchTermViewServiceClient is the client API for SearchTermViewService service.
//
// For semantics around ctx use and closing/ending streaming RPCs, please refer to https://godoc.org/google.golang.org/grpc#ClientConn.NewStream.
type SearchTermViewServiceClient interface {
	// Returns the attributes of the requested search term view.
	GetSearchTermView(ctx context.Context, in *GetSearchTermViewRequest, opts ...grpc.CallOption) (*resources.SearchTermView, error)
}

type searchTermViewServiceClient struct {
	cc *grpc.ClientConn
}

func NewSearchTermViewServiceClient(cc *grpc.ClientConn) SearchTermViewServiceClient {
	return &searchTermViewServiceClient{cc}
}

func (c *searchTermViewServiceClient) GetSearchTermView(ctx context.Context, in *GetSearchTermViewRequest, opts ...grpc.CallOption) (*resources.SearchTermView, error) {
	out := new(resources.SearchTermView)
	err := c.cc.Invoke(ctx, "/google.ads.googleads.v2.services.SearchTermViewService/GetSearchTermView", in, out, opts...)
	if err != nil {
		return nil, err
	}
	return out, nil
}

// SearchTermViewServiceServer is the server API for SearchTermViewService service.
type SearchTermViewServiceServer interface {
	// Returns the attributes of the requested search term view.
	GetSearchTermView(context.Context, *GetSearchTermViewRequest) (*resources.SearchTermView, error)
}

func RegisterSearchTermViewServiceServer(s *grpc.Server, srv SearchTermViewServiceServer) {
	s.RegisterService(&_SearchTermViewService_serviceDesc, srv)
}

func _SearchTermViewService_GetSearchTermView_Handler(srv interface{}, ctx context.Context, dec func(interface{}) error, interceptor grpc.UnaryServerInterceptor) (interface{}, error) {
	in := new(GetSearchTermViewRequest)
	if err := dec(in); err != nil {
		return nil, err
	}
	if interceptor == nil {
		return srv.(SearchTermViewServiceServer).GetSearchTermView(ctx, in)
	}
	info := &grpc.UnaryServerInfo{
		Server:     srv,
		FullMethod: "/google.ads.googleads.v2.services.SearchTermViewService/GetSearchTermView",
	}
	handler := func(ctx context.Context, req interface{}) (interface{}, error) {
		return srv.(SearchTermViewServiceServer).GetSearchTermView(ctx, req.(*GetSearchTermViewRequest))
	}
	return interceptor(ctx, in, info, handler)
}

var _SearchTermViewService_serviceDesc = grpc.ServiceDesc{
	ServiceName: "google.ads.googleads.v2.services.SearchTermViewService",
	HandlerType: (*SearchTermViewServiceServer)(nil),
	Methods: []grpc.MethodDesc{
		{
			MethodName: "GetSearchTermView",
			Handler:    _SearchTermViewService_GetSearchTermView_Handler,
		},
	},
	Streams:  []grpc.StreamDesc{},
	Metadata: "google/ads/googleads/v2/services/search_term_view_service.proto",
}
