// Code generated by protoc-gen-go. DO NOT EDIT.
// source: google/cloud/tasks/v2/target.proto

package tasks

import (
	fmt "fmt"
	math "math"

	proto "github.com/golang/protobuf/proto"
	_ "google.golang.org/genproto/googleapis/api/annotations"
)

// Reference imports to suppress errors if they are not otherwise used.
var _ = proto.Marshal
var _ = fmt.Errorf
var _ = math.Inf

// This is a compile-time assertion to ensure that this generated file
// is compatible with the proto package it is being compiled against.
// A compilation error at this line likely means your copy of the
// proto package needs to be updated.
const _ = proto.ProtoPackageIsVersion3 // please upgrade the proto package

// The HTTP method used to deliver the task.
type HttpMethod int32

const (
	// HTTP method unspecified
	HttpMethod_HTTP_METHOD_UNSPECIFIED HttpMethod = 0
	// HTTP POST
	HttpMethod_POST HttpMethod = 1
	// HTTP GET
	HttpMethod_GET HttpMethod = 2
	// HTTP HEAD
	HttpMethod_HEAD HttpMethod = 3
	// HTTP PUT
	HttpMethod_PUT HttpMethod = 4
	// HTTP DELETE
	HttpMethod_DELETE HttpMethod = 5
	// HTTP PATCH
	HttpMethod_PATCH HttpMethod = 6
	// HTTP OPTIONS
	HttpMethod_OPTIONS HttpMethod = 7
)

var HttpMethod_name = map[int32]string{
	0: "HTTP_METHOD_UNSPECIFIED",
	1: "POST",
	2: "GET",
	3: "HEAD",
	4: "PUT",
	5: "DELETE",
	6: "PATCH",
	7: "OPTIONS",
}

var HttpMethod_value = map[string]int32{
	"HTTP_METHOD_UNSPECIFIED": 0,
	"POST":                    1,
	"GET":                     2,
	"HEAD":                    3,
	"PUT":                     4,
	"DELETE":                  5,
	"PATCH":                   6,
	"OPTIONS":                 7,
}

func (x HttpMethod) String() string {
	return proto.EnumName(HttpMethod_name, int32(x))
}

func (HttpMethod) EnumDescriptor() ([]byte, []int) {
	return fileDescriptor_9ccba55e885aeacf, []int{0}
}

// App Engine HTTP request.
//
// The message defines the HTTP request that is sent to an App Engine app when
// the task is dispatched.
//
// Using [AppEngineHttpRequest][google.cloud.tasks.v2.AppEngineHttpRequest] requires
// [`appengine.applications.get`](https://cloud.google.com/appengine/docs/admin-api/access-control)
// Google IAM permission for the project
// and the following scope:
//
// `https://www.googleapis.com/auth/cloud-platform`
//
// The task will be delivered to the App Engine app which belongs to the same
// project as the queue. For more information, see
// [How Requests are
// Routed](https://cloud.google.com/appengine/docs/standard/python/how-requests-are-routed)
// and how routing is affected by
// [dispatch
// files](https://cloud.google.com/appengine/docs/python/config/dispatchref).
// Traffic is encrypted during transport and never leaves Google datacenters.
// Because this traffic is carried over a communication mechanism internal to
// Google, you cannot explicitly set the protocol (for example, HTTP or HTTPS).
// The request to the handler, however, will appear to have used the HTTP
// protocol.
//
// The [AppEngineRouting][google.cloud.tasks.v2.AppEngineRouting] used to construct the URL that the task is
// delivered to can be set at the queue-level or task-level:
//
// * If set,
//    [app_engine_routing_override][google.cloud.tasks.v2.AppEngineHttpQueue.app_engine_routing_override]
//    is used for all tasks in the queue, no matter what the setting
//    is for the
//    [task-level app_engine_routing][google.cloud.tasks.v2.AppEngineHttpRequest.app_engine_routing].
//
//
// The `url` that the task will be sent to is:
//
// * `url =` [host][google.cloud.tasks.v2.AppEngineRouting.host] `+`
//   [relative_uri][google.cloud.tasks.v2.AppEngineHttpRequest.relative_uri]
//
// Tasks can be dispatched to secure app handlers, unsecure app handlers, and
// URIs restricted with
// [`login:
// admin`](https://cloud.google.com/appengine/docs/standard/python/config/appref).
// Because tasks are not run as any user, they cannot be dispatched to URIs
// restricted with
// [`login:
// required`](https://cloud.google.com/appengine/docs/standard/python/config/appref)
// Task dispatches also do not follow redirects.
//
// The task attempt has succeeded if the app's request handler returns an HTTP
// response code in the range [`200` - `299`]. The task attempt has failed if
// the app's handler returns a non-2xx response code or Cloud Tasks does
// not receive response before the [deadline][google.cloud.tasks.v2.Task.dispatch_deadline]. Failed
// tasks will be retried according to the
// [retry configuration][Queue.RetryConfig]. `503` (Service Unavailable) is
// considered an App Engine system error instead of an application error and
// will cause Cloud Tasks' traffic congestion control to temporarily throttle
// the queue's dispatches. Unlike other types of task targets, a `429` (Too Many
// Requests) response from an app handler does not cause traffic congestion
// control to throttle the queue.
type AppEngineHttpRequest struct {
	// The HTTP method to use for the request. The default is POST.
	//
	// The app's request handler for the task's target URL must be able to handle
	// HTTP requests with this http_method, otherwise the task attempt will fail
	// with error code 405 (Method Not Allowed). See
	// [Writing a push task request
	// handler](https://cloud.google.com/appengine/docs/java/taskqueue/push/creating-handlers#writing_a_push_task_request_handler)
	// and the documentation for the request handlers in the language your app is
	// written in e.g.
	// [Python Request
	// Handler](https://cloud.google.com/appengine/docs/python/tools/webapp/requesthandlerclass).
	HttpMethod HttpMethod `protobuf:"varint,1,opt,name=http_method,json=httpMethod,proto3,enum=google.cloud.tasks.v2.HttpMethod" json:"http_method,omitempty"`
	// Task-level setting for App Engine routing.
	//
	// If set,
	// [app_engine_routing_override][google.cloud.tasks.v2.AppEngineHttpQueue.app_engine_routing_override]
	// is used for all tasks in the queue, no matter what the setting is for the
	// [task-level app_engine_routing][google.cloud.tasks.v2.AppEngineHttpRequest.app_engine_routing].
	AppEngineRouting *AppEngineRouting `protobuf:"bytes,2,opt,name=app_engine_routing,json=appEngineRouting,proto3" json:"app_engine_routing,omitempty"`
	// The relative URI.
	//
	// The relative URI must begin with "/" and must be a valid HTTP relative URI.
	// It can contain a path and query string arguments.
	// If the relative URI is empty, then the root path "/" will be used.
	// No spaces are allowed, and the maximum length allowed is 2083 characters.
	RelativeUri string `protobuf:"bytes,3,opt,name=relative_uri,json=relativeUri,proto3" json:"relative_uri,omitempty"`
	// HTTP request headers.
	//
	// This map contains the header field names and values.
	// Headers can be set when the
	// [task is created][google.cloud.tasks.v2.CloudTasks.CreateTask].
	// Repeated headers are not supported but a header value can contain commas.
	//
	// Cloud Tasks sets some headers to default values:
	//
	// * `User-Agent`: By default, this header is
	//   `"AppEngine-Google; (+http://code.google.com/appengine)"`.
	//   This header can be modified, but Cloud Tasks will append
	//   `"AppEngine-Google; (+http://code.google.com/appengine)"` to the
	//   modified `User-Agent`.
	//
	// If the task has a [body][google.cloud.tasks.v2.AppEngineHttpRequest.body], Cloud
	// Tasks sets the following headers:
	//
	// * `Content-Type`: By default, the `Content-Type` header is set to
	//   `"application/octet-stream"`. The default can be overridden by explicitly
	//   setting `Content-Type` to a particular media type when the
	//   [task is created][google.cloud.tasks.v2.CloudTasks.CreateTask].
	//   For example, `Content-Type` can be set to `"application/json"`.
	// * `Content-Length`: This is computed by Cloud Tasks. This value is
	//   output only.   It cannot be changed.
	//
	// The headers below cannot be set or overridden:
	//
	// * `Host`
	// * `X-Google-*`
	// * `X-AppEngine-*`
	//
	// In addition, Cloud Tasks sets some headers when the task is dispatched,
	// such as headers containing information about the task; see
	// [request
	// headers](https://cloud.google.com/appengine/docs/python/taskqueue/push/creating-handlers#reading_request_headers).
	// These headers are set only when the task is dispatched, so they are not
	// visible when the task is returned in a Cloud Tasks response.
	//
	// Although there is no specific limit for the maximum number of headers or
	// the size, there is a limit on the maximum size of the [Task][google.cloud.tasks.v2.Task]. For more
	// information, see the [CreateTask][google.cloud.tasks.v2.CloudTasks.CreateTask] documentation.
	Headers map[string]string `protobuf:"bytes,4,rep,name=headers,proto3" json:"headers,omitempty" protobuf_key:"bytes,1,opt,name=key,proto3" protobuf_val:"bytes,2,opt,name=value,proto3"`
	// HTTP request body.
	//
	// A request body is allowed only if the HTTP method is POST or PUT. It is
	// an error to set a body on a task with an incompatible [HttpMethod][google.cloud.tasks.v2.HttpMethod].
	Body                 []byte   `protobuf:"bytes,5,opt,name=body,proto3" json:"body,omitempty"`
	XXX_NoUnkeyedLiteral struct{} `json:"-"`
	XXX_unrecognized     []byte   `json:"-"`
	XXX_sizecache        int32    `json:"-"`
}

func (m *AppEngineHttpRequest) Reset()         { *m = AppEngineHttpRequest{} }
func (m *AppEngineHttpRequest) String() string { return proto.CompactTextString(m) }
func (*AppEngineHttpRequest) ProtoMessage()    {}
func (*AppEngineHttpRequest) Descriptor() ([]byte, []int) {
	return fileDescriptor_9ccba55e885aeacf, []int{0}
}

func (m *AppEngineHttpRequest) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_AppEngineHttpRequest.Unmarshal(m, b)
}
func (m *AppEngineHttpRequest) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_AppEngineHttpRequest.Marshal(b, m, deterministic)
}
func (m *AppEngineHttpRequest) XXX_Merge(src proto.Message) {
	xxx_messageInfo_AppEngineHttpRequest.Merge(m, src)
}
func (m *AppEngineHttpRequest) XXX_Size() int {
	return xxx_messageInfo_AppEngineHttpRequest.Size(m)
}
func (m *AppEngineHttpRequest) XXX_DiscardUnknown() {
	xxx_messageInfo_AppEngineHttpRequest.DiscardUnknown(m)
}

var xxx_messageInfo_AppEngineHttpRequest proto.InternalMessageInfo

func (m *AppEngineHttpRequest) GetHttpMethod() HttpMethod {
	if m != nil {
		return m.HttpMethod
	}
	return HttpMethod_HTTP_METHOD_UNSPECIFIED
}

func (m *AppEngineHttpRequest) GetAppEngineRouting() *AppEngineRouting {
	if m != nil {
		return m.AppEngineRouting
	}
	return nil
}

func (m *AppEngineHttpRequest) GetRelativeUri() string {
	if m != nil {
		return m.RelativeUri
	}
	return ""
}

func (m *AppEngineHttpRequest) GetHeaders() map[string]string {
	if m != nil {
		return m.Headers
	}
	return nil
}

func (m *AppEngineHttpRequest) GetBody() []byte {
	if m != nil {
		return m.Body
	}
	return nil
}

// App Engine Routing.
//
// Defines routing characteristics specific to App Engine - service, version,
// and instance.
//
// For more information about services, versions, and instances see
// [An Overview of App
// Engine](https://cloud.google.com/appengine/docs/python/an-overview-of-app-engine),
// [Microservices Architecture on Google App
// Engine](https://cloud.google.com/appengine/docs/python/microservices-on-app-engine),
// [App Engine Standard request
// routing](https://cloud.google.com/appengine/docs/standard/python/how-requests-are-routed),
// and [App Engine Flex request
// routing](https://cloud.google.com/appengine/docs/flexible/python/how-requests-are-routed).
type AppEngineRouting struct {
	// App service.
	//
	// By default, the task is sent to the service which is the default
	// service when the task is attempted.
	//
	// For some queues or tasks which were created using the App Engine
	// Task Queue API, [host][google.cloud.tasks.v2.AppEngineRouting.host] is not parsable
	// into [service][google.cloud.tasks.v2.AppEngineRouting.service],
	// [version][google.cloud.tasks.v2.AppEngineRouting.version], and
	// [instance][google.cloud.tasks.v2.AppEngineRouting.instance]. For example, some tasks
	// which were created using the App Engine SDK use a custom domain
	// name; custom domains are not parsed by Cloud Tasks. If
	// [host][google.cloud.tasks.v2.AppEngineRouting.host] is not parsable, then
	// [service][google.cloud.tasks.v2.AppEngineRouting.service],
	// [version][google.cloud.tasks.v2.AppEngineRouting.version], and
	// [instance][google.cloud.tasks.v2.AppEngineRouting.instance] are the empty string.
	Service string `protobuf:"bytes,1,opt,name=service,proto3" json:"service,omitempty"`
	// App version.
	//
	// By default, the task is sent to the version which is the default
	// version when the task is attempted.
	//
	// For some queues or tasks which were created using the App Engine
	// Task Queue API, [host][google.cloud.tasks.v2.AppEngineRouting.host] is not parsable
	// into [service][google.cloud.tasks.v2.AppEngineRouting.service],
	// [version][google.cloud.tasks.v2.AppEngineRouting.version], and
	// [instance][google.cloud.tasks.v2.AppEngineRouting.instance]. For example, some tasks
	// which were created using the App Engine SDK use a custom domain
	// name; custom domains are not parsed by Cloud Tasks. If
	// [host][google.cloud.tasks.v2.AppEngineRouting.host] is not parsable, then
	// [service][google.cloud.tasks.v2.AppEngineRouting.service],
	// [version][google.cloud.tasks.v2.AppEngineRouting.version], and
	// [instance][google.cloud.tasks.v2.AppEngineRouting.instance] are the empty string.
	Version string `protobuf:"bytes,2,opt,name=version,proto3" json:"version,omitempty"`
	// App instance.
	//
	// By default, the task is sent to an instance which is available when
	// the task is attempted.
	//
	// Requests can only be sent to a specific instance if
	// [manual scaling is used in App Engine
	// Standard](https://cloud.google.com/appengine/docs/python/an-overview-of-app-engine?hl=en_US#scaling_types_and_instance_classes).
	// App Engine Flex does not support instances. For more information, see
	// [App Engine Standard request
	// routing](https://cloud.google.com/appengine/docs/standard/python/how-requests-are-routed)
	// and [App Engine Flex request
	// routing](https://cloud.google.com/appengine/docs/flexible/python/how-requests-are-routed).
	Instance string `protobuf:"bytes,3,opt,name=instance,proto3" json:"instance,omitempty"`
	// Output only. The host that the task is sent to.
	//
	// The host is constructed from the domain name of the app associated with
	// the queue's project ID (for example <app-id>.appspot.com), and the
	// [service][google.cloud.tasks.v2.AppEngineRouting.service], [version][google.cloud.tasks.v2.AppEngineRouting.version],
	// and [instance][google.cloud.tasks.v2.AppEngineRouting.instance]. Tasks which were created using
	// the App Engine SDK might have a custom domain name.
	//
	// For more information, see
	// [How Requests are
	// Routed](https://cloud.google.com/appengine/docs/standard/python/how-requests-are-routed).
	Host                 string   `protobuf:"bytes,4,opt,name=host,proto3" json:"host,omitempty"`
	XXX_NoUnkeyedLiteral struct{} `json:"-"`
	XXX_unrecognized     []byte   `json:"-"`
	XXX_sizecache        int32    `json:"-"`
}

func (m *AppEngineRouting) Reset()         { *m = AppEngineRouting{} }
func (m *AppEngineRouting) String() string { return proto.CompactTextString(m) }
func (*AppEngineRouting) ProtoMessage()    {}
func (*AppEngineRouting) Descriptor() ([]byte, []int) {
	return fileDescriptor_9ccba55e885aeacf, []int{1}
}

func (m *AppEngineRouting) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_AppEngineRouting.Unmarshal(m, b)
}
func (m *AppEngineRouting) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_AppEngineRouting.Marshal(b, m, deterministic)
}
func (m *AppEngineRouting) XXX_Merge(src proto.Message) {
	xxx_messageInfo_AppEngineRouting.Merge(m, src)
}
func (m *AppEngineRouting) XXX_Size() int {
	return xxx_messageInfo_AppEngineRouting.Size(m)
}
func (m *AppEngineRouting) XXX_DiscardUnknown() {
	xxx_messageInfo_AppEngineRouting.DiscardUnknown(m)
}

var xxx_messageInfo_AppEngineRouting proto.InternalMessageInfo

func (m *AppEngineRouting) GetService() string {
	if m != nil {
		return m.Service
	}
	return ""
}

func (m *AppEngineRouting) GetVersion() string {
	if m != nil {
		return m.Version
	}
	return ""
}

func (m *AppEngineRouting) GetInstance() string {
	if m != nil {
		return m.Instance
	}
	return ""
}

func (m *AppEngineRouting) GetHost() string {
	if m != nil {
		return m.Host
	}
	return ""
}

func init() {
	proto.RegisterEnum("google.cloud.tasks.v2.HttpMethod", HttpMethod_name, HttpMethod_value)
	proto.RegisterType((*AppEngineHttpRequest)(nil), "google.cloud.tasks.v2.AppEngineHttpRequest")
	proto.RegisterMapType((map[string]string)(nil), "google.cloud.tasks.v2.AppEngineHttpRequest.HeadersEntry")
	proto.RegisterType((*AppEngineRouting)(nil), "google.cloud.tasks.v2.AppEngineRouting")
}

func init() { proto.RegisterFile("google/cloud/tasks/v2/target.proto", fileDescriptor_9ccba55e885aeacf) }

var fileDescriptor_9ccba55e885aeacf = []byte{
	// 490 bytes of a gzipped FileDescriptorProto
	0x1f, 0x8b, 0x08, 0x00, 0x00, 0x00, 0x00, 0x00, 0x02, 0xff, 0x84, 0x53, 0xcf, 0x6f, 0xda, 0x30,
	0x18, 0x5d, 0xf8, 0x51, 0xca, 0x17, 0x34, 0x59, 0x56, 0xa7, 0x65, 0x6c, 0x07, 0xca, 0x65, 0x68,
	0x87, 0x44, 0x62, 0x97, 0x8a, 0x9d, 0xa0, 0x64, 0x0b, 0xd2, 0x5a, 0xa2, 0x60, 0x2e, 0xbb, 0x44,
	0x2e, 0x78, 0xc1, 0x2a, 0xb5, 0x33, 0xdb, 0x44, 0xe2, 0x3f, 0xdf, 0x71, 0x8a, 0x03, 0xac, 0x42,
	0x9d, 0x76, 0x7b, 0xdf, 0xf3, 0x7b, 0xcf, 0xfe, 0xec, 0xcf, 0xd0, 0xcf, 0xa4, 0xcc, 0xb6, 0x2c,
	0x58, 0x6d, 0xe5, 0x6e, 0x1d, 0x18, 0xaa, 0x1f, 0x75, 0x50, 0x0c, 0x03, 0x43, 0x55, 0xc6, 0x8c,
	0x9f, 0x2b, 0x69, 0x24, 0x7e, 0x53, 0x69, 0x7c, 0xab, 0xf1, 0xad, 0xc6, 0x2f, 0x86, 0xdd, 0x0f,
	0x07, 0x2b, 0xcd, 0x79, 0x40, 0x85, 0x90, 0x86, 0x1a, 0x2e, 0x85, 0xae, 0x4c, 0xfd, 0xdf, 0x35,
	0xb8, 0x1a, 0xe7, 0x79, 0x28, 0x32, 0x2e, 0x58, 0x64, 0x4c, 0x9e, 0xb0, 0x5f, 0x3b, 0xa6, 0x0d,
	0x9e, 0x80, 0xbb, 0x31, 0x26, 0x4f, 0x9f, 0x98, 0xd9, 0xc8, 0xb5, 0xe7, 0xf4, 0x9c, 0xc1, 0xeb,
	0xe1, 0xb5, 0xff, 0xe2, 0x1e, 0x7e, 0x69, 0xbc, 0xb3, 0xc2, 0x04, 0x36, 0x27, 0x8c, 0x97, 0x80,
	0x69, 0x9e, 0xa7, 0xcc, 0x86, 0xa7, 0x4a, 0xee, 0x0c, 0x17, 0x99, 0x57, 0xeb, 0x39, 0x03, 0x77,
	0xf8, 0xf1, 0x1f, 0x51, 0xa7, 0xc3, 0x24, 0x95, 0x3c, 0x41, 0xf4, 0x8c, 0xc1, 0xd7, 0xd0, 0x51,
	0x6c, 0x4b, 0x0d, 0x2f, 0x58, 0xba, 0x53, 0xdc, 0xab, 0xf7, 0x9c, 0x41, 0x3b, 0x71, 0x8f, 0xdc,
	0x52, 0x71, 0x9c, 0x40, 0x6b, 0xc3, 0xe8, 0x9a, 0x29, 0xed, 0x35, 0x7a, 0xf5, 0x81, 0x3b, 0xbc,
	0xf9, 0xdf, 0x76, 0xcf, 0x7a, 0xf7, 0xa3, 0xca, 0x1a, 0x0a, 0xa3, 0xf6, 0xc9, 0x31, 0x08, 0x63,
	0x68, 0x3c, 0xc8, 0xf5, 0xde, 0x6b, 0xf6, 0x9c, 0x41, 0x27, 0xb1, 0xb8, 0x3b, 0x82, 0xce, 0x73,
	0x31, 0x46, 0x50, 0x7f, 0x64, 0x7b, 0x7b, 0x5b, 0xed, 0xa4, 0x84, 0xf8, 0x0a, 0x9a, 0x05, 0xdd,
	0xee, 0x98, 0x6d, 0xbb, 0x9d, 0x54, 0xc5, 0xa8, 0x76, 0xe3, 0xf4, 0x0b, 0x40, 0xe7, 0xcd, 0x62,
	0x0f, 0x5a, 0x9a, 0xa9, 0x82, 0xaf, 0xd8, 0x21, 0xe3, 0x58, 0x96, 0x2b, 0x05, 0x53, 0x9a, 0x4b,
	0x71, 0x48, 0x3a, 0x96, 0xb8, 0x0b, 0x97, 0x5c, 0x68, 0x43, 0xc5, 0x8a, 0x1d, 0xae, 0xe2, 0x54,
	0x97, 0x67, 0xde, 0x48, 0x6d, 0xbc, 0x86, 0xe5, 0x2d, 0xfe, 0xa4, 0x01, 0xfe, 0xbe, 0x17, 0x7e,
	0x0f, 0x6f, 0x23, 0x42, 0xe2, 0xf4, 0x2e, 0x24, 0xd1, 0x7c, 0x9a, 0x2e, 0xef, 0x17, 0x71, 0x78,
	0x3b, 0xfb, 0x3a, 0x0b, 0xa7, 0xe8, 0x15, 0xbe, 0x84, 0x46, 0x3c, 0x5f, 0x10, 0xe4, 0xe0, 0x16,
	0xd4, 0xbf, 0x85, 0x04, 0xd5, 0x4a, 0x2a, 0x0a, 0xc7, 0x53, 0x54, 0x2f, 0xa9, 0x78, 0x49, 0x50,
	0x03, 0x03, 0x5c, 0x4c, 0xc3, 0xef, 0x21, 0x09, 0x51, 0x13, 0xb7, 0xa1, 0x19, 0x8f, 0xc9, 0x6d,
	0x84, 0x2e, 0xb0, 0x0b, 0xad, 0x79, 0x4c, 0x66, 0xf3, 0xfb, 0x05, 0x6a, 0x4d, 0x7e, 0xc2, 0xbb,
	0x95, 0x7c, 0x7a, 0xf9, 0x11, 0x26, 0x2e, 0xb1, 0x73, 0x1c, 0x97, 0x13, 0x19, 0x3b, 0x3f, 0x46,
	0x07, 0x55, 0x26, 0xb7, 0x54, 0x64, 0xbe, 0x54, 0x59, 0x90, 0x31, 0x61, 0xe7, 0x35, 0xa8, 0x96,
	0x68, 0xce, 0xf5, 0xd9, 0x5f, 0xf8, 0x62, 0xc1, 0xc3, 0x85, 0x95, 0x7d, 0xfe, 0x13, 0x00, 0x00,
	0xff, 0xff, 0xb4, 0x23, 0x16, 0x6a, 0x31, 0x03, 0x00, 0x00,
}
