// Code generated by protoc-gen-go. DO NOT EDIT.
// source: google/ads/googleads/v1/services/keyword_plan_campaign_service.proto

package services

import (
	context "context"
	fmt "fmt"
	math "math"

	proto "github.com/golang/protobuf/proto"
	_ "github.com/golang/protobuf/ptypes/wrappers"
	resources "google.golang.org/genproto/googleapis/ads/googleads/v1/resources"
	_ "google.golang.org/genproto/googleapis/api/annotations"
	status "google.golang.org/genproto/googleapis/rpc/status"
	field_mask "google.golang.org/genproto/protobuf/field_mask"
	grpc "google.golang.org/grpc"
)

// Reference imports to suppress errors if they are not otherwise used.
var _ = proto.Marshal
var _ = fmt.Errorf
var _ = math.Inf

// This is a compile-time assertion to ensure that this generated file
// is compatible with the proto package it is being compiled against.
// A compilation error at this line likely means your copy of the
// proto package needs to be updated.
const _ = proto.ProtoPackageIsVersion3 // please upgrade the proto package

// Request message for
// [KeywordPlanCampaignService.GetKeywordPlanCampaign][google.ads.googleads.v1.services.KeywordPlanCampaignService.GetKeywordPlanCampaign].
type GetKeywordPlanCampaignRequest struct {
	// The resource name of the Keyword Plan campaign to fetch.
	ResourceName         string   `protobuf:"bytes,1,opt,name=resource_name,json=resourceName,proto3" json:"resource_name,omitempty"`
	XXX_NoUnkeyedLiteral struct{} `json:"-"`
	XXX_unrecognized     []byte   `json:"-"`
	XXX_sizecache        int32    `json:"-"`
}

func (m *GetKeywordPlanCampaignRequest) Reset()         { *m = GetKeywordPlanCampaignRequest{} }
func (m *GetKeywordPlanCampaignRequest) String() string { return proto.CompactTextString(m) }
func (*GetKeywordPlanCampaignRequest) ProtoMessage()    {}
func (*GetKeywordPlanCampaignRequest) Descriptor() ([]byte, []int) {
	return fileDescriptor_1fdb1b9d1a4eb099, []int{0}
}

func (m *GetKeywordPlanCampaignRequest) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_GetKeywordPlanCampaignRequest.Unmarshal(m, b)
}
func (m *GetKeywordPlanCampaignRequest) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_GetKeywordPlanCampaignRequest.Marshal(b, m, deterministic)
}
func (m *GetKeywordPlanCampaignRequest) XXX_Merge(src proto.Message) {
	xxx_messageInfo_GetKeywordPlanCampaignRequest.Merge(m, src)
}
func (m *GetKeywordPlanCampaignRequest) XXX_Size() int {
	return xxx_messageInfo_GetKeywordPlanCampaignRequest.Size(m)
}
func (m *GetKeywordPlanCampaignRequest) XXX_DiscardUnknown() {
	xxx_messageInfo_GetKeywordPlanCampaignRequest.DiscardUnknown(m)
}

var xxx_messageInfo_GetKeywordPlanCampaignRequest proto.InternalMessageInfo

func (m *GetKeywordPlanCampaignRequest) GetResourceName() string {
	if m != nil {
		return m.ResourceName
	}
	return ""
}

// Request message for
// [KeywordPlanCampaignService.MutateKeywordPlanCampaigns][google.ads.googleads.v1.services.KeywordPlanCampaignService.MutateKeywordPlanCampaigns].
type MutateKeywordPlanCampaignsRequest struct {
	// The ID of the customer whose Keyword Plan campaigns are being modified.
	CustomerId string `protobuf:"bytes,1,opt,name=customer_id,json=customerId,proto3" json:"customer_id,omitempty"`
	// The list of operations to perform on individual Keyword Plan campaigns.
	Operations []*KeywordPlanCampaignOperation `protobuf:"bytes,2,rep,name=operations,proto3" json:"operations,omitempty"`
	// If true, successful operations will be carried out and invalid
	// operations will return errors. If false, all operations will be carried
	// out in one transaction if and only if they are all valid.
	// Default is false.
	PartialFailure bool `protobuf:"varint,3,opt,name=partial_failure,json=partialFailure,proto3" json:"partial_failure,omitempty"`
	// If true, the request is validated but not executed. Only errors are
	// returned, not results.
	ValidateOnly         bool     `protobuf:"varint,4,opt,name=validate_only,json=validateOnly,proto3" json:"validate_only,omitempty"`
	XXX_NoUnkeyedLiteral struct{} `json:"-"`
	XXX_unrecognized     []byte   `json:"-"`
	XXX_sizecache        int32    `json:"-"`
}

func (m *MutateKeywordPlanCampaignsRequest) Reset()         { *m = MutateKeywordPlanCampaignsRequest{} }
func (m *MutateKeywordPlanCampaignsRequest) String() string { return proto.CompactTextString(m) }
func (*MutateKeywordPlanCampaignsRequest) ProtoMessage()    {}
func (*MutateKeywordPlanCampaignsRequest) Descriptor() ([]byte, []int) {
	return fileDescriptor_1fdb1b9d1a4eb099, []int{1}
}

func (m *MutateKeywordPlanCampaignsRequest) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_MutateKeywordPlanCampaignsRequest.Unmarshal(m, b)
}
func (m *MutateKeywordPlanCampaignsRequest) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_MutateKeywordPlanCampaignsRequest.Marshal(b, m, deterministic)
}
func (m *MutateKeywordPlanCampaignsRequest) XXX_Merge(src proto.Message) {
	xxx_messageInfo_MutateKeywordPlanCampaignsRequest.Merge(m, src)
}
func (m *MutateKeywordPlanCampaignsRequest) XXX_Size() int {
	return xxx_messageInfo_MutateKeywordPlanCampaignsRequest.Size(m)
}
func (m *MutateKeywordPlanCampaignsRequest) XXX_DiscardUnknown() {
	xxx_messageInfo_MutateKeywordPlanCampaignsRequest.DiscardUnknown(m)
}

var xxx_messageInfo_MutateKeywordPlanCampaignsRequest proto.InternalMessageInfo

func (m *MutateKeywordPlanCampaignsRequest) GetCustomerId() string {
	if m != nil {
		return m.CustomerId
	}
	return ""
}

func (m *MutateKeywordPlanCampaignsRequest) GetOperations() []*KeywordPlanCampaignOperation {
	if m != nil {
		return m.Operations
	}
	return nil
}

func (m *MutateKeywordPlanCampaignsRequest) GetPartialFailure() bool {
	if m != nil {
		return m.PartialFailure
	}
	return false
}

func (m *MutateKeywordPlanCampaignsRequest) GetValidateOnly() bool {
	if m != nil {
		return m.ValidateOnly
	}
	return false
}

// A single operation (create, update, remove) on a Keyword Plan campaign.
type KeywordPlanCampaignOperation struct {
	// The FieldMask that determines which resource fields are modified in an
	// update.
	UpdateMask *field_mask.FieldMask `protobuf:"bytes,4,opt,name=update_mask,json=updateMask,proto3" json:"update_mask,omitempty"`
	// The mutate operation.
	//
	// Types that are valid to be assigned to Operation:
	//	*KeywordPlanCampaignOperation_Create
	//	*KeywordPlanCampaignOperation_Update
	//	*KeywordPlanCampaignOperation_Remove
	Operation            isKeywordPlanCampaignOperation_Operation `protobuf_oneof:"operation"`
	XXX_NoUnkeyedLiteral struct{}                                 `json:"-"`
	XXX_unrecognized     []byte                                   `json:"-"`
	XXX_sizecache        int32                                    `json:"-"`
}

func (m *KeywordPlanCampaignOperation) Reset()         { *m = KeywordPlanCampaignOperation{} }
func (m *KeywordPlanCampaignOperation) String() string { return proto.CompactTextString(m) }
func (*KeywordPlanCampaignOperation) ProtoMessage()    {}
func (*KeywordPlanCampaignOperation) Descriptor() ([]byte, []int) {
	return fileDescriptor_1fdb1b9d1a4eb099, []int{2}
}

func (m *KeywordPlanCampaignOperation) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_KeywordPlanCampaignOperation.Unmarshal(m, b)
}
func (m *KeywordPlanCampaignOperation) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_KeywordPlanCampaignOperation.Marshal(b, m, deterministic)
}
func (m *KeywordPlanCampaignOperation) XXX_Merge(src proto.Message) {
	xxx_messageInfo_KeywordPlanCampaignOperation.Merge(m, src)
}
func (m *KeywordPlanCampaignOperation) XXX_Size() int {
	return xxx_messageInfo_KeywordPlanCampaignOperation.Size(m)
}
func (m *KeywordPlanCampaignOperation) XXX_DiscardUnknown() {
	xxx_messageInfo_KeywordPlanCampaignOperation.DiscardUnknown(m)
}

var xxx_messageInfo_KeywordPlanCampaignOperation proto.InternalMessageInfo

func (m *KeywordPlanCampaignOperation) GetUpdateMask() *field_mask.FieldMask {
	if m != nil {
		return m.UpdateMask
	}
	return nil
}

type isKeywordPlanCampaignOperation_Operation interface {
	isKeywordPlanCampaignOperation_Operation()
}

type KeywordPlanCampaignOperation_Create struct {
	Create *resources.KeywordPlanCampaign `protobuf:"bytes,1,opt,name=create,proto3,oneof"`
}

type KeywordPlanCampaignOperation_Update struct {
	Update *resources.KeywordPlanCampaign `protobuf:"bytes,2,opt,name=update,proto3,oneof"`
}

type KeywordPlanCampaignOperation_Remove struct {
	Remove string `protobuf:"bytes,3,opt,name=remove,proto3,oneof"`
}

func (*KeywordPlanCampaignOperation_Create) isKeywordPlanCampaignOperation_Operation() {}

func (*KeywordPlanCampaignOperation_Update) isKeywordPlanCampaignOperation_Operation() {}

func (*KeywordPlanCampaignOperation_Remove) isKeywordPlanCampaignOperation_Operation() {}

func (m *KeywordPlanCampaignOperation) GetOperation() isKeywordPlanCampaignOperation_Operation {
	if m != nil {
		return m.Operation
	}
	return nil
}

func (m *KeywordPlanCampaignOperation) GetCreate() *resources.KeywordPlanCampaign {
	if x, ok := m.GetOperation().(*KeywordPlanCampaignOperation_Create); ok {
		return x.Create
	}
	return nil
}

func (m *KeywordPlanCampaignOperation) GetUpdate() *resources.KeywordPlanCampaign {
	if x, ok := m.GetOperation().(*KeywordPlanCampaignOperation_Update); ok {
		return x.Update
	}
	return nil
}

func (m *KeywordPlanCampaignOperation) GetRemove() string {
	if x, ok := m.GetOperation().(*KeywordPlanCampaignOperation_Remove); ok {
		return x.Remove
	}
	return ""
}

// XXX_OneofWrappers is for the internal use of the proto package.
func (*KeywordPlanCampaignOperation) XXX_OneofWrappers() []interface{} {
	return []interface{}{
		(*KeywordPlanCampaignOperation_Create)(nil),
		(*KeywordPlanCampaignOperation_Update)(nil),
		(*KeywordPlanCampaignOperation_Remove)(nil),
	}
}

// Response message for a Keyword Plan campaign mutate.
type MutateKeywordPlanCampaignsResponse struct {
	// Errors that pertain to operation failures in the partial failure mode.
	// Returned only when partial_failure = true and all errors occur inside the
	// operations. If any errors occur outside the operations (e.g. auth errors),
	// we return an RPC level error.
	PartialFailureError *status.Status `protobuf:"bytes,3,opt,name=partial_failure_error,json=partialFailureError,proto3" json:"partial_failure_error,omitempty"`
	// All results for the mutate.
	Results              []*MutateKeywordPlanCampaignResult `protobuf:"bytes,2,rep,name=results,proto3" json:"results,omitempty"`
	XXX_NoUnkeyedLiteral struct{}                           `json:"-"`
	XXX_unrecognized     []byte                             `json:"-"`
	XXX_sizecache        int32                              `json:"-"`
}

func (m *MutateKeywordPlanCampaignsResponse) Reset()         { *m = MutateKeywordPlanCampaignsResponse{} }
func (m *MutateKeywordPlanCampaignsResponse) String() string { return proto.CompactTextString(m) }
func (*MutateKeywordPlanCampaignsResponse) ProtoMessage()    {}
func (*MutateKeywordPlanCampaignsResponse) Descriptor() ([]byte, []int) {
	return fileDescriptor_1fdb1b9d1a4eb099, []int{3}
}

func (m *MutateKeywordPlanCampaignsResponse) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_MutateKeywordPlanCampaignsResponse.Unmarshal(m, b)
}
func (m *MutateKeywordPlanCampaignsResponse) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_MutateKeywordPlanCampaignsResponse.Marshal(b, m, deterministic)
}
func (m *MutateKeywordPlanCampaignsResponse) XXX_Merge(src proto.Message) {
	xxx_messageInfo_MutateKeywordPlanCampaignsResponse.Merge(m, src)
}
func (m *MutateKeywordPlanCampaignsResponse) XXX_Size() int {
	return xxx_messageInfo_MutateKeywordPlanCampaignsResponse.Size(m)
}
func (m *MutateKeywordPlanCampaignsResponse) XXX_DiscardUnknown() {
	xxx_messageInfo_MutateKeywordPlanCampaignsResponse.DiscardUnknown(m)
}

var xxx_messageInfo_MutateKeywordPlanCampaignsResponse proto.InternalMessageInfo

func (m *MutateKeywordPlanCampaignsResponse) GetPartialFailureError() *status.Status {
	if m != nil {
		return m.PartialFailureError
	}
	return nil
}

func (m *MutateKeywordPlanCampaignsResponse) GetResults() []*MutateKeywordPlanCampaignResult {
	if m != nil {
		return m.Results
	}
	return nil
}

// The result for the Keyword Plan campaign mutate.
type MutateKeywordPlanCampaignResult struct {
	// Returned for successful operations.
	ResourceName         string   `protobuf:"bytes,1,opt,name=resource_name,json=resourceName,proto3" json:"resource_name,omitempty"`
	XXX_NoUnkeyedLiteral struct{} `json:"-"`
	XXX_unrecognized     []byte   `json:"-"`
	XXX_sizecache        int32    `json:"-"`
}

func (m *MutateKeywordPlanCampaignResult) Reset()         { *m = MutateKeywordPlanCampaignResult{} }
func (m *MutateKeywordPlanCampaignResult) String() string { return proto.CompactTextString(m) }
func (*MutateKeywordPlanCampaignResult) ProtoMessage()    {}
func (*MutateKeywordPlanCampaignResult) Descriptor() ([]byte, []int) {
	return fileDescriptor_1fdb1b9d1a4eb099, []int{4}
}

func (m *MutateKeywordPlanCampaignResult) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_MutateKeywordPlanCampaignResult.Unmarshal(m, b)
}
func (m *MutateKeywordPlanCampaignResult) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_MutateKeywordPlanCampaignResult.Marshal(b, m, deterministic)
}
func (m *MutateKeywordPlanCampaignResult) XXX_Merge(src proto.Message) {
	xxx_messageInfo_MutateKeywordPlanCampaignResult.Merge(m, src)
}
func (m *MutateKeywordPlanCampaignResult) XXX_Size() int {
	return xxx_messageInfo_MutateKeywordPlanCampaignResult.Size(m)
}
func (m *MutateKeywordPlanCampaignResult) XXX_DiscardUnknown() {
	xxx_messageInfo_MutateKeywordPlanCampaignResult.DiscardUnknown(m)
}

var xxx_messageInfo_MutateKeywordPlanCampaignResult proto.InternalMessageInfo

func (m *MutateKeywordPlanCampaignResult) GetResourceName() string {
	if m != nil {
		return m.ResourceName
	}
	return ""
}

func init() {
	proto.RegisterType((*GetKeywordPlanCampaignRequest)(nil), "google.ads.googleads.v1.services.GetKeywordPlanCampaignRequest")
	proto.RegisterType((*MutateKeywordPlanCampaignsRequest)(nil), "google.ads.googleads.v1.services.MutateKeywordPlanCampaignsRequest")
	proto.RegisterType((*KeywordPlanCampaignOperation)(nil), "google.ads.googleads.v1.services.KeywordPlanCampaignOperation")
	proto.RegisterType((*MutateKeywordPlanCampaignsResponse)(nil), "google.ads.googleads.v1.services.MutateKeywordPlanCampaignsResponse")
	proto.RegisterType((*MutateKeywordPlanCampaignResult)(nil), "google.ads.googleads.v1.services.MutateKeywordPlanCampaignResult")
}

func init() {
	proto.RegisterFile("google/ads/googleads/v1/services/keyword_plan_campaign_service.proto", fileDescriptor_1fdb1b9d1a4eb099)
}

var fileDescriptor_1fdb1b9d1a4eb099 = []byte{
	// 728 bytes of a gzipped FileDescriptorProto
	0x1f, 0x8b, 0x08, 0x00, 0x00, 0x00, 0x00, 0x00, 0x02, 0xff, 0xa4, 0x95, 0x4f, 0x6b, 0xd4, 0x4c,
	0x18, 0xc0, 0xdf, 0x64, 0x5f, 0xaa, 0x9d, 0x54, 0x85, 0x11, 0x75, 0x09, 0xd5, 0xae, 0xb1, 0x60,
	0xd9, 0x43, 0xc2, 0xae, 0x50, 0x34, 0xa5, 0x95, 0x6d, 0xd7, 0x6d, 0x45, 0x6a, 0x97, 0x14, 0x7a,
	0xd0, 0xc5, 0x30, 0x4d, 0xa6, 0x21, 0x34, 0xc9, 0xc4, 0x99, 0xc9, 0x96, 0x52, 0x7a, 0xf1, 0xe0,
	0x17, 0xf0, 0x1b, 0x78, 0xf0, 0xe0, 0x37, 0xd1, 0x9b, 0xf8, 0x05, 0x3c, 0x78, 0x12, 0xbc, 0xf8,
	0x09, 0x24, 0x99, 0xcc, 0xda, 0x96, 0x4d, 0x57, 0xec, 0xed, 0xc9, 0x33, 0x4f, 0x7e, 0xcf, 0xdf,
	0x79, 0x06, 0x74, 0x03, 0x42, 0x82, 0x08, 0x5b, 0xc8, 0x67, 0x96, 0x10, 0x73, 0x69, 0xd8, 0xb2,
	0x18, 0xa6, 0xc3, 0xd0, 0xc3, 0xcc, 0xda, 0xc7, 0x87, 0x07, 0x84, 0xfa, 0x6e, 0x1a, 0xa1, 0xc4,
	0xf5, 0x50, 0x9c, 0xa2, 0x30, 0x48, 0xdc, 0xf2, 0xd8, 0x4c, 0x29, 0xe1, 0x04, 0x36, 0xc4, 0xaf,
	0x26, 0xf2, 0x99, 0x39, 0xa2, 0x98, 0xc3, 0x96, 0x29, 0x29, 0xfa, 0x72, 0x95, 0x1f, 0x8a, 0x19,
	0xc9, 0x68, 0xa5, 0x23, 0xe1, 0x40, 0x9f, 0x95, 0xbf, 0xa7, 0xa1, 0x85, 0x92, 0x84, 0x70, 0xc4,
	0x43, 0x92, 0xb0, 0xf2, 0xb4, 0x74, 0x6f, 0x15, 0x5f, 0xbb, 0xd9, 0x9e, 0xb5, 0x17, 0xe2, 0xc8,
	0x77, 0x63, 0xc4, 0xf6, 0x4b, 0x8b, 0x3b, 0x67, 0x2d, 0x0e, 0x28, 0x4a, 0x53, 0x4c, 0x25, 0xe1,
	0x56, 0x79, 0x4e, 0x53, 0xcf, 0x62, 0x1c, 0xf1, 0xac, 0x3c, 0x30, 0xba, 0xe0, 0xf6, 0x3a, 0xe6,
	0xcf, 0x44, 0x68, 0xfd, 0x08, 0x25, 0x6b, 0x65, 0x60, 0x0e, 0x7e, 0x9d, 0x61, 0xc6, 0xe1, 0x3d,
	0x70, 0x45, 0xa6, 0xe0, 0x26, 0x28, 0xc6, 0x75, 0xa5, 0xa1, 0x2c, 0x4c, 0x3b, 0x33, 0x52, 0xf9,
	0x1c, 0xc5, 0xd8, 0xf8, 0xa5, 0x80, 0xbb, 0x9b, 0x19, 0x47, 0x1c, 0x8f, 0x21, 0x31, 0x89, 0x9a,
	0x03, 0x9a, 0x97, 0x31, 0x4e, 0x62, 0x4c, 0xdd, 0xd0, 0x2f, 0x41, 0x40, 0xaa, 0x9e, 0xfa, 0xf0,
	0x15, 0x00, 0x24, 0xc5, 0x54, 0xe4, 0x5e, 0x57, 0x1b, 0xb5, 0x05, 0xad, 0xbd, 0x62, 0x4e, 0xaa,
	0xbd, 0x39, 0xc6, 0xe7, 0x96, 0xc4, 0x38, 0x27, 0x88, 0xf0, 0x3e, 0xb8, 0x96, 0x22, 0xca, 0x43,
	0x14, 0xb9, 0x7b, 0x28, 0x8c, 0x32, 0x8a, 0xeb, 0xb5, 0x86, 0xb2, 0x70, 0xd9, 0xb9, 0x5a, 0xaa,
	0x7b, 0x42, 0x9b, 0x27, 0x3d, 0x44, 0x51, 0xe8, 0x23, 0x8e, 0x5d, 0x92, 0x44, 0x87, 0xf5, 0xff,
	0x0b, 0xb3, 0x19, 0xa9, 0xdc, 0x4a, 0xa2, 0x43, 0xe3, 0x83, 0x0a, 0x66, 0xcf, 0x73, 0x0d, 0x97,
	0x80, 0x96, 0xa5, 0x05, 0x23, 0xef, 0x54, 0xc1, 0xd0, 0xda, 0xba, 0xcc, 0x47, 0xb6, 0xca, 0xec,
	0xe5, 0xcd, 0xdc, 0x44, 0x6c, 0xdf, 0x01, 0xc2, 0x3c, 0x97, 0x61, 0x1f, 0x4c, 0x79, 0x14, 0x23,
	0x2e, 0x0a, 0xae, 0xb5, 0x17, 0x2b, 0xeb, 0x30, 0x9a, 0xb0, 0x71, 0x85, 0xd8, 0xf8, 0xcf, 0x29,
	0x39, 0x39, 0x51, 0xf0, 0xeb, 0xea, 0x45, 0x89, 0x82, 0x03, 0xeb, 0x60, 0x8a, 0xe2, 0x98, 0x0c,
	0x45, 0x19, 0xa7, 0xf3, 0x13, 0xf1, 0xbd, 0xaa, 0x81, 0xe9, 0x51, 0xdd, 0x8d, 0x4f, 0x0a, 0x30,
	0xce, 0x9b, 0x0e, 0x96, 0x92, 0x84, 0x61, 0xd8, 0x03, 0x37, 0xce, 0x74, 0xc7, 0xc5, 0x94, 0x12,
	0x5a, 0xc0, 0xb5, 0x36, 0x94, 0xe1, 0xd2, 0xd4, 0x33, 0xb7, 0x8b, 0x19, 0x76, 0xae, 0x9f, 0xee,
	0xdb, 0x93, 0xdc, 0x1c, 0xbe, 0x04, 0x97, 0x28, 0x66, 0x59, 0xc4, 0xe5, 0x08, 0x75, 0x26, 0x8f,
	0x50, 0x65, 0x78, 0x4e, 0x41, 0x72, 0x24, 0xd1, 0xe8, 0x81, 0xb9, 0x09, 0xb6, 0x7f, 0x75, 0x63,
	0xda, 0xdf, 0x6a, 0x40, 0x1f, 0x83, 0xd8, 0x16, 0x01, 0xc1, 0x2f, 0x0a, 0xb8, 0x39, 0xfe, 0x5e,
	0xc2, 0xc7, 0x93, 0xb3, 0x39, 0xf7, 0x46, 0xeb, 0xff, 0xd8, 0x77, 0x63, 0xe5, 0xcd, 0xd7, 0xef,
	0xef, 0xd4, 0x87, 0x70, 0x31, 0x5f, 0x6b, 0x47, 0xa7, 0x52, 0x5c, 0x96, 0x97, 0x98, 0x59, 0x4d,
	0xb9, 0xe7, 0x4e, 0x35, 0xd9, 0x6a, 0x1e, 0xc3, 0x9f, 0x0a, 0xd0, 0xab, 0xc7, 0x00, 0xae, 0x5d,
	0xa0, 0x4b, 0x72, 0xc5, 0xe8, 0xdd, 0x8b, 0x41, 0xc4, 0x24, 0x1a, 0xdd, 0x22, 0xd3, 0x15, 0xe3,
	0x51, 0x9e, 0xe9, 0x9f, 0xd4, 0x8e, 0x4e, 0x6c, 0xaf, 0xe5, 0xe6, 0xf1, 0xd8, 0x44, 0xed, 0xb8,
	0xc0, 0xdb, 0x4a, 0x73, 0xf5, 0xad, 0x0a, 0xe6, 0x3d, 0x12, 0x4f, 0x8c, 0x68, 0x75, 0xae, 0x7a,
	0x10, 0xfa, 0xf9, 0x92, 0xe8, 0x2b, 0x2f, 0x36, 0x4a, 0x48, 0x40, 0x22, 0x94, 0x04, 0x26, 0xa1,
	0x81, 0x15, 0xe0, 0xa4, 0x58, 0x21, 0xf2, 0xb9, 0x49, 0x43, 0x56, 0xfd, 0xca, 0x2d, 0x49, 0xe1,
	0xbd, 0x5a, 0x5b, 0xef, 0x74, 0x3e, 0xaa, 0x8d, 0x75, 0x01, 0xec, 0xf8, 0xcc, 0x14, 0x62, 0x2e,
	0xed, 0xb4, 0xcc, 0xd2, 0x31, 0xfb, 0x2c, 0x4d, 0x06, 0x1d, 0x9f, 0x0d, 0x46, 0x26, 0x83, 0x9d,
	0xd6, 0x40, 0x9a, 0xfc, 0x50, 0xe7, 0x85, 0xde, 0xb6, 0x3b, 0x3e, 0xb3, 0xed, 0x91, 0x91, 0x6d,
	0xef, 0xb4, 0x6c, 0x5b, 0x9a, 0xed, 0x4e, 0x15, 0x71, 0x3e, 0xf8, 0x1d, 0x00, 0x00, 0xff, 0xff,
	0x79, 0x2e, 0x5d, 0x8a, 0x8c, 0x07, 0x00, 0x00,
}

// Reference imports to suppress errors if they are not otherwise used.
var _ context.Context
var _ grpc.ClientConn

// This is a compile-time assertion to ensure that this generated file
// is compatible with the grpc package it is being compiled against.
const _ = grpc.SupportPackageIsVersion4

// KeywordPlanCampaignServiceClient is the client API for KeywordPlanCampaignService service.
//
// For semantics around ctx use and closing/ending streaming RPCs, please refer to https://godoc.org/google.golang.org/grpc#ClientConn.NewStream.
type KeywordPlanCampaignServiceClient interface {
	// Returns the requested Keyword Plan campaign in full detail.
	GetKeywordPlanCampaign(ctx context.Context, in *GetKeywordPlanCampaignRequest, opts ...grpc.CallOption) (*resources.KeywordPlanCampaign, error)
	// Creates, updates, or removes Keyword Plan campaigns. Operation statuses are
	// returned.
	MutateKeywordPlanCampaigns(ctx context.Context, in *MutateKeywordPlanCampaignsRequest, opts ...grpc.CallOption) (*MutateKeywordPlanCampaignsResponse, error)
}

type keywordPlanCampaignServiceClient struct {
	cc *grpc.ClientConn
}

func NewKeywordPlanCampaignServiceClient(cc *grpc.ClientConn) KeywordPlanCampaignServiceClient {
	return &keywordPlanCampaignServiceClient{cc}
}

func (c *keywordPlanCampaignServiceClient) GetKeywordPlanCampaign(ctx context.Context, in *GetKeywordPlanCampaignRequest, opts ...grpc.CallOption) (*resources.KeywordPlanCampaign, error) {
	out := new(resources.KeywordPlanCampaign)
	err := c.cc.Invoke(ctx, "/google.ads.googleads.v1.services.KeywordPlanCampaignService/GetKeywordPlanCampaign", in, out, opts...)
	if err != nil {
		return nil, err
	}
	return out, nil
}

func (c *keywordPlanCampaignServiceClient) MutateKeywordPlanCampaigns(ctx context.Context, in *MutateKeywordPlanCampaignsRequest, opts ...grpc.CallOption) (*MutateKeywordPlanCampaignsResponse, error) {
	out := new(MutateKeywordPlanCampaignsResponse)
	err := c.cc.Invoke(ctx, "/google.ads.googleads.v1.services.KeywordPlanCampaignService/MutateKeywordPlanCampaigns", in, out, opts...)
	if err != nil {
		return nil, err
	}
	return out, nil
}

// KeywordPlanCampaignServiceServer is the server API for KeywordPlanCampaignService service.
type KeywordPlanCampaignServiceServer interface {
	// Returns the requested Keyword Plan campaign in full detail.
	GetKeywordPlanCampaign(context.Context, *GetKeywordPlanCampaignRequest) (*resources.KeywordPlanCampaign, error)
	// Creates, updates, or removes Keyword Plan campaigns. Operation statuses are
	// returned.
	MutateKeywordPlanCampaigns(context.Context, *MutateKeywordPlanCampaignsRequest) (*MutateKeywordPlanCampaignsResponse, error)
}

func RegisterKeywordPlanCampaignServiceServer(s *grpc.Server, srv KeywordPlanCampaignServiceServer) {
	s.RegisterService(&_KeywordPlanCampaignService_serviceDesc, srv)
}

func _KeywordPlanCampaignService_GetKeywordPlanCampaign_Handler(srv interface{}, ctx context.Context, dec func(interface{}) error, interceptor grpc.UnaryServerInterceptor) (interface{}, error) {
	in := new(GetKeywordPlanCampaignRequest)
	if err := dec(in); err != nil {
		return nil, err
	}
	if interceptor == nil {
		return srv.(KeywordPlanCampaignServiceServer).GetKeywordPlanCampaign(ctx, in)
	}
	info := &grpc.UnaryServerInfo{
		Server:     srv,
		FullMethod: "/google.ads.googleads.v1.services.KeywordPlanCampaignService/GetKeywordPlanCampaign",
	}
	handler := func(ctx context.Context, req interface{}) (interface{}, error) {
		return srv.(KeywordPlanCampaignServiceServer).GetKeywordPlanCampaign(ctx, req.(*GetKeywordPlanCampaignRequest))
	}
	return interceptor(ctx, in, info, handler)
}

func _KeywordPlanCampaignService_MutateKeywordPlanCampaigns_Handler(srv interface{}, ctx context.Context, dec func(interface{}) error, interceptor grpc.UnaryServerInterceptor) (interface{}, error) {
	in := new(MutateKeywordPlanCampaignsRequest)
	if err := dec(in); err != nil {
		return nil, err
	}
	if interceptor == nil {
		return srv.(KeywordPlanCampaignServiceServer).MutateKeywordPlanCampaigns(ctx, in)
	}
	info := &grpc.UnaryServerInfo{
		Server:     srv,
		FullMethod: "/google.ads.googleads.v1.services.KeywordPlanCampaignService/MutateKeywordPlanCampaigns",
	}
	handler := func(ctx context.Context, req interface{}) (interface{}, error) {
		return srv.(KeywordPlanCampaignServiceServer).MutateKeywordPlanCampaigns(ctx, req.(*MutateKeywordPlanCampaignsRequest))
	}
	return interceptor(ctx, in, info, handler)
}

var _KeywordPlanCampaignService_serviceDesc = grpc.ServiceDesc{
	ServiceName: "google.ads.googleads.v1.services.KeywordPlanCampaignService",
	HandlerType: (*KeywordPlanCampaignServiceServer)(nil),
	Methods: []grpc.MethodDesc{
		{
			MethodName: "GetKeywordPlanCampaign",
			Handler:    _KeywordPlanCampaignService_GetKeywordPlanCampaign_Handler,
		},
		{
			MethodName: "MutateKeywordPlanCampaigns",
			Handler:    _KeywordPlanCampaignService_MutateKeywordPlanCampaigns_Handler,
		},
	},
	Streams:  []grpc.StreamDesc{},
	Metadata: "google/ads/googleads/v1/services/keyword_plan_campaign_service.proto",
}
