// Code generated by protoc-gen-go. DO NOT EDIT.
// source: google/ads/googleads/v1/enums/product_bidding_category_status.proto

package enums

import (
	fmt "fmt"
	math "math"

	proto "github.com/golang/protobuf/proto"
	_ "google.golang.org/genproto/googleapis/api/annotations"
)

// Reference imports to suppress errors if they are not otherwise used.
var _ = proto.Marshal
var _ = fmt.Errorf
var _ = math.Inf

// This is a compile-time assertion to ensure that this generated file
// is compatible with the proto package it is being compiled against.
// A compilation error at this line likely means your copy of the
// proto package needs to be updated.
const _ = proto.ProtoPackageIsVersion3 // please upgrade the proto package

// Enum describing the status of the product bidding category.
type ProductBiddingCategoryStatusEnum_ProductBiddingCategoryStatus int32

const (
	// Not specified.
	ProductBiddingCategoryStatusEnum_UNSPECIFIED ProductBiddingCategoryStatusEnum_ProductBiddingCategoryStatus = 0
	// Used for return value only. Represents value unknown in this version.
	ProductBiddingCategoryStatusEnum_UNKNOWN ProductBiddingCategoryStatusEnum_ProductBiddingCategoryStatus = 1
	// The category is active and can be used for bidding.
	ProductBiddingCategoryStatusEnum_ACTIVE ProductBiddingCategoryStatusEnum_ProductBiddingCategoryStatus = 2
	// The category is obsolete. Used only for reporting purposes.
	ProductBiddingCategoryStatusEnum_OBSOLETE ProductBiddingCategoryStatusEnum_ProductBiddingCategoryStatus = 3
)

var ProductBiddingCategoryStatusEnum_ProductBiddingCategoryStatus_name = map[int32]string{
	0: "UNSPECIFIED",
	1: "UNKNOWN",
	2: "ACTIVE",
	3: "OBSOLETE",
}

var ProductBiddingCategoryStatusEnum_ProductBiddingCategoryStatus_value = map[string]int32{
	"UNSPECIFIED": 0,
	"UNKNOWN":     1,
	"ACTIVE":      2,
	"OBSOLETE":    3,
}

func (x ProductBiddingCategoryStatusEnum_ProductBiddingCategoryStatus) String() string {
	return proto.EnumName(ProductBiddingCategoryStatusEnum_ProductBiddingCategoryStatus_name, int32(x))
}

func (ProductBiddingCategoryStatusEnum_ProductBiddingCategoryStatus) EnumDescriptor() ([]byte, []int) {
	return fileDescriptor_d3fc354717fb5b27, []int{0, 0}
}

// Status of the product bidding category.
type ProductBiddingCategoryStatusEnum struct {
	XXX_NoUnkeyedLiteral struct{} `json:"-"`
	XXX_unrecognized     []byte   `json:"-"`
	XXX_sizecache        int32    `json:"-"`
}

func (m *ProductBiddingCategoryStatusEnum) Reset()         { *m = ProductBiddingCategoryStatusEnum{} }
func (m *ProductBiddingCategoryStatusEnum) String() string { return proto.CompactTextString(m) }
func (*ProductBiddingCategoryStatusEnum) ProtoMessage()    {}
func (*ProductBiddingCategoryStatusEnum) Descriptor() ([]byte, []int) {
	return fileDescriptor_d3fc354717fb5b27, []int{0}
}

func (m *ProductBiddingCategoryStatusEnum) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_ProductBiddingCategoryStatusEnum.Unmarshal(m, b)
}
func (m *ProductBiddingCategoryStatusEnum) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_ProductBiddingCategoryStatusEnum.Marshal(b, m, deterministic)
}
func (m *ProductBiddingCategoryStatusEnum) XXX_Merge(src proto.Message) {
	xxx_messageInfo_ProductBiddingCategoryStatusEnum.Merge(m, src)
}
func (m *ProductBiddingCategoryStatusEnum) XXX_Size() int {
	return xxx_messageInfo_ProductBiddingCategoryStatusEnum.Size(m)
}
func (m *ProductBiddingCategoryStatusEnum) XXX_DiscardUnknown() {
	xxx_messageInfo_ProductBiddingCategoryStatusEnum.DiscardUnknown(m)
}

var xxx_messageInfo_ProductBiddingCategoryStatusEnum proto.InternalMessageInfo

func init() {
	proto.RegisterEnum("google.ads.googleads.v1.enums.ProductBiddingCategoryStatusEnum_ProductBiddingCategoryStatus", ProductBiddingCategoryStatusEnum_ProductBiddingCategoryStatus_name, ProductBiddingCategoryStatusEnum_ProductBiddingCategoryStatus_value)
	proto.RegisterType((*ProductBiddingCategoryStatusEnum)(nil), "google.ads.googleads.v1.enums.ProductBiddingCategoryStatusEnum")
}

func init() {
	proto.RegisterFile("google/ads/googleads/v1/enums/product_bidding_category_status.proto", fileDescriptor_d3fc354717fb5b27)
}

var fileDescriptor_d3fc354717fb5b27 = []byte{
	// 319 bytes of a gzipped FileDescriptorProto
	0x1f, 0x8b, 0x08, 0x00, 0x00, 0x00, 0x00, 0x00, 0x02, 0xff, 0x7c, 0x90, 0xd1, 0x4a, 0xc3, 0x30,
	0x14, 0x86, 0x5d, 0x07, 0x53, 0x32, 0xc1, 0xd2, 0x4b, 0xd9, 0xc0, 0xed, 0x01, 0x12, 0x8a, 0x77,
	0xf1, 0x2a, 0xad, 0x71, 0x0c, 0xa5, 0x2b, 0x6c, 0xab, 0x20, 0x85, 0x91, 0x2d, 0x25, 0x14, 0xb6,
	0xa4, 0x34, 0xe9, 0x40, 0x1f, 0xc7, 0x4b, 0x1f, 0xc5, 0x47, 0xf1, 0x01, 0xbc, 0x96, 0x26, 0xdb,
	0xee, 0xdc, 0x4d, 0xf8, 0xc9, 0x39, 0xe7, 0xff, 0xce, 0xf9, 0x41, 0x2c, 0x94, 0x12, 0xdb, 0x02,
	0x31, 0xae, 0x91, 0x93, 0xad, 0xda, 0x87, 0xa8, 0x90, 0xcd, 0x4e, 0xa3, 0xaa, 0x56, 0xbc, 0xd9,
	0x98, 0xd5, 0xba, 0xe4, 0xbc, 0x94, 0x62, 0xb5, 0x61, 0xa6, 0x10, 0xaa, 0x7e, 0x5f, 0x69, 0xc3,
	0x4c, 0xa3, 0x61, 0x55, 0x2b, 0xa3, 0x82, 0xa1, 0x9b, 0x84, 0x8c, 0x6b, 0x78, 0x32, 0x81, 0xfb,
	0x10, 0x5a, 0x93, 0xdb, 0xc1, 0x91, 0x51, 0x95, 0x88, 0x49, 0xa9, 0x0c, 0x33, 0xa5, 0x92, 0x87,
	0xe1, 0xf1, 0x07, 0xb8, 0x4b, 0x1d, 0x25, 0x72, 0x90, 0xf8, 0xc0, 0x98, 0x5b, 0x04, 0x95, 0xcd,
	0x6e, 0x9c, 0x81, 0xc1, 0xb9, 0x9e, 0xe0, 0x06, 0xf4, 0x97, 0xc9, 0x3c, 0xa5, 0xf1, 0xf4, 0x69,
	0x4a, 0x1f, 0xfd, 0x8b, 0xa0, 0x0f, 0x2e, 0x97, 0xc9, 0x73, 0x32, 0x7b, 0x4d, 0xfc, 0x4e, 0x00,
	0x40, 0x8f, 0xc4, 0x8b, 0x69, 0x46, 0x7d, 0x2f, 0xb8, 0x06, 0x57, 0xb3, 0x68, 0x3e, 0x7b, 0xa1,
	0x0b, 0xea, 0x77, 0xa3, 0xdf, 0x0e, 0x18, 0x6d, 0xd4, 0x0e, 0x9e, 0xdd, 0x3f, 0x1a, 0x9d, 0x63,
	0xa7, 0xed, 0x11, 0x69, 0xe7, 0x2d, 0x3a, 0x78, 0x08, 0xb5, 0x65, 0x52, 0x40, 0x55, 0x0b, 0x24,
	0x0a, 0x69, 0x4f, 0x3c, 0x06, 0x5b, 0x95, 0xfa, 0x9f, 0x9c, 0x1f, 0xec, 0xfb, 0xe9, 0x75, 0x27,
	0x84, 0x7c, 0x79, 0xc3, 0x89, 0xb3, 0x22, 0x5c, 0x43, 0x27, 0x5b, 0x95, 0x85, 0xb0, 0xcd, 0x42,
	0x7f, 0x1f, 0xeb, 0x39, 0xe1, 0x3a, 0x3f, 0xd5, 0xf3, 0x2c, 0xcc, 0x6d, 0xfd, 0xc7, 0x1b, 0xb9,
	0x4f, 0x8c, 0x09, 0xd7, 0x18, 0x9f, 0x3a, 0x30, 0xce, 0x42, 0x8c, 0x6d, 0xcf, 0xba, 0x67, 0x17,
	0xbb, 0xff, 0x0b, 0x00, 0x00, 0xff, 0xff, 0xba, 0x44, 0x1c, 0x67, 0xff, 0x01, 0x00, 0x00,
}
