// Code generated by protoc-gen-go. DO NOT EDIT.
// source: google/ads/googleads/v2/enums/distance_bucket.proto

package enums

import (
	fmt "fmt"
	math "math"

	proto "github.com/golang/protobuf/proto"
	_ "google.golang.org/genproto/googleapis/api/annotations"
)

// Reference imports to suppress errors if they are not otherwise used.
var _ = proto.Marshal
var _ = fmt.Errorf
var _ = math.Inf

// This is a compile-time assertion to ensure that this generated file
// is compatible with the proto package it is being compiled against.
// A compilation error at this line likely means your copy of the
// proto package needs to be updated.
const _ = proto.ProtoPackageIsVersion3 // please upgrade the proto package

// The distance bucket for a user’s distance from an advertiser’s location
// extension.
type DistanceBucketEnum_DistanceBucket int32

const (
	// Not specified.
	DistanceBucketEnum_UNSPECIFIED DistanceBucketEnum_DistanceBucket = 0
	// Used for return value only. Represents value unknown in this version.
	DistanceBucketEnum_UNKNOWN DistanceBucketEnum_DistanceBucket = 1
	// User was within 700m of the location.
	DistanceBucketEnum_WITHIN_700M DistanceBucketEnum_DistanceBucket = 2
	// User was within 1KM of the location.
	DistanceBucketEnum_WITHIN_1KM DistanceBucketEnum_DistanceBucket = 3
	// User was within 5KM of the location.
	DistanceBucketEnum_WITHIN_5KM DistanceBucketEnum_DistanceBucket = 4
	// User was within 10KM of the location.
	DistanceBucketEnum_WITHIN_10KM DistanceBucketEnum_DistanceBucket = 5
	// User was within 15KM of the location.
	DistanceBucketEnum_WITHIN_15KM DistanceBucketEnum_DistanceBucket = 6
	// User was within 20KM of the location.
	DistanceBucketEnum_WITHIN_20KM DistanceBucketEnum_DistanceBucket = 7
	// User was within 25KM of the location.
	DistanceBucketEnum_WITHIN_25KM DistanceBucketEnum_DistanceBucket = 8
	// User was within 30KM of the location.
	DistanceBucketEnum_WITHIN_30KM DistanceBucketEnum_DistanceBucket = 9
	// User was within 35KM of the location.
	DistanceBucketEnum_WITHIN_35KM DistanceBucketEnum_DistanceBucket = 10
	// User was within 40KM of the location.
	DistanceBucketEnum_WITHIN_40KM DistanceBucketEnum_DistanceBucket = 11
	// User was within 45KM of the location.
	DistanceBucketEnum_WITHIN_45KM DistanceBucketEnum_DistanceBucket = 12
	// User was within 50KM of the location.
	DistanceBucketEnum_WITHIN_50KM DistanceBucketEnum_DistanceBucket = 13
	// User was within 55KM of the location.
	DistanceBucketEnum_WITHIN_55KM DistanceBucketEnum_DistanceBucket = 14
	// User was within 60KM of the location.
	DistanceBucketEnum_WITHIN_60KM DistanceBucketEnum_DistanceBucket = 15
	// User was within 65KM of the location.
	DistanceBucketEnum_WITHIN_65KM DistanceBucketEnum_DistanceBucket = 16
	// User was beyond 65KM of the location.
	DistanceBucketEnum_BEYOND_65KM DistanceBucketEnum_DistanceBucket = 17
	// User was within 0.7 miles of the location.
	DistanceBucketEnum_WITHIN_0_7MILES DistanceBucketEnum_DistanceBucket = 18
	// User was within 1 mile of the location.
	DistanceBucketEnum_WITHIN_1MILE DistanceBucketEnum_DistanceBucket = 19
	// User was within 5 miles of the location.
	DistanceBucketEnum_WITHIN_5MILES DistanceBucketEnum_DistanceBucket = 20
	// User was within 10 miles of the location.
	DistanceBucketEnum_WITHIN_10MILES DistanceBucketEnum_DistanceBucket = 21
	// User was within 15 miles of the location.
	DistanceBucketEnum_WITHIN_15MILES DistanceBucketEnum_DistanceBucket = 22
	// User was within 20 miles of the location.
	DistanceBucketEnum_WITHIN_20MILES DistanceBucketEnum_DistanceBucket = 23
	// User was within 25 miles of the location.
	DistanceBucketEnum_WITHIN_25MILES DistanceBucketEnum_DistanceBucket = 24
	// User was within 30 miles of the location.
	DistanceBucketEnum_WITHIN_30MILES DistanceBucketEnum_DistanceBucket = 25
	// User was within 35 miles of the location.
	DistanceBucketEnum_WITHIN_35MILES DistanceBucketEnum_DistanceBucket = 26
	// User was within 40 miles of the location.
	DistanceBucketEnum_WITHIN_40MILES DistanceBucketEnum_DistanceBucket = 27
	// User was beyond 40 miles of the location.
	DistanceBucketEnum_BEYOND_40MILES DistanceBucketEnum_DistanceBucket = 28
)

var DistanceBucketEnum_DistanceBucket_name = map[int32]string{
	0:  "UNSPECIFIED",
	1:  "UNKNOWN",
	2:  "WITHIN_700M",
	3:  "WITHIN_1KM",
	4:  "WITHIN_5KM",
	5:  "WITHIN_10KM",
	6:  "WITHIN_15KM",
	7:  "WITHIN_20KM",
	8:  "WITHIN_25KM",
	9:  "WITHIN_30KM",
	10: "WITHIN_35KM",
	11: "WITHIN_40KM",
	12: "WITHIN_45KM",
	13: "WITHIN_50KM",
	14: "WITHIN_55KM",
	15: "WITHIN_60KM",
	16: "WITHIN_65KM",
	17: "BEYOND_65KM",
	18: "WITHIN_0_7MILES",
	19: "WITHIN_1MILE",
	20: "WITHIN_5MILES",
	21: "WITHIN_10MILES",
	22: "WITHIN_15MILES",
	23: "WITHIN_20MILES",
	24: "WITHIN_25MILES",
	25: "WITHIN_30MILES",
	26: "WITHIN_35MILES",
	27: "WITHIN_40MILES",
	28: "BEYOND_40MILES",
}

var DistanceBucketEnum_DistanceBucket_value = map[string]int32{
	"UNSPECIFIED":     0,
	"UNKNOWN":         1,
	"WITHIN_700M":     2,
	"WITHIN_1KM":      3,
	"WITHIN_5KM":      4,
	"WITHIN_10KM":     5,
	"WITHIN_15KM":     6,
	"WITHIN_20KM":     7,
	"WITHIN_25KM":     8,
	"WITHIN_30KM":     9,
	"WITHIN_35KM":     10,
	"WITHIN_40KM":     11,
	"WITHIN_45KM":     12,
	"WITHIN_50KM":     13,
	"WITHIN_55KM":     14,
	"WITHIN_60KM":     15,
	"WITHIN_65KM":     16,
	"BEYOND_65KM":     17,
	"WITHIN_0_7MILES": 18,
	"WITHIN_1MILE":    19,
	"WITHIN_5MILES":   20,
	"WITHIN_10MILES":  21,
	"WITHIN_15MILES":  22,
	"WITHIN_20MILES":  23,
	"WITHIN_25MILES":  24,
	"WITHIN_30MILES":  25,
	"WITHIN_35MILES":  26,
	"WITHIN_40MILES":  27,
	"BEYOND_40MILES":  28,
}

func (x DistanceBucketEnum_DistanceBucket) String() string {
	return proto.EnumName(DistanceBucketEnum_DistanceBucket_name, int32(x))
}

func (DistanceBucketEnum_DistanceBucket) EnumDescriptor() ([]byte, []int) {
	return fileDescriptor_c866c6249f77d850, []int{0, 0}
}

// Container for distance buckets of a user’s distance from an advertiser’s
// location extension.
type DistanceBucketEnum struct {
	XXX_NoUnkeyedLiteral struct{} `json:"-"`
	XXX_unrecognized     []byte   `json:"-"`
	XXX_sizecache        int32    `json:"-"`
}

func (m *DistanceBucketEnum) Reset()         { *m = DistanceBucketEnum{} }
func (m *DistanceBucketEnum) String() string { return proto.CompactTextString(m) }
func (*DistanceBucketEnum) ProtoMessage()    {}
func (*DistanceBucketEnum) Descriptor() ([]byte, []int) {
	return fileDescriptor_c866c6249f77d850, []int{0}
}

func (m *DistanceBucketEnum) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_DistanceBucketEnum.Unmarshal(m, b)
}
func (m *DistanceBucketEnum) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_DistanceBucketEnum.Marshal(b, m, deterministic)
}
func (m *DistanceBucketEnum) XXX_Merge(src proto.Message) {
	xxx_messageInfo_DistanceBucketEnum.Merge(m, src)
}
func (m *DistanceBucketEnum) XXX_Size() int {
	return xxx_messageInfo_DistanceBucketEnum.Size(m)
}
func (m *DistanceBucketEnum) XXX_DiscardUnknown() {
	xxx_messageInfo_DistanceBucketEnum.DiscardUnknown(m)
}

var xxx_messageInfo_DistanceBucketEnum proto.InternalMessageInfo

func init() {
	proto.RegisterEnum("google.ads.googleads.v2.enums.DistanceBucketEnum_DistanceBucket", DistanceBucketEnum_DistanceBucket_name, DistanceBucketEnum_DistanceBucket_value)
	proto.RegisterType((*DistanceBucketEnum)(nil), "google.ads.googleads.v2.enums.DistanceBucketEnum")
}

func init() {
	proto.RegisterFile("google/ads/googleads/v2/enums/distance_bucket.proto", fileDescriptor_c866c6249f77d850)
}

var fileDescriptor_c866c6249f77d850 = []byte{
	// 457 bytes of a gzipped FileDescriptorProto
	0x1f, 0x8b, 0x08, 0x00, 0x00, 0x00, 0x00, 0x00, 0x02, 0xff, 0x7c, 0x92, 0xdf, 0x6e, 0xd3, 0x30,
	0x14, 0x87, 0x69, 0x57, 0x36, 0x70, 0xb7, 0xd6, 0x73, 0xf9, 0x3b, 0xb6, 0x8b, 0xed, 0x01, 0x9c,
	0x2e, 0xdd, 0x98, 0x64, 0xae, 0x12, 0x1a, 0x46, 0x54, 0x92, 0x55, 0x1a, 0xeb, 0x04, 0xaa, 0x54,
	0x65, 0x4d, 0x14, 0x55, 0xac, 0x76, 0x35, 0xa7, 0x7b, 0x14, 0x1e, 0x80, 0x4b, 0x24, 0x5e, 0x84,
	0x27, 0x41, 0x3c, 0x05, 0x3a, 0xb1, 0x53, 0x9d, 0x5e, 0xb0, 0x9b, 0xe8, 0xe4, 0x3b, 0xdf, 0x39,
	0x89, 0xad, 0x1f, 0xe9, 0xe5, 0x4a, 0xe5, 0xb7, 0x99, 0x93, 0xa4, 0xda, 0x31, 0x25, 0x54, 0xf7,
	0xae, 0x93, 0xc9, 0xe5, 0x5c, 0x3b, 0xe9, 0x4c, 0x17, 0x89, 0x9c, 0x66, 0x93, 0x9b, 0xe5, 0xf4,
	0x5b, 0x56, 0xf0, 0xc5, 0x9d, 0x2a, 0x14, 0x3b, 0x30, 0x26, 0x4f, 0x52, 0xcd, 0x57, 0x43, 0xfc,
	0xde, 0xe5, 0xe5, 0xd0, 0xde, 0x7e, 0xb5, 0x73, 0x31, 0x73, 0x12, 0x29, 0x55, 0x91, 0x14, 0x33,
	0x25, 0xb5, 0x19, 0x3e, 0xfa, 0xd5, 0x20, 0xac, 0x6f, 0xd7, 0xfa, 0xe5, 0xd6, 0x40, 0x2e, 0xe7,
	0x47, 0xdf, 0x1b, 0xa4, 0xb5, 0x8e, 0x59, 0x9b, 0x34, 0xaf, 0xe2, 0xcb, 0x61, 0xf0, 0x3e, 0xfc,
	0x10, 0x06, 0x7d, 0xfa, 0x88, 0x35, 0xc9, 0xd6, 0x55, 0x3c, 0x88, 0x2f, 0xae, 0x63, 0x5a, 0x83,
	0xee, 0x75, 0xf8, 0xf9, 0x63, 0x18, 0x4f, 0xce, 0xba, 0xdd, 0x88, 0xd6, 0x59, 0x8b, 0x10, 0x0b,
	0x8e, 0x07, 0x11, 0xdd, 0x40, 0xef, 0xa7, 0x83, 0x88, 0x36, 0xd0, 0xc0, 0x71, 0x77, 0x10, 0xd1,
	0xc7, 0x18, 0x80, 0xb1, 0x89, 0x80, 0x0b, 0xc6, 0x16, 0x06, 0x60, 0x3c, 0x41, 0xa0, 0x07, 0xc6,
	0x53, 0x0c, 0xc0, 0x20, 0x08, 0x9c, 0x80, 0xd1, 0xc4, 0x00, 0x8c, 0x6d, 0x04, 0x4e, 0xc1, 0xd8,
	0xc1, 0x00, 0x8c, 0x16, 0x02, 0x6f, 0xc1, 0x68, 0x63, 0x00, 0x06, 0x05, 0xe0, 0x07, 0x5f, 0x2e,
	0xe2, 0xbe, 0x01, 0xbb, 0xac, 0x43, 0xda, 0xd6, 0xe8, 0x4e, 0xce, 0xa2, 0xf0, 0x53, 0x70, 0x49,
	0x19, 0xa3, 0x64, 0xbb, 0x3a, 0x20, 0x20, 0xda, 0x61, 0xbb, 0x64, 0xa7, 0xfa, 0x94, 0x91, 0x9e,
	0x31, 0x46, 0x5a, 0xab, 0x6b, 0x31, 0xec, 0x39, 0x66, 0xd6, 0x7b, 0x81, 0x98, 0x6b, 0xbd, 0x97,
	0x98, 0x59, 0xef, 0x15, 0x62, 0x3d, 0xeb, 0xbd, 0xc6, 0xcc, 0x7a, 0x7b, 0x88, 0x9d, 0x58, 0xef,
	0x0d, 0x30, 0x7b, 0xac, 0x8a, 0xed, 0xfb, 0x7f, 0x6a, 0xe4, 0x70, 0xaa, 0xe6, 0xfc, 0xc1, 0xcc,
	0xf9, 0x9d, 0xf5, 0xec, 0x0c, 0x21, 0x6a, 0xc3, 0xda, 0x57, 0xdf, 0x4e, 0xe5, 0xea, 0x36, 0x91,
	0x39, 0x57, 0x77, 0xb9, 0x93, 0x67, 0xb2, 0x0c, 0x62, 0x15, 0xf7, 0xc5, 0x4c, 0xff, 0x27, 0xfd,
	0xef, 0xca, 0xe7, 0x8f, 0xfa, 0xc6, 0xb9, 0xe7, 0xfd, 0xac, 0x1f, 0x9c, 0x9b, 0x55, 0x5e, 0xaa,
	0xb9, 0x29, 0xa1, 0x1a, 0xb9, 0x1c, 0xe2, 0xab, 0x7f, 0x57, 0xfd, 0xb1, 0x97, 0xea, 0xf1, 0xaa,
	0x3f, 0x1e, 0xb9, 0xe3, 0xb2, 0xff, 0xb7, 0x7e, 0x68, 0xa0, 0x10, 0x5e, 0xaa, 0x85, 0x58, 0x19,
	0x42, 0x8c, 0x5c, 0x21, 0x4a, 0xe7, 0x66, 0xb3, 0xfc, 0xb1, 0xde, 0xbf, 0x00, 0x00, 0x00, 0xff,
	0xff, 0x17, 0x0f, 0x87, 0x18, 0x95, 0x03, 0x00, 0x00,
}
