// Code generated by protoc-gen-go. DO NOT EDIT.
// source: google/ads/googleads/v1/resources/shared_criterion.proto

package resources

import (
	fmt "fmt"
	math "math"

	proto "github.com/golang/protobuf/proto"
	wrappers "github.com/golang/protobuf/ptypes/wrappers"
	common "google.golang.org/genproto/googleapis/ads/googleads/v1/common"
	enums "google.golang.org/genproto/googleapis/ads/googleads/v1/enums"
	_ "google.golang.org/genproto/googleapis/api/annotations"
)

// Reference imports to suppress errors if they are not otherwise used.
var _ = proto.Marshal
var _ = fmt.Errorf
var _ = math.Inf

// This is a compile-time assertion to ensure that this generated file
// is compatible with the proto package it is being compiled against.
// A compilation error at this line likely means your copy of the
// proto package needs to be updated.
const _ = proto.ProtoPackageIsVersion3 // please upgrade the proto package

// A criterion belonging to a shared set.
type SharedCriterion struct {
	// The resource name of the shared criterion.
	// Shared set resource names have the form:
	//
	// `customers/{customer_id}/sharedCriteria/{shared_set_id}~{criterion_id}`
	ResourceName string `protobuf:"bytes,1,opt,name=resource_name,json=resourceName,proto3" json:"resource_name,omitempty"`
	// The shared set to which the shared criterion belongs.
	SharedSet *wrappers.StringValue `protobuf:"bytes,2,opt,name=shared_set,json=sharedSet,proto3" json:"shared_set,omitempty"`
	// The ID of the criterion.
	//
	// This field is ignored for mutates.
	CriterionId *wrappers.Int64Value `protobuf:"bytes,26,opt,name=criterion_id,json=criterionId,proto3" json:"criterion_id,omitempty"`
	// The type of the criterion.
	Type enums.CriterionTypeEnum_CriterionType `protobuf:"varint,4,opt,name=type,proto3,enum=google.ads.googleads.v1.enums.CriterionTypeEnum_CriterionType" json:"type,omitempty"`
	// The criterion.
	//
	// Exactly one must be set.
	//
	// Types that are valid to be assigned to Criterion:
	//	*SharedCriterion_Keyword
	//	*SharedCriterion_YoutubeVideo
	//	*SharedCriterion_YoutubeChannel
	//	*SharedCriterion_Placement
	//	*SharedCriterion_MobileAppCategory
	//	*SharedCriterion_MobileApplication
	Criterion            isSharedCriterion_Criterion `protobuf_oneof:"criterion"`
	XXX_NoUnkeyedLiteral struct{}                    `json:"-"`
	XXX_unrecognized     []byte                      `json:"-"`
	XXX_sizecache        int32                       `json:"-"`
}

func (m *SharedCriterion) Reset()         { *m = SharedCriterion{} }
func (m *SharedCriterion) String() string { return proto.CompactTextString(m) }
func (*SharedCriterion) ProtoMessage()    {}
func (*SharedCriterion) Descriptor() ([]byte, []int) {
	return fileDescriptor_c8be09b18890bd33, []int{0}
}

func (m *SharedCriterion) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_SharedCriterion.Unmarshal(m, b)
}
func (m *SharedCriterion) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_SharedCriterion.Marshal(b, m, deterministic)
}
func (m *SharedCriterion) XXX_Merge(src proto.Message) {
	xxx_messageInfo_SharedCriterion.Merge(m, src)
}
func (m *SharedCriterion) XXX_Size() int {
	return xxx_messageInfo_SharedCriterion.Size(m)
}
func (m *SharedCriterion) XXX_DiscardUnknown() {
	xxx_messageInfo_SharedCriterion.DiscardUnknown(m)
}

var xxx_messageInfo_SharedCriterion proto.InternalMessageInfo

func (m *SharedCriterion) GetResourceName() string {
	if m != nil {
		return m.ResourceName
	}
	return ""
}

func (m *SharedCriterion) GetSharedSet() *wrappers.StringValue {
	if m != nil {
		return m.SharedSet
	}
	return nil
}

func (m *SharedCriterion) GetCriterionId() *wrappers.Int64Value {
	if m != nil {
		return m.CriterionId
	}
	return nil
}

func (m *SharedCriterion) GetType() enums.CriterionTypeEnum_CriterionType {
	if m != nil {
		return m.Type
	}
	return enums.CriterionTypeEnum_UNSPECIFIED
}

type isSharedCriterion_Criterion interface {
	isSharedCriterion_Criterion()
}

type SharedCriterion_Keyword struct {
	Keyword *common.KeywordInfo `protobuf:"bytes,3,opt,name=keyword,proto3,oneof"`
}

type SharedCriterion_YoutubeVideo struct {
	YoutubeVideo *common.YouTubeVideoInfo `protobuf:"bytes,5,opt,name=youtube_video,json=youtubeVideo,proto3,oneof"`
}

type SharedCriterion_YoutubeChannel struct {
	YoutubeChannel *common.YouTubeChannelInfo `protobuf:"bytes,6,opt,name=youtube_channel,json=youtubeChannel,proto3,oneof"`
}

type SharedCriterion_Placement struct {
	Placement *common.PlacementInfo `protobuf:"bytes,7,opt,name=placement,proto3,oneof"`
}

type SharedCriterion_MobileAppCategory struct {
	MobileAppCategory *common.MobileAppCategoryInfo `protobuf:"bytes,8,opt,name=mobile_app_category,json=mobileAppCategory,proto3,oneof"`
}

type SharedCriterion_MobileApplication struct {
	MobileApplication *common.MobileApplicationInfo `protobuf:"bytes,9,opt,name=mobile_application,json=mobileApplication,proto3,oneof"`
}

func (*SharedCriterion_Keyword) isSharedCriterion_Criterion() {}

func (*SharedCriterion_YoutubeVideo) isSharedCriterion_Criterion() {}

func (*SharedCriterion_YoutubeChannel) isSharedCriterion_Criterion() {}

func (*SharedCriterion_Placement) isSharedCriterion_Criterion() {}

func (*SharedCriterion_MobileAppCategory) isSharedCriterion_Criterion() {}

func (*SharedCriterion_MobileApplication) isSharedCriterion_Criterion() {}

func (m *SharedCriterion) GetCriterion() isSharedCriterion_Criterion {
	if m != nil {
		return m.Criterion
	}
	return nil
}

func (m *SharedCriterion) GetKeyword() *common.KeywordInfo {
	if x, ok := m.GetCriterion().(*SharedCriterion_Keyword); ok {
		return x.Keyword
	}
	return nil
}

func (m *SharedCriterion) GetYoutubeVideo() *common.YouTubeVideoInfo {
	if x, ok := m.GetCriterion().(*SharedCriterion_YoutubeVideo); ok {
		return x.YoutubeVideo
	}
	return nil
}

func (m *SharedCriterion) GetYoutubeChannel() *common.YouTubeChannelInfo {
	if x, ok := m.GetCriterion().(*SharedCriterion_YoutubeChannel); ok {
		return x.YoutubeChannel
	}
	return nil
}

func (m *SharedCriterion) GetPlacement() *common.PlacementInfo {
	if x, ok := m.GetCriterion().(*SharedCriterion_Placement); ok {
		return x.Placement
	}
	return nil
}

func (m *SharedCriterion) GetMobileAppCategory() *common.MobileAppCategoryInfo {
	if x, ok := m.GetCriterion().(*SharedCriterion_MobileAppCategory); ok {
		return x.MobileAppCategory
	}
	return nil
}

func (m *SharedCriterion) GetMobileApplication() *common.MobileApplicationInfo {
	if x, ok := m.GetCriterion().(*SharedCriterion_MobileApplication); ok {
		return x.MobileApplication
	}
	return nil
}

// XXX_OneofWrappers is for the internal use of the proto package.
func (*SharedCriterion) XXX_OneofWrappers() []interface{} {
	return []interface{}{
		(*SharedCriterion_Keyword)(nil),
		(*SharedCriterion_YoutubeVideo)(nil),
		(*SharedCriterion_YoutubeChannel)(nil),
		(*SharedCriterion_Placement)(nil),
		(*SharedCriterion_MobileAppCategory)(nil),
		(*SharedCriterion_MobileApplication)(nil),
	}
}

func init() {
	proto.RegisterType((*SharedCriterion)(nil), "google.ads.googleads.v1.resources.SharedCriterion")
}

func init() {
	proto.RegisterFile("google/ads/googleads/v1/resources/shared_criterion.proto", fileDescriptor_c8be09b18890bd33)
}

var fileDescriptor_c8be09b18890bd33 = []byte{
	// 593 bytes of a gzipped FileDescriptorProto
	0x1f, 0x8b, 0x08, 0x00, 0x00, 0x00, 0x00, 0x00, 0x02, 0xff, 0x94, 0x94, 0xdd, 0x6a, 0xd4, 0x40,
	0x14, 0xc7, 0xdd, 0x6d, 0x6d, 0xdd, 0xe9, 0x17, 0x8e, 0x5e, 0x84, 0x5a, 0xa4, 0x55, 0x0a, 0x05,
	0xe9, 0xc4, 0x5d, 0x3f, 0x90, 0x14, 0x0a, 0x69, 0x91, 0x5a, 0xa5, 0x52, 0xd2, 0xb2, 0xa2, 0xac,
	0x84, 0xd9, 0xe4, 0x34, 0x0d, 0x26, 0x33, 0xc3, 0xcc, 0xa4, 0x65, 0x2f, 0x7d, 0x15, 0x2f, 0xbd,
	0xf7, 0x25, 0x7c, 0x14, 0x9f, 0x42, 0x76, 0x32, 0x93, 0x62, 0xcb, 0xba, 0x7a, 0x77, 0x32, 0xe7,
	0xff, 0xff, 0x9d, 0x39, 0x27, 0x27, 0x41, 0xaf, 0x32, 0xce, 0xb3, 0x02, 0x7c, 0x9a, 0x2a, 0xbf,
	0x0e, 0xc7, 0xd1, 0x45, 0xd7, 0x97, 0xa0, 0x78, 0x25, 0x13, 0x50, 0xbe, 0x3a, 0xa7, 0x12, 0xd2,
	0x38, 0x91, 0xb9, 0x06, 0x99, 0x73, 0x46, 0x84, 0xe4, 0x9a, 0xe3, 0x8d, 0x5a, 0x4e, 0x68, 0xaa,
	0x48, 0xe3, 0x24, 0x17, 0x5d, 0xd2, 0x38, 0x57, 0xb7, 0x27, 0xc1, 0x13, 0x5e, 0x96, 0x9c, 0xf9,
	0x16, 0x49, 0x6b, 0xe2, 0x6a, 0x6f, 0x92, 0x1c, 0x58, 0x55, 0x2a, 0xbf, 0xb9, 0x40, 0xac, 0x47,
	0x02, 0xac, 0x67, 0xcd, 0x79, 0x44, 0xee, 0x53, 0xc6, 0xb8, 0xa6, 0x3a, 0xe7, 0x4c, 0xd9, 0xec,
	0x43, 0x9b, 0x35, 0x4f, 0xc3, 0xea, 0xcc, 0xbf, 0x94, 0x54, 0x08, 0x90, 0x36, 0xff, 0xe8, 0xc7,
	0x1c, 0x5a, 0x39, 0x31, 0xed, 0xed, 0x3b, 0x38, 0x7e, 0x8c, 0x96, 0x5c, 0x07, 0x31, 0xa3, 0x25,
	0x78, 0xad, 0xf5, 0xd6, 0x56, 0x27, 0x5a, 0x74, 0x87, 0xef, 0x69, 0x09, 0x78, 0x07, 0x21, 0x3b,
	0x16, 0x05, 0xda, 0x6b, 0xaf, 0xb7, 0xb6, 0x16, 0x7a, 0x6b, 0x76, 0x0c, 0xc4, 0x55, 0x23, 0x27,
	0x5a, 0xe6, 0x2c, 0xeb, 0xd3, 0xa2, 0x82, 0xa8, 0x53, 0xeb, 0x4f, 0x40, 0xe3, 0x5d, 0xb4, 0x78,
	0xd5, 0x4b, 0x9e, 0x7a, 0xab, 0xc6, 0xfe, 0xe0, 0x86, 0xfd, 0x90, 0xe9, 0x97, 0xcf, 0x6b, 0xf7,
	0x42, 0x63, 0x38, 0x4c, 0x71, 0x84, 0x66, 0xc7, 0x13, 0xf0, 0x66, 0xd7, 0x5b, 0x5b, 0xcb, 0xbd,
	0x5d, 0x32, 0xe9, 0x45, 0x98, 0xb1, 0x91, 0xa6, 0xb3, 0xd3, 0x91, 0x80, 0xd7, 0xac, 0x2a, 0xff,
	0x3c, 0x89, 0x0c, 0x0b, 0x1f, 0xa0, 0xf9, 0x2f, 0x30, 0xba, 0xe4, 0x32, 0xf5, 0x66, 0xcc, 0x75,
	0x9e, 0x4c, 0xc4, 0xd6, 0x2f, 0x8f, 0xbc, 0xab, 0xe5, 0x87, 0xec, 0x8c, 0xbf, 0xb9, 0x15, 0x39,
	0x37, 0xfe, 0x80, 0x96, 0x46, 0xbc, 0xd2, 0xd5, 0x10, 0xe2, 0x8b, 0x3c, 0x05, 0xee, 0xdd, 0x36,
	0xb8, 0xa7, 0xd3, 0x70, 0x1f, 0x79, 0x75, 0x5a, 0x0d, 0xa1, 0x3f, 0xf6, 0x58, 0xe6, 0xa2, 0x05,
	0x99, 0x33, 0xfc, 0x19, 0xad, 0x38, 0x70, 0x72, 0x4e, 0x19, 0x83, 0xc2, 0x9b, 0x33, 0xe8, 0xde,
	0x3f, 0xa2, 0xf7, 0x6b, 0x97, 0x85, 0x2f, 0x5b, 0x98, 0x3d, 0xc5, 0x47, 0xa8, 0x23, 0x0a, 0x9a,
	0x40, 0x09, 0x4c, 0x7b, 0xf3, 0x06, 0xbc, 0x3d, 0x0d, 0x7c, 0xec, 0x0c, 0x96, 0x79, 0x45, 0xc0,
	0x19, 0xba, 0x57, 0xf2, 0x61, 0x5e, 0x40, 0x4c, 0x85, 0x88, 0x13, 0xaa, 0x21, 0xe3, 0x72, 0xe4,
	0xdd, 0x31, 0xe0, 0x17, 0xd3, 0xc0, 0x47, 0xc6, 0x1a, 0x0a, 0xb1, 0x6f, 0x8d, 0xb6, 0xc0, 0xdd,
	0xf2, 0x7a, 0x02, 0x9f, 0x21, 0x7c, 0x55, 0xa8, 0xc8, 0x13, 0xb3, 0xff, 0x5e, 0xe7, 0x3f, 0xeb,
	0x38, 0xe3, 0x8d, 0x3a, 0x2e, 0xb1, 0xb7, 0x80, 0x3a, 0xcd, 0x0e, 0xee, 0x7d, 0x6d, 0xa3, 0xcd,
	0x84, 0x97, 0x64, 0xea, 0x2f, 0x60, 0xef, 0xfe, 0xb5, 0xcf, 0xeb, 0x78, 0xbc, 0xdc, 0xc7, 0xad,
	0x4f, 0x6f, 0xad, 0x35, 0xe3, 0x05, 0x65, 0x19, 0xe1, 0x32, 0xf3, 0x33, 0x60, 0x66, 0xf5, 0xdd,
	0xb7, 0x2f, 0x72, 0xf5, 0x97, 0xdf, 0xd2, 0x4e, 0x13, 0x7d, 0x6b, 0xcf, 0x1c, 0x84, 0xe1, 0xf7,
	0xf6, 0xc6, 0x41, 0x8d, 0x0c, 0x53, 0x45, 0xea, 0x70, 0x1c, 0xf5, 0xbb, 0x24, 0x72, 0xca, 0x9f,
	0x4e, 0x33, 0x08, 0x53, 0x35, 0x68, 0x34, 0x83, 0x7e, 0x77, 0xd0, 0x68, 0x7e, 0xb5, 0x37, 0xeb,
	0x44, 0x10, 0x84, 0xa9, 0x0a, 0x82, 0x46, 0x15, 0x04, 0xfd, 0x6e, 0x10, 0x34, 0xba, 0xe1, 0x9c,
	0xb9, 0xec, 0xb3, 0xdf, 0x01, 0x00, 0x00, 0xff, 0xff, 0xe6, 0x70, 0x08, 0x49, 0x42, 0x05, 0x00,
	0x00,
}
