// Code generated by protoc-gen-go. DO NOT EDIT.
// source: google/ads/googleads/v1/services/domain_category_service.proto

package services

import (
	context "context"
	fmt "fmt"
	math "math"

	proto "github.com/golang/protobuf/proto"
	resources "google.golang.org/genproto/googleapis/ads/googleads/v1/resources"
	_ "google.golang.org/genproto/googleapis/api/annotations"
	grpc "google.golang.org/grpc"
)

// Reference imports to suppress errors if they are not otherwise used.
var _ = proto.Marshal
var _ = fmt.Errorf
var _ = math.Inf

// This is a compile-time assertion to ensure that this generated file
// is compatible with the proto package it is being compiled against.
// A compilation error at this line likely means your copy of the
// proto package needs to be updated.
const _ = proto.ProtoPackageIsVersion3 // please upgrade the proto package

// Request message for
// [DomainCategoryService.GetDomainCategory][google.ads.googleads.v1.services.DomainCategoryService.GetDomainCategory].
type GetDomainCategoryRequest struct {
	// Resource name of the domain category to fetch.
	ResourceName         string   `protobuf:"bytes,1,opt,name=resource_name,json=resourceName,proto3" json:"resource_name,omitempty"`
	XXX_NoUnkeyedLiteral struct{} `json:"-"`
	XXX_unrecognized     []byte   `json:"-"`
	XXX_sizecache        int32    `json:"-"`
}

func (m *GetDomainCategoryRequest) Reset()         { *m = GetDomainCategoryRequest{} }
func (m *GetDomainCategoryRequest) String() string { return proto.CompactTextString(m) }
func (*GetDomainCategoryRequest) ProtoMessage()    {}
func (*GetDomainCategoryRequest) Descriptor() ([]byte, []int) {
	return fileDescriptor_15e4bcffa65a4ff8, []int{0}
}

func (m *GetDomainCategoryRequest) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_GetDomainCategoryRequest.Unmarshal(m, b)
}
func (m *GetDomainCategoryRequest) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_GetDomainCategoryRequest.Marshal(b, m, deterministic)
}
func (m *GetDomainCategoryRequest) XXX_Merge(src proto.Message) {
	xxx_messageInfo_GetDomainCategoryRequest.Merge(m, src)
}
func (m *GetDomainCategoryRequest) XXX_Size() int {
	return xxx_messageInfo_GetDomainCategoryRequest.Size(m)
}
func (m *GetDomainCategoryRequest) XXX_DiscardUnknown() {
	xxx_messageInfo_GetDomainCategoryRequest.DiscardUnknown(m)
}

var xxx_messageInfo_GetDomainCategoryRequest proto.InternalMessageInfo

func (m *GetDomainCategoryRequest) GetResourceName() string {
	if m != nil {
		return m.ResourceName
	}
	return ""
}

func init() {
	proto.RegisterType((*GetDomainCategoryRequest)(nil), "google.ads.googleads.v1.services.GetDomainCategoryRequest")
}

func init() {
	proto.RegisterFile("google/ads/googleads/v1/services/domain_category_service.proto", fileDescriptor_15e4bcffa65a4ff8)
}

var fileDescriptor_15e4bcffa65a4ff8 = []byte{
	// 367 bytes of a gzipped FileDescriptorProto
	0x1f, 0x8b, 0x08, 0x00, 0x00, 0x00, 0x00, 0x00, 0x02, 0xff, 0x84, 0x92, 0x41, 0x4a, 0xfb, 0x40,
	0x18, 0xc5, 0x49, 0xfe, 0xf0, 0x07, 0x83, 0x2e, 0x0c, 0x08, 0x25, 0xb8, 0x28, 0xb5, 0x0b, 0xe9,
	0x62, 0x86, 0x54, 0x41, 0x18, 0x51, 0x49, 0x15, 0xea, 0x4a, 0x4a, 0x85, 0x2e, 0x24, 0x50, 0xc6,
	0x64, 0x18, 0x02, 0xcd, 0x4c, 0x9d, 0x6f, 0x5a, 0x10, 0x71, 0xa1, 0x57, 0xf0, 0x06, 0x2e, 0x3d,
	0x84, 0x07, 0x70, 0xeb, 0xc6, 0x03, 0xb8, 0xf2, 0x14, 0x92, 0x4e, 0x26, 0x50, 0x6c, 0xe8, 0xee,
	0x31, 0xf3, 0x7e, 0xdf, 0xf7, 0xe6, 0x25, 0xde, 0x29, 0x97, 0x92, 0x4f, 0x18, 0xa6, 0x29, 0x60,
	0x23, 0x0b, 0x35, 0x0f, 0x31, 0x30, 0x35, 0xcf, 0x12, 0x06, 0x38, 0x95, 0x39, 0xcd, 0xc4, 0x38,
	0xa1, 0x9a, 0x71, 0xa9, 0xee, 0xc7, 0xe5, 0x05, 0x9a, 0x2a, 0xa9, 0xa5, 0xdf, 0x34, 0x10, 0xa2,
	0x29, 0xa0, 0x8a, 0x47, 0xf3, 0x10, 0x59, 0x3e, 0x38, 0xaa, 0xdb, 0xa0, 0x18, 0xc8, 0x99, 0x5a,
	0xb1, 0xc2, 0x8c, 0x0e, 0x76, 0x2d, 0x38, 0xcd, 0x30, 0x15, 0x42, 0x6a, 0xaa, 0x33, 0x29, 0xc0,
	0xdc, 0xb6, 0xce, 0xbc, 0x46, 0x9f, 0xe9, 0x8b, 0x05, 0x79, 0x5e, 0x82, 0x43, 0x76, 0x37, 0x63,
	0xa0, 0xfd, 0x3d, 0x6f, 0xcb, 0x0e, 0x1f, 0x0b, 0x9a, 0xb3, 0x86, 0xd3, 0x74, 0xf6, 0x37, 0x86,
	0x9b, 0xf6, 0xf0, 0x8a, 0xe6, 0xac, 0xfb, 0xe5, 0x78, 0x3b, 0xcb, 0xf8, 0xb5, 0x89, 0xec, 0xbf,
	0x3b, 0xde, 0xf6, 0x9f, 0xd9, 0x3e, 0x41, 0xeb, 0x9e, 0x8a, 0xea, 0x02, 0x05, 0x61, 0x2d, 0x5b,
	0x95, 0x80, 0x96, 0xc9, 0x16, 0x79, 0xfe, 0xfc, 0x7e, 0x71, 0x0f, 0xfd, 0x6e, 0x51, 0xd5, 0xc3,
	0xd2, 0x73, 0x4e, 0x92, 0x19, 0x68, 0x99, 0x33, 0x05, 0xb8, 0x53, 0x76, 0x57, 0x62, 0x19, 0x03,
	0xdc, 0x79, 0xec, 0x3d, 0xb9, 0x5e, 0x3b, 0x91, 0xf9, 0xda, 0xc0, 0xbd, 0x60, 0x65, 0x01, 0x83,
	0xa2, 0xe0, 0x81, 0x73, 0x73, 0x59, 0xf2, 0x5c, 0x4e, 0xa8, 0xe0, 0x48, 0x2a, 0x8e, 0x39, 0x13,
	0x8b, 0xfa, 0xed, 0x97, 0x9c, 0x66, 0x50, 0xff, 0xeb, 0x1c, 0x5b, 0xf1, 0xea, 0xfe, 0xeb, 0x47,
	0xd1, 0x9b, 0xdb, 0xec, 0x9b, 0x81, 0x51, 0x0a, 0xc8, 0xc8, 0x42, 0x8d, 0x42, 0x54, 0x2e, 0x86,
	0x0f, 0x6b, 0x89, 0xa3, 0x14, 0xe2, 0xca, 0x12, 0x8f, 0xc2, 0xd8, 0x5a, 0x7e, 0xdc, 0xb6, 0x39,
	0x27, 0x24, 0x4a, 0x81, 0x90, 0xca, 0x44, 0xc8, 0x28, 0x24, 0xc4, 0xda, 0x6e, 0xff, 0x2f, 0x72,
	0x1e, 0xfc, 0x06, 0x00, 0x00, 0xff, 0xff, 0x0a, 0xaa, 0x05, 0x1b, 0xe1, 0x02, 0x00, 0x00,
}

// Reference imports to suppress errors if they are not otherwise used.
var _ context.Context
var _ grpc.ClientConn

// This is a compile-time assertion to ensure that this generated file
// is compatible with the grpc package it is being compiled against.
const _ = grpc.SupportPackageIsVersion4

// DomainCategoryServiceClient is the client API for DomainCategoryService service.
//
// For semantics around ctx use and closing/ending streaming RPCs, please refer to https://godoc.org/google.golang.org/grpc#ClientConn.NewStream.
type DomainCategoryServiceClient interface {
	// Returns the requested domain category.
	GetDomainCategory(ctx context.Context, in *GetDomainCategoryRequest, opts ...grpc.CallOption) (*resources.DomainCategory, error)
}

type domainCategoryServiceClient struct {
	cc *grpc.ClientConn
}

func NewDomainCategoryServiceClient(cc *grpc.ClientConn) DomainCategoryServiceClient {
	return &domainCategoryServiceClient{cc}
}

func (c *domainCategoryServiceClient) GetDomainCategory(ctx context.Context, in *GetDomainCategoryRequest, opts ...grpc.CallOption) (*resources.DomainCategory, error) {
	out := new(resources.DomainCategory)
	err := c.cc.Invoke(ctx, "/google.ads.googleads.v1.services.DomainCategoryService/GetDomainCategory", in, out, opts...)
	if err != nil {
		return nil, err
	}
	return out, nil
}

// DomainCategoryServiceServer is the server API for DomainCategoryService service.
type DomainCategoryServiceServer interface {
	// Returns the requested domain category.
	GetDomainCategory(context.Context, *GetDomainCategoryRequest) (*resources.DomainCategory, error)
}

func RegisterDomainCategoryServiceServer(s *grpc.Server, srv DomainCategoryServiceServer) {
	s.RegisterService(&_DomainCategoryService_serviceDesc, srv)
}

func _DomainCategoryService_GetDomainCategory_Handler(srv interface{}, ctx context.Context, dec func(interface{}) error, interceptor grpc.UnaryServerInterceptor) (interface{}, error) {
	in := new(GetDomainCategoryRequest)
	if err := dec(in); err != nil {
		return nil, err
	}
	if interceptor == nil {
		return srv.(DomainCategoryServiceServer).GetDomainCategory(ctx, in)
	}
	info := &grpc.UnaryServerInfo{
		Server:     srv,
		FullMethod: "/google.ads.googleads.v1.services.DomainCategoryService/GetDomainCategory",
	}
	handler := func(ctx context.Context, req interface{}) (interface{}, error) {
		return srv.(DomainCategoryServiceServer).GetDomainCategory(ctx, req.(*GetDomainCategoryRequest))
	}
	return interceptor(ctx, in, info, handler)
}

var _DomainCategoryService_serviceDesc = grpc.ServiceDesc{
	ServiceName: "google.ads.googleads.v1.services.DomainCategoryService",
	HandlerType: (*DomainCategoryServiceServer)(nil),
	Methods: []grpc.MethodDesc{
		{
			MethodName: "GetDomainCategory",
			Handler:    _DomainCategoryService_GetDomainCategory_Handler,
		},
	},
	Streams:  []grpc.StreamDesc{},
	Metadata: "google/ads/googleads/v1/services/domain_category_service.proto",
}
