// Code generated by protoc-gen-go. DO NOT EDIT.
// source: google/ads/googleads/v1/enums/legacy_app_install_ad_app_store.proto

package enums

import (
	fmt "fmt"
	math "math"

	proto "github.com/golang/protobuf/proto"
	_ "google.golang.org/genproto/googleapis/api/annotations"
)

// Reference imports to suppress errors if they are not otherwise used.
var _ = proto.Marshal
var _ = fmt.Errorf
var _ = math.Inf

// This is a compile-time assertion to ensure that this generated file
// is compatible with the proto package it is being compiled against.
// A compilation error at this line likely means your copy of the
// proto package needs to be updated.
const _ = proto.ProtoPackageIsVersion3 // please upgrade the proto package

// App store type in a legacy app install ad.
type LegacyAppInstallAdAppStoreEnum_LegacyAppInstallAdAppStore int32

const (
	// Not specified.
	LegacyAppInstallAdAppStoreEnum_UNSPECIFIED LegacyAppInstallAdAppStoreEnum_LegacyAppInstallAdAppStore = 0
	// Used for return value only. Represents value unknown in this version.
	LegacyAppInstallAdAppStoreEnum_UNKNOWN LegacyAppInstallAdAppStoreEnum_LegacyAppInstallAdAppStore = 1
	// Apple iTunes.
	LegacyAppInstallAdAppStoreEnum_APPLE_APP_STORE LegacyAppInstallAdAppStoreEnum_LegacyAppInstallAdAppStore = 2
	// Google Play.
	LegacyAppInstallAdAppStoreEnum_GOOGLE_PLAY LegacyAppInstallAdAppStoreEnum_LegacyAppInstallAdAppStore = 3
	// Windows Store.
	LegacyAppInstallAdAppStoreEnum_WINDOWS_STORE LegacyAppInstallAdAppStoreEnum_LegacyAppInstallAdAppStore = 4
	// Windows Phone Store.
	LegacyAppInstallAdAppStoreEnum_WINDOWS_PHONE_STORE LegacyAppInstallAdAppStoreEnum_LegacyAppInstallAdAppStore = 5
	// The app is hosted in a Chinese app store.
	LegacyAppInstallAdAppStoreEnum_CN_APP_STORE LegacyAppInstallAdAppStoreEnum_LegacyAppInstallAdAppStore = 6
)

var LegacyAppInstallAdAppStoreEnum_LegacyAppInstallAdAppStore_name = map[int32]string{
	0: "UNSPECIFIED",
	1: "UNKNOWN",
	2: "APPLE_APP_STORE",
	3: "GOOGLE_PLAY",
	4: "WINDOWS_STORE",
	5: "WINDOWS_PHONE_STORE",
	6: "CN_APP_STORE",
}

var LegacyAppInstallAdAppStoreEnum_LegacyAppInstallAdAppStore_value = map[string]int32{
	"UNSPECIFIED":         0,
	"UNKNOWN":             1,
	"APPLE_APP_STORE":     2,
	"GOOGLE_PLAY":         3,
	"WINDOWS_STORE":       4,
	"WINDOWS_PHONE_STORE": 5,
	"CN_APP_STORE":        6,
}

func (x LegacyAppInstallAdAppStoreEnum_LegacyAppInstallAdAppStore) String() string {
	return proto.EnumName(LegacyAppInstallAdAppStoreEnum_LegacyAppInstallAdAppStore_name, int32(x))
}

func (LegacyAppInstallAdAppStoreEnum_LegacyAppInstallAdAppStore) EnumDescriptor() ([]byte, []int) {
	return fileDescriptor_676a144a27afa9f6, []int{0, 0}
}

// Container for enum describing app store type in a legacy app install ad.
type LegacyAppInstallAdAppStoreEnum struct {
	XXX_NoUnkeyedLiteral struct{} `json:"-"`
	XXX_unrecognized     []byte   `json:"-"`
	XXX_sizecache        int32    `json:"-"`
}

func (m *LegacyAppInstallAdAppStoreEnum) Reset()         { *m = LegacyAppInstallAdAppStoreEnum{} }
func (m *LegacyAppInstallAdAppStoreEnum) String() string { return proto.CompactTextString(m) }
func (*LegacyAppInstallAdAppStoreEnum) ProtoMessage()    {}
func (*LegacyAppInstallAdAppStoreEnum) Descriptor() ([]byte, []int) {
	return fileDescriptor_676a144a27afa9f6, []int{0}
}

func (m *LegacyAppInstallAdAppStoreEnum) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_LegacyAppInstallAdAppStoreEnum.Unmarshal(m, b)
}
func (m *LegacyAppInstallAdAppStoreEnum) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_LegacyAppInstallAdAppStoreEnum.Marshal(b, m, deterministic)
}
func (m *LegacyAppInstallAdAppStoreEnum) XXX_Merge(src proto.Message) {
	xxx_messageInfo_LegacyAppInstallAdAppStoreEnum.Merge(m, src)
}
func (m *LegacyAppInstallAdAppStoreEnum) XXX_Size() int {
	return xxx_messageInfo_LegacyAppInstallAdAppStoreEnum.Size(m)
}
func (m *LegacyAppInstallAdAppStoreEnum) XXX_DiscardUnknown() {
	xxx_messageInfo_LegacyAppInstallAdAppStoreEnum.DiscardUnknown(m)
}

var xxx_messageInfo_LegacyAppInstallAdAppStoreEnum proto.InternalMessageInfo

func init() {
	proto.RegisterEnum("google.ads.googleads.v1.enums.LegacyAppInstallAdAppStoreEnum_LegacyAppInstallAdAppStore", LegacyAppInstallAdAppStoreEnum_LegacyAppInstallAdAppStore_name, LegacyAppInstallAdAppStoreEnum_LegacyAppInstallAdAppStore_value)
	proto.RegisterType((*LegacyAppInstallAdAppStoreEnum)(nil), "google.ads.googleads.v1.enums.LegacyAppInstallAdAppStoreEnum")
}

func init() {
	proto.RegisterFile("google/ads/googleads/v1/enums/legacy_app_install_ad_app_store.proto", fileDescriptor_676a144a27afa9f6)
}

var fileDescriptor_676a144a27afa9f6 = []byte{
	// 371 bytes of a gzipped FileDescriptorProto
	0x1f, 0x8b, 0x08, 0x00, 0x00, 0x00, 0x00, 0x00, 0x02, 0xff, 0x7c, 0x51, 0x41, 0x6b, 0xa3, 0x40,
	0x18, 0x5d, 0xcd, 0x6e, 0x16, 0x26, 0xbb, 0xc4, 0x35, 0x87, 0x85, 0xb0, 0xd9, 0x25, 0xf9, 0x01,
	0x23, 0xb2, 0xb7, 0xe9, 0x69, 0x92, 0x58, 0x2b, 0x15, 0x1d, 0x6a, 0x93, 0xd0, 0x22, 0xc8, 0x34,
	0x8a, 0x08, 0x66, 0x66, 0xc8, 0x98, 0x40, 0xff, 0x4c, 0x0f, 0x3d, 0xf6, 0x5f, 0xf4, 0xda, 0x9f,
	0xd2, 0x73, 0x7f, 0x40, 0x71, 0x8c, 0xa1, 0x97, 0xf4, 0x22, 0xcf, 0xef, 0xbd, 0xef, 0x3d, 0x7d,
	0x1f, 0x98, 0xe5, 0x9c, 0xe7, 0x65, 0x66, 0xd1, 0x54, 0x5a, 0x0d, 0xac, 0xd1, 0xde, 0xb6, 0x32,
	0xb6, 0xdb, 0x48, 0xab, 0xcc, 0x72, 0xba, 0xbe, 0x4f, 0xa8, 0x10, 0x49, 0xc1, 0x64, 0x45, 0xcb,
	0x32, 0xa1, 0xa9, 0x7a, 0x95, 0x15, 0xdf, 0x66, 0x50, 0x6c, 0x79, 0xc5, 0xcd, 0x51, 0xb3, 0x09,
	0x69, 0x2a, 0xe1, 0xd1, 0x04, 0xee, 0x6d, 0xa8, 0x4c, 0x86, 0x7f, 0xda, 0x0c, 0x51, 0x58, 0x94,
	0x31, 0x5e, 0xd1, 0xaa, 0xe0, 0x4c, 0x36, 0xcb, 0x93, 0x67, 0x0d, 0xfc, 0xf5, 0x55, 0x0c, 0x16,
	0xc2, 0x6b, 0x42, 0x70, 0x8a, 0x85, 0x88, 0xea, 0x04, 0x87, 0xed, 0x36, 0x93, 0x07, 0x0d, 0x0c,
	0x4f, 0x4b, 0xcc, 0x3e, 0xe8, 0x2d, 0x82, 0x88, 0x38, 0x33, 0xef, 0xdc, 0x73, 0xe6, 0xc6, 0x17,
	0xb3, 0x07, 0xbe, 0x2f, 0x82, 0xcb, 0x20, 0x5c, 0x05, 0x86, 0x66, 0x0e, 0x40, 0x1f, 0x13, 0xe2,
	0x3b, 0x09, 0x26, 0x24, 0x89, 0xae, 0xc3, 0x2b, 0xc7, 0xd0, 0xeb, 0x15, 0x37, 0x0c, 0x5d, 0xdf,
	0x49, 0x88, 0x8f, 0x6f, 0x8c, 0x8e, 0xf9, 0x0b, 0xfc, 0x5c, 0x79, 0xc1, 0x3c, 0x5c, 0x45, 0x07,
	0xcd, 0x57, 0xf3, 0x37, 0x18, 0xb4, 0x23, 0x72, 0x11, 0x06, 0xce, 0x81, 0xf8, 0x66, 0x1a, 0xe0,
	0xc7, 0x2c, 0xf8, 0x60, 0xd7, 0x9d, 0xbe, 0x69, 0x60, 0xbc, 0xe6, 0x1b, 0xf8, 0x69, 0x0f, 0xd3,
	0x7f, 0xa7, 0xff, 0x81, 0xd4, 0x55, 0x10, 0xed, 0x76, 0x7a, 0x70, 0xc8, 0x79, 0x49, 0x59, 0x0e,
	0xf9, 0x36, 0xb7, 0xf2, 0x8c, 0xa9, 0xa2, 0xda, 0xf3, 0x88, 0x42, 0x9e, 0xb8, 0xd6, 0x99, 0x7a,
	0x3e, 0xea, 0x1d, 0x17, 0xe3, 0x27, 0x7d, 0xe4, 0x36, 0x56, 0x38, 0x95, 0xb0, 0x81, 0x35, 0x5a,
	0xda, 0xb0, 0xae, 0x54, 0xbe, 0xb4, 0x7c, 0x8c, 0x53, 0x19, 0x1f, 0xf9, 0x78, 0x69, 0xc7, 0x8a,
	0x7f, 0xd5, 0xc7, 0xcd, 0x10, 0x21, 0x9c, 0x4a, 0x84, 0x8e, 0x0a, 0x84, 0x96, 0x36, 0x42, 0x4a,
	0x73, 0xd7, 0x55, 0x1f, 0xf6, 0xff, 0x3d, 0x00, 0x00, 0xff, 0xff, 0x0c, 0x96, 0x83, 0x7a, 0x45,
	0x02, 0x00, 0x00,
}
