// Code generated by protoc-gen-go. DO NOT EDIT.
// source: google/ads/googleads/v2/errors/resource_count_limit_exceeded_error.proto

package errors

import (
	fmt "fmt"
	math "math"

	proto "github.com/golang/protobuf/proto"
	_ "google.golang.org/genproto/googleapis/api/annotations"
)

// Reference imports to suppress errors if they are not otherwise used.
var _ = proto.Marshal
var _ = fmt.Errorf
var _ = math.Inf

// This is a compile-time assertion to ensure that this generated file
// is compatible with the proto package it is being compiled against.
// A compilation error at this line likely means your copy of the
// proto package needs to be updated.
const _ = proto.ProtoPackageIsVersion3 // please upgrade the proto package

// Enum describing possible resource count limit exceeded errors.
type ResourceCountLimitExceededErrorEnum_ResourceCountLimitExceededError int32

const (
	// Enum unspecified.
	ResourceCountLimitExceededErrorEnum_UNSPECIFIED ResourceCountLimitExceededErrorEnum_ResourceCountLimitExceededError = 0
	// The received error code is not known in this version.
	ResourceCountLimitExceededErrorEnum_UNKNOWN ResourceCountLimitExceededErrorEnum_ResourceCountLimitExceededError = 1
	// Indicates that this request would exceed the number of allowed resources
	// for the Google Ads account. The exact resource type and limit being
	// checked can be inferred from accountLimitType.
	ResourceCountLimitExceededErrorEnum_ACCOUNT_LIMIT ResourceCountLimitExceededErrorEnum_ResourceCountLimitExceededError = 2
	// Indicates that this request would exceed the number of allowed resources
	// in a Campaign. The exact resource type and limit being checked can be
	// inferred from accountLimitType, and the numeric id of the
	// Campaign involved is given by enclosingId.
	ResourceCountLimitExceededErrorEnum_CAMPAIGN_LIMIT ResourceCountLimitExceededErrorEnum_ResourceCountLimitExceededError = 3
	// Indicates that this request would exceed the number of allowed resources
	// in an ad group. The exact resource type and limit being checked can be
	// inferred from accountLimitType, and the numeric id of the
	// ad group involved is given by enclosingId.
	ResourceCountLimitExceededErrorEnum_ADGROUP_LIMIT ResourceCountLimitExceededErrorEnum_ResourceCountLimitExceededError = 4
	// Indicates that this request would exceed the number of allowed resources
	// in an ad group ad. The exact resource type and limit being checked can
	// be inferred from accountLimitType, and the enclosingId
	// contains the ad group id followed by the ad id, separated by a single
	// comma (,).
	ResourceCountLimitExceededErrorEnum_AD_GROUP_AD_LIMIT ResourceCountLimitExceededErrorEnum_ResourceCountLimitExceededError = 5
	// Indicates that this request would exceed the number of allowed resources
	// in an ad group criterion. The exact resource type and limit being checked
	// can be inferred from accountLimitType, and the
	// enclosingId contains the ad group id followed by the
	// criterion id, separated by a single comma (,).
	ResourceCountLimitExceededErrorEnum_AD_GROUP_CRITERION_LIMIT ResourceCountLimitExceededErrorEnum_ResourceCountLimitExceededError = 6
	// Indicates that this request would exceed the number of allowed resources
	// in this shared set. The exact resource type and limit being checked can
	// be inferred from accountLimitType, and the numeric id of the
	// shared set involved is given by enclosingId.
	ResourceCountLimitExceededErrorEnum_SHARED_SET_LIMIT ResourceCountLimitExceededErrorEnum_ResourceCountLimitExceededError = 7
	// Exceeds a limit related to a matching function.
	ResourceCountLimitExceededErrorEnum_MATCHING_FUNCTION_LIMIT ResourceCountLimitExceededErrorEnum_ResourceCountLimitExceededError = 8
	// The response for this request would exceed the maximum number of rows
	// that can be returned.
	ResourceCountLimitExceededErrorEnum_RESPONSE_ROW_LIMIT_EXCEEDED ResourceCountLimitExceededErrorEnum_ResourceCountLimitExceededError = 9
	// This request would exceed a limit on the number of allowed resources.
	// The details of which type of limit was exceeded will eventually be
	// returned in ErrorDetails.
	ResourceCountLimitExceededErrorEnum_RESOURCE_LIMIT ResourceCountLimitExceededErrorEnum_ResourceCountLimitExceededError = 10
)

var ResourceCountLimitExceededErrorEnum_ResourceCountLimitExceededError_name = map[int32]string{
	0:  "UNSPECIFIED",
	1:  "UNKNOWN",
	2:  "ACCOUNT_LIMIT",
	3:  "CAMPAIGN_LIMIT",
	4:  "ADGROUP_LIMIT",
	5:  "AD_GROUP_AD_LIMIT",
	6:  "AD_GROUP_CRITERION_LIMIT",
	7:  "SHARED_SET_LIMIT",
	8:  "MATCHING_FUNCTION_LIMIT",
	9:  "RESPONSE_ROW_LIMIT_EXCEEDED",
	10: "RESOURCE_LIMIT",
}

var ResourceCountLimitExceededErrorEnum_ResourceCountLimitExceededError_value = map[string]int32{
	"UNSPECIFIED":                 0,
	"UNKNOWN":                     1,
	"ACCOUNT_LIMIT":               2,
	"CAMPAIGN_LIMIT":              3,
	"ADGROUP_LIMIT":               4,
	"AD_GROUP_AD_LIMIT":           5,
	"AD_GROUP_CRITERION_LIMIT":    6,
	"SHARED_SET_LIMIT":            7,
	"MATCHING_FUNCTION_LIMIT":     8,
	"RESPONSE_ROW_LIMIT_EXCEEDED": 9,
	"RESOURCE_LIMIT":              10,
}

func (x ResourceCountLimitExceededErrorEnum_ResourceCountLimitExceededError) String() string {
	return proto.EnumName(ResourceCountLimitExceededErrorEnum_ResourceCountLimitExceededError_name, int32(x))
}

func (ResourceCountLimitExceededErrorEnum_ResourceCountLimitExceededError) EnumDescriptor() ([]byte, []int) {
	return fileDescriptor_00f247ba537a319f, []int{0, 0}
}

// Container for enum describing possible resource count limit exceeded errors.
type ResourceCountLimitExceededErrorEnum struct {
	XXX_NoUnkeyedLiteral struct{} `json:"-"`
	XXX_unrecognized     []byte   `json:"-"`
	XXX_sizecache        int32    `json:"-"`
}

func (m *ResourceCountLimitExceededErrorEnum) Reset()         { *m = ResourceCountLimitExceededErrorEnum{} }
func (m *ResourceCountLimitExceededErrorEnum) String() string { return proto.CompactTextString(m) }
func (*ResourceCountLimitExceededErrorEnum) ProtoMessage()    {}
func (*ResourceCountLimitExceededErrorEnum) Descriptor() ([]byte, []int) {
	return fileDescriptor_00f247ba537a319f, []int{0}
}

func (m *ResourceCountLimitExceededErrorEnum) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_ResourceCountLimitExceededErrorEnum.Unmarshal(m, b)
}
func (m *ResourceCountLimitExceededErrorEnum) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_ResourceCountLimitExceededErrorEnum.Marshal(b, m, deterministic)
}
func (m *ResourceCountLimitExceededErrorEnum) XXX_Merge(src proto.Message) {
	xxx_messageInfo_ResourceCountLimitExceededErrorEnum.Merge(m, src)
}
func (m *ResourceCountLimitExceededErrorEnum) XXX_Size() int {
	return xxx_messageInfo_ResourceCountLimitExceededErrorEnum.Size(m)
}
func (m *ResourceCountLimitExceededErrorEnum) XXX_DiscardUnknown() {
	xxx_messageInfo_ResourceCountLimitExceededErrorEnum.DiscardUnknown(m)
}

var xxx_messageInfo_ResourceCountLimitExceededErrorEnum proto.InternalMessageInfo

func init() {
	proto.RegisterEnum("google.ads.googleads.v2.errors.ResourceCountLimitExceededErrorEnum_ResourceCountLimitExceededError", ResourceCountLimitExceededErrorEnum_ResourceCountLimitExceededError_name, ResourceCountLimitExceededErrorEnum_ResourceCountLimitExceededError_value)
	proto.RegisterType((*ResourceCountLimitExceededErrorEnum)(nil), "google.ads.googleads.v2.errors.ResourceCountLimitExceededErrorEnum")
}

func init() {
	proto.RegisterFile("google/ads/googleads/v2/errors/resource_count_limit_exceeded_error.proto", fileDescriptor_00f247ba537a319f)
}

var fileDescriptor_00f247ba537a319f = []byte{
	// 440 bytes of a gzipped FileDescriptorProto
	0x1f, 0x8b, 0x08, 0x00, 0x00, 0x00, 0x00, 0x00, 0x02, 0xff, 0x84, 0x92, 0xd1, 0x6e, 0x94, 0x40,
	0x18, 0x85, 0x5d, 0xaa, 0xad, 0x4e, 0xa3, 0xd2, 0x89, 0x46, 0x63, 0x9b, 0x36, 0x59, 0xbd, 0x1e,
	0x12, 0xbc, 0xc3, 0xab, 0xe9, 0x30, 0x65, 0x89, 0xdd, 0x81, 0x0c, 0xb0, 0x35, 0x66, 0x93, 0x09,
	0x2e, 0x13, 0x42, 0xb2, 0xcb, 0x6c, 0x18, 0xb6, 0xf1, 0x49, 0x7c, 0x00, 0x2f, 0x7d, 0x08, 0x1f,
	0xc0, 0x47, 0xf1, 0x25, 0x34, 0x30, 0xb0, 0x5e, 0xd9, 0x5e, 0xf1, 0xe7, 0xe4, 0x3b, 0xe7, 0x4c,
	0xf8, 0x7f, 0x30, 0x2b, 0x95, 0x2a, 0xd7, 0xd2, 0xc9, 0x0b, 0xed, 0x98, 0xb1, 0x9b, 0x6e, 0x5d,
	0x47, 0x36, 0x8d, 0x6a, 0xb4, 0xd3, 0x48, 0xad, 0x76, 0xcd, 0x4a, 0x8a, 0x95, 0xda, 0xd5, 0xad,
	0x58, 0x57, 0x9b, 0xaa, 0x15, 0xf2, 0xeb, 0x4a, 0xca, 0x42, 0x16, 0xa2, 0x87, 0xd0, 0xb6, 0x51,
	0xad, 0x82, 0xe7, 0xc6, 0x8e, 0xf2, 0x42, 0xa3, 0x7d, 0x12, 0xba, 0x75, 0x91, 0x49, 0x7a, 0x73,
	0x36, 0x36, 0x6d, 0x2b, 0x27, 0xaf, 0x6b, 0xd5, 0xe6, 0x6d, 0xa5, 0x6a, 0x6d, 0xdc, 0xd3, 0x9f,
	0x16, 0x78, 0xcb, 0x87, 0x2e, 0xd2, 0x55, 0x5d, 0x77, 0x4d, 0x74, 0x28, 0xa2, 0x5d, 0x04, 0xad,
	0x77, 0x9b, 0xe9, 0x37, 0x0b, 0x5c, 0xdc, 0xc3, 0xc1, 0xe7, 0xe0, 0x38, 0x63, 0x49, 0x4c, 0x49,
	0x78, 0x15, 0x52, 0xdf, 0x7e, 0x00, 0x8f, 0xc1, 0x51, 0xc6, 0x3e, 0xb2, 0xe8, 0x86, 0xd9, 0x13,
	0x78, 0x02, 0x9e, 0x62, 0x42, 0xa2, 0x8c, 0xa5, 0xe2, 0x3a, 0x9c, 0x87, 0xa9, 0x6d, 0x41, 0x08,
	0x9e, 0x11, 0x3c, 0x8f, 0x71, 0x18, 0xb0, 0x41, 0x3b, 0xe8, 0x31, 0x3f, 0xe0, 0x51, 0x16, 0x0f,
	0xd2, 0x43, 0xf8, 0x12, 0x9c, 0x60, 0x5f, 0x18, 0x0d, 0xfb, 0x83, 0xfc, 0x08, 0x9e, 0x81, 0xd7,
	0x7b, 0x99, 0xf0, 0x30, 0xa5, 0x3c, 0x8c, 0xc6, 0x9c, 0x43, 0xf8, 0x02, 0xd8, 0xc9, 0x0c, 0x73,
	0xea, 0x8b, 0x84, 0x8e, 0x8d, 0x47, 0xf0, 0x14, 0xbc, 0x9a, 0xe3, 0x94, 0xcc, 0x42, 0x16, 0x88,
	0xab, 0x8c, 0x91, 0xf4, 0x9f, 0xe5, 0x31, 0xbc, 0x00, 0xa7, 0x9c, 0x26, 0x71, 0xc4, 0x12, 0x2a,
	0x78, 0x74, 0x63, 0x74, 0x41, 0x3f, 0x11, 0x4a, 0x7d, 0xea, 0xdb, 0x4f, 0xba, 0xf7, 0x72, 0x9a,
	0x44, 0x19, 0x27, 0x74, 0x30, 0x81, 0xcb, 0x3f, 0x13, 0x30, 0x5d, 0xa9, 0x0d, 0xba, 0x7b, 0x0b,
	0x97, 0xef, 0xee, 0xf9, 0x79, 0x71, 0xb7, 0x8d, 0x78, 0xf2, 0xd9, 0x1f, 0x72, 0x4a, 0xb5, 0xce,
	0xeb, 0x12, 0xa9, 0xa6, 0x74, 0x4a, 0x59, 0xf7, 0xbb, 0x1a, 0xef, 0x64, 0x5b, 0xe9, 0xff, 0x9d,
	0xcd, 0x07, 0xf3, 0xf9, 0x6e, 0x1d, 0x04, 0x18, 0xff, 0xb0, 0xce, 0x03, 0x13, 0x86, 0x0b, 0x8d,
	0xcc, 0xd8, 0x4d, 0x0b, 0x17, 0xf5, 0x95, 0xfa, 0xd7, 0x08, 0x2c, 0x71, 0xa1, 0x97, 0x7b, 0x60,
	0xb9, 0x70, 0x97, 0x06, 0xf8, 0x6d, 0x4d, 0x8d, 0xea, 0x79, 0xb8, 0xd0, 0x9e, 0xb7, 0x47, 0x3c,
	0x6f, 0xe1, 0x7a, 0x9e, 0x81, 0xbe, 0x1c, 0xf6, 0xaf, 0x7b, 0xff, 0x37, 0x00, 0x00, 0xff, 0xff,
	0x97, 0xdf, 0xe1, 0x9f, 0xd3, 0x02, 0x00, 0x00,
}
