// Code generated by protoc-gen-go. DO NOT EDIT.
// source: google/ads/googleads/v2/services/age_range_view_service.proto

package services

import (
	context "context"
	fmt "fmt"
	math "math"

	proto "github.com/golang/protobuf/proto"
	resources "google.golang.org/genproto/googleapis/ads/googleads/v2/resources"
	_ "google.golang.org/genproto/googleapis/api/annotations"
	grpc "google.golang.org/grpc"
)

// Reference imports to suppress errors if they are not otherwise used.
var _ = proto.Marshal
var _ = fmt.Errorf
var _ = math.Inf

// This is a compile-time assertion to ensure that this generated file
// is compatible with the proto package it is being compiled against.
// A compilation error at this line likely means your copy of the
// proto package needs to be updated.
const _ = proto.ProtoPackageIsVersion3 // please upgrade the proto package

// Request message for [AgeRangeViewService.GetAgeRangeView][google.ads.googleads.v2.services.AgeRangeViewService.GetAgeRangeView].
type GetAgeRangeViewRequest struct {
	// The resource name of the age range view to fetch.
	ResourceName         string   `protobuf:"bytes,1,opt,name=resource_name,json=resourceName,proto3" json:"resource_name,omitempty"`
	XXX_NoUnkeyedLiteral struct{} `json:"-"`
	XXX_unrecognized     []byte   `json:"-"`
	XXX_sizecache        int32    `json:"-"`
}

func (m *GetAgeRangeViewRequest) Reset()         { *m = GetAgeRangeViewRequest{} }
func (m *GetAgeRangeViewRequest) String() string { return proto.CompactTextString(m) }
func (*GetAgeRangeViewRequest) ProtoMessage()    {}
func (*GetAgeRangeViewRequest) Descriptor() ([]byte, []int) {
	return fileDescriptor_057905eda0e1111f, []int{0}
}

func (m *GetAgeRangeViewRequest) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_GetAgeRangeViewRequest.Unmarshal(m, b)
}
func (m *GetAgeRangeViewRequest) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_GetAgeRangeViewRequest.Marshal(b, m, deterministic)
}
func (m *GetAgeRangeViewRequest) XXX_Merge(src proto.Message) {
	xxx_messageInfo_GetAgeRangeViewRequest.Merge(m, src)
}
func (m *GetAgeRangeViewRequest) XXX_Size() int {
	return xxx_messageInfo_GetAgeRangeViewRequest.Size(m)
}
func (m *GetAgeRangeViewRequest) XXX_DiscardUnknown() {
	xxx_messageInfo_GetAgeRangeViewRequest.DiscardUnknown(m)
}

var xxx_messageInfo_GetAgeRangeViewRequest proto.InternalMessageInfo

func (m *GetAgeRangeViewRequest) GetResourceName() string {
	if m != nil {
		return m.ResourceName
	}
	return ""
}

func init() {
	proto.RegisterType((*GetAgeRangeViewRequest)(nil), "google.ads.googleads.v2.services.GetAgeRangeViewRequest")
}

func init() {
	proto.RegisterFile("google/ads/googleads/v2/services/age_range_view_service.proto", fileDescriptor_057905eda0e1111f)
}

var fileDescriptor_057905eda0e1111f = []byte{
	// 389 bytes of a gzipped FileDescriptorProto
	0x1f, 0x8b, 0x08, 0x00, 0x00, 0x00, 0x00, 0x00, 0x02, 0xff, 0x84, 0x92, 0xc1, 0x4a, 0xeb, 0x40,
	0x14, 0x86, 0x49, 0x2e, 0x5c, 0xb8, 0xe1, 0x5e, 0x2e, 0x44, 0xd0, 0x12, 0x5d, 0x94, 0xda, 0x85,
	0x74, 0x31, 0x83, 0x11, 0x54, 0x46, 0xba, 0x48, 0x37, 0x75, 0x25, 0xa5, 0x42, 0x16, 0x12, 0x08,
	0x63, 0x72, 0x18, 0x02, 0xcd, 0x4c, 0xcd, 0xa4, 0xe9, 0x42, 0xdc, 0xf8, 0x0a, 0xbe, 0x81, 0x4b,
	0xf7, 0xbe, 0x44, 0xb7, 0xbe, 0x82, 0xab, 0xbe, 0x84, 0x92, 0x4e, 0x26, 0xad, 0xda, 0xd2, 0xdd,
	0xcf, 0x39, 0xe7, 0x3b, 0xff, 0x9c, 0x3f, 0xb1, 0xba, 0x4c, 0x08, 0x36, 0x02, 0x4c, 0x63, 0x89,
	0x95, 0x2c, 0x55, 0xe1, 0x62, 0x09, 0x59, 0x91, 0x44, 0x20, 0x31, 0x65, 0x10, 0x66, 0x94, 0x33,
	0x08, 0x8b, 0x04, 0xa6, 0x61, 0x55, 0x47, 0xe3, 0x4c, 0xe4, 0xc2, 0x6e, 0x2a, 0x06, 0xd1, 0x58,
	0xa2, 0x1a, 0x47, 0x85, 0x8b, 0x34, 0xee, 0x9c, 0x6e, 0x32, 0xc8, 0x40, 0x8a, 0x49, 0xf6, 0xd3,
	0x41, 0x6d, 0x76, 0x0e, 0x34, 0x37, 0x4e, 0x30, 0xe5, 0x5c, 0xe4, 0x34, 0x4f, 0x04, 0x97, 0x55,
	0x77, 0x6f, 0xa5, 0x1b, 0x8d, 0x12, 0xe0, 0xb9, 0x6a, 0xb4, 0xba, 0xd6, 0x6e, 0x1f, 0x72, 0x8f,
	0xc1, 0xb0, 0x5c, 0xe8, 0x27, 0x30, 0x1d, 0xc2, 0xdd, 0x04, 0x64, 0x6e, 0x1f, 0x5a, 0xff, 0xb4,
	0x65, 0xc8, 0x69, 0x0a, 0x0d, 0xa3, 0x69, 0x1c, 0xfd, 0x19, 0xfe, 0xd5, 0xc5, 0x2b, 0x9a, 0x82,
	0x3b, 0x37, 0xac, 0x9d, 0x55, 0xf8, 0x5a, 0x9d, 0x61, 0xbf, 0x1a, 0xd6, 0xff, 0x6f, 0x7b, 0xed,
	0x73, 0xb4, 0xed, 0x78, 0xb4, 0xfe, 0x29, 0x0e, 0xde, 0x48, 0xd6, 0xa1, 0xa0, 0x55, 0xae, 0x75,
	0xf6, 0xf8, 0xf6, 0xfe, 0x64, 0x1e, 0xdb, 0xb8, 0x0c, 0xee, 0xfe, 0xcb, 0x19, 0xdd, 0x68, 0x22,
	0x73, 0x91, 0x42, 0x26, 0x71, 0xa7, 0x4c, 0xb2, 0x86, 0x24, 0xee, 0x3c, 0x38, 0xfb, 0x33, 0xaf,
	0xb1, 0x34, 0xa8, 0xd4, 0x38, 0x91, 0x28, 0x12, 0x69, 0xef, 0xc3, 0xb0, 0xda, 0x91, 0x48, 0xb7,
	0x9e, 0xd1, 0x6b, 0xac, 0x89, 0x64, 0x50, 0xc6, 0x3d, 0x30, 0x6e, 0x2e, 0x2b, 0x9a, 0x89, 0x11,
	0xe5, 0x0c, 0x89, 0x8c, 0x61, 0x06, 0x7c, 0xf1, 0x31, 0xf0, 0xd2, 0x6f, 0xf3, 0xff, 0x75, 0xa1,
	0xc5, 0xb3, 0xf9, 0xab, 0xef, 0x79, 0x2f, 0x66, 0xb3, 0xaf, 0x16, 0x7a, 0xb1, 0x44, 0x4a, 0x96,
	0xca, 0x77, 0x51, 0x65, 0x2c, 0x67, 0x7a, 0x24, 0xf0, 0x62, 0x19, 0xd4, 0x23, 0x81, 0xef, 0x06,
	0x7a, 0x64, 0x6e, 0xb6, 0x55, 0x9d, 0x10, 0x2f, 0x96, 0x84, 0xd4, 0x43, 0x84, 0xf8, 0x2e, 0x21,
	0x7a, 0xec, 0xf6, 0xf7, 0xe2, 0x9d, 0x27, 0x9f, 0x01, 0x00, 0x00, 0xff, 0xff, 0x11, 0x09, 0xe0,
	0xf8, 0x06, 0x03, 0x00, 0x00,
}

// Reference imports to suppress errors if they are not otherwise used.
var _ context.Context
var _ grpc.ClientConn

// This is a compile-time assertion to ensure that this generated file
// is compatible with the grpc package it is being compiled against.
const _ = grpc.SupportPackageIsVersion4

// AgeRangeViewServiceClient is the client API for AgeRangeViewService service.
//
// For semantics around ctx use and closing/ending streaming RPCs, please refer to https://godoc.org/google.golang.org/grpc#ClientConn.NewStream.
type AgeRangeViewServiceClient interface {
	// Returns the requested age range view in full detail.
	GetAgeRangeView(ctx context.Context, in *GetAgeRangeViewRequest, opts ...grpc.CallOption) (*resources.AgeRangeView, error)
}

type ageRangeViewServiceClient struct {
	cc *grpc.ClientConn
}

func NewAgeRangeViewServiceClient(cc *grpc.ClientConn) AgeRangeViewServiceClient {
	return &ageRangeViewServiceClient{cc}
}

func (c *ageRangeViewServiceClient) GetAgeRangeView(ctx context.Context, in *GetAgeRangeViewRequest, opts ...grpc.CallOption) (*resources.AgeRangeView, error) {
	out := new(resources.AgeRangeView)
	err := c.cc.Invoke(ctx, "/google.ads.googleads.v2.services.AgeRangeViewService/GetAgeRangeView", in, out, opts...)
	if err != nil {
		return nil, err
	}
	return out, nil
}

// AgeRangeViewServiceServer is the server API for AgeRangeViewService service.
type AgeRangeViewServiceServer interface {
	// Returns the requested age range view in full detail.
	GetAgeRangeView(context.Context, *GetAgeRangeViewRequest) (*resources.AgeRangeView, error)
}

func RegisterAgeRangeViewServiceServer(s *grpc.Server, srv AgeRangeViewServiceServer) {
	s.RegisterService(&_AgeRangeViewService_serviceDesc, srv)
}

func _AgeRangeViewService_GetAgeRangeView_Handler(srv interface{}, ctx context.Context, dec func(interface{}) error, interceptor grpc.UnaryServerInterceptor) (interface{}, error) {
	in := new(GetAgeRangeViewRequest)
	if err := dec(in); err != nil {
		return nil, err
	}
	if interceptor == nil {
		return srv.(AgeRangeViewServiceServer).GetAgeRangeView(ctx, in)
	}
	info := &grpc.UnaryServerInfo{
		Server:     srv,
		FullMethod: "/google.ads.googleads.v2.services.AgeRangeViewService/GetAgeRangeView",
	}
	handler := func(ctx context.Context, req interface{}) (interface{}, error) {
		return srv.(AgeRangeViewServiceServer).GetAgeRangeView(ctx, req.(*GetAgeRangeViewRequest))
	}
	return interceptor(ctx, in, info, handler)
}

var _AgeRangeViewService_serviceDesc = grpc.ServiceDesc{
	ServiceName: "google.ads.googleads.v2.services.AgeRangeViewService",
	HandlerType: (*AgeRangeViewServiceServer)(nil),
	Methods: []grpc.MethodDesc{
		{
			MethodName: "GetAgeRangeView",
			Handler:    _AgeRangeViewService_GetAgeRangeView_Handler,
		},
	},
	Streams:  []grpc.StreamDesc{},
	Metadata: "google/ads/googleads/v2/services/age_range_view_service.proto",
}
