// Code generated by protoc-gen-go. DO NOT EDIT.
// source: google/ads/googleads/v1/errors/keyword_plan_error.proto

package errors

import (
	fmt "fmt"
	math "math"

	proto "github.com/golang/protobuf/proto"
	_ "google.golang.org/genproto/googleapis/api/annotations"
)

// Reference imports to suppress errors if they are not otherwise used.
var _ = proto.Marshal
var _ = fmt.Errorf
var _ = math.Inf

// This is a compile-time assertion to ensure that this generated file
// is compatible with the proto package it is being compiled against.
// A compilation error at this line likely means your copy of the
// proto package needs to be updated.
const _ = proto.ProtoPackageIsVersion3 // please upgrade the proto package

// Enum describing possible errors from applying a keyword plan.
type KeywordPlanErrorEnum_KeywordPlanError int32

const (
	// Enum unspecified.
	KeywordPlanErrorEnum_UNSPECIFIED KeywordPlanErrorEnum_KeywordPlanError = 0
	// The received error code is not known in this version.
	KeywordPlanErrorEnum_UNKNOWN KeywordPlanErrorEnum_KeywordPlanError = 1
	// The plan's bid multiplier value is outside the valid range.
	KeywordPlanErrorEnum_BID_MULTIPLIER_OUT_OF_RANGE KeywordPlanErrorEnum_KeywordPlanError = 2
	// The plan's bid value is too high.
	KeywordPlanErrorEnum_BID_TOO_HIGH KeywordPlanErrorEnum_KeywordPlanError = 3
	// The plan's bid value is too low.
	KeywordPlanErrorEnum_BID_TOO_LOW KeywordPlanErrorEnum_KeywordPlanError = 4
	// The plan's cpc bid is not a multiple of the minimum billable unit.
	KeywordPlanErrorEnum_BID_TOO_MANY_FRACTIONAL_DIGITS KeywordPlanErrorEnum_KeywordPlanError = 5
	// The plan's daily budget value is too low.
	KeywordPlanErrorEnum_DAILY_BUDGET_TOO_LOW KeywordPlanErrorEnum_KeywordPlanError = 6
	// The plan's daily budget is not a multiple of the minimum billable unit.
	KeywordPlanErrorEnum_DAILY_BUDGET_TOO_MANY_FRACTIONAL_DIGITS KeywordPlanErrorEnum_KeywordPlanError = 7
	// The input has an invalid value.
	KeywordPlanErrorEnum_INVALID_VALUE KeywordPlanErrorEnum_KeywordPlanError = 8
	// The plan has no keyword.
	KeywordPlanErrorEnum_KEYWORD_PLAN_HAS_NO_KEYWORDS KeywordPlanErrorEnum_KeywordPlanError = 9
	// The plan is not enabled and API cannot provide mutation, forecast or
	// stats.
	KeywordPlanErrorEnum_KEYWORD_PLAN_NOT_ENABLED KeywordPlanErrorEnum_KeywordPlanError = 10
	// The requested plan cannot be found for providing forecast or stats.
	KeywordPlanErrorEnum_KEYWORD_PLAN_NOT_FOUND KeywordPlanErrorEnum_KeywordPlanError = 11
	// The plan is missing a cpc bid.
	KeywordPlanErrorEnum_MISSING_BID KeywordPlanErrorEnum_KeywordPlanError = 13
	// The plan is missing required forecast_period field.
	KeywordPlanErrorEnum_MISSING_FORECAST_PERIOD KeywordPlanErrorEnum_KeywordPlanError = 14
	// The plan's forecast_period has invalid forecast date range.
	KeywordPlanErrorEnum_INVALID_FORECAST_DATE_RANGE KeywordPlanErrorEnum_KeywordPlanError = 15
	// The plan's name is invalid.
	KeywordPlanErrorEnum_INVALID_NAME KeywordPlanErrorEnum_KeywordPlanError = 16
)

var KeywordPlanErrorEnum_KeywordPlanError_name = map[int32]string{
	0:  "UNSPECIFIED",
	1:  "UNKNOWN",
	2:  "BID_MULTIPLIER_OUT_OF_RANGE",
	3:  "BID_TOO_HIGH",
	4:  "BID_TOO_LOW",
	5:  "BID_TOO_MANY_FRACTIONAL_DIGITS",
	6:  "DAILY_BUDGET_TOO_LOW",
	7:  "DAILY_BUDGET_TOO_MANY_FRACTIONAL_DIGITS",
	8:  "INVALID_VALUE",
	9:  "KEYWORD_PLAN_HAS_NO_KEYWORDS",
	10: "KEYWORD_PLAN_NOT_ENABLED",
	11: "KEYWORD_PLAN_NOT_FOUND",
	13: "MISSING_BID",
	14: "MISSING_FORECAST_PERIOD",
	15: "INVALID_FORECAST_DATE_RANGE",
	16: "INVALID_NAME",
}

var KeywordPlanErrorEnum_KeywordPlanError_value = map[string]int32{
	"UNSPECIFIED":                             0,
	"UNKNOWN":                                 1,
	"BID_MULTIPLIER_OUT_OF_RANGE":             2,
	"BID_TOO_HIGH":                            3,
	"BID_TOO_LOW":                             4,
	"BID_TOO_MANY_FRACTIONAL_DIGITS":          5,
	"DAILY_BUDGET_TOO_LOW":                    6,
	"DAILY_BUDGET_TOO_MANY_FRACTIONAL_DIGITS": 7,
	"INVALID_VALUE":                           8,
	"KEYWORD_PLAN_HAS_NO_KEYWORDS":            9,
	"KEYWORD_PLAN_NOT_ENABLED":                10,
	"KEYWORD_PLAN_NOT_FOUND":                  11,
	"MISSING_BID":                             13,
	"MISSING_FORECAST_PERIOD":                 14,
	"INVALID_FORECAST_DATE_RANGE":             15,
	"INVALID_NAME":                            16,
}

func (x KeywordPlanErrorEnum_KeywordPlanError) String() string {
	return proto.EnumName(KeywordPlanErrorEnum_KeywordPlanError_name, int32(x))
}

func (KeywordPlanErrorEnum_KeywordPlanError) EnumDescriptor() ([]byte, []int) {
	return fileDescriptor_c1ce5991f7c4173e, []int{0, 0}
}

// Container for enum describing possible errors from applying a keyword plan
// resource (keyword plan, keyword plan campaign, keyword plan ad group or
// keyword plan keyword) or KeywordPlanService RPC.
type KeywordPlanErrorEnum struct {
	XXX_NoUnkeyedLiteral struct{} `json:"-"`
	XXX_unrecognized     []byte   `json:"-"`
	XXX_sizecache        int32    `json:"-"`
}

func (m *KeywordPlanErrorEnum) Reset()         { *m = KeywordPlanErrorEnum{} }
func (m *KeywordPlanErrorEnum) String() string { return proto.CompactTextString(m) }
func (*KeywordPlanErrorEnum) ProtoMessage()    {}
func (*KeywordPlanErrorEnum) Descriptor() ([]byte, []int) {
	return fileDescriptor_c1ce5991f7c4173e, []int{0}
}

func (m *KeywordPlanErrorEnum) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_KeywordPlanErrorEnum.Unmarshal(m, b)
}
func (m *KeywordPlanErrorEnum) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_KeywordPlanErrorEnum.Marshal(b, m, deterministic)
}
func (m *KeywordPlanErrorEnum) XXX_Merge(src proto.Message) {
	xxx_messageInfo_KeywordPlanErrorEnum.Merge(m, src)
}
func (m *KeywordPlanErrorEnum) XXX_Size() int {
	return xxx_messageInfo_KeywordPlanErrorEnum.Size(m)
}
func (m *KeywordPlanErrorEnum) XXX_DiscardUnknown() {
	xxx_messageInfo_KeywordPlanErrorEnum.DiscardUnknown(m)
}

var xxx_messageInfo_KeywordPlanErrorEnum proto.InternalMessageInfo

func init() {
	proto.RegisterEnum("google.ads.googleads.v1.errors.KeywordPlanErrorEnum_KeywordPlanError", KeywordPlanErrorEnum_KeywordPlanError_name, KeywordPlanErrorEnum_KeywordPlanError_value)
	proto.RegisterType((*KeywordPlanErrorEnum)(nil), "google.ads.googleads.v1.errors.KeywordPlanErrorEnum")
}

func init() {
	proto.RegisterFile("google/ads/googleads/v1/errors/keyword_plan_error.proto", fileDescriptor_c1ce5991f7c4173e)
}

var fileDescriptor_c1ce5991f7c4173e = []byte{
	// 508 bytes of a gzipped FileDescriptorProto
	0x1f, 0x8b, 0x08, 0x00, 0x00, 0x00, 0x00, 0x00, 0x02, 0xff, 0x7c, 0x92, 0x4f, 0x8b, 0xd3, 0x4e,
	0x1c, 0xc6, 0x7f, 0x6d, 0x7f, 0xee, 0xea, 0xd4, 0x75, 0xc7, 0x61, 0xd5, 0x65, 0xb7, 0x54, 0xe9,
	0xc5, 0x83, 0x90, 0x50, 0x3c, 0x08, 0xf1, 0x34, 0xe9, 0x4c, 0xd3, 0xa1, 0xe9, 0x4c, 0xc8, 0xbf,
	0x52, 0x29, 0x0c, 0xd1, 0x94, 0x50, 0xec, 0x66, 0x4a, 0x52, 0x57, 0x7c, 0x3b, 0x1e, 0xbd, 0xf8,
	0x36, 0xc4, 0x97, 0xe2, 0xc9, 0x97, 0x20, 0xe9, 0x34, 0x01, 0x77, 0x59, 0x4f, 0xf9, 0xf2, 0x7c,
	0x3f, 0xcf, 0x93, 0xc9, 0xe4, 0x01, 0x6f, 0x32, 0xa5, 0xb2, 0xcd, 0xca, 0x4c, 0xd2, 0xd2, 0xd4,
	0x63, 0x35, 0x5d, 0x0f, 0xcd, 0x55, 0x51, 0xa8, 0xa2, 0x34, 0x3f, 0xae, 0xbe, 0x7c, 0x56, 0x45,
	0x2a, 0xb7, 0x9b, 0x24, 0x97, 0x7b, 0xcd, 0xd8, 0x16, 0x6a, 0xa7, 0x50, 0x5f, 0xd3, 0x46, 0x92,
	0x96, 0x46, 0x63, 0x34, 0xae, 0x87, 0x86, 0x36, 0x5e, 0xf4, 0xea, 0xe0, 0xed, 0xda, 0x4c, 0xf2,
	0x5c, 0xed, 0x92, 0xdd, 0x5a, 0xe5, 0xa5, 0x76, 0x0f, 0x7e, 0x74, 0xc0, 0xd9, 0x54, 0x47, 0x7b,
	0x9b, 0x24, 0xa7, 0x95, 0x87, 0xe6, 0x9f, 0xae, 0x06, 0xdf, 0x3b, 0x00, 0xde, 0x5c, 0xa0, 0x53,
	0xd0, 0x8d, 0x78, 0xe0, 0xd1, 0x11, 0x1b, 0x33, 0x4a, 0xe0, 0x7f, 0xa8, 0x0b, 0x8e, 0x23, 0x3e,
	0xe5, 0x62, 0xce, 0x61, 0x0b, 0x3d, 0x07, 0x97, 0x36, 0x23, 0x72, 0x16, 0xb9, 0x21, 0xf3, 0x5c,
	0x46, 0x7d, 0x29, 0xa2, 0x50, 0x8a, 0xb1, 0xf4, 0x31, 0x77, 0x28, 0x6c, 0x23, 0x08, 0x1e, 0x56,
	0x40, 0x28, 0x84, 0x9c, 0x30, 0x67, 0x02, 0x3b, 0x55, 0x60, 0xad, 0xb8, 0x62, 0x0e, 0xff, 0x47,
	0x03, 0xd0, 0xaf, 0x85, 0x19, 0xe6, 0x0b, 0x39, 0xf6, 0xf1, 0x28, 0x64, 0x82, 0x63, 0x57, 0x12,
	0xe6, 0xb0, 0x30, 0x80, 0xf7, 0xd0, 0x39, 0x38, 0x23, 0x98, 0xb9, 0x0b, 0x69, 0x47, 0xc4, 0xa1,
	0x61, 0xe3, 0x3e, 0x42, 0xaf, 0xc0, 0xcb, 0x5b, 0x9b, 0x3b, 0x62, 0x8e, 0xd1, 0x63, 0x70, 0xc2,
	0x78, 0x8c, 0x5d, 0x46, 0x64, 0x8c, 0xdd, 0x88, 0xc2, 0xfb, 0xe8, 0x05, 0xe8, 0x4d, 0xe9, 0x62,
	0x2e, 0x7c, 0x22, 0x3d, 0x17, 0x73, 0x39, 0xc1, 0x81, 0xe4, 0x42, 0x1e, 0xb4, 0x00, 0x3e, 0x40,
	0x3d, 0x70, 0xfe, 0x17, 0xc1, 0x45, 0x28, 0x29, 0xc7, 0xb6, 0x4b, 0x09, 0x04, 0xe8, 0x02, 0x3c,
	0xbd, 0xb5, 0x1d, 0x8b, 0x88, 0x13, 0xd8, 0xad, 0x3e, 0x75, 0xc6, 0x82, 0x80, 0x71, 0x47, 0xda,
	0x8c, 0xc0, 0x13, 0x74, 0x09, 0x9e, 0xd5, 0xc2, 0x58, 0xf8, 0x74, 0x84, 0x83, 0x50, 0x7a, 0xd4,
	0x67, 0x82, 0xc0, 0x47, 0xd5, 0x5d, 0xd6, 0x87, 0x6b, 0x96, 0x04, 0x87, 0xf4, 0x70, 0x97, 0xa7,
	0xd5, 0x5d, 0xd6, 0x00, 0xc7, 0x33, 0x0a, 0xa1, 0xfd, 0xbb, 0x05, 0x06, 0x1f, 0xd4, 0x95, 0xf1,
	0xef, 0x3e, 0xd8, 0x4f, 0x6e, 0xfe, 0x55, 0xaf, 0x2a, 0x82, 0xd7, 0x7a, 0x47, 0x0e, 0xc6, 0x4c,
	0x6d, 0x92, 0x3c, 0x33, 0x54, 0x91, 0x99, 0xd9, 0x2a, 0xdf, 0xd7, 0xa4, 0x6e, 0xe4, 0x76, 0x5d,
	0xde, 0x55, 0xd0, 0xb7, 0xfa, 0xf1, 0xb5, 0xdd, 0x71, 0x30, 0xfe, 0xd6, 0xee, 0x3b, 0x3a, 0x0c,
	0xa7, 0xa5, 0xa1, 0xc7, 0x6a, 0x8a, 0x87, 0xc6, 0xfe, 0x95, 0xe5, 0xcf, 0x1a, 0x58, 0xe2, 0xb4,
	0x5c, 0x36, 0xc0, 0x32, 0x1e, 0x2e, 0x35, 0xf0, 0xab, 0x3d, 0xd0, 0xaa, 0x65, 0xe1, 0xb4, 0xb4,
	0xac, 0x06, 0xb1, 0xac, 0x78, 0x68, 0x59, 0x1a, 0x7a, 0x7f, 0xb4, 0x3f, 0xdd, 0xeb, 0x3f, 0x01,
	0x00, 0x00, 0xff, 0xff, 0x7a, 0xf0, 0xe0, 0x47, 0x3d, 0x03, 0x00, 0x00,
}
