// Code generated by protoc-gen-go. DO NOT EDIT.
// source: google/ads/googleads/v2/services/payments_account_service.proto

package services

import (
	context "context"
	fmt "fmt"
	math "math"

	proto "github.com/golang/protobuf/proto"
	resources "google.golang.org/genproto/googleapis/ads/googleads/v2/resources"
	_ "google.golang.org/genproto/googleapis/api/annotations"
	grpc "google.golang.org/grpc"
)

// Reference imports to suppress errors if they are not otherwise used.
var _ = proto.Marshal
var _ = fmt.Errorf
var _ = math.Inf

// This is a compile-time assertion to ensure that this generated file
// is compatible with the proto package it is being compiled against.
// A compilation error at this line likely means your copy of the
// proto package needs to be updated.
const _ = proto.ProtoPackageIsVersion3 // please upgrade the proto package

// Request message for fetching all accessible Payments accounts.
type ListPaymentsAccountsRequest struct {
	// The ID of the customer to apply the PaymentsAccount list operation to.
	CustomerId           string   `protobuf:"bytes,1,opt,name=customer_id,json=customerId,proto3" json:"customer_id,omitempty"`
	XXX_NoUnkeyedLiteral struct{} `json:"-"`
	XXX_unrecognized     []byte   `json:"-"`
	XXX_sizecache        int32    `json:"-"`
}

func (m *ListPaymentsAccountsRequest) Reset()         { *m = ListPaymentsAccountsRequest{} }
func (m *ListPaymentsAccountsRequest) String() string { return proto.CompactTextString(m) }
func (*ListPaymentsAccountsRequest) ProtoMessage()    {}
func (*ListPaymentsAccountsRequest) Descriptor() ([]byte, []int) {
	return fileDescriptor_5f39f8a725594994, []int{0}
}

func (m *ListPaymentsAccountsRequest) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_ListPaymentsAccountsRequest.Unmarshal(m, b)
}
func (m *ListPaymentsAccountsRequest) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_ListPaymentsAccountsRequest.Marshal(b, m, deterministic)
}
func (m *ListPaymentsAccountsRequest) XXX_Merge(src proto.Message) {
	xxx_messageInfo_ListPaymentsAccountsRequest.Merge(m, src)
}
func (m *ListPaymentsAccountsRequest) XXX_Size() int {
	return xxx_messageInfo_ListPaymentsAccountsRequest.Size(m)
}
func (m *ListPaymentsAccountsRequest) XXX_DiscardUnknown() {
	xxx_messageInfo_ListPaymentsAccountsRequest.DiscardUnknown(m)
}

var xxx_messageInfo_ListPaymentsAccountsRequest proto.InternalMessageInfo

func (m *ListPaymentsAccountsRequest) GetCustomerId() string {
	if m != nil {
		return m.CustomerId
	}
	return ""
}

// Response message for [PaymentsAccountService.ListPaymentsAccounts][google.ads.googleads.v2.services.PaymentsAccountService.ListPaymentsAccounts].
type ListPaymentsAccountsResponse struct {
	// The list of accessible Payments accounts.
	PaymentsAccounts     []*resources.PaymentsAccount `protobuf:"bytes,1,rep,name=payments_accounts,json=paymentsAccounts,proto3" json:"payments_accounts,omitempty"`
	XXX_NoUnkeyedLiteral struct{}                     `json:"-"`
	XXX_unrecognized     []byte                       `json:"-"`
	XXX_sizecache        int32                        `json:"-"`
}

func (m *ListPaymentsAccountsResponse) Reset()         { *m = ListPaymentsAccountsResponse{} }
func (m *ListPaymentsAccountsResponse) String() string { return proto.CompactTextString(m) }
func (*ListPaymentsAccountsResponse) ProtoMessage()    {}
func (*ListPaymentsAccountsResponse) Descriptor() ([]byte, []int) {
	return fileDescriptor_5f39f8a725594994, []int{1}
}

func (m *ListPaymentsAccountsResponse) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_ListPaymentsAccountsResponse.Unmarshal(m, b)
}
func (m *ListPaymentsAccountsResponse) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_ListPaymentsAccountsResponse.Marshal(b, m, deterministic)
}
func (m *ListPaymentsAccountsResponse) XXX_Merge(src proto.Message) {
	xxx_messageInfo_ListPaymentsAccountsResponse.Merge(m, src)
}
func (m *ListPaymentsAccountsResponse) XXX_Size() int {
	return xxx_messageInfo_ListPaymentsAccountsResponse.Size(m)
}
func (m *ListPaymentsAccountsResponse) XXX_DiscardUnknown() {
	xxx_messageInfo_ListPaymentsAccountsResponse.DiscardUnknown(m)
}

var xxx_messageInfo_ListPaymentsAccountsResponse proto.InternalMessageInfo

func (m *ListPaymentsAccountsResponse) GetPaymentsAccounts() []*resources.PaymentsAccount {
	if m != nil {
		return m.PaymentsAccounts
	}
	return nil
}

func init() {
	proto.RegisterType((*ListPaymentsAccountsRequest)(nil), "google.ads.googleads.v2.services.ListPaymentsAccountsRequest")
	proto.RegisterType((*ListPaymentsAccountsResponse)(nil), "google.ads.googleads.v2.services.ListPaymentsAccountsResponse")
}

func init() {
	proto.RegisterFile("google/ads/googleads/v2/services/payments_account_service.proto", fileDescriptor_5f39f8a725594994)
}

var fileDescriptor_5f39f8a725594994 = []byte{
	// 417 bytes of a gzipped FileDescriptorProto
	0x1f, 0x8b, 0x08, 0x00, 0x00, 0x00, 0x00, 0x00, 0x02, 0xff, 0x9c, 0x53, 0xcd, 0xaa, 0xd3, 0x40,
	0x14, 0x26, 0xb9, 0x20, 0x38, 0x77, 0xa3, 0x41, 0xb4, 0xa4, 0x17, 0x0c, 0xa5, 0x8b, 0xe2, 0x62,
	0x46, 0x46, 0x10, 0x19, 0x69, 0x25, 0xdd, 0x54, 0xc1, 0x45, 0xa9, 0xd0, 0x85, 0x04, 0x42, 0x4c,
	0x86, 0x10, 0x68, 0x66, 0x62, 0xce, 0xa4, 0x20, 0x22, 0x42, 0xc1, 0x27, 0xf0, 0x0d, 0x5c, 0xfa,
	0x28, 0x05, 0x57, 0xbe, 0x82, 0x2b, 0x9f, 0x42, 0xd2, 0xc9, 0xa4, 0x25, 0xa4, 0x16, 0xee, 0xee,
	0x23, 0xe7, 0xfb, 0x39, 0xf3, 0xcd, 0x04, 0xbd, 0x4a, 0xa5, 0x4c, 0x37, 0x9c, 0x44, 0x09, 0x10,
	0x0d, 0x6b, 0xb4, 0xa5, 0x04, 0x78, 0xb9, 0xcd, 0x62, 0x0e, 0xa4, 0x88, 0x3e, 0xe5, 0x5c, 0x28,
	0x08, 0xa3, 0x38, 0x96, 0x95, 0x50, 0x61, 0x33, 0xc1, 0x45, 0x29, 0x95, 0x74, 0x3c, 0xad, 0xc2,
	0x51, 0x02, 0xb8, 0x35, 0xc0, 0x5b, 0x8a, 0x8d, 0x81, 0xfb, 0xe2, 0x5c, 0x44, 0xc9, 0x41, 0x56,
	0x65, 0x5f, 0x86, 0xf6, 0x76, 0x6f, 0x8c, 0xb2, 0xc8, 0x48, 0x24, 0x84, 0x54, 0x91, 0xca, 0xa4,
	0x80, 0x66, 0xfa, 0xe8, 0x64, 0x1a, 0x6f, 0x32, 0x6e, 0x64, 0xa3, 0x19, 0x1a, 0xbe, 0xcd, 0x40,
	0x2d, 0x1b, 0x53, 0x5f, 0x7b, 0xc2, 0x8a, 0x7f, 0xac, 0x38, 0x28, 0xe7, 0x31, 0xba, 0x8e, 0x2b,
	0x50, 0x32, 0xe7, 0x65, 0x98, 0x25, 0x03, 0xcb, 0xb3, 0x26, 0x77, 0x57, 0xc8, 0x7c, 0x7a, 0x93,
	0x8c, 0xbe, 0xa2, 0x9b, 0x7e, 0x3d, 0x14, 0x52, 0x00, 0x77, 0x42, 0x74, 0xbf, 0xbb, 0x30, 0x0c,
	0x2c, 0xef, 0x6a, 0x72, 0x4d, 0x29, 0x3e, 0x57, 0x47, 0x7b, 0x58, 0xdc, 0xf1, 0x5d, 0xdd, 0x2b,
	0x3a, 0x41, 0xf4, 0x9b, 0x8d, 0x1e, 0x76, 0x58, 0xef, 0x74, 0x9b, 0xce, 0x2f, 0x0b, 0x3d, 0xe8,
	0x5b, 0xce, 0x99, 0xe2, 0x4b, 0x17, 0x81, 0xff, 0x53, 0x8a, 0x3b, 0xbb, 0xad, 0x5c, 0x77, 0x32,
	0x7a, 0xbe, 0xfb, 0xfd, 0xe7, 0xbb, 0xfd, 0xd4, 0xc1, 0xf5, 0xc5, 0x9a, 0x2e, 0x81, 0x7c, 0x3e,
	0x69, 0x7a, 0xfa, 0xe4, 0x0b, 0xe9, 0x1e, 0xd5, 0x1d, 0xee, 0xfd, 0xc1, 0x31, 0xae, 0x41, 0x45,
	0x06, 0x38, 0x96, 0xf9, 0x7c, 0x67, 0xa3, 0x71, 0x2c, 0xf3, 0x8b, 0xab, 0xcd, 0x87, 0xfd, 0x6d,
	0x2d, 0xeb, 0xe7, 0xb0, 0xb4, 0xde, 0xbf, 0x6e, 0x0c, 0x52, 0xb9, 0x89, 0x44, 0x8a, 0x65, 0x99,
	0x92, 0x94, 0x8b, 0xc3, 0x63, 0x21, 0xc7, 0xc8, 0xf3, 0xff, 0xc0, 0x4b, 0x03, 0x7e, 0xd8, 0x57,
	0x0b, 0xdf, 0xff, 0x69, 0x7b, 0x0b, 0x6d, 0xe8, 0x27, 0x80, 0x35, 0xac, 0xd1, 0x9a, 0xe2, 0x26,
	0x18, 0xf6, 0x86, 0x12, 0xf8, 0x09, 0x04, 0x2d, 0x25, 0x58, 0xd3, 0xc0, 0x50, 0xfe, 0xda, 0x63,
	0xfd, 0x9d, 0x31, 0x3f, 0x01, 0xc6, 0x5a, 0x12, 0x63, 0x6b, 0xca, 0x98, 0xa1, 0x7d, 0xb8, 0x73,
	0xd8, 0xf3, 0xd9, 0xbf, 0x00, 0x00, 0x00, 0xff, 0xff, 0x02, 0xd1, 0xc1, 0x47, 0xaa, 0x03, 0x00,
	0x00,
}

// Reference imports to suppress errors if they are not otherwise used.
var _ context.Context
var _ grpc.ClientConn

// This is a compile-time assertion to ensure that this generated file
// is compatible with the grpc package it is being compiled against.
const _ = grpc.SupportPackageIsVersion4

// PaymentsAccountServiceClient is the client API for PaymentsAccountService service.
//
// For semantics around ctx use and closing/ending streaming RPCs, please refer to https://godoc.org/google.golang.org/grpc#ClientConn.NewStream.
type PaymentsAccountServiceClient interface {
	// Returns all Payments accounts associated with all managers
	// between the login customer ID and specified serving customer in the
	// hierarchy, inclusive.
	ListPaymentsAccounts(ctx context.Context, in *ListPaymentsAccountsRequest, opts ...grpc.CallOption) (*ListPaymentsAccountsResponse, error)
}

type paymentsAccountServiceClient struct {
	cc *grpc.ClientConn
}

func NewPaymentsAccountServiceClient(cc *grpc.ClientConn) PaymentsAccountServiceClient {
	return &paymentsAccountServiceClient{cc}
}

func (c *paymentsAccountServiceClient) ListPaymentsAccounts(ctx context.Context, in *ListPaymentsAccountsRequest, opts ...grpc.CallOption) (*ListPaymentsAccountsResponse, error) {
	out := new(ListPaymentsAccountsResponse)
	err := c.cc.Invoke(ctx, "/google.ads.googleads.v2.services.PaymentsAccountService/ListPaymentsAccounts", in, out, opts...)
	if err != nil {
		return nil, err
	}
	return out, nil
}

// PaymentsAccountServiceServer is the server API for PaymentsAccountService service.
type PaymentsAccountServiceServer interface {
	// Returns all Payments accounts associated with all managers
	// between the login customer ID and specified serving customer in the
	// hierarchy, inclusive.
	ListPaymentsAccounts(context.Context, *ListPaymentsAccountsRequest) (*ListPaymentsAccountsResponse, error)
}

func RegisterPaymentsAccountServiceServer(s *grpc.Server, srv PaymentsAccountServiceServer) {
	s.RegisterService(&_PaymentsAccountService_serviceDesc, srv)
}

func _PaymentsAccountService_ListPaymentsAccounts_Handler(srv interface{}, ctx context.Context, dec func(interface{}) error, interceptor grpc.UnaryServerInterceptor) (interface{}, error) {
	in := new(ListPaymentsAccountsRequest)
	if err := dec(in); err != nil {
		return nil, err
	}
	if interceptor == nil {
		return srv.(PaymentsAccountServiceServer).ListPaymentsAccounts(ctx, in)
	}
	info := &grpc.UnaryServerInfo{
		Server:     srv,
		FullMethod: "/google.ads.googleads.v2.services.PaymentsAccountService/ListPaymentsAccounts",
	}
	handler := func(ctx context.Context, req interface{}) (interface{}, error) {
		return srv.(PaymentsAccountServiceServer).ListPaymentsAccounts(ctx, req.(*ListPaymentsAccountsRequest))
	}
	return interceptor(ctx, in, info, handler)
}

var _PaymentsAccountService_serviceDesc = grpc.ServiceDesc{
	ServiceName: "google.ads.googleads.v2.services.PaymentsAccountService",
	HandlerType: (*PaymentsAccountServiceServer)(nil),
	Methods: []grpc.MethodDesc{
		{
			MethodName: "ListPaymentsAccounts",
			Handler:    _PaymentsAccountService_ListPaymentsAccounts_Handler,
		},
	},
	Streams:  []grpc.StreamDesc{},
	Metadata: "google/ads/googleads/v2/services/payments_account_service.proto",
}
