// Code generated by protoc-gen-go. DO NOT EDIT.
// source: google/cloud/securitycenter/v1/source.proto

package securitycenter

import (
	fmt "fmt"
	math "math"

	proto "github.com/golang/protobuf/proto"
	_ "google.golang.org/genproto/googleapis/api/annotations"
)

// Reference imports to suppress errors if they are not otherwise used.
var _ = proto.Marshal
var _ = fmt.Errorf
var _ = math.Inf

// This is a compile-time assertion to ensure that this generated file
// is compatible with the proto package it is being compiled against.
// A compilation error at this line likely means your copy of the
// proto package needs to be updated.
const _ = proto.ProtoPackageIsVersion3 // please upgrade the proto package

// Cloud Security Command Center's (Cloud SCC) finding source. A finding source
// is an entity or a mechanism that can produce a finding. A source is like a
// container of findings that come from the same scanner, logger, monitor, etc.
type Source struct {
	// The relative resource name of this source. See:
	// https://cloud.google.com/apis/design/resource_names#relative_resource_name
	// Example:
	// "organizations/123/sources/456"
	Name string `protobuf:"bytes,1,opt,name=name,proto3" json:"name,omitempty"`
	// The source’s display name.
	// A source’s display name must be unique amongst its siblings, for example,
	// two sources with the same parent can't share the same display name.
	// The display name must start and end with a letter or digit, may contain
	// letters, digits, spaces, hyphens, and underscores, and can be no longer
	// than 32 characters. This is captured by the regular expression:
	// [\p{L}\p{N}]({\p{L}\p{N}_- ]{0,30}[\p{L}\p{N}])?.
	DisplayName string `protobuf:"bytes,2,opt,name=display_name,json=displayName,proto3" json:"display_name,omitempty"`
	// The description of the source (max of 1024 characters).
	// Example:
	// "Cloud Security Scanner is a web security scanner for common
	// vulnerabilities in App Engine applications. It can automatically
	// scan and detect four common vulnerabilities, including cross-site-scripting
	// (XSS), Flash injection, mixed content (HTTP in HTTPS), and
	// outdated/insecure libraries."
	Description          string   `protobuf:"bytes,3,opt,name=description,proto3" json:"description,omitempty"`
	XXX_NoUnkeyedLiteral struct{} `json:"-"`
	XXX_unrecognized     []byte   `json:"-"`
	XXX_sizecache        int32    `json:"-"`
}

func (m *Source) Reset()         { *m = Source{} }
func (m *Source) String() string { return proto.CompactTextString(m) }
func (*Source) ProtoMessage()    {}
func (*Source) Descriptor() ([]byte, []int) {
	return fileDescriptor_43f5cbeb6a51b224, []int{0}
}

func (m *Source) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_Source.Unmarshal(m, b)
}
func (m *Source) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_Source.Marshal(b, m, deterministic)
}
func (m *Source) XXX_Merge(src proto.Message) {
	xxx_messageInfo_Source.Merge(m, src)
}
func (m *Source) XXX_Size() int {
	return xxx_messageInfo_Source.Size(m)
}
func (m *Source) XXX_DiscardUnknown() {
	xxx_messageInfo_Source.DiscardUnknown(m)
}

var xxx_messageInfo_Source proto.InternalMessageInfo

func (m *Source) GetName() string {
	if m != nil {
		return m.Name
	}
	return ""
}

func (m *Source) GetDisplayName() string {
	if m != nil {
		return m.DisplayName
	}
	return ""
}

func (m *Source) GetDescription() string {
	if m != nil {
		return m.Description
	}
	return ""
}

func init() {
	proto.RegisterType((*Source)(nil), "google.cloud.securitycenter.v1.Source")
}

func init() {
	proto.RegisterFile("google/cloud/securitycenter/v1/source.proto", fileDescriptor_43f5cbeb6a51b224)
}

var fileDescriptor_43f5cbeb6a51b224 = []byte{
	// 272 bytes of a gzipped FileDescriptorProto
	0x1f, 0x8b, 0x08, 0x00, 0x00, 0x00, 0x00, 0x00, 0x02, 0xff, 0x7c, 0xd0, 0x41, 0x4a, 0xf4, 0x30,
	0x14, 0x07, 0x70, 0xda, 0xaf, 0xdf, 0xa0, 0x19, 0x17, 0xd2, 0xd5, 0x20, 0x32, 0xcc, 0xcc, 0x4a,
	0x10, 0x12, 0x8a, 0xbb, 0xb8, 0x73, 0x16, 0x82, 0x88, 0x88, 0x03, 0x5d, 0x48, 0x41, 0x62, 0x1a,
	0x42, 0xa0, 0x93, 0x57, 0x92, 0x74, 0x60, 0xae, 0xe4, 0x51, 0x3c, 0x82, 0x47, 0xf0, 0x14, 0x32,
	0x2f, 0x11, 0xe9, 0x42, 0x77, 0xe5, 0xfd, 0x7f, 0xfd, 0xbf, 0x47, 0xc8, 0xa5, 0x06, 0xd0, 0x9d,
	0x62, 0xb2, 0x83, 0xa1, 0x65, 0x5e, 0xc9, 0xc1, 0x99, 0xb0, 0x97, 0xca, 0x06, 0xe5, 0xd8, 0xae,
	0x62, 0x1e, 0x06, 0x27, 0x15, 0xed, 0x1d, 0x04, 0x28, 0xe7, 0x11, 0x53, 0xc4, 0x74, 0x8c, 0xe9,
	0xae, 0x3a, 0x3b, 0x4f, 0x65, 0xa2, 0x37, 0x4c, 0x58, 0x0b, 0x41, 0x04, 0x03, 0xd6, 0xc7, 0xbf,
	0x57, 0x9a, 0x4c, 0x36, 0xd8, 0x56, 0x96, 0xa4, 0xb0, 0x62, 0xab, 0x66, 0xd9, 0x22, 0xbb, 0x38,
	0x7e, 0xc2, 0xef, 0x72, 0x49, 0x4e, 0x5a, 0xe3, 0xfb, 0x4e, 0xec, 0x5f, 0x30, 0xcb, 0x31, 0x9b,
	0xa6, 0xd9, 0xc3, 0x81, 0x2c, 0xc8, 0xb4, 0x55, 0x5e, 0x3a, 0xd3, 0x1f, 0x6a, 0x67, 0xff, 0x92,
	0xf8, 0x19, 0xdd, 0x15, 0x47, 0xc5, 0xe9, 0xff, 0x9b, 0x8f, 0x8c, 0xac, 0x24, 0x6c, 0xe9, 0xdf,
	0xd7, 0x3e, 0x66, 0xcf, 0xf7, 0x49, 0x68, 0xe8, 0x84, 0xd5, 0x14, 0x9c, 0x66, 0x5a, 0x59, 0xbc,
	0x96, 0xc5, 0x48, 0xf4, 0xc6, 0xff, 0xf6, 0x36, 0xd7, 0xe3, 0xc9, 0x5b, 0x3e, 0xbf, 0x8d, 0x75,
	0x6b, 0x5c, 0xb8, 0x49, 0xe9, 0x3a, 0x2e, 0xac, 0xab, 0xf7, 0x6f, 0xd0, 0x20, 0x68, 0xc6, 0xa0,
	0xa9, 0xab, 0xcf, 0x7c, 0x19, 0x01, 0xe7, 0x28, 0x38, 0x1f, 0x13, 0xce, 0xeb, 0xea, 0x75, 0x82,
	0xe7, 0x5d, 0x7d, 0x05, 0x00, 0x00, 0xff, 0xff, 0xa6, 0x8f, 0xba, 0x1a, 0xb9, 0x01, 0x00, 0x00,
}
