// Code generated by protoc-gen-go. DO NOT EDIT.
// source: google/cloud/vision/v1p4beta1/product_search.proto

package vision

import (
	fmt "fmt"
	math "math"

	proto "github.com/golang/protobuf/proto"
	timestamp "github.com/golang/protobuf/ptypes/timestamp"
	_ "google.golang.org/genproto/googleapis/api/annotations"
)

// Reference imports to suppress errors if they are not otherwise used.
var _ = proto.Marshal
var _ = fmt.Errorf
var _ = math.Inf

// This is a compile-time assertion to ensure that this generated file
// is compatible with the proto package it is being compiled against.
// A compilation error at this line likely means your copy of the
// proto package needs to be updated.
const _ = proto.ProtoPackageIsVersion3 // please upgrade the proto package

// Parameters for a product search request.
type ProductSearchParams struct {
	// The bounding polygon around the area of interest in the image.
	// Optional. If it is not specified, system discretion will be applied.
	BoundingPoly *BoundingPoly `protobuf:"bytes,9,opt,name=bounding_poly,json=boundingPoly,proto3" json:"bounding_poly,omitempty"`
	// The resource name of a
	// [ProductSet][google.cloud.vision.v1p4beta1.ProductSet] to be searched for
	// similar images.
	//
	// Format is:
	// `projects/PROJECT_ID/locations/LOC_ID/productSets/PRODUCT_SET_ID`.
	ProductSet string `protobuf:"bytes,6,opt,name=product_set,json=productSet,proto3" json:"product_set,omitempty"`
	// The list of product categories to search in. Currently, we only consider
	// the first category, and either "homegoods-v2", "apparel-v2", "toys-v2", or
	// "packagedgoods-v1" should be specified. The legacy categories "homegoods",
	// "apparel", and "toys" are still supported but will be deprecated. For new
	// products, please use "homegoods-v2", "apparel-v2", or "toys-v2" for better
	// product search accuracy. It is recommended to migrate existing products to
	// these categories as well.
	ProductCategories []string `protobuf:"bytes,7,rep,name=product_categories,json=productCategories,proto3" json:"product_categories,omitempty"`
	// The filtering expression. This can be used to restrict search results based
	// on Product labels. We currently support an AND of OR of key-value
	// expressions, where each expression within an OR must have the same key.
	//
	// For example, "(color = red OR color = blue) AND brand = Google" is
	// acceptable, but not "(color = red OR brand = Google)" or "color: red".
	Filter               string   `protobuf:"bytes,8,opt,name=filter,proto3" json:"filter,omitempty"`
	XXX_NoUnkeyedLiteral struct{} `json:"-"`
	XXX_unrecognized     []byte   `json:"-"`
	XXX_sizecache        int32    `json:"-"`
}

func (m *ProductSearchParams) Reset()         { *m = ProductSearchParams{} }
func (m *ProductSearchParams) String() string { return proto.CompactTextString(m) }
func (*ProductSearchParams) ProtoMessage()    {}
func (*ProductSearchParams) Descriptor() ([]byte, []int) {
	return fileDescriptor_788f05efda4e1c3a, []int{0}
}

func (m *ProductSearchParams) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_ProductSearchParams.Unmarshal(m, b)
}
func (m *ProductSearchParams) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_ProductSearchParams.Marshal(b, m, deterministic)
}
func (m *ProductSearchParams) XXX_Merge(src proto.Message) {
	xxx_messageInfo_ProductSearchParams.Merge(m, src)
}
func (m *ProductSearchParams) XXX_Size() int {
	return xxx_messageInfo_ProductSearchParams.Size(m)
}
func (m *ProductSearchParams) XXX_DiscardUnknown() {
	xxx_messageInfo_ProductSearchParams.DiscardUnknown(m)
}

var xxx_messageInfo_ProductSearchParams proto.InternalMessageInfo

func (m *ProductSearchParams) GetBoundingPoly() *BoundingPoly {
	if m != nil {
		return m.BoundingPoly
	}
	return nil
}

func (m *ProductSearchParams) GetProductSet() string {
	if m != nil {
		return m.ProductSet
	}
	return ""
}

func (m *ProductSearchParams) GetProductCategories() []string {
	if m != nil {
		return m.ProductCategories
	}
	return nil
}

func (m *ProductSearchParams) GetFilter() string {
	if m != nil {
		return m.Filter
	}
	return ""
}

// Results for a product search request.
type ProductSearchResults struct {
	// Timestamp of the index which provided these results. Changes made after
	// this time are not reflected in the current results.
	IndexTime *timestamp.Timestamp `protobuf:"bytes,2,opt,name=index_time,json=indexTime,proto3" json:"index_time,omitempty"`
	// List of results, one for each product match.
	Results []*ProductSearchResults_Result `protobuf:"bytes,5,rep,name=results,proto3" json:"results,omitempty"`
	// List of results grouped by products detected in the query image. Each entry
	// corresponds to one bounding polygon in the query image, and contains the
	// matching products specific to that region. There may be duplicate product
	// matches in the union of all the per-product results.
	ProductGroupedResults []*ProductSearchResults_GroupedResult `protobuf:"bytes,6,rep,name=product_grouped_results,json=productGroupedResults,proto3" json:"product_grouped_results,omitempty"`
	XXX_NoUnkeyedLiteral  struct{}                              `json:"-"`
	XXX_unrecognized      []byte                                `json:"-"`
	XXX_sizecache         int32                                 `json:"-"`
}

func (m *ProductSearchResults) Reset()         { *m = ProductSearchResults{} }
func (m *ProductSearchResults) String() string { return proto.CompactTextString(m) }
func (*ProductSearchResults) ProtoMessage()    {}
func (*ProductSearchResults) Descriptor() ([]byte, []int) {
	return fileDescriptor_788f05efda4e1c3a, []int{1}
}

func (m *ProductSearchResults) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_ProductSearchResults.Unmarshal(m, b)
}
func (m *ProductSearchResults) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_ProductSearchResults.Marshal(b, m, deterministic)
}
func (m *ProductSearchResults) XXX_Merge(src proto.Message) {
	xxx_messageInfo_ProductSearchResults.Merge(m, src)
}
func (m *ProductSearchResults) XXX_Size() int {
	return xxx_messageInfo_ProductSearchResults.Size(m)
}
func (m *ProductSearchResults) XXX_DiscardUnknown() {
	xxx_messageInfo_ProductSearchResults.DiscardUnknown(m)
}

var xxx_messageInfo_ProductSearchResults proto.InternalMessageInfo

func (m *ProductSearchResults) GetIndexTime() *timestamp.Timestamp {
	if m != nil {
		return m.IndexTime
	}
	return nil
}

func (m *ProductSearchResults) GetResults() []*ProductSearchResults_Result {
	if m != nil {
		return m.Results
	}
	return nil
}

func (m *ProductSearchResults) GetProductGroupedResults() []*ProductSearchResults_GroupedResult {
	if m != nil {
		return m.ProductGroupedResults
	}
	return nil
}

// Information about a product.
type ProductSearchResults_Result struct {
	// The Product.
	Product *Product `protobuf:"bytes,1,opt,name=product,proto3" json:"product,omitempty"`
	// A confidence level on the match, ranging from 0 (no confidence) to
	// 1 (full confidence).
	Score float32 `protobuf:"fixed32,2,opt,name=score,proto3" json:"score,omitempty"`
	// The resource name of the image from the product that is the closest match
	// to the query.
	Image                string   `protobuf:"bytes,3,opt,name=image,proto3" json:"image,omitempty"`
	XXX_NoUnkeyedLiteral struct{} `json:"-"`
	XXX_unrecognized     []byte   `json:"-"`
	XXX_sizecache        int32    `json:"-"`
}

func (m *ProductSearchResults_Result) Reset()         { *m = ProductSearchResults_Result{} }
func (m *ProductSearchResults_Result) String() string { return proto.CompactTextString(m) }
func (*ProductSearchResults_Result) ProtoMessage()    {}
func (*ProductSearchResults_Result) Descriptor() ([]byte, []int) {
	return fileDescriptor_788f05efda4e1c3a, []int{1, 0}
}

func (m *ProductSearchResults_Result) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_ProductSearchResults_Result.Unmarshal(m, b)
}
func (m *ProductSearchResults_Result) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_ProductSearchResults_Result.Marshal(b, m, deterministic)
}
func (m *ProductSearchResults_Result) XXX_Merge(src proto.Message) {
	xxx_messageInfo_ProductSearchResults_Result.Merge(m, src)
}
func (m *ProductSearchResults_Result) XXX_Size() int {
	return xxx_messageInfo_ProductSearchResults_Result.Size(m)
}
func (m *ProductSearchResults_Result) XXX_DiscardUnknown() {
	xxx_messageInfo_ProductSearchResults_Result.DiscardUnknown(m)
}

var xxx_messageInfo_ProductSearchResults_Result proto.InternalMessageInfo

func (m *ProductSearchResults_Result) GetProduct() *Product {
	if m != nil {
		return m.Product
	}
	return nil
}

func (m *ProductSearchResults_Result) GetScore() float32 {
	if m != nil {
		return m.Score
	}
	return 0
}

func (m *ProductSearchResults_Result) GetImage() string {
	if m != nil {
		return m.Image
	}
	return ""
}

// Information about the products similar to a single product in a query
// image.
type ProductSearchResults_GroupedResult struct {
	// The bounding polygon around the product detected in the query image.
	BoundingPoly *BoundingPoly `protobuf:"bytes,1,opt,name=bounding_poly,json=boundingPoly,proto3" json:"bounding_poly,omitempty"`
	// List of results, one for each product match.
	Results              []*ProductSearchResults_Result `protobuf:"bytes,2,rep,name=results,proto3" json:"results,omitempty"`
	XXX_NoUnkeyedLiteral struct{}                       `json:"-"`
	XXX_unrecognized     []byte                         `json:"-"`
	XXX_sizecache        int32                          `json:"-"`
}

func (m *ProductSearchResults_GroupedResult) Reset()         { *m = ProductSearchResults_GroupedResult{} }
func (m *ProductSearchResults_GroupedResult) String() string { return proto.CompactTextString(m) }
func (*ProductSearchResults_GroupedResult) ProtoMessage()    {}
func (*ProductSearchResults_GroupedResult) Descriptor() ([]byte, []int) {
	return fileDescriptor_788f05efda4e1c3a, []int{1, 1}
}

func (m *ProductSearchResults_GroupedResult) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_ProductSearchResults_GroupedResult.Unmarshal(m, b)
}
func (m *ProductSearchResults_GroupedResult) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_ProductSearchResults_GroupedResult.Marshal(b, m, deterministic)
}
func (m *ProductSearchResults_GroupedResult) XXX_Merge(src proto.Message) {
	xxx_messageInfo_ProductSearchResults_GroupedResult.Merge(m, src)
}
func (m *ProductSearchResults_GroupedResult) XXX_Size() int {
	return xxx_messageInfo_ProductSearchResults_GroupedResult.Size(m)
}
func (m *ProductSearchResults_GroupedResult) XXX_DiscardUnknown() {
	xxx_messageInfo_ProductSearchResults_GroupedResult.DiscardUnknown(m)
}

var xxx_messageInfo_ProductSearchResults_GroupedResult proto.InternalMessageInfo

func (m *ProductSearchResults_GroupedResult) GetBoundingPoly() *BoundingPoly {
	if m != nil {
		return m.BoundingPoly
	}
	return nil
}

func (m *ProductSearchResults_GroupedResult) GetResults() []*ProductSearchResults_Result {
	if m != nil {
		return m.Results
	}
	return nil
}

func init() {
	proto.RegisterType((*ProductSearchParams)(nil), "google.cloud.vision.v1p4beta1.ProductSearchParams")
	proto.RegisterType((*ProductSearchResults)(nil), "google.cloud.vision.v1p4beta1.ProductSearchResults")
	proto.RegisterType((*ProductSearchResults_Result)(nil), "google.cloud.vision.v1p4beta1.ProductSearchResults.Result")
	proto.RegisterType((*ProductSearchResults_GroupedResult)(nil), "google.cloud.vision.v1p4beta1.ProductSearchResults.GroupedResult")
}

func init() {
	proto.RegisterFile("google/cloud/vision/v1p4beta1/product_search.proto", fileDescriptor_788f05efda4e1c3a)
}

var fileDescriptor_788f05efda4e1c3a = []byte{
	// 495 bytes of a gzipped FileDescriptorProto
	0x1f, 0x8b, 0x08, 0x00, 0x00, 0x00, 0x00, 0x00, 0x02, 0xff, 0xac, 0x53, 0xcd, 0x8e, 0xd3, 0x3c,
	0x14, 0x95, 0xdb, 0x99, 0xf4, 0xab, 0xfb, 0xcd, 0x02, 0x33, 0x40, 0x14, 0x81, 0xa6, 0xcc, 0x02,
	0x55, 0x02, 0x12, 0x4d, 0x61, 0xc3, 0xb0, 0x81, 0x76, 0x31, 0x3b, 0x14, 0x85, 0x11, 0x0b, 0x36,
	0x91, 0x93, 0x78, 0x8c, 0xa5, 0x24, 0x37, 0xb2, 0x9d, 0x8a, 0xbe, 0x01, 0xcf, 0xc1, 0x4b, 0xf0,
	0x18, 0x6c, 0x78, 0x18, 0x96, 0xa8, 0xfe, 0x19, 0xa6, 0x02, 0xca, 0xef, 0x2a, 0xb9, 0xf6, 0x3d,
	0xe7, 0xdc, 0x7b, 0xee, 0x35, 0x9e, 0x73, 0x00, 0x5e, 0xb3, 0xa4, 0xac, 0xa1, 0xaf, 0x92, 0x95,
	0x50, 0x02, 0xda, 0x64, 0x75, 0xd2, 0x3d, 0x2e, 0x98, 0xa6, 0x27, 0x49, 0x27, 0xa1, 0xea, 0x4b,
	0x9d, 0x2b, 0x46, 0x65, 0xf9, 0x26, 0xee, 0x24, 0x68, 0x20, 0x77, 0x2c, 0x26, 0x36, 0x98, 0xd8,
	0x62, 0xe2, 0x4b, 0x4c, 0x74, 0xdb, 0x51, 0xd2, 0x4e, 0x24, 0xb4, 0x6d, 0x41, 0x53, 0x2d, 0xa0,
	0x55, 0x16, 0x1c, 0x3d, 0xd8, 0x2d, 0xc8, 0x19, 0x34, 0x4c, 0xcb, 0xb5, 0xcb, 0x3e, 0xfd, 0x9d,
	0xf2, 0x72, 0xc5, 0xe4, 0x4a, 0x94, 0xcc, 0x61, 0x8f, 0x1c, 0xd6, 0x44, 0x45, 0x7f, 0x91, 0x68,
	0xd1, 0x30, 0xa5, 0x69, 0xd3, 0xd9, 0x84, 0xe3, 0x8f, 0x08, 0x5f, 0x4f, 0x2d, 0xc3, 0x4b, 0x43,
	0x90, 0x52, 0x49, 0x1b, 0x45, 0x52, 0x7c, 0x50, 0x40, 0xdf, 0x56, 0xa2, 0xe5, 0x79, 0x07, 0xf5,
	0x3a, 0x1c, 0x4f, 0xd1, 0x6c, 0x32, 0xbf, 0x1f, 0xef, 0xec, 0x3b, 0x5e, 0x38, 0x4c, 0x0a, 0xf5,
	0x3a, 0xfb, 0xbf, 0xb8, 0x12, 0x91, 0x23, 0x3c, 0xf9, 0x5a, 0xaa, 0x0e, 0x83, 0x29, 0x9a, 0x8d,
	0x33, 0xdc, 0x79, 0x6d, 0x4d, 0x1e, 0x62, 0xe2, 0x13, 0x4a, 0xaa, 0x19, 0x07, 0x29, 0x98, 0x0a,
	0x47, 0xd3, 0xe1, 0x6c, 0x9c, 0x5d, 0x73, 0x37, 0xcb, 0xcb, 0x0b, 0x72, 0x13, 0x07, 0x17, 0xa2,
	0xd6, 0x4c, 0x86, 0xff, 0x19, 0x2a, 0x17, 0x1d, 0x7f, 0xda, 0xc3, 0x87, 0x5b, 0x1d, 0x65, 0x4c,
	0xf5, 0xb5, 0x56, 0xe4, 0x09, 0xc6, 0xa2, 0xad, 0xd8, 0xdb, 0x7c, 0xe3, 0x41, 0x38, 0x30, 0xfd,
	0x44, 0xbe, 0x1f, 0x6f, 0x50, 0x7c, 0xee, 0x0d, 0xca, 0xc6, 0x26, 0x7b, 0x13, 0x93, 0x73, 0x3c,
	0x92, 0x96, 0x25, 0xdc, 0x9f, 0x0e, 0x67, 0x93, 0xf9, 0xe9, 0x4f, 0x7c, 0xf8, 0x5e, 0x01, 0xb1,
	0xfd, 0x66, 0x9e, 0x8a, 0xac, 0xf1, 0x2d, 0xdf, 0x30, 0x97, 0xd0, 0x77, 0xac, 0xca, 0xbd, 0x4a,
	0x60, 0x54, 0x9e, 0xff, 0x89, 0xca, 0x99, 0xa5, 0x72, 0x62, 0x37, 0x9c, 0xc2, 0xd6, 0xa9, 0x8a,
	0x56, 0x38, 0xb0, 0xbf, 0xe4, 0x19, 0x1e, 0xb9, 0x94, 0x10, 0x19, 0x4b, 0xee, 0xfd, 0x9a, 0x68,
	0xe6, 0x61, 0xe4, 0x10, 0xef, 0xab, 0x12, 0xa4, 0xb5, 0x74, 0x90, 0xd9, 0x60, 0x73, 0x2a, 0x1a,
	0xca, 0x59, 0x38, 0x34, 0xd3, 0xb1, 0x41, 0xf4, 0x01, 0xe1, 0x83, 0xad, 0x52, 0xbe, 0x5d, 0x34,
	0xf4, 0xb7, 0x8b, 0x76, 0x65, 0x58, 0x83, 0x7f, 0x36, 0xac, 0xc5, 0x3b, 0x84, 0xef, 0x96, 0xd0,
	0xec, 0xa6, 0x5a, 0x90, 0xed, 0xb7, 0xb4, 0x59, 0xaa, 0x14, 0xbd, 0x5e, 0x3a, 0x10, 0x87, 0x9a,
	0xb6, 0x3c, 0x06, 0xc9, 0x13, 0xce, 0x5a, 0xb3, 0x72, 0x89, 0xbd, 0xa2, 0x9d, 0x50, 0x3f, 0x78,
	0xe0, 0x4f, 0xed, 0xc1, 0x67, 0x84, 0xde, 0x0f, 0xf6, 0xce, 0x96, 0xaf, 0x5e, 0x14, 0x81, 0x41,
	0x3e, 0xfa, 0x12, 0x00, 0x00, 0xff, 0xff, 0x50, 0x51, 0x5b, 0x19, 0xb8, 0x04, 0x00, 0x00,
}
