// Code generated by protoc-gen-go. DO NOT EDIT.
// source: google/firestore/admin/v1beta2/operation.proto

package admin

import (
	fmt "fmt"
	math "math"

	proto "github.com/golang/protobuf/proto"
	timestamp "github.com/golang/protobuf/ptypes/timestamp"
	_ "google.golang.org/genproto/googleapis/api/annotations"
)

// Reference imports to suppress errors if they are not otherwise used.
var _ = proto.Marshal
var _ = fmt.Errorf
var _ = math.Inf

// This is a compile-time assertion to ensure that this generated file
// is compatible with the proto package it is being compiled against.
// A compilation error at this line likely means your copy of the
// proto package needs to be updated.
const _ = proto.ProtoPackageIsVersion3 // please upgrade the proto package

// Describes the state of the operation.
type OperationState int32

const (
	// Unspecified.
	OperationState_OPERATION_STATE_UNSPECIFIED OperationState = 0
	// Request is being prepared for processing.
	OperationState_INITIALIZING OperationState = 1
	// Request is actively being processed.
	OperationState_PROCESSING OperationState = 2
	// Request is in the process of being cancelled after user called
	// google.longrunning.Operations.CancelOperation on the operation.
	OperationState_CANCELLING OperationState = 3
	// Request has been processed and is in its finalization stage.
	OperationState_FINALIZING OperationState = 4
	// Request has completed successfully.
	OperationState_SUCCESSFUL OperationState = 5
	// Request has finished being processed, but encountered an error.
	OperationState_FAILED OperationState = 6
	// Request has finished being cancelled after user called
	// google.longrunning.Operations.CancelOperation.
	OperationState_CANCELLED OperationState = 7
)

var OperationState_name = map[int32]string{
	0: "OPERATION_STATE_UNSPECIFIED",
	1: "INITIALIZING",
	2: "PROCESSING",
	3: "CANCELLING",
	4: "FINALIZING",
	5: "SUCCESSFUL",
	6: "FAILED",
	7: "CANCELLED",
}

var OperationState_value = map[string]int32{
	"OPERATION_STATE_UNSPECIFIED": 0,
	"INITIALIZING":                1,
	"PROCESSING":                  2,
	"CANCELLING":                  3,
	"FINALIZING":                  4,
	"SUCCESSFUL":                  5,
	"FAILED":                      6,
	"CANCELLED":                   7,
}

func (x OperationState) String() string {
	return proto.EnumName(OperationState_name, int32(x))
}

func (OperationState) EnumDescriptor() ([]byte, []int) {
	return fileDescriptor_f946ae2a57533608, []int{0}
}

// Specifies how the index is changing.
type FieldOperationMetadata_IndexConfigDelta_ChangeType int32

const (
	// The type of change is not specified or known.
	FieldOperationMetadata_IndexConfigDelta_CHANGE_TYPE_UNSPECIFIED FieldOperationMetadata_IndexConfigDelta_ChangeType = 0
	// The single field index is being added.
	FieldOperationMetadata_IndexConfigDelta_ADD FieldOperationMetadata_IndexConfigDelta_ChangeType = 1
	// The single field index is being removed.
	FieldOperationMetadata_IndexConfigDelta_REMOVE FieldOperationMetadata_IndexConfigDelta_ChangeType = 2
)

var FieldOperationMetadata_IndexConfigDelta_ChangeType_name = map[int32]string{
	0: "CHANGE_TYPE_UNSPECIFIED",
	1: "ADD",
	2: "REMOVE",
}

var FieldOperationMetadata_IndexConfigDelta_ChangeType_value = map[string]int32{
	"CHANGE_TYPE_UNSPECIFIED": 0,
	"ADD":                     1,
	"REMOVE":                  2,
}

func (x FieldOperationMetadata_IndexConfigDelta_ChangeType) String() string {
	return proto.EnumName(FieldOperationMetadata_IndexConfigDelta_ChangeType_name, int32(x))
}

func (FieldOperationMetadata_IndexConfigDelta_ChangeType) EnumDescriptor() ([]byte, []int) {
	return fileDescriptor_f946ae2a57533608, []int{1, 0, 0}
}

// Metadata for [google.longrunning.Operation][google.longrunning.Operation] results from
// [FirestoreAdmin.CreateIndex][google.firestore.admin.v1beta2.FirestoreAdmin.CreateIndex].
type IndexOperationMetadata struct {
	// The time this operation started.
	StartTime *timestamp.Timestamp `protobuf:"bytes,1,opt,name=start_time,json=startTime,proto3" json:"start_time,omitempty"`
	// The time this operation completed. Will be unset if operation still in
	// progress.
	EndTime *timestamp.Timestamp `protobuf:"bytes,2,opt,name=end_time,json=endTime,proto3" json:"end_time,omitempty"`
	// The index resource that this operation is acting on. For example:
	// `projects/{project_id}/databases/{database_id}/collectionGroups/{collection_id}/indexes/{index_id}`
	Index string `protobuf:"bytes,3,opt,name=index,proto3" json:"index,omitempty"`
	// The state of the operation.
	State OperationState `protobuf:"varint,4,opt,name=state,proto3,enum=google.firestore.admin.v1beta2.OperationState" json:"state,omitempty"`
	// The progress, in documents, of this operation.
	ProgressDocuments *Progress `protobuf:"bytes,5,opt,name=progress_documents,json=progressDocuments,proto3" json:"progress_documents,omitempty"`
	// The progress, in bytes, of this operation.
	ProgressBytes        *Progress `protobuf:"bytes,6,opt,name=progress_bytes,json=progressBytes,proto3" json:"progress_bytes,omitempty"`
	XXX_NoUnkeyedLiteral struct{}  `json:"-"`
	XXX_unrecognized     []byte    `json:"-"`
	XXX_sizecache        int32     `json:"-"`
}

func (m *IndexOperationMetadata) Reset()         { *m = IndexOperationMetadata{} }
func (m *IndexOperationMetadata) String() string { return proto.CompactTextString(m) }
func (*IndexOperationMetadata) ProtoMessage()    {}
func (*IndexOperationMetadata) Descriptor() ([]byte, []int) {
	return fileDescriptor_f946ae2a57533608, []int{0}
}

func (m *IndexOperationMetadata) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_IndexOperationMetadata.Unmarshal(m, b)
}
func (m *IndexOperationMetadata) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_IndexOperationMetadata.Marshal(b, m, deterministic)
}
func (m *IndexOperationMetadata) XXX_Merge(src proto.Message) {
	xxx_messageInfo_IndexOperationMetadata.Merge(m, src)
}
func (m *IndexOperationMetadata) XXX_Size() int {
	return xxx_messageInfo_IndexOperationMetadata.Size(m)
}
func (m *IndexOperationMetadata) XXX_DiscardUnknown() {
	xxx_messageInfo_IndexOperationMetadata.DiscardUnknown(m)
}

var xxx_messageInfo_IndexOperationMetadata proto.InternalMessageInfo

func (m *IndexOperationMetadata) GetStartTime() *timestamp.Timestamp {
	if m != nil {
		return m.StartTime
	}
	return nil
}

func (m *IndexOperationMetadata) GetEndTime() *timestamp.Timestamp {
	if m != nil {
		return m.EndTime
	}
	return nil
}

func (m *IndexOperationMetadata) GetIndex() string {
	if m != nil {
		return m.Index
	}
	return ""
}

func (m *IndexOperationMetadata) GetState() OperationState {
	if m != nil {
		return m.State
	}
	return OperationState_OPERATION_STATE_UNSPECIFIED
}

func (m *IndexOperationMetadata) GetProgressDocuments() *Progress {
	if m != nil {
		return m.ProgressDocuments
	}
	return nil
}

func (m *IndexOperationMetadata) GetProgressBytes() *Progress {
	if m != nil {
		return m.ProgressBytes
	}
	return nil
}

// Metadata for [google.longrunning.Operation][google.longrunning.Operation] results from
// [FirestoreAdmin.UpdateField][google.firestore.admin.v1beta2.FirestoreAdmin.UpdateField].
type FieldOperationMetadata struct {
	// The time this operation started.
	StartTime *timestamp.Timestamp `protobuf:"bytes,1,opt,name=start_time,json=startTime,proto3" json:"start_time,omitempty"`
	// The time this operation completed. Will be unset if operation still in
	// progress.
	EndTime *timestamp.Timestamp `protobuf:"bytes,2,opt,name=end_time,json=endTime,proto3" json:"end_time,omitempty"`
	// The field resource that this operation is acting on. For example:
	// `projects/{project_id}/databases/{database_id}/collectionGroups/{collection_id}/fields/{field_path}`
	Field string `protobuf:"bytes,3,opt,name=field,proto3" json:"field,omitempty"`
	// A list of [IndexConfigDelta][google.firestore.admin.v1beta2.FieldOperationMetadata.IndexConfigDelta], which describe the intent of this
	// operation.
	IndexConfigDeltas []*FieldOperationMetadata_IndexConfigDelta `protobuf:"bytes,4,rep,name=index_config_deltas,json=indexConfigDeltas,proto3" json:"index_config_deltas,omitempty"`
	// The state of the operation.
	State OperationState `protobuf:"varint,5,opt,name=state,proto3,enum=google.firestore.admin.v1beta2.OperationState" json:"state,omitempty"`
	// The progress, in documents, of this operation.
	DocumentProgress *Progress `protobuf:"bytes,6,opt,name=document_progress,json=documentProgress,proto3" json:"document_progress,omitempty"`
	// The progress, in bytes, of this operation.
	BytesProgress        *Progress `protobuf:"bytes,7,opt,name=bytes_progress,json=bytesProgress,proto3" json:"bytes_progress,omitempty"`
	XXX_NoUnkeyedLiteral struct{}  `json:"-"`
	XXX_unrecognized     []byte    `json:"-"`
	XXX_sizecache        int32     `json:"-"`
}

func (m *FieldOperationMetadata) Reset()         { *m = FieldOperationMetadata{} }
func (m *FieldOperationMetadata) String() string { return proto.CompactTextString(m) }
func (*FieldOperationMetadata) ProtoMessage()    {}
func (*FieldOperationMetadata) Descriptor() ([]byte, []int) {
	return fileDescriptor_f946ae2a57533608, []int{1}
}

func (m *FieldOperationMetadata) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_FieldOperationMetadata.Unmarshal(m, b)
}
func (m *FieldOperationMetadata) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_FieldOperationMetadata.Marshal(b, m, deterministic)
}
func (m *FieldOperationMetadata) XXX_Merge(src proto.Message) {
	xxx_messageInfo_FieldOperationMetadata.Merge(m, src)
}
func (m *FieldOperationMetadata) XXX_Size() int {
	return xxx_messageInfo_FieldOperationMetadata.Size(m)
}
func (m *FieldOperationMetadata) XXX_DiscardUnknown() {
	xxx_messageInfo_FieldOperationMetadata.DiscardUnknown(m)
}

var xxx_messageInfo_FieldOperationMetadata proto.InternalMessageInfo

func (m *FieldOperationMetadata) GetStartTime() *timestamp.Timestamp {
	if m != nil {
		return m.StartTime
	}
	return nil
}

func (m *FieldOperationMetadata) GetEndTime() *timestamp.Timestamp {
	if m != nil {
		return m.EndTime
	}
	return nil
}

func (m *FieldOperationMetadata) GetField() string {
	if m != nil {
		return m.Field
	}
	return ""
}

func (m *FieldOperationMetadata) GetIndexConfigDeltas() []*FieldOperationMetadata_IndexConfigDelta {
	if m != nil {
		return m.IndexConfigDeltas
	}
	return nil
}

func (m *FieldOperationMetadata) GetState() OperationState {
	if m != nil {
		return m.State
	}
	return OperationState_OPERATION_STATE_UNSPECIFIED
}

func (m *FieldOperationMetadata) GetDocumentProgress() *Progress {
	if m != nil {
		return m.DocumentProgress
	}
	return nil
}

func (m *FieldOperationMetadata) GetBytesProgress() *Progress {
	if m != nil {
		return m.BytesProgress
	}
	return nil
}

// Information about an index configuration change.
type FieldOperationMetadata_IndexConfigDelta struct {
	// Specifies how the index is changing.
	ChangeType FieldOperationMetadata_IndexConfigDelta_ChangeType `protobuf:"varint,1,opt,name=change_type,json=changeType,proto3,enum=google.firestore.admin.v1beta2.FieldOperationMetadata_IndexConfigDelta_ChangeType" json:"change_type,omitempty"`
	// The index being changed.
	Index                *Index   `protobuf:"bytes,2,opt,name=index,proto3" json:"index,omitempty"`
	XXX_NoUnkeyedLiteral struct{} `json:"-"`
	XXX_unrecognized     []byte   `json:"-"`
	XXX_sizecache        int32    `json:"-"`
}

func (m *FieldOperationMetadata_IndexConfigDelta) Reset() {
	*m = FieldOperationMetadata_IndexConfigDelta{}
}
func (m *FieldOperationMetadata_IndexConfigDelta) String() string { return proto.CompactTextString(m) }
func (*FieldOperationMetadata_IndexConfigDelta) ProtoMessage()    {}
func (*FieldOperationMetadata_IndexConfigDelta) Descriptor() ([]byte, []int) {
	return fileDescriptor_f946ae2a57533608, []int{1, 0}
}

func (m *FieldOperationMetadata_IndexConfigDelta) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_FieldOperationMetadata_IndexConfigDelta.Unmarshal(m, b)
}
func (m *FieldOperationMetadata_IndexConfigDelta) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_FieldOperationMetadata_IndexConfigDelta.Marshal(b, m, deterministic)
}
func (m *FieldOperationMetadata_IndexConfigDelta) XXX_Merge(src proto.Message) {
	xxx_messageInfo_FieldOperationMetadata_IndexConfigDelta.Merge(m, src)
}
func (m *FieldOperationMetadata_IndexConfigDelta) XXX_Size() int {
	return xxx_messageInfo_FieldOperationMetadata_IndexConfigDelta.Size(m)
}
func (m *FieldOperationMetadata_IndexConfigDelta) XXX_DiscardUnknown() {
	xxx_messageInfo_FieldOperationMetadata_IndexConfigDelta.DiscardUnknown(m)
}

var xxx_messageInfo_FieldOperationMetadata_IndexConfigDelta proto.InternalMessageInfo

func (m *FieldOperationMetadata_IndexConfigDelta) GetChangeType() FieldOperationMetadata_IndexConfigDelta_ChangeType {
	if m != nil {
		return m.ChangeType
	}
	return FieldOperationMetadata_IndexConfigDelta_CHANGE_TYPE_UNSPECIFIED
}

func (m *FieldOperationMetadata_IndexConfigDelta) GetIndex() *Index {
	if m != nil {
		return m.Index
	}
	return nil
}

// Metadata for [google.longrunning.Operation][google.longrunning.Operation] results from
// [FirestoreAdmin.ExportDocuments][google.firestore.admin.v1beta2.FirestoreAdmin.ExportDocuments].
type ExportDocumentsMetadata struct {
	// The time this operation started.
	StartTime *timestamp.Timestamp `protobuf:"bytes,1,opt,name=start_time,json=startTime,proto3" json:"start_time,omitempty"`
	// The time this operation completed. Will be unset if operation still in
	// progress.
	EndTime *timestamp.Timestamp `protobuf:"bytes,2,opt,name=end_time,json=endTime,proto3" json:"end_time,omitempty"`
	// The state of the export operation.
	OperationState OperationState `protobuf:"varint,3,opt,name=operation_state,json=operationState,proto3,enum=google.firestore.admin.v1beta2.OperationState" json:"operation_state,omitempty"`
	// The progress, in documents, of this operation.
	ProgressDocuments *Progress `protobuf:"bytes,4,opt,name=progress_documents,json=progressDocuments,proto3" json:"progress_documents,omitempty"`
	// The progress, in bytes, of this operation.
	ProgressBytes *Progress `protobuf:"bytes,5,opt,name=progress_bytes,json=progressBytes,proto3" json:"progress_bytes,omitempty"`
	// Which collection ids are being exported.
	CollectionIds []string `protobuf:"bytes,6,rep,name=collection_ids,json=collectionIds,proto3" json:"collection_ids,omitempty"`
	// Where the entities are being exported to.
	OutputUriPrefix      string   `protobuf:"bytes,7,opt,name=output_uri_prefix,json=outputUriPrefix,proto3" json:"output_uri_prefix,omitempty"`
	XXX_NoUnkeyedLiteral struct{} `json:"-"`
	XXX_unrecognized     []byte   `json:"-"`
	XXX_sizecache        int32    `json:"-"`
}

func (m *ExportDocumentsMetadata) Reset()         { *m = ExportDocumentsMetadata{} }
func (m *ExportDocumentsMetadata) String() string { return proto.CompactTextString(m) }
func (*ExportDocumentsMetadata) ProtoMessage()    {}
func (*ExportDocumentsMetadata) Descriptor() ([]byte, []int) {
	return fileDescriptor_f946ae2a57533608, []int{2}
}

func (m *ExportDocumentsMetadata) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_ExportDocumentsMetadata.Unmarshal(m, b)
}
func (m *ExportDocumentsMetadata) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_ExportDocumentsMetadata.Marshal(b, m, deterministic)
}
func (m *ExportDocumentsMetadata) XXX_Merge(src proto.Message) {
	xxx_messageInfo_ExportDocumentsMetadata.Merge(m, src)
}
func (m *ExportDocumentsMetadata) XXX_Size() int {
	return xxx_messageInfo_ExportDocumentsMetadata.Size(m)
}
func (m *ExportDocumentsMetadata) XXX_DiscardUnknown() {
	xxx_messageInfo_ExportDocumentsMetadata.DiscardUnknown(m)
}

var xxx_messageInfo_ExportDocumentsMetadata proto.InternalMessageInfo

func (m *ExportDocumentsMetadata) GetStartTime() *timestamp.Timestamp {
	if m != nil {
		return m.StartTime
	}
	return nil
}

func (m *ExportDocumentsMetadata) GetEndTime() *timestamp.Timestamp {
	if m != nil {
		return m.EndTime
	}
	return nil
}

func (m *ExportDocumentsMetadata) GetOperationState() OperationState {
	if m != nil {
		return m.OperationState
	}
	return OperationState_OPERATION_STATE_UNSPECIFIED
}

func (m *ExportDocumentsMetadata) GetProgressDocuments() *Progress {
	if m != nil {
		return m.ProgressDocuments
	}
	return nil
}

func (m *ExportDocumentsMetadata) GetProgressBytes() *Progress {
	if m != nil {
		return m.ProgressBytes
	}
	return nil
}

func (m *ExportDocumentsMetadata) GetCollectionIds() []string {
	if m != nil {
		return m.CollectionIds
	}
	return nil
}

func (m *ExportDocumentsMetadata) GetOutputUriPrefix() string {
	if m != nil {
		return m.OutputUriPrefix
	}
	return ""
}

// Metadata for [google.longrunning.Operation][google.longrunning.Operation] results from
// [FirestoreAdmin.ImportDocuments][google.firestore.admin.v1beta2.FirestoreAdmin.ImportDocuments].
type ImportDocumentsMetadata struct {
	// The time this operation started.
	StartTime *timestamp.Timestamp `protobuf:"bytes,1,opt,name=start_time,json=startTime,proto3" json:"start_time,omitempty"`
	// The time this operation completed. Will be unset if operation still in
	// progress.
	EndTime *timestamp.Timestamp `protobuf:"bytes,2,opt,name=end_time,json=endTime,proto3" json:"end_time,omitempty"`
	// The state of the import operation.
	OperationState OperationState `protobuf:"varint,3,opt,name=operation_state,json=operationState,proto3,enum=google.firestore.admin.v1beta2.OperationState" json:"operation_state,omitempty"`
	// The progress, in documents, of this operation.
	ProgressDocuments *Progress `protobuf:"bytes,4,opt,name=progress_documents,json=progressDocuments,proto3" json:"progress_documents,omitempty"`
	// The progress, in bytes, of this operation.
	ProgressBytes *Progress `protobuf:"bytes,5,opt,name=progress_bytes,json=progressBytes,proto3" json:"progress_bytes,omitempty"`
	// Which collection ids are being imported.
	CollectionIds []string `protobuf:"bytes,6,rep,name=collection_ids,json=collectionIds,proto3" json:"collection_ids,omitempty"`
	// The location of the documents being imported.
	InputUriPrefix       string   `protobuf:"bytes,7,opt,name=input_uri_prefix,json=inputUriPrefix,proto3" json:"input_uri_prefix,omitempty"`
	XXX_NoUnkeyedLiteral struct{} `json:"-"`
	XXX_unrecognized     []byte   `json:"-"`
	XXX_sizecache        int32    `json:"-"`
}

func (m *ImportDocumentsMetadata) Reset()         { *m = ImportDocumentsMetadata{} }
func (m *ImportDocumentsMetadata) String() string { return proto.CompactTextString(m) }
func (*ImportDocumentsMetadata) ProtoMessage()    {}
func (*ImportDocumentsMetadata) Descriptor() ([]byte, []int) {
	return fileDescriptor_f946ae2a57533608, []int{3}
}

func (m *ImportDocumentsMetadata) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_ImportDocumentsMetadata.Unmarshal(m, b)
}
func (m *ImportDocumentsMetadata) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_ImportDocumentsMetadata.Marshal(b, m, deterministic)
}
func (m *ImportDocumentsMetadata) XXX_Merge(src proto.Message) {
	xxx_messageInfo_ImportDocumentsMetadata.Merge(m, src)
}
func (m *ImportDocumentsMetadata) XXX_Size() int {
	return xxx_messageInfo_ImportDocumentsMetadata.Size(m)
}
func (m *ImportDocumentsMetadata) XXX_DiscardUnknown() {
	xxx_messageInfo_ImportDocumentsMetadata.DiscardUnknown(m)
}

var xxx_messageInfo_ImportDocumentsMetadata proto.InternalMessageInfo

func (m *ImportDocumentsMetadata) GetStartTime() *timestamp.Timestamp {
	if m != nil {
		return m.StartTime
	}
	return nil
}

func (m *ImportDocumentsMetadata) GetEndTime() *timestamp.Timestamp {
	if m != nil {
		return m.EndTime
	}
	return nil
}

func (m *ImportDocumentsMetadata) GetOperationState() OperationState {
	if m != nil {
		return m.OperationState
	}
	return OperationState_OPERATION_STATE_UNSPECIFIED
}

func (m *ImportDocumentsMetadata) GetProgressDocuments() *Progress {
	if m != nil {
		return m.ProgressDocuments
	}
	return nil
}

func (m *ImportDocumentsMetadata) GetProgressBytes() *Progress {
	if m != nil {
		return m.ProgressBytes
	}
	return nil
}

func (m *ImportDocumentsMetadata) GetCollectionIds() []string {
	if m != nil {
		return m.CollectionIds
	}
	return nil
}

func (m *ImportDocumentsMetadata) GetInputUriPrefix() string {
	if m != nil {
		return m.InputUriPrefix
	}
	return ""
}

// Returned in the [google.longrunning.Operation][google.longrunning.Operation] response field.
type ExportDocumentsResponse struct {
	// Location of the output files. This can be used to begin an import
	// into Cloud Firestore (this project or another project) after the operation
	// completes successfully.
	OutputUriPrefix      string   `protobuf:"bytes,1,opt,name=output_uri_prefix,json=outputUriPrefix,proto3" json:"output_uri_prefix,omitempty"`
	XXX_NoUnkeyedLiteral struct{} `json:"-"`
	XXX_unrecognized     []byte   `json:"-"`
	XXX_sizecache        int32    `json:"-"`
}

func (m *ExportDocumentsResponse) Reset()         { *m = ExportDocumentsResponse{} }
func (m *ExportDocumentsResponse) String() string { return proto.CompactTextString(m) }
func (*ExportDocumentsResponse) ProtoMessage()    {}
func (*ExportDocumentsResponse) Descriptor() ([]byte, []int) {
	return fileDescriptor_f946ae2a57533608, []int{4}
}

func (m *ExportDocumentsResponse) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_ExportDocumentsResponse.Unmarshal(m, b)
}
func (m *ExportDocumentsResponse) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_ExportDocumentsResponse.Marshal(b, m, deterministic)
}
func (m *ExportDocumentsResponse) XXX_Merge(src proto.Message) {
	xxx_messageInfo_ExportDocumentsResponse.Merge(m, src)
}
func (m *ExportDocumentsResponse) XXX_Size() int {
	return xxx_messageInfo_ExportDocumentsResponse.Size(m)
}
func (m *ExportDocumentsResponse) XXX_DiscardUnknown() {
	xxx_messageInfo_ExportDocumentsResponse.DiscardUnknown(m)
}

var xxx_messageInfo_ExportDocumentsResponse proto.InternalMessageInfo

func (m *ExportDocumentsResponse) GetOutputUriPrefix() string {
	if m != nil {
		return m.OutputUriPrefix
	}
	return ""
}

// Describes the progress of the operation.
// Unit of work is generic and must be interpreted based on where [Progress][google.firestore.admin.v1beta2.Progress]
// is used.
type Progress struct {
	// The amount of work estimated.
	EstimatedWork int64 `protobuf:"varint,1,opt,name=estimated_work,json=estimatedWork,proto3" json:"estimated_work,omitempty"`
	// The amount of work completed.
	CompletedWork        int64    `protobuf:"varint,2,opt,name=completed_work,json=completedWork,proto3" json:"completed_work,omitempty"`
	XXX_NoUnkeyedLiteral struct{} `json:"-"`
	XXX_unrecognized     []byte   `json:"-"`
	XXX_sizecache        int32    `json:"-"`
}

func (m *Progress) Reset()         { *m = Progress{} }
func (m *Progress) String() string { return proto.CompactTextString(m) }
func (*Progress) ProtoMessage()    {}
func (*Progress) Descriptor() ([]byte, []int) {
	return fileDescriptor_f946ae2a57533608, []int{5}
}

func (m *Progress) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_Progress.Unmarshal(m, b)
}
func (m *Progress) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_Progress.Marshal(b, m, deterministic)
}
func (m *Progress) XXX_Merge(src proto.Message) {
	xxx_messageInfo_Progress.Merge(m, src)
}
func (m *Progress) XXX_Size() int {
	return xxx_messageInfo_Progress.Size(m)
}
func (m *Progress) XXX_DiscardUnknown() {
	xxx_messageInfo_Progress.DiscardUnknown(m)
}

var xxx_messageInfo_Progress proto.InternalMessageInfo

func (m *Progress) GetEstimatedWork() int64 {
	if m != nil {
		return m.EstimatedWork
	}
	return 0
}

func (m *Progress) GetCompletedWork() int64 {
	if m != nil {
		return m.CompletedWork
	}
	return 0
}

func init() {
	proto.RegisterEnum("google.firestore.admin.v1beta2.OperationState", OperationState_name, OperationState_value)
	proto.RegisterEnum("google.firestore.admin.v1beta2.FieldOperationMetadata_IndexConfigDelta_ChangeType", FieldOperationMetadata_IndexConfigDelta_ChangeType_name, FieldOperationMetadata_IndexConfigDelta_ChangeType_value)
	proto.RegisterType((*IndexOperationMetadata)(nil), "google.firestore.admin.v1beta2.IndexOperationMetadata")
	proto.RegisterType((*FieldOperationMetadata)(nil), "google.firestore.admin.v1beta2.FieldOperationMetadata")
	proto.RegisterType((*FieldOperationMetadata_IndexConfigDelta)(nil), "google.firestore.admin.v1beta2.FieldOperationMetadata.IndexConfigDelta")
	proto.RegisterType((*ExportDocumentsMetadata)(nil), "google.firestore.admin.v1beta2.ExportDocumentsMetadata")
	proto.RegisterType((*ImportDocumentsMetadata)(nil), "google.firestore.admin.v1beta2.ImportDocumentsMetadata")
	proto.RegisterType((*ExportDocumentsResponse)(nil), "google.firestore.admin.v1beta2.ExportDocumentsResponse")
	proto.RegisterType((*Progress)(nil), "google.firestore.admin.v1beta2.Progress")
}

func init() {
	proto.RegisterFile("google/firestore/admin/v1beta2/operation.proto", fileDescriptor_f946ae2a57533608)
}

var fileDescriptor_f946ae2a57533608 = []byte{
	// 858 bytes of a gzipped FileDescriptorProto
	0x1f, 0x8b, 0x08, 0x00, 0x00, 0x00, 0x00, 0x00, 0x02, 0xff, 0xec, 0x56, 0xcf, 0x6f, 0xe3, 0x44,
	0x14, 0xc6, 0x71, 0x92, 0x6e, 0x5e, 0xa9, 0xd7, 0x1d, 0xd0, 0x36, 0xea, 0x22, 0xb6, 0x8a, 0xa8,
	0x14, 0xf5, 0xe0, 0x68, 0x83, 0x38, 0xa0, 0x95, 0x90, 0x52, 0xc7, 0x09, 0x96, 0xb2, 0x49, 0xe4,
	0x24, 0x5b, 0xd8, 0x8b, 0x35, 0x8d, 0x27, 0x66, 0xb4, 0xb1, 0xc7, 0xf2, 0x4c, 0xd8, 0xf6, 0xce,
	0x19, 0xf1, 0x17, 0x70, 0xe0, 0x06, 0xff, 0x14, 0xe2, 0x3f, 0x41, 0x33, 0xfe, 0x11, 0x6d, 0xe9,
	0x12, 0x95, 0x82, 0x00, 0x69, 0x6f, 0x79, 0xcf, 0xdf, 0xf7, 0xcd, 0xbc, 0x79, 0xdf, 0x7b, 0x0a,
	0x58, 0x21, 0x63, 0xe1, 0x9a, 0x74, 0x56, 0x34, 0x25, 0x5c, 0xb0, 0x94, 0x74, 0x70, 0x10, 0xd1,
	0xb8, 0xf3, 0xed, 0xd3, 0x4b, 0x22, 0x70, 0xb7, 0xc3, 0x12, 0x92, 0x62, 0x41, 0x59, 0x6c, 0x25,
	0x29, 0x13, 0x0c, 0x7d, 0x9c, 0xe1, 0xad, 0x12, 0x6f, 0x29, 0xbc, 0x95, 0xe3, 0x8f, 0xcf, 0x76,
	0xe8, 0xd1, 0x38, 0x20, 0x57, 0x99, 0xd6, 0xf1, 0x93, 0x1c, 0xab, 0xa2, 0xcb, 0xcd, 0xaa, 0x23,
	0x68, 0x44, 0xb8, 0xc0, 0x51, 0x92, 0x03, 0x3e, 0xca, 0x01, 0x38, 0xa1, 0x1d, 0x1c, 0xc7, 0x4c,
	0xa8, 0x9b, 0xf0, 0xec, 0x6b, 0xeb, 0x07, 0x1d, 0x1e, 0xb9, 0x52, 0x6e, 0x52, 0xdc, 0xf1, 0x39,
	0x11, 0x38, 0xc0, 0x02, 0xa3, 0xcf, 0x01, 0xb8, 0xc0, 0xa9, 0xf0, 0xa5, 0x62, 0x53, 0x3b, 0xd1,
	0xda, 0xfb, 0xdd, 0xe3, 0xbc, 0x54, 0xab, 0x38, 0xce, 0x9a, 0x17, 0xc7, 0x79, 0x0d, 0x85, 0x96,
	0x31, 0xfa, 0x0c, 0x1e, 0x90, 0x38, 0xc8, 0x88, 0x95, 0x9d, 0xc4, 0x3d, 0x12, 0x07, 0x8a, 0xf6,
	0x21, 0xd4, 0x54, 0x69, 0x4d, 0xfd, 0x44, 0x6b, 0x37, 0xbc, 0x2c, 0x40, 0x7d, 0xa8, 0x71, 0x81,
	0x05, 0x69, 0x56, 0x4f, 0xb4, 0xb6, 0xd1, 0xb5, 0xac, 0x3f, 0x7f, 0x3d, 0xab, 0xac, 0x64, 0x26,
	0x59, 0x5e, 0x46, 0x46, 0x17, 0x80, 0x92, 0x94, 0x85, 0x29, 0xe1, 0xdc, 0x0f, 0xd8, 0x72, 0x13,
	0x91, 0x58, 0xf0, 0x66, 0x4d, 0x5d, 0xae, 0xbd, 0x4b, 0x72, 0x9a, 0x33, 0xbd, 0xc3, 0x42, 0xa3,
	0x5f, 0x48, 0xa0, 0x09, 0x18, 0xa5, 0xf0, 0xe5, 0xb5, 0x20, 0xbc, 0x59, 0xbf, 0xa3, 0xe8, 0x41,
	0xc1, 0x3f, 0x97, 0xf4, 0xd6, 0xf7, 0x75, 0x78, 0x34, 0xa0, 0x64, 0x1d, 0xfc, 0x47, 0x5a, 0xb2,
	0x92, 0x77, 0x29, 0x5a, 0xa2, 0x02, 0xf4, 0x1a, 0x3e, 0x50, 0xbd, 0xf1, 0x97, 0x2c, 0x5e, 0xd1,
	0xd0, 0x0f, 0xc8, 0x5a, 0x60, 0xde, 0xac, 0x9e, 0xe8, 0xed, 0xfd, 0xee, 0x70, 0x57, 0xe1, 0xb7,
	0x17, 0x67, 0x29, 0x1b, 0xda, 0x4a, 0xb0, 0x2f, 0xf5, 0xbc, 0x43, 0x7a, 0x23, 0xc3, 0xb7, 0x5e,
	0xa8, 0xdd, 0xc7, 0x0b, 0x0b, 0x38, 0x2c, 0x2c, 0xe0, 0x17, 0x6f, 0x7f, 0xe7, 0xae, 0x99, 0x85,
	0x44, 0x91, 0x91, 0x4e, 0x50, 0x06, 0xd8, 0x6a, 0xee, 0xdd, 0xd5, 0x09, 0x8a, 0x5f, 0x84, 0xc7,
	0xdf, 0x55, 0xc0, 0xbc, 0xf9, 0x2a, 0x88, 0xc3, 0xfe, 0xf2, 0x1b, 0x1c, 0x87, 0xc4, 0x17, 0xd7,
	0x49, 0x66, 0x02, 0xa3, 0xeb, 0xfd, 0x4d, 0x6f, 0x6e, 0xd9, 0x4a, 0x7a, 0x7e, 0x9d, 0x10, 0x0f,
	0x96, 0xe5, 0x6f, 0xf4, 0xac, 0x98, 0xcc, 0xcc, 0x3a, 0xa7, 0xbb, 0x8e, 0x53, 0xba, 0xf9, 0x00,
	0xb7, 0xbe, 0x00, 0xd8, 0xca, 0xa2, 0xc7, 0x70, 0x64, 0x7f, 0xd9, 0x1b, 0x0f, 0x1d, 0x7f, 0xfe,
	0xf5, 0xd4, 0xf1, 0x17, 0xe3, 0xd9, 0xd4, 0xb1, 0xdd, 0x81, 0xeb, 0xf4, 0xcd, 0xf7, 0xd0, 0x1e,
	0xe8, 0xbd, 0x7e, 0xdf, 0xd4, 0x10, 0x40, 0xdd, 0x73, 0x9e, 0x4f, 0x5e, 0x38, 0x66, 0xa5, 0xf5,
	0x9b, 0x0e, 0x47, 0xce, 0x55, 0xc2, 0x52, 0x51, 0x4e, 0xdd, 0xbf, 0x38, 0x11, 0x17, 0xf0, 0xb0,
	0xdc, 0xe7, 0x7e, 0x66, 0x46, 0xfd, 0x2f, 0x99, 0xd1, 0x60, 0x6f, 0xc4, 0x6f, 0xd9, 0x50, 0xd5,
	0x7f, 0x62, 0x43, 0xd5, 0xee, 0xb5, 0xa1, 0xd0, 0x29, 0x18, 0x4b, 0xb6, 0x5e, 0x93, 0xa5, 0x7a,
	0x03, 0x1a, 0xc8, 0xe1, 0xd1, 0xdb, 0x0d, 0xef, 0x60, 0x9b, 0x75, 0x03, 0x8e, 0xce, 0xe0, 0x90,
	0x6d, 0x44, 0xb2, 0x11, 0xfe, 0x26, 0xa5, 0x7e, 0x92, 0x92, 0x15, 0xbd, 0x52, 0x23, 0xd1, 0xf0,
	0x1e, 0x66, 0x1f, 0x16, 0x29, 0x9d, 0xaa, 0x74, 0xeb, 0x57, 0x1d, 0x8e, 0xdc, 0xe8, 0x5d, 0x8f,
	0xff, 0x6f, 0x3d, 0x6e, 0x83, 0x49, 0xe3, 0x5b, 0x5b, 0x6c, 0xa8, 0xfc, 0xb6, 0xc3, 0xce, 0x1f,
	0x86, 0xd8, 0x23, 0x3c, 0x61, 0x31, 0x27, 0xb7, 0x1b, 0x45, 0xbb, 0xdd, 0x28, 0x5f, 0xc1, 0x83,
	0x72, 0xe1, 0x9e, 0x82, 0x41, 0xb8, 0xa0, 0x11, 0x16, 0x24, 0xf0, 0x5f, 0xb3, 0xf4, 0x95, 0x22,
	0xe9, 0xde, 0x41, 0x99, 0xbd, 0x60, 0xe9, 0xab, 0xac, 0x94, 0x28, 0x59, 0x93, 0x12, 0x56, 0xc9,
	0x60, 0x65, 0x56, 0xc2, 0xce, 0x7e, 0xd4, 0xc0, 0x78, 0xb3, 0x7d, 0xe8, 0x09, 0x3c, 0x9e, 0x4c,
	0x1d, 0xaf, 0x37, 0x77, 0x27, 0x63, 0x7f, 0x36, 0xef, 0xcd, 0x6f, 0xee, 0x2b, 0x13, 0xde, 0x77,
	0xc7, 0xee, 0xdc, 0xed, 0x8d, 0xdc, 0x97, 0xee, 0x78, 0x68, 0x6a, 0xc8, 0x00, 0x98, 0x7a, 0x13,
	0xdb, 0x99, 0xcd, 0x64, 0x5c, 0x91, 0xb1, 0xdd, 0x1b, 0xdb, 0xce, 0x68, 0x24, 0x63, 0x5d, 0xc6,
	0x03, 0x77, 0x5c, 0xe0, 0xab, 0x32, 0x9e, 0x2d, 0x6c, 0x89, 0x1f, 0x2c, 0x46, 0x66, 0x4d, 0x2e,
	0xbe, 0x41, 0xcf, 0x1d, 0x39, 0x7d, 0xb3, 0x8e, 0x0e, 0xa0, 0x91, 0x73, 0x9d, 0xbe, 0xb9, 0x77,
	0xfe, 0xb3, 0x06, 0xad, 0x25, 0x8b, 0x76, 0x74, 0xf4, 0x7c, 0x5b, 0xc4, 0x54, 0x5a, 0x7c, 0xaa,
	0xbd, 0xb4, 0x73, 0x46, 0xc8, 0xd6, 0x38, 0x0e, 0x2d, 0x96, 0x86, 0x9d, 0x90, 0xc4, 0x6a, 0x00,
	0x3a, 0xd9, 0x27, 0x9c, 0x50, 0xfe, 0xb6, 0xbf, 0x9b, 0xcf, 0x54, 0xf4, 0x53, 0xa5, 0x3a, 0xb4,
	0x07, 0xb3, 0x5f, 0x2a, 0x9f, 0x0c, 0x33, 0x31, 0x7b, 0xcd, 0x36, 0x81, 0x35, 0x28, 0x2f, 0xd1,
	0x53, 0x97, 0x78, 0xf1, 0xf4, 0x5c, 0x72, 0x2e, 0xeb, 0x4a, 0xfd, 0xd3, 0xdf, 0x03, 0x00, 0x00,
	0xff, 0xff, 0xae, 0xa2, 0x85, 0xc8, 0x1b, 0x0b, 0x00, 0x00,
}
