// Code generated by protoc-gen-go. DO NOT EDIT.
// source: google/ads/googleads/v2/errors/ad_customizer_error.proto

package errors

import (
	fmt "fmt"
	math "math"

	proto "github.com/golang/protobuf/proto"
	_ "google.golang.org/genproto/googleapis/api/annotations"
)

// Reference imports to suppress errors if they are not otherwise used.
var _ = proto.Marshal
var _ = fmt.Errorf
var _ = math.Inf

// This is a compile-time assertion to ensure that this generated file
// is compatible with the proto package it is being compiled against.
// A compilation error at this line likely means your copy of the
// proto package needs to be updated.
const _ = proto.ProtoPackageIsVersion3 // please upgrade the proto package

// Enum describing possible ad customizer errors.
type AdCustomizerErrorEnum_AdCustomizerError int32

const (
	// Enum unspecified.
	AdCustomizerErrorEnum_UNSPECIFIED AdCustomizerErrorEnum_AdCustomizerError = 0
	// The received error code is not known in this version.
	AdCustomizerErrorEnum_UNKNOWN AdCustomizerErrorEnum_AdCustomizerError = 1
	// Invalid date argument in countdown function.
	AdCustomizerErrorEnum_COUNTDOWN_INVALID_DATE_FORMAT AdCustomizerErrorEnum_AdCustomizerError = 2
	// Countdown end date is in the past.
	AdCustomizerErrorEnum_COUNTDOWN_DATE_IN_PAST AdCustomizerErrorEnum_AdCustomizerError = 3
	// Invalid locale string in countdown function.
	AdCustomizerErrorEnum_COUNTDOWN_INVALID_LOCALE AdCustomizerErrorEnum_AdCustomizerError = 4
	// Days-before argument to countdown function is not positive.
	AdCustomizerErrorEnum_COUNTDOWN_INVALID_START_DAYS_BEFORE AdCustomizerErrorEnum_AdCustomizerError = 5
	// A user list referenced in an IF function does not exist.
	AdCustomizerErrorEnum_UNKNOWN_USER_LIST AdCustomizerErrorEnum_AdCustomizerError = 6
)

var AdCustomizerErrorEnum_AdCustomizerError_name = map[int32]string{
	0: "UNSPECIFIED",
	1: "UNKNOWN",
	2: "COUNTDOWN_INVALID_DATE_FORMAT",
	3: "COUNTDOWN_DATE_IN_PAST",
	4: "COUNTDOWN_INVALID_LOCALE",
	5: "COUNTDOWN_INVALID_START_DAYS_BEFORE",
	6: "UNKNOWN_USER_LIST",
}

var AdCustomizerErrorEnum_AdCustomizerError_value = map[string]int32{
	"UNSPECIFIED":                         0,
	"UNKNOWN":                             1,
	"COUNTDOWN_INVALID_DATE_FORMAT":       2,
	"COUNTDOWN_DATE_IN_PAST":              3,
	"COUNTDOWN_INVALID_LOCALE":            4,
	"COUNTDOWN_INVALID_START_DAYS_BEFORE": 5,
	"UNKNOWN_USER_LIST":                   6,
}

func (x AdCustomizerErrorEnum_AdCustomizerError) String() string {
	return proto.EnumName(AdCustomizerErrorEnum_AdCustomizerError_name, int32(x))
}

func (AdCustomizerErrorEnum_AdCustomizerError) EnumDescriptor() ([]byte, []int) {
	return fileDescriptor_bcf33080dbc92e14, []int{0, 0}
}

// Container for enum describing possible ad customizer errors.
type AdCustomizerErrorEnum struct {
	XXX_NoUnkeyedLiteral struct{} `json:"-"`
	XXX_unrecognized     []byte   `json:"-"`
	XXX_sizecache        int32    `json:"-"`
}

func (m *AdCustomizerErrorEnum) Reset()         { *m = AdCustomizerErrorEnum{} }
func (m *AdCustomizerErrorEnum) String() string { return proto.CompactTextString(m) }
func (*AdCustomizerErrorEnum) ProtoMessage()    {}
func (*AdCustomizerErrorEnum) Descriptor() ([]byte, []int) {
	return fileDescriptor_bcf33080dbc92e14, []int{0}
}

func (m *AdCustomizerErrorEnum) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_AdCustomizerErrorEnum.Unmarshal(m, b)
}
func (m *AdCustomizerErrorEnum) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_AdCustomizerErrorEnum.Marshal(b, m, deterministic)
}
func (m *AdCustomizerErrorEnum) XXX_Merge(src proto.Message) {
	xxx_messageInfo_AdCustomizerErrorEnum.Merge(m, src)
}
func (m *AdCustomizerErrorEnum) XXX_Size() int {
	return xxx_messageInfo_AdCustomizerErrorEnum.Size(m)
}
func (m *AdCustomizerErrorEnum) XXX_DiscardUnknown() {
	xxx_messageInfo_AdCustomizerErrorEnum.DiscardUnknown(m)
}

var xxx_messageInfo_AdCustomizerErrorEnum proto.InternalMessageInfo

func init() {
	proto.RegisterEnum("google.ads.googleads.v2.errors.AdCustomizerErrorEnum_AdCustomizerError", AdCustomizerErrorEnum_AdCustomizerError_name, AdCustomizerErrorEnum_AdCustomizerError_value)
	proto.RegisterType((*AdCustomizerErrorEnum)(nil), "google.ads.googleads.v2.errors.AdCustomizerErrorEnum")
}

func init() {
	proto.RegisterFile("google/ads/googleads/v2/errors/ad_customizer_error.proto", fileDescriptor_bcf33080dbc92e14)
}

var fileDescriptor_bcf33080dbc92e14 = []byte{
	// 386 bytes of a gzipped FileDescriptorProto
	0x1f, 0x8b, 0x08, 0x00, 0x00, 0x00, 0x00, 0x00, 0x02, 0xff, 0x7c, 0x91, 0xcf, 0x8a, 0xd4, 0x40,
	0x10, 0xc6, 0x4d, 0x56, 0x57, 0xe8, 0x3d, 0x98, 0x6d, 0xd8, 0x45, 0x96, 0x75, 0xc1, 0x78, 0xf0,
	0xd6, 0x81, 0x78, 0x91, 0xf6, 0xd4, 0x93, 0xf4, 0x0c, 0xc1, 0xd8, 0x09, 0xf9, 0x37, 0x28, 0x81,
	0x26, 0x4e, 0x42, 0x08, 0xcc, 0xa4, 0x87, 0x74, 0x66, 0x0e, 0x3e, 0x8e, 0x47, 0x1f, 0xc5, 0x83,
	0xcf, 0x21, 0xde, 0x7c, 0x03, 0x49, 0x7a, 0x26, 0x1e, 0x82, 0x9e, 0xf2, 0x51, 0xf5, 0xfb, 0x2a,
	0xd5, 0x5f, 0x81, 0xb7, 0xb5, 0x10, 0xf5, 0xb6, 0xb2, 0x8a, 0x52, 0x5a, 0x4a, 0x0e, 0xea, 0x68,
	0x5b, 0x55, 0xd7, 0x89, 0x4e, 0x5a, 0x45, 0xc9, 0x37, 0x07, 0xd9, 0x8b, 0x5d, 0xf3, 0xa5, 0xea,
	0xf8, 0x58, 0x44, 0xfb, 0x4e, 0xf4, 0x02, 0x3e, 0x28, 0x1c, 0x15, 0xa5, 0x44, 0x93, 0x13, 0x1d,
	0x6d, 0xa4, 0x9c, 0x77, 0xf7, 0xe7, 0xc9, 0xfb, 0xc6, 0x2a, 0xda, 0x56, 0xf4, 0x45, 0xdf, 0x88,
	0x56, 0x2a, 0xb7, 0xf9, 0x53, 0x03, 0x37, 0xa4, 0x74, 0xa6, 0xd1, 0x74, 0x30, 0xd1, 0xf6, 0xb0,
	0x33, 0x7f, 0x68, 0xe0, 0x7a, 0xd6, 0x81, 0xcf, 0xc0, 0x55, 0xca, 0xe2, 0x90, 0x3a, 0xde, 0xd2,
	0xa3, 0xae, 0xf1, 0x08, 0x5e, 0x81, 0xa7, 0x29, 0x7b, 0xcf, 0x82, 0x35, 0x33, 0x34, 0xf8, 0x12,
	0xbc, 0x70, 0x82, 0x94, 0x25, 0x6e, 0xb0, 0x66, 0xdc, 0x63, 0x19, 0xf1, 0x3d, 0x97, 0xbb, 0x24,
	0xa1, 0x7c, 0x19, 0x44, 0x1f, 0x48, 0x62, 0xe8, 0xf0, 0x0e, 0xdc, 0xfe, 0x45, 0xc6, 0x96, 0xc7,
	0x78, 0x48, 0xe2, 0xc4, 0xb8, 0x80, 0xf7, 0xe0, 0xf9, 0xdc, 0xee, 0x07, 0x0e, 0xf1, 0xa9, 0xf1,
	0x18, 0xbe, 0x06, 0xaf, 0xe6, 0xdd, 0x38, 0x21, 0x51, 0xc2, 0x5d, 0xf2, 0x31, 0xe6, 0x0b, 0xba,
	0x0c, 0x22, 0x6a, 0x3c, 0x81, 0x37, 0xe0, 0xfa, 0xb4, 0x12, 0x4f, 0x63, 0x1a, 0x71, 0xdf, 0x8b,
	0x13, 0xe3, 0x72, 0xf1, 0x5b, 0x03, 0xe6, 0x46, 0xec, 0xd0, 0xff, 0xf3, 0x5a, 0xdc, 0xce, 0x1e,
	0x1d, 0x0e, 0x49, 0x85, 0xda, 0x27, 0xf7, 0xe4, 0xac, 0xc5, 0xb6, 0x68, 0x6b, 0x24, 0xba, 0xda,
	0xaa, 0xab, 0x76, 0xcc, 0xf1, 0x7c, 0xb3, 0x7d, 0x23, 0xff, 0x75, 0xc2, 0x77, 0xea, 0xf3, 0x55,
	0xbf, 0x58, 0x11, 0xf2, 0x4d, 0x7f, 0x58, 0xa9, 0x61, 0xa4, 0x94, 0x48, 0xc9, 0x41, 0x65, 0x36,
	0x1a, 0x7f, 0x29, 0xbf, 0x9f, 0x81, 0x9c, 0x94, 0x32, 0x9f, 0x80, 0x3c, 0xb3, 0x73, 0x05, 0xfc,
	0xd2, 0x4d, 0x55, 0xc5, 0x98, 0x94, 0x12, 0xe3, 0x09, 0xc1, 0x38, 0xb3, 0x31, 0x56, 0xd0, 0xe7,
	0xcb, 0x71, 0xbb, 0x37, 0x7f, 0x02, 0x00, 0x00, 0xff, 0xff, 0xc2, 0xb8, 0xa0, 0x43, 0x5f, 0x02,
	0x00, 0x00,
}
