// Code generated by protoc-gen-go. DO NOT EDIT.
// source: google/ads/googleads/v2/resources/payments_account.proto

package resources

import (
	fmt "fmt"
	math "math"

	proto "github.com/golang/protobuf/proto"
	wrappers "github.com/golang/protobuf/ptypes/wrappers"
	_ "google.golang.org/genproto/googleapis/api/annotations"
)

// Reference imports to suppress errors if they are not otherwise used.
var _ = proto.Marshal
var _ = fmt.Errorf
var _ = math.Inf

// This is a compile-time assertion to ensure that this generated file
// is compatible with the proto package it is being compiled against.
// A compilation error at this line likely means your copy of the
// proto package needs to be updated.
const _ = proto.ProtoPackageIsVersion3 // please upgrade the proto package

// A Payments account, which can be used to set up billing for an Ads customer.
type PaymentsAccount struct {
	// The resource name of the Payments account.
	// PaymentsAccount resource names have the form:
	//
	// `customers/{customer_id}/paymentsAccounts/{payments_account_id}`
	ResourceName string `protobuf:"bytes,1,opt,name=resource_name,json=resourceName,proto3" json:"resource_name,omitempty"`
	// A 16 digit ID used to identify a Payments account.
	PaymentsAccountId *wrappers.StringValue `protobuf:"bytes,2,opt,name=payments_account_id,json=paymentsAccountId,proto3" json:"payments_account_id,omitempty"`
	// The name of the Payments account.
	Name *wrappers.StringValue `protobuf:"bytes,3,opt,name=name,proto3" json:"name,omitempty"`
	// The currency code of the Payments account.
	// A subset of the currency codes derived from the ISO 4217 standard is
	// supported.
	CurrencyCode *wrappers.StringValue `protobuf:"bytes,4,opt,name=currency_code,json=currencyCode,proto3" json:"currency_code,omitempty"`
	// A 12 digit ID used to identify the Payments profile associated with the
	// Payments account.
	PaymentsProfileId *wrappers.StringValue `protobuf:"bytes,5,opt,name=payments_profile_id,json=paymentsProfileId,proto3" json:"payments_profile_id,omitempty"`
	// A secondary Payments profile ID present in uncommon situations, e.g.
	// when a sequential liability agreement has been arranged.
	SecondaryPaymentsProfileId *wrappers.StringValue `protobuf:"bytes,6,opt,name=secondary_payments_profile_id,json=secondaryPaymentsProfileId,proto3" json:"secondary_payments_profile_id,omitempty"`
	XXX_NoUnkeyedLiteral       struct{}              `json:"-"`
	XXX_unrecognized           []byte                `json:"-"`
	XXX_sizecache              int32                 `json:"-"`
}

func (m *PaymentsAccount) Reset()         { *m = PaymentsAccount{} }
func (m *PaymentsAccount) String() string { return proto.CompactTextString(m) }
func (*PaymentsAccount) ProtoMessage()    {}
func (*PaymentsAccount) Descriptor() ([]byte, []int) {
	return fileDescriptor_34c461c9d9699366, []int{0}
}

func (m *PaymentsAccount) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_PaymentsAccount.Unmarshal(m, b)
}
func (m *PaymentsAccount) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_PaymentsAccount.Marshal(b, m, deterministic)
}
func (m *PaymentsAccount) XXX_Merge(src proto.Message) {
	xxx_messageInfo_PaymentsAccount.Merge(m, src)
}
func (m *PaymentsAccount) XXX_Size() int {
	return xxx_messageInfo_PaymentsAccount.Size(m)
}
func (m *PaymentsAccount) XXX_DiscardUnknown() {
	xxx_messageInfo_PaymentsAccount.DiscardUnknown(m)
}

var xxx_messageInfo_PaymentsAccount proto.InternalMessageInfo

func (m *PaymentsAccount) GetResourceName() string {
	if m != nil {
		return m.ResourceName
	}
	return ""
}

func (m *PaymentsAccount) GetPaymentsAccountId() *wrappers.StringValue {
	if m != nil {
		return m.PaymentsAccountId
	}
	return nil
}

func (m *PaymentsAccount) GetName() *wrappers.StringValue {
	if m != nil {
		return m.Name
	}
	return nil
}

func (m *PaymentsAccount) GetCurrencyCode() *wrappers.StringValue {
	if m != nil {
		return m.CurrencyCode
	}
	return nil
}

func (m *PaymentsAccount) GetPaymentsProfileId() *wrappers.StringValue {
	if m != nil {
		return m.PaymentsProfileId
	}
	return nil
}

func (m *PaymentsAccount) GetSecondaryPaymentsProfileId() *wrappers.StringValue {
	if m != nil {
		return m.SecondaryPaymentsProfileId
	}
	return nil
}

func init() {
	proto.RegisterType((*PaymentsAccount)(nil), "google.ads.googleads.v2.resources.PaymentsAccount")
}

func init() {
	proto.RegisterFile("google/ads/googleads/v2/resources/payments_account.proto", fileDescriptor_34c461c9d9699366)
}

var fileDescriptor_34c461c9d9699366 = []byte{
	// 397 bytes of a gzipped FileDescriptorProto
	0x1f, 0x8b, 0x08, 0x00, 0x00, 0x00, 0x00, 0x00, 0x02, 0xff, 0x94, 0x52, 0x4f, 0xcb, 0xd3, 0x30,
	0x18, 0xa7, 0xdd, 0xeb, 0x0b, 0xc6, 0x77, 0x88, 0xd5, 0xc3, 0x18, 0x53, 0x36, 0x65, 0xb0, 0x53,
	0x2a, 0xf5, 0x22, 0xf1, 0xd4, 0x79, 0x18, 0x13, 0x91, 0x32, 0xa1, 0x07, 0x29, 0x94, 0x2c, 0xc9,
	0x4a, 0xa1, 0x4d, 0x42, 0xd2, 0x4e, 0x76, 0xf4, 0xab, 0x78, 0x12, 0x3f, 0x8a, 0x1f, 0xc5, 0x4f,
	0x21, 0x6d, 0x9a, 0xc0, 0x86, 0xe8, 0xde, 0xdb, 0x8f, 0x3c, 0xbf, 0x7f, 0x0f, 0x79, 0xc0, 0xdb,
	0x42, 0x88, 0xa2, 0x62, 0x21, 0xa6, 0x3a, 0x34, 0xb0, 0x43, 0xc7, 0x28, 0x54, 0x4c, 0x8b, 0x56,
	0x11, 0xa6, 0x43, 0x89, 0x4f, 0x35, 0xe3, 0x8d, 0xce, 0x31, 0x21, 0xa2, 0xe5, 0x0d, 0x94, 0x4a,
	0x34, 0x22, 0x58, 0x18, 0x3a, 0xc4, 0x54, 0x43, 0xa7, 0x84, 0xc7, 0x08, 0x3a, 0xe5, 0xf4, 0xc5,
	0x60, 0xde, 0x0b, 0xf6, 0xed, 0x21, 0xfc, 0xaa, 0xb0, 0x94, 0x4c, 0x69, 0x63, 0x31, 0x9d, 0xd9,
	0x70, 0x59, 0x86, 0x98, 0x73, 0xd1, 0xe0, 0xa6, 0x14, 0x7c, 0x98, 0xbe, 0xfc, 0x31, 0x02, 0x8f,
	0x93, 0x21, 0x3b, 0x36, 0xd1, 0xc1, 0x2b, 0x30, 0xb6, 0xf6, 0x39, 0xc7, 0x35, 0x9b, 0x78, 0x73,
	0x6f, 0xf5, 0x70, 0x77, 0x67, 0x1f, 0x3f, 0xe1, 0x9a, 0x05, 0x1f, 0xc1, 0xd3, 0xcb, 0xce, 0x79,
	0x49, 0x27, 0xfe, 0xdc, 0x5b, 0x3d, 0x8a, 0x66, 0x43, 0x59, 0x68, 0x4b, 0xc1, 0xcf, 0x8d, 0x2a,
	0x79, 0x91, 0xe2, 0xaa, 0x65, 0xbb, 0x27, 0xf2, 0x3c, 0x70, 0x4b, 0x83, 0xd7, 0xe0, 0xa6, 0x4f,
	0x1a, 0x5d, 0x21, 0xef, 0x99, 0x41, 0x0c, 0xc6, 0xa4, 0x55, 0x8a, 0x71, 0x72, 0xca, 0x89, 0xa0,
	0x6c, 0x72, 0x73, 0x85, 0xf4, 0xce, 0x4a, 0xde, 0x0b, 0x7a, 0xbe, 0x82, 0x54, 0xe2, 0x50, 0x56,
	0xac, 0x5b, 0xe1, 0xc1, 0x7d, 0x56, 0x48, 0x8c, 0x6e, 0x4b, 0x83, 0x1c, 0x3c, 0xd7, 0x8c, 0x08,
	0x4e, 0xb1, 0x3a, 0xe5, 0x7f, 0xf3, 0xbd, 0xbd, 0xc2, 0x77, 0xea, 0x2c, 0x92, 0xcb, 0x80, 0xf5,
	0x37, 0x1f, 0x2c, 0x89, 0xa8, 0xe1, 0x7f, 0x4f, 0x62, 0xfd, 0xec, 0xe2, 0x47, 0x93, 0x2e, 0x2a,
	0xf1, 0xbe, 0x7c, 0x18, 0xa4, 0x85, 0xa8, 0x30, 0x2f, 0xa0, 0x50, 0x45, 0x58, 0x30, 0xde, 0x17,
	0xb1, 0x77, 0x29, 0x4b, 0xfd, 0x8f, 0x33, 0x7d, 0xe7, 0xd0, 0x77, 0x7f, 0xb4, 0x89, 0xe3, 0x9f,
	0xfe, 0x62, 0x63, 0x2c, 0x63, 0xaa, 0xa1, 0x81, 0x1d, 0x4a, 0x23, 0xb8, 0xb3, 0xcc, 0x5f, 0x96,
	0x93, 0xc5, 0x54, 0x67, 0x8e, 0x93, 0xa5, 0x51, 0xe6, 0x38, 0xbf, 0xfd, 0xa5, 0x19, 0x20, 0x14,
	0x53, 0x8d, 0x90, 0x63, 0x21, 0x94, 0x46, 0x08, 0x39, 0xde, 0xfe, 0xb6, 0x2f, 0xfb, 0xe6, 0x4f,
	0x00, 0x00, 0x00, 0xff, 0xff, 0xee, 0x01, 0xe5, 0x26, 0x52, 0x03, 0x00, 0x00,
}
