// Code generated by protoc-gen-go. DO NOT EDIT.
// source: google/ads/googleads/v2/services/hotel_group_view_service.proto

package services

import (
	context "context"
	fmt "fmt"
	math "math"

	proto "github.com/golang/protobuf/proto"
	resources "google.golang.org/genproto/googleapis/ads/googleads/v2/resources"
	_ "google.golang.org/genproto/googleapis/api/annotations"
	grpc "google.golang.org/grpc"
)

// Reference imports to suppress errors if they are not otherwise used.
var _ = proto.Marshal
var _ = fmt.Errorf
var _ = math.Inf

// This is a compile-time assertion to ensure that this generated file
// is compatible with the proto package it is being compiled against.
// A compilation error at this line likely means your copy of the
// proto package needs to be updated.
const _ = proto.ProtoPackageIsVersion3 // please upgrade the proto package

// Request message for [HotelGroupViewService.GetHotelGroupView][google.ads.googleads.v2.services.HotelGroupViewService.GetHotelGroupView].
type GetHotelGroupViewRequest struct {
	// Resource name of the Hotel Group View to fetch.
	ResourceName         string   `protobuf:"bytes,1,opt,name=resource_name,json=resourceName,proto3" json:"resource_name,omitempty"`
	XXX_NoUnkeyedLiteral struct{} `json:"-"`
	XXX_unrecognized     []byte   `json:"-"`
	XXX_sizecache        int32    `json:"-"`
}

func (m *GetHotelGroupViewRequest) Reset()         { *m = GetHotelGroupViewRequest{} }
func (m *GetHotelGroupViewRequest) String() string { return proto.CompactTextString(m) }
func (*GetHotelGroupViewRequest) ProtoMessage()    {}
func (*GetHotelGroupViewRequest) Descriptor() ([]byte, []int) {
	return fileDescriptor_879c80fa4777e520, []int{0}
}

func (m *GetHotelGroupViewRequest) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_GetHotelGroupViewRequest.Unmarshal(m, b)
}
func (m *GetHotelGroupViewRequest) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_GetHotelGroupViewRequest.Marshal(b, m, deterministic)
}
func (m *GetHotelGroupViewRequest) XXX_Merge(src proto.Message) {
	xxx_messageInfo_GetHotelGroupViewRequest.Merge(m, src)
}
func (m *GetHotelGroupViewRequest) XXX_Size() int {
	return xxx_messageInfo_GetHotelGroupViewRequest.Size(m)
}
func (m *GetHotelGroupViewRequest) XXX_DiscardUnknown() {
	xxx_messageInfo_GetHotelGroupViewRequest.DiscardUnknown(m)
}

var xxx_messageInfo_GetHotelGroupViewRequest proto.InternalMessageInfo

func (m *GetHotelGroupViewRequest) GetResourceName() string {
	if m != nil {
		return m.ResourceName
	}
	return ""
}

func init() {
	proto.RegisterType((*GetHotelGroupViewRequest)(nil), "google.ads.googleads.v2.services.GetHotelGroupViewRequest")
}

func init() {
	proto.RegisterFile("google/ads/googleads/v2/services/hotel_group_view_service.proto", fileDescriptor_879c80fa4777e520)
}

var fileDescriptor_879c80fa4777e520 = []byte{
	// 394 bytes of a gzipped FileDescriptorProto
	0x1f, 0x8b, 0x08, 0x00, 0x00, 0x00, 0x00, 0x00, 0x02, 0xff, 0x84, 0x52, 0xcf, 0x6a, 0xa3, 0x40,
	0x18, 0x47, 0x17, 0x16, 0x56, 0x76, 0x0f, 0x2b, 0x2c, 0x1b, 0xdc, 0x3d, 0x84, 0x6c, 0x0e, 0x4b,
	0x0e, 0x33, 0xc4, 0x5c, 0x76, 0xa7, 0x94, 0x60, 0x2e, 0xe6, 0x54, 0x42, 0x0a, 0x1e, 0x8a, 0x20,
	0x56, 0x07, 0x2b, 0xa8, 0x63, 0xfd, 0x46, 0x73, 0x28, 0x3d, 0xb4, 0xaf, 0xd0, 0x37, 0xe8, 0xb1,
	0xef, 0xd0, 0x17, 0xc8, 0xb5, 0xaf, 0xd0, 0x53, 0xcf, 0x7d, 0x80, 0x62, 0xc6, 0x31, 0x0d, 0x8d,
	0xe4, 0xf6, 0x63, 0xbe, 0xdf, 0x9f, 0xef, 0xfb, 0xa9, 0x36, 0x8d, 0x18, 0x8b, 0x12, 0x8a, 0xfd,
	0x10, 0xb0, 0x80, 0x35, 0xaa, 0x4c, 0x0c, 0xb4, 0xa8, 0xe2, 0x80, 0x02, 0xbe, 0x60, 0x9c, 0x26,
	0x5e, 0x54, 0xb0, 0x32, 0xf7, 0xaa, 0x98, 0xae, 0xbc, 0x66, 0x82, 0xf2, 0x82, 0x71, 0xa6, 0xf7,
	0x85, 0x0a, 0xf9, 0x21, 0xa0, 0xd6, 0x00, 0x55, 0x26, 0x92, 0x06, 0xc6, 0xbf, 0xae, 0x88, 0x82,
	0x02, 0x2b, 0x8b, 0x7d, 0x19, 0xc2, 0xdb, 0xf8, 0x2d, 0x95, 0x79, 0x8c, 0xfd, 0x2c, 0x63, 0xdc,
	0xe7, 0x31, 0xcb, 0xa0, 0x99, 0xfe, 0x7c, 0x37, 0x0d, 0x92, 0x98, 0x66, 0x5c, 0x0c, 0x06, 0x53,
	0xad, 0x67, 0x53, 0x3e, 0xaf, 0x3d, 0xed, 0xda, 0xd2, 0x89, 0xe9, 0x6a, 0x49, 0x2f, 0x4b, 0x0a,
	0x5c, 0xff, 0xa3, 0x7d, 0x93, 0xb1, 0x5e, 0xe6, 0xa7, 0xb4, 0xa7, 0xf4, 0x95, 0xbf, 0x5f, 0x96,
	0x5f, 0xe5, 0xe3, 0x89, 0x9f, 0x52, 0xf3, 0x55, 0xd1, 0x7e, 0xec, 0xca, 0x4f, 0xc5, 0x31, 0xfa,
	0xa3, 0xa2, 0x7d, 0xff, 0xe0, 0xad, 0x13, 0x74, 0xa8, 0x04, 0xd4, 0xb5, 0x90, 0x31, 0xee, 0xd4,
	0xb6, 0xf5, 0xa0, 0x5d, 0xe5, 0xe0, 0xff, 0xed, 0xd3, 0xf3, 0x9d, 0x3a, 0xd1, 0xc7, 0x75, 0x89,
	0x57, 0x3b, 0xe7, 0x1c, 0x07, 0x25, 0x70, 0x96, 0xd2, 0x02, 0xf0, 0x48, 0xb4, 0xda, 0xca, 0x00,
	0x8f, 0xae, 0x8d, 0x5f, 0x6b, 0xab, 0xb7, 0x0d, 0x69, 0x50, 0x1e, 0x03, 0x0a, 0x58, 0x3a, 0xbb,
	0x51, 0xb5, 0x61, 0xc0, 0xd2, 0x83, 0xc7, 0xcc, 0x8c, 0xbd, 0xe5, 0x2c, 0xea, 0xf2, 0x17, 0xca,
	0xd9, 0xbc, 0xd1, 0x47, 0x2c, 0xf1, 0xb3, 0x08, 0xb1, 0x22, 0xc2, 0x11, 0xcd, 0x36, 0x9f, 0x06,
	0x6f, 0x13, 0xbb, 0xff, 0xb8, 0x23, 0x09, 0xee, 0xd5, 0x4f, 0xb6, 0x65, 0x3d, 0xa8, 0x7d, 0x5b,
	0x18, 0x5a, 0x21, 0x20, 0x01, 0x6b, 0xe4, 0x98, 0xa8, 0x09, 0x86, 0xb5, 0xa4, 0xb8, 0x56, 0x08,
	0x6e, 0x4b, 0x71, 0x1d, 0xd3, 0x95, 0x94, 0x17, 0x75, 0x28, 0xde, 0x09, 0xb1, 0x42, 0x20, 0xa4,
	0x25, 0x11, 0xe2, 0x98, 0x84, 0x48, 0xda, 0xf9, 0xe7, 0xcd, 0x9e, 0x93, 0xb7, 0x00, 0x00, 0x00,
	0xff, 0xff, 0xac, 0xdd, 0xea, 0xdb, 0x18, 0x03, 0x00, 0x00,
}

// Reference imports to suppress errors if they are not otherwise used.
var _ context.Context
var _ grpc.ClientConn

// This is a compile-time assertion to ensure that this generated file
// is compatible with the grpc package it is being compiled against.
const _ = grpc.SupportPackageIsVersion4

// HotelGroupViewServiceClient is the client API for HotelGroupViewService service.
//
// For semantics around ctx use and closing/ending streaming RPCs, please refer to https://godoc.org/google.golang.org/grpc#ClientConn.NewStream.
type HotelGroupViewServiceClient interface {
	// Returns the requested Hotel Group View in full detail.
	GetHotelGroupView(ctx context.Context, in *GetHotelGroupViewRequest, opts ...grpc.CallOption) (*resources.HotelGroupView, error)
}

type hotelGroupViewServiceClient struct {
	cc *grpc.ClientConn
}

func NewHotelGroupViewServiceClient(cc *grpc.ClientConn) HotelGroupViewServiceClient {
	return &hotelGroupViewServiceClient{cc}
}

func (c *hotelGroupViewServiceClient) GetHotelGroupView(ctx context.Context, in *GetHotelGroupViewRequest, opts ...grpc.CallOption) (*resources.HotelGroupView, error) {
	out := new(resources.HotelGroupView)
	err := c.cc.Invoke(ctx, "/google.ads.googleads.v2.services.HotelGroupViewService/GetHotelGroupView", in, out, opts...)
	if err != nil {
		return nil, err
	}
	return out, nil
}

// HotelGroupViewServiceServer is the server API for HotelGroupViewService service.
type HotelGroupViewServiceServer interface {
	// Returns the requested Hotel Group View in full detail.
	GetHotelGroupView(context.Context, *GetHotelGroupViewRequest) (*resources.HotelGroupView, error)
}

func RegisterHotelGroupViewServiceServer(s *grpc.Server, srv HotelGroupViewServiceServer) {
	s.RegisterService(&_HotelGroupViewService_serviceDesc, srv)
}

func _HotelGroupViewService_GetHotelGroupView_Handler(srv interface{}, ctx context.Context, dec func(interface{}) error, interceptor grpc.UnaryServerInterceptor) (interface{}, error) {
	in := new(GetHotelGroupViewRequest)
	if err := dec(in); err != nil {
		return nil, err
	}
	if interceptor == nil {
		return srv.(HotelGroupViewServiceServer).GetHotelGroupView(ctx, in)
	}
	info := &grpc.UnaryServerInfo{
		Server:     srv,
		FullMethod: "/google.ads.googleads.v2.services.HotelGroupViewService/GetHotelGroupView",
	}
	handler := func(ctx context.Context, req interface{}) (interface{}, error) {
		return srv.(HotelGroupViewServiceServer).GetHotelGroupView(ctx, req.(*GetHotelGroupViewRequest))
	}
	return interceptor(ctx, in, info, handler)
}

var _HotelGroupViewService_serviceDesc = grpc.ServiceDesc{
	ServiceName: "google.ads.googleads.v2.services.HotelGroupViewService",
	HandlerType: (*HotelGroupViewServiceServer)(nil),
	Methods: []grpc.MethodDesc{
		{
			MethodName: "GetHotelGroupView",
			Handler:    _HotelGroupViewService_GetHotelGroupView_Handler,
		},
	},
	Streams:  []grpc.StreamDesc{},
	Metadata: "google/ads/googleads/v2/services/hotel_group_view_service.proto",
}
