// Code generated by protoc-gen-go. DO NOT EDIT.
// source: google/ads/googleads/v2/services/display_keyword_view_service.proto

package services

import (
	context "context"
	fmt "fmt"
	math "math"

	proto "github.com/golang/protobuf/proto"
	resources "google.golang.org/genproto/googleapis/ads/googleads/v2/resources"
	_ "google.golang.org/genproto/googleapis/api/annotations"
	grpc "google.golang.org/grpc"
)

// Reference imports to suppress errors if they are not otherwise used.
var _ = proto.Marshal
var _ = fmt.Errorf
var _ = math.Inf

// This is a compile-time assertion to ensure that this generated file
// is compatible with the proto package it is being compiled against.
// A compilation error at this line likely means your copy of the
// proto package needs to be updated.
const _ = proto.ProtoPackageIsVersion3 // please upgrade the proto package

// Request message for [DisplayKeywordViewService.GetDisplayKeywordView][google.ads.googleads.v2.services.DisplayKeywordViewService.GetDisplayKeywordView].
type GetDisplayKeywordViewRequest struct {
	// The resource name of the display keyword view to fetch.
	ResourceName         string   `protobuf:"bytes,1,opt,name=resource_name,json=resourceName,proto3" json:"resource_name,omitempty"`
	XXX_NoUnkeyedLiteral struct{} `json:"-"`
	XXX_unrecognized     []byte   `json:"-"`
	XXX_sizecache        int32    `json:"-"`
}

func (m *GetDisplayKeywordViewRequest) Reset()         { *m = GetDisplayKeywordViewRequest{} }
func (m *GetDisplayKeywordViewRequest) String() string { return proto.CompactTextString(m) }
func (*GetDisplayKeywordViewRequest) ProtoMessage()    {}
func (*GetDisplayKeywordViewRequest) Descriptor() ([]byte, []int) {
	return fileDescriptor_4afaa60c29d9a48e, []int{0}
}

func (m *GetDisplayKeywordViewRequest) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_GetDisplayKeywordViewRequest.Unmarshal(m, b)
}
func (m *GetDisplayKeywordViewRequest) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_GetDisplayKeywordViewRequest.Marshal(b, m, deterministic)
}
func (m *GetDisplayKeywordViewRequest) XXX_Merge(src proto.Message) {
	xxx_messageInfo_GetDisplayKeywordViewRequest.Merge(m, src)
}
func (m *GetDisplayKeywordViewRequest) XXX_Size() int {
	return xxx_messageInfo_GetDisplayKeywordViewRequest.Size(m)
}
func (m *GetDisplayKeywordViewRequest) XXX_DiscardUnknown() {
	xxx_messageInfo_GetDisplayKeywordViewRequest.DiscardUnknown(m)
}

var xxx_messageInfo_GetDisplayKeywordViewRequest proto.InternalMessageInfo

func (m *GetDisplayKeywordViewRequest) GetResourceName() string {
	if m != nil {
		return m.ResourceName
	}
	return ""
}

func init() {
	proto.RegisterType((*GetDisplayKeywordViewRequest)(nil), "google.ads.googleads.v2.services.GetDisplayKeywordViewRequest")
}

func init() {
	proto.RegisterFile("google/ads/googleads/v2/services/display_keyword_view_service.proto", fileDescriptor_4afaa60c29d9a48e)
}

var fileDescriptor_4afaa60c29d9a48e = []byte{
	// 400 bytes of a gzipped FileDescriptorProto
	0x1f, 0x8b, 0x08, 0x00, 0x00, 0x00, 0x00, 0x00, 0x02, 0xff, 0x84, 0x52, 0xcf, 0x8a, 0xd3, 0x40,
	0x18, 0x27, 0x11, 0x04, 0x83, 0x5e, 0x02, 0x62, 0x8d, 0x45, 0x4a, 0xed, 0x41, 0x7a, 0x98, 0x81,
	0x48, 0x11, 0x46, 0x2b, 0xa4, 0x15, 0x2a, 0x08, 0x52, 0x2a, 0xe4, 0x20, 0x81, 0x30, 0x26, 0x43,
	0x18, 0x4c, 0x32, 0x31, 0x5f, 0x9a, 0x52, 0xc4, 0xcb, 0xc2, 0xc2, 0xde, 0xf7, 0x0d, 0xf6, 0xb8,
	0x8f, 0x52, 0xd8, 0xd3, 0xbe, 0xc2, 0x9e, 0xf6, 0x29, 0x96, 0x74, 0x32, 0x69, 0x97, 0x6e, 0xb6,
	0xb7, 0x1f, 0xf3, 0xfd, 0xfe, 0xcc, 0xf7, 0x9b, 0x31, 0xa6, 0x91, 0x10, 0x51, 0xcc, 0x30, 0x0d,
	0x01, 0x4b, 0x58, 0xa1, 0xd2, 0xc6, 0xc0, 0xf2, 0x92, 0x07, 0x0c, 0x70, 0xc8, 0x21, 0x8b, 0xe9,
	0xda, 0xff, 0xc3, 0xd6, 0x2b, 0x91, 0x87, 0x7e, 0xc9, 0xd9, 0xca, 0xaf, 0xa7, 0x28, 0xcb, 0x45,
	0x21, 0xcc, 0x9e, 0x54, 0x22, 0x1a, 0x02, 0x6a, 0x4c, 0x50, 0x69, 0x23, 0x65, 0x62, 0x7d, 0x6e,
	0x8b, 0xc9, 0x19, 0x88, 0x65, 0xde, 0x96, 0x23, 0xfd, 0xad, 0xae, 0x52, 0x67, 0x1c, 0xd3, 0x34,
	0x15, 0x05, 0x2d, 0xb8, 0x48, 0xa1, 0x9e, 0xbe, 0xda, 0x9b, 0x06, 0x31, 0x67, 0x69, 0x21, 0x07,
	0xfd, 0xa9, 0xd1, 0x9d, 0xb1, 0xe2, 0xab, 0xf4, 0xfd, 0x2e, 0x6d, 0x5d, 0xce, 0x56, 0x0b, 0xf6,
	0x77, 0xc9, 0xa0, 0x30, 0xdf, 0x19, 0x2f, 0x54, 0xbc, 0x9f, 0xd2, 0x84, 0x75, 0xb4, 0x9e, 0xf6,
	0xfe, 0xd9, 0xe2, 0xb9, 0x3a, 0xfc, 0x41, 0x13, 0x66, 0x9f, 0xe9, 0xc6, 0xeb, 0x43, 0x8b, 0x9f,
	0x72, 0x31, 0xf3, 0x4a, 0x33, 0x5e, 0x3e, 0x98, 0x61, 0x7e, 0x41, 0xc7, 0x4a, 0x41, 0x8f, 0x5d,
	0xce, 0x1a, 0xb5, 0xea, 0x9b, 0xca, 0xd0, 0xa1, 0xba, 0x3f, 0x3e, 0xb9, 0xbe, 0x39, 0xd7, 0x3f,
	0x9a, 0xa3, 0xaa, 0xdc, 0x7f, 0xf7, 0xd6, 0x1b, 0x07, 0x4b, 0x28, 0x44, 0xc2, 0x72, 0xc0, 0x43,
	0xd5, 0xf6, 0x9e, 0x14, 0xf0, 0xf0, 0xbf, 0xf5, 0x66, 0xe3, 0x74, 0x76, 0x61, 0x35, 0xca, 0x38,
	0xa0, 0x40, 0x24, 0x93, 0x53, 0xdd, 0x18, 0x04, 0x22, 0x39, 0xba, 0xd8, 0xe4, 0x6d, 0x6b, 0x61,
	0xf3, 0xea, 0x61, 0xe6, 0xda, 0xaf, 0x6f, 0xb5, 0x47, 0x24, 0x62, 0x9a, 0x46, 0x48, 0xe4, 0x11,
	0x8e, 0x58, 0xba, 0x7d, 0x36, 0xbc, 0x4b, 0x6d, 0xff, 0x95, 0x9f, 0x14, 0xb8, 0xd0, 0x9f, 0xcc,
	0x1c, 0xe7, 0x52, 0xef, 0xcd, 0xa4, 0xa1, 0x13, 0x02, 0x92, 0xb0, 0x42, 0xae, 0x8d, 0xea, 0x60,
	0xd8, 0x28, 0x8a, 0xe7, 0x84, 0xe0, 0x35, 0x14, 0xcf, 0xb5, 0x3d, 0x45, 0xb9, 0xd5, 0x07, 0xf2,
	0x9c, 0x10, 0x27, 0x04, 0x42, 0x1a, 0x12, 0x21, 0xae, 0x4d, 0x88, 0xa2, 0xfd, 0x7e, 0xba, 0xbd,
	0xe7, 0x87, 0xbb, 0x00, 0x00, 0x00, 0xff, 0xff, 0xfb, 0x1e, 0x09, 0x1b, 0x3c, 0x03, 0x00, 0x00,
}

// Reference imports to suppress errors if they are not otherwise used.
var _ context.Context
var _ grpc.ClientConn

// This is a compile-time assertion to ensure that this generated file
// is compatible with the grpc package it is being compiled against.
const _ = grpc.SupportPackageIsVersion4

// DisplayKeywordViewServiceClient is the client API for DisplayKeywordViewService service.
//
// For semantics around ctx use and closing/ending streaming RPCs, please refer to https://godoc.org/google.golang.org/grpc#ClientConn.NewStream.
type DisplayKeywordViewServiceClient interface {
	// Returns the requested display keyword view in full detail.
	GetDisplayKeywordView(ctx context.Context, in *GetDisplayKeywordViewRequest, opts ...grpc.CallOption) (*resources.DisplayKeywordView, error)
}

type displayKeywordViewServiceClient struct {
	cc *grpc.ClientConn
}

func NewDisplayKeywordViewServiceClient(cc *grpc.ClientConn) DisplayKeywordViewServiceClient {
	return &displayKeywordViewServiceClient{cc}
}

func (c *displayKeywordViewServiceClient) GetDisplayKeywordView(ctx context.Context, in *GetDisplayKeywordViewRequest, opts ...grpc.CallOption) (*resources.DisplayKeywordView, error) {
	out := new(resources.DisplayKeywordView)
	err := c.cc.Invoke(ctx, "/google.ads.googleads.v2.services.DisplayKeywordViewService/GetDisplayKeywordView", in, out, opts...)
	if err != nil {
		return nil, err
	}
	return out, nil
}

// DisplayKeywordViewServiceServer is the server API for DisplayKeywordViewService service.
type DisplayKeywordViewServiceServer interface {
	// Returns the requested display keyword view in full detail.
	GetDisplayKeywordView(context.Context, *GetDisplayKeywordViewRequest) (*resources.DisplayKeywordView, error)
}

func RegisterDisplayKeywordViewServiceServer(s *grpc.Server, srv DisplayKeywordViewServiceServer) {
	s.RegisterService(&_DisplayKeywordViewService_serviceDesc, srv)
}

func _DisplayKeywordViewService_GetDisplayKeywordView_Handler(srv interface{}, ctx context.Context, dec func(interface{}) error, interceptor grpc.UnaryServerInterceptor) (interface{}, error) {
	in := new(GetDisplayKeywordViewRequest)
	if err := dec(in); err != nil {
		return nil, err
	}
	if interceptor == nil {
		return srv.(DisplayKeywordViewServiceServer).GetDisplayKeywordView(ctx, in)
	}
	info := &grpc.UnaryServerInfo{
		Server:     srv,
		FullMethod: "/google.ads.googleads.v2.services.DisplayKeywordViewService/GetDisplayKeywordView",
	}
	handler := func(ctx context.Context, req interface{}) (interface{}, error) {
		return srv.(DisplayKeywordViewServiceServer).GetDisplayKeywordView(ctx, req.(*GetDisplayKeywordViewRequest))
	}
	return interceptor(ctx, in, info, handler)
}

var _DisplayKeywordViewService_serviceDesc = grpc.ServiceDesc{
	ServiceName: "google.ads.googleads.v2.services.DisplayKeywordViewService",
	HandlerType: (*DisplayKeywordViewServiceServer)(nil),
	Methods: []grpc.MethodDesc{
		{
			MethodName: "GetDisplayKeywordView",
			Handler:    _DisplayKeywordViewService_GetDisplayKeywordView_Handler,
		},
	},
	Streams:  []grpc.StreamDesc{},
	Metadata: "google/ads/googleads/v2/services/display_keyword_view_service.proto",
}
