// Code generated by protoc-gen-go. DO NOT EDIT.
// source: google/ads/googleads/v2/resources/campaign_label.proto

package resources

import (
	fmt "fmt"
	math "math"

	proto "github.com/golang/protobuf/proto"
	wrappers "github.com/golang/protobuf/ptypes/wrappers"
	_ "google.golang.org/genproto/googleapis/api/annotations"
)

// Reference imports to suppress errors if they are not otherwise used.
var _ = proto.Marshal
var _ = fmt.Errorf
var _ = math.Inf

// This is a compile-time assertion to ensure that this generated file
// is compatible with the proto package it is being compiled against.
// A compilation error at this line likely means your copy of the
// proto package needs to be updated.
const _ = proto.ProtoPackageIsVersion3 // please upgrade the proto package

// Represents a relationship between a campaign and a label.
type CampaignLabel struct {
	// Name of the resource.
	// Campaign label resource names have the form:
	// `customers/{customer_id}/campaignLabels/{campaign_id}~{label_id}`
	ResourceName string `protobuf:"bytes,1,opt,name=resource_name,json=resourceName,proto3" json:"resource_name,omitempty"`
	// The campaign to which the label is attached.
	Campaign *wrappers.StringValue `protobuf:"bytes,2,opt,name=campaign,proto3" json:"campaign,omitempty"`
	// The label assigned to the campaign.
	Label                *wrappers.StringValue `protobuf:"bytes,3,opt,name=label,proto3" json:"label,omitempty"`
	XXX_NoUnkeyedLiteral struct{}              `json:"-"`
	XXX_unrecognized     []byte                `json:"-"`
	XXX_sizecache        int32                 `json:"-"`
}

func (m *CampaignLabel) Reset()         { *m = CampaignLabel{} }
func (m *CampaignLabel) String() string { return proto.CompactTextString(m) }
func (*CampaignLabel) ProtoMessage()    {}
func (*CampaignLabel) Descriptor() ([]byte, []int) {
	return fileDescriptor_1a6c77ba70ba8330, []int{0}
}

func (m *CampaignLabel) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_CampaignLabel.Unmarshal(m, b)
}
func (m *CampaignLabel) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_CampaignLabel.Marshal(b, m, deterministic)
}
func (m *CampaignLabel) XXX_Merge(src proto.Message) {
	xxx_messageInfo_CampaignLabel.Merge(m, src)
}
func (m *CampaignLabel) XXX_Size() int {
	return xxx_messageInfo_CampaignLabel.Size(m)
}
func (m *CampaignLabel) XXX_DiscardUnknown() {
	xxx_messageInfo_CampaignLabel.DiscardUnknown(m)
}

var xxx_messageInfo_CampaignLabel proto.InternalMessageInfo

func (m *CampaignLabel) GetResourceName() string {
	if m != nil {
		return m.ResourceName
	}
	return ""
}

func (m *CampaignLabel) GetCampaign() *wrappers.StringValue {
	if m != nil {
		return m.Campaign
	}
	return nil
}

func (m *CampaignLabel) GetLabel() *wrappers.StringValue {
	if m != nil {
		return m.Label
	}
	return nil
}

func init() {
	proto.RegisterType((*CampaignLabel)(nil), "google.ads.googleads.v2.resources.CampaignLabel")
}

func init() {
	proto.RegisterFile("google/ads/googleads/v2/resources/campaign_label.proto", fileDescriptor_1a6c77ba70ba8330)
}

var fileDescriptor_1a6c77ba70ba8330 = []byte{
	// 322 bytes of a gzipped FileDescriptorProto
	0x1f, 0x8b, 0x08, 0x00, 0x00, 0x00, 0x00, 0x00, 0x02, 0xff, 0x8c, 0x91, 0xcf, 0x4a, 0xc3, 0x30,
	0x1c, 0xc7, 0x69, 0x87, 0xa2, 0xd5, 0x5d, 0x7a, 0x1a, 0x63, 0xc8, 0xa6, 0x0c, 0x76, 0x4a, 0x20,
	0x82, 0x48, 0x3c, 0x75, 0x1e, 0x06, 0x22, 0x32, 0x26, 0xf4, 0x20, 0x85, 0xf1, 0xdb, 0x1a, 0x43,
	0xa1, 0x4d, 0x42, 0xd2, 0xcd, 0xf7, 0xd9, 0xd1, 0x47, 0xf1, 0x51, 0x7c, 0x09, 0xa5, 0x4d, 0x13,
	0xf0, 0xa2, 0xde, 0xbe, 0x34, 0x9f, 0xef, 0x9f, 0x34, 0xd1, 0x0d, 0x97, 0x92, 0x97, 0x0c, 0x43,
	0x6e, 0xb0, 0x95, 0x8d, 0xda, 0x13, 0xac, 0x99, 0x91, 0x3b, 0xbd, 0x65, 0x06, 0x6f, 0xa1, 0x52,
	0x50, 0x70, 0xb1, 0x2e, 0x61, 0xc3, 0x4a, 0xa4, 0xb4, 0xac, 0x65, 0x3c, 0xb1, 0x30, 0x82, 0xdc,
	0x20, 0xef, 0x43, 0x7b, 0x82, 0xbc, 0x6f, 0x78, 0xd1, 0x45, 0xb7, 0x86, 0xcd, 0xee, 0x15, 0xbf,
	0x69, 0x50, 0x8a, 0x69, 0x63, 0x23, 0x86, 0x23, 0x57, 0xad, 0x0a, 0x0c, 0x42, 0xc8, 0x1a, 0xea,
	0x42, 0x8a, 0xee, 0xf4, 0xf2, 0x10, 0x44, 0xfd, 0xfb, 0xae, 0xf9, 0xb1, 0x29, 0x8e, 0xaf, 0xa2,
	0xbe, 0x0b, 0x5f, 0x0b, 0xa8, 0xd8, 0x20, 0x18, 0x07, 0xb3, 0xd3, 0xd5, 0xb9, 0xfb, 0xf8, 0x04,
	0x15, 0x8b, 0x6f, 0xa3, 0x13, 0xb7, 0x77, 0x10, 0x8e, 0x83, 0xd9, 0x19, 0x19, 0x75, 0xfb, 0x90,
	0xdb, 0x81, 0x9e, 0x6b, 0x5d, 0x08, 0x9e, 0x42, 0xb9, 0x63, 0x2b, 0x4f, 0xc7, 0x24, 0x3a, 0x6a,
	0x2f, 0x38, 0xe8, 0xfd, 0xc3, 0x66, 0xd1, 0xf9, 0x57, 0x10, 0x4d, 0xb7, 0xb2, 0x42, 0x7f, 0xfe,
	0x8c, 0x79, 0xfc, 0xe3, 0x2e, 0xcb, 0x26, 0x73, 0x19, 0xbc, 0x3c, 0x74, 0x46, 0x2e, 0x4b, 0x10,
	0x1c, 0x49, 0xcd, 0x31, 0x67, 0xa2, 0x6d, 0x74, 0xaf, 0xa1, 0x0a, 0xf3, 0xcb, 0xe3, 0xdc, 0x79,
	0x75, 0x08, 0x7b, 0x8b, 0x24, 0x79, 0x0f, 0x27, 0x0b, 0x1b, 0x99, 0xe4, 0x06, 0x59, 0xd9, 0xa8,
	0x94, 0xa0, 0x95, 0x23, 0x3f, 0x1c, 0x93, 0x25, 0xb9, 0xc9, 0x3c, 0x93, 0xa5, 0x24, 0xf3, 0xcc,
	0x67, 0x38, 0xb5, 0x07, 0x94, 0x26, 0xb9, 0xa1, 0xd4, 0x53, 0x94, 0xa6, 0x84, 0x52, 0xcf, 0x6d,
	0x8e, 0xdb, 0xb1, 0xd7, 0xdf, 0x01, 0x00, 0x00, 0xff, 0xff, 0x04, 0xee, 0x34, 0x00, 0x48, 0x02,
	0x00, 0x00,
}
