// Code generated by protoc-gen-go. DO NOT EDIT.
// source: google/ads/googleads/v2/resources/user_interest.proto

package resources

import (
	fmt "fmt"
	math "math"

	proto "github.com/golang/protobuf/proto"
	wrappers "github.com/golang/protobuf/ptypes/wrappers"
	common "google.golang.org/genproto/googleapis/ads/googleads/v2/common"
	enums "google.golang.org/genproto/googleapis/ads/googleads/v2/enums"
	_ "google.golang.org/genproto/googleapis/api/annotations"
)

// Reference imports to suppress errors if they are not otherwise used.
var _ = proto.Marshal
var _ = fmt.Errorf
var _ = math.Inf

// This is a compile-time assertion to ensure that this generated file
// is compatible with the proto package it is being compiled against.
// A compilation error at this line likely means your copy of the
// proto package needs to be updated.
const _ = proto.ProtoPackageIsVersion3 // please upgrade the proto package

// A user interest: a particular interest-based vertical to be targeted.
type UserInterest struct {
	// The resource name of the user interest.
	// User interest resource names have the form:
	//
	// `customers/{customer_id}/userInterests/{user_interest_id}`
	ResourceName string `protobuf:"bytes,1,opt,name=resource_name,json=resourceName,proto3" json:"resource_name,omitempty"`
	// Taxonomy type of the user interest.
	TaxonomyType enums.UserInterestTaxonomyTypeEnum_UserInterestTaxonomyType `protobuf:"varint,2,opt,name=taxonomy_type,json=taxonomyType,proto3,enum=google.ads.googleads.v2.enums.UserInterestTaxonomyTypeEnum_UserInterestTaxonomyType" json:"taxonomy_type,omitempty"`
	// The ID of the user interest.
	UserInterestId *wrappers.Int64Value `protobuf:"bytes,3,opt,name=user_interest_id,json=userInterestId,proto3" json:"user_interest_id,omitempty"`
	// The name of the user interest.
	Name *wrappers.StringValue `protobuf:"bytes,4,opt,name=name,proto3" json:"name,omitempty"`
	// The parent of the user interest.
	UserInterestParent *wrappers.StringValue `protobuf:"bytes,5,opt,name=user_interest_parent,json=userInterestParent,proto3" json:"user_interest_parent,omitempty"`
	// True if the user interest is launched to all channels and locales.
	LaunchedToAll *wrappers.BoolValue `protobuf:"bytes,6,opt,name=launched_to_all,json=launchedToAll,proto3" json:"launched_to_all,omitempty"`
	// Availability information of the user interest.
	Availabilities       []*common.CriterionCategoryAvailability `protobuf:"bytes,7,rep,name=availabilities,proto3" json:"availabilities,omitempty"`
	XXX_NoUnkeyedLiteral struct{}                                `json:"-"`
	XXX_unrecognized     []byte                                  `json:"-"`
	XXX_sizecache        int32                                   `json:"-"`
}

func (m *UserInterest) Reset()         { *m = UserInterest{} }
func (m *UserInterest) String() string { return proto.CompactTextString(m) }
func (*UserInterest) ProtoMessage()    {}
func (*UserInterest) Descriptor() ([]byte, []int) {
	return fileDescriptor_3f0e313311c98402, []int{0}
}

func (m *UserInterest) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_UserInterest.Unmarshal(m, b)
}
func (m *UserInterest) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_UserInterest.Marshal(b, m, deterministic)
}
func (m *UserInterest) XXX_Merge(src proto.Message) {
	xxx_messageInfo_UserInterest.Merge(m, src)
}
func (m *UserInterest) XXX_Size() int {
	return xxx_messageInfo_UserInterest.Size(m)
}
func (m *UserInterest) XXX_DiscardUnknown() {
	xxx_messageInfo_UserInterest.DiscardUnknown(m)
}

var xxx_messageInfo_UserInterest proto.InternalMessageInfo

func (m *UserInterest) GetResourceName() string {
	if m != nil {
		return m.ResourceName
	}
	return ""
}

func (m *UserInterest) GetTaxonomyType() enums.UserInterestTaxonomyTypeEnum_UserInterestTaxonomyType {
	if m != nil {
		return m.TaxonomyType
	}
	return enums.UserInterestTaxonomyTypeEnum_UNSPECIFIED
}

func (m *UserInterest) GetUserInterestId() *wrappers.Int64Value {
	if m != nil {
		return m.UserInterestId
	}
	return nil
}

func (m *UserInterest) GetName() *wrappers.StringValue {
	if m != nil {
		return m.Name
	}
	return nil
}

func (m *UserInterest) GetUserInterestParent() *wrappers.StringValue {
	if m != nil {
		return m.UserInterestParent
	}
	return nil
}

func (m *UserInterest) GetLaunchedToAll() *wrappers.BoolValue {
	if m != nil {
		return m.LaunchedToAll
	}
	return nil
}

func (m *UserInterest) GetAvailabilities() []*common.CriterionCategoryAvailability {
	if m != nil {
		return m.Availabilities
	}
	return nil
}

func init() {
	proto.RegisterType((*UserInterest)(nil), "google.ads.googleads.v2.resources.UserInterest")
}

func init() {
	proto.RegisterFile("google/ads/googleads/v2/resources/user_interest.proto", fileDescriptor_3f0e313311c98402)
}

var fileDescriptor_3f0e313311c98402 = []byte{
	// 518 bytes of a gzipped FileDescriptorProto
	0x1f, 0x8b, 0x08, 0x00, 0x00, 0x00, 0x00, 0x00, 0x02, 0xff, 0x8c, 0x53, 0xdd, 0x8a, 0xd3, 0x40,
	0x14, 0x26, 0x6d, 0x5d, 0x31, 0xdb, 0x56, 0x0d, 0x5e, 0x84, 0xba, 0x48, 0x57, 0x59, 0xe8, 0xd5,
	0x44, 0xe2, 0xcf, 0x45, 0x44, 0x24, 0x5d, 0x97, 0xa5, 0x5e, 0x2c, 0xa5, 0xd6, 0x5e, 0x48, 0x21,
	0x4c, 0x93, 0x63, 0x1c, 0x98, 0xcc, 0x09, 0x33, 0x93, 0x6a, 0x5e, 0x67, 0x2f, 0x7d, 0x14, 0x1f,
	0xc5, 0x87, 0x10, 0x69, 0xfe, 0x48, 0x77, 0xa9, 0x7a, 0x77, 0x92, 0xf3, 0xfd, 0x9c, 0x33, 0xf3,
	0x8d, 0xf9, 0x2a, 0x46, 0x8c, 0x39, 0x38, 0x34, 0x52, 0x4e, 0x59, 0xee, 0xaa, 0xad, 0xeb, 0x48,
	0x50, 0x98, 0xc9, 0x10, 0x94, 0x93, 0x29, 0x90, 0x01, 0x13, 0x1a, 0x24, 0x28, 0x4d, 0x52, 0x89,
	0x1a, 0xad, 0xd3, 0x12, 0x4b, 0x68, 0xa4, 0x48, 0x43, 0x23, 0x5b, 0x97, 0x34, 0xb4, 0xd1, 0xfb,
	0x43, 0xca, 0x21, 0x26, 0x09, 0x0a, 0x27, 0x94, 0x4c, 0x83, 0x64, 0x28, 0x82, 0x90, 0x6a, 0x88,
	0x51, 0xe6, 0x01, 0xdd, 0x52, 0xc6, 0xe9, 0x86, 0x71, 0xa6, 0xf3, 0xd2, 0x68, 0xf4, 0xee, 0x90,
	0x0a, 0x88, 0x2c, 0xb9, 0x31, 0x5b, 0xa0, 0xe9, 0x77, 0x14, 0x98, 0xe4, 0x81, 0xce, 0x53, 0xa8,
	0x04, 0x9e, 0x54, 0x02, 0xc5, 0xd7, 0x26, 0xfb, 0xe2, 0x7c, 0x93, 0x34, 0x4d, 0x41, 0xaa, 0xaa,
	0x7f, 0x52, 0x1b, 0xa4, 0xcc, 0xa1, 0x42, 0xa0, 0xa6, 0x9a, 0xa1, 0xa8, 0xba, 0x4f, 0xaf, 0x7b,
	0x66, 0xff, 0x93, 0x02, 0x39, 0xab, 0x2c, 0xac, 0x67, 0xe6, 0xa0, 0x5e, 0x31, 0x10, 0x34, 0x01,
	0xdb, 0x18, 0x1b, 0x93, 0x7b, 0x8b, 0x7e, 0xfd, 0xf3, 0x8a, 0x26, 0x60, 0xe5, 0xe6, 0x60, 0x6f,
	0x14, 0xbb, 0x33, 0x36, 0x26, 0x43, 0x77, 0x49, 0x0e, 0x9d, 0x5a, 0xb1, 0x0c, 0x69, 0x1b, 0x2d,
	0x2b, 0xfe, 0x32, 0x4f, 0xe1, 0x42, 0x64, 0xc9, 0xc1, 0xe6, 0xa2, 0xaf, 0x5b, 0x5f, 0xd6, 0x85,
	0xf9, 0x60, 0xff, 0x4c, 0x58, 0x64, 0x77, 0xc7, 0xc6, 0xe4, 0xd8, 0x7d, 0x5c, 0xbb, 0xd7, 0x27,
	0x41, 0x66, 0x42, 0xbf, 0x7e, 0xb9, 0xa2, 0x3c, 0x83, 0xc5, 0x30, 0x6b, 0xc9, 0xcf, 0x22, 0xeb,
	0xb9, 0xd9, 0x2b, 0xb6, 0xeb, 0x15, 0xd4, 0x93, 0x5b, 0xd4, 0x8f, 0x5a, 0x32, 0x11, 0x97, 0xdc,
	0x02, 0x69, 0x5d, 0x99, 0x8f, 0xf6, 0x8d, 0x53, 0x2a, 0x41, 0x68, 0xfb, 0xce, 0x7f, 0x28, 0x58,
	0x6d, 0xf7, 0x79, 0xc1, 0xb3, 0xa6, 0xe6, 0x7d, 0x4e, 0x33, 0x11, 0x7e, 0x85, 0x28, 0xd0, 0x18,
	0x50, 0xce, 0xed, 0xa3, 0x42, 0x6a, 0x74, 0x4b, 0x6a, 0x8a, 0xc8, 0x4b, 0xa1, 0x41, 0x4d, 0x59,
	0xa2, 0xcf, 0xb9, 0x05, 0xe6, 0xb0, 0x15, 0x29, 0x06, 0xca, 0xbe, 0x3b, 0xee, 0x4e, 0x8e, 0xdd,
	0xb7, 0x07, 0x2f, 0xa2, 0xcc, 0x26, 0x39, 0xaf, 0xb3, 0x79, 0x5e, 0x45, 0xd3, 0x6f, 0x25, 0x73,
	0x71, 0x43, 0x74, 0xfa, 0xdb, 0x30, 0xcf, 0x42, 0x4c, 0xc8, 0x3f, 0xdf, 0xc4, 0xf4, 0x61, 0xfb,
	0x16, 0xe7, 0xbb, 0xf9, 0xe7, 0xc6, 0xe7, 0x0f, 0x15, 0x2f, 0x46, 0x4e, 0x45, 0x4c, 0x50, 0xc6,
	0x4e, 0x0c, 0xa2, 0xd8, 0xae, 0x8e, 0x7c, 0xca, 0xd4, 0x5f, 0x5e, 0xe8, 0x9b, 0xa6, 0xba, 0xee,
	0x74, 0x2f, 0x7d, 0xff, 0x47, 0xe7, 0xf4, 0xb2, 0x94, 0xf4, 0x23, 0x45, 0xca, 0x72, 0x57, 0xad,
	0x5c, 0xb2, 0xa8, 0x91, 0x3f, 0x6b, 0xcc, 0xda, 0x8f, 0xd4, 0xba, 0xc1, 0xac, 0x57, 0xee, 0xba,
	0xc1, 0xfc, 0xea, 0x9c, 0x95, 0x0d, 0xcf, 0xf3, 0x23, 0xe5, 0x79, 0x0d, 0xca, 0xf3, 0x56, 0xae,
	0xe7, 0x35, 0xb8, 0xcd, 0x51, 0x31, 0xec, 0x8b, 0x3f, 0x01, 0x00, 0x00, 0xff, 0xff, 0xa8, 0x89,
	0x72, 0xd1, 0x4d, 0x04, 0x00, 0x00,
}
