// Code generated by protoc-gen-go. DO NOT EDIT.
// source: google/cloud/phishingprotection/v1beta1/phishingprotection.proto

package phishingprotection

import (
	context "context"
	fmt "fmt"
	math "math"

	proto "github.com/golang/protobuf/proto"
	_ "google.golang.org/genproto/googleapis/api/annotations"
	grpc "google.golang.org/grpc"
)

// Reference imports to suppress errors if they are not otherwise used.
var _ = proto.Marshal
var _ = fmt.Errorf
var _ = math.Inf

// This is a compile-time assertion to ensure that this generated file
// is compatible with the proto package it is being compiled against.
// A compilation error at this line likely means your copy of the
// proto package needs to be updated.
const _ = proto.ProtoPackageIsVersion3 // please upgrade the proto package

// The ReportPhishing request message.
type ReportPhishingRequest struct {
	// Required. The name of the project for which the report will be created,
	// in the format "projects/{project_number}".
	Parent string `protobuf:"bytes,1,opt,name=parent,proto3" json:"parent,omitempty"`
	// The URI that is being reported for phishing content to be analyzed.
	Uri                  string   `protobuf:"bytes,2,opt,name=uri,proto3" json:"uri,omitempty"`
	XXX_NoUnkeyedLiteral struct{} `json:"-"`
	XXX_unrecognized     []byte   `json:"-"`
	XXX_sizecache        int32    `json:"-"`
}

func (m *ReportPhishingRequest) Reset()         { *m = ReportPhishingRequest{} }
func (m *ReportPhishingRequest) String() string { return proto.CompactTextString(m) }
func (*ReportPhishingRequest) ProtoMessage()    {}
func (*ReportPhishingRequest) Descriptor() ([]byte, []int) {
	return fileDescriptor_fa2769de3b7011f5, []int{0}
}

func (m *ReportPhishingRequest) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_ReportPhishingRequest.Unmarshal(m, b)
}
func (m *ReportPhishingRequest) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_ReportPhishingRequest.Marshal(b, m, deterministic)
}
func (m *ReportPhishingRequest) XXX_Merge(src proto.Message) {
	xxx_messageInfo_ReportPhishingRequest.Merge(m, src)
}
func (m *ReportPhishingRequest) XXX_Size() int {
	return xxx_messageInfo_ReportPhishingRequest.Size(m)
}
func (m *ReportPhishingRequest) XXX_DiscardUnknown() {
	xxx_messageInfo_ReportPhishingRequest.DiscardUnknown(m)
}

var xxx_messageInfo_ReportPhishingRequest proto.InternalMessageInfo

func (m *ReportPhishingRequest) GetParent() string {
	if m != nil {
		return m.Parent
	}
	return ""
}

func (m *ReportPhishingRequest) GetUri() string {
	if m != nil {
		return m.Uri
	}
	return ""
}

// The ReportPhishing (empty) response message.
type ReportPhishingResponse struct {
	XXX_NoUnkeyedLiteral struct{} `json:"-"`
	XXX_unrecognized     []byte   `json:"-"`
	XXX_sizecache        int32    `json:"-"`
}

func (m *ReportPhishingResponse) Reset()         { *m = ReportPhishingResponse{} }
func (m *ReportPhishingResponse) String() string { return proto.CompactTextString(m) }
func (*ReportPhishingResponse) ProtoMessage()    {}
func (*ReportPhishingResponse) Descriptor() ([]byte, []int) {
	return fileDescriptor_fa2769de3b7011f5, []int{1}
}

func (m *ReportPhishingResponse) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_ReportPhishingResponse.Unmarshal(m, b)
}
func (m *ReportPhishingResponse) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_ReportPhishingResponse.Marshal(b, m, deterministic)
}
func (m *ReportPhishingResponse) XXX_Merge(src proto.Message) {
	xxx_messageInfo_ReportPhishingResponse.Merge(m, src)
}
func (m *ReportPhishingResponse) XXX_Size() int {
	return xxx_messageInfo_ReportPhishingResponse.Size(m)
}
func (m *ReportPhishingResponse) XXX_DiscardUnknown() {
	xxx_messageInfo_ReportPhishingResponse.DiscardUnknown(m)
}

var xxx_messageInfo_ReportPhishingResponse proto.InternalMessageInfo

func init() {
	proto.RegisterType((*ReportPhishingRequest)(nil), "google.cloud.phishingprotection.v1beta1.ReportPhishingRequest")
	proto.RegisterType((*ReportPhishingResponse)(nil), "google.cloud.phishingprotection.v1beta1.ReportPhishingResponse")
}

func init() {
	proto.RegisterFile("google/cloud/phishingprotection/v1beta1/phishingprotection.proto", fileDescriptor_fa2769de3b7011f5)
}

var fileDescriptor_fa2769de3b7011f5 = []byte{
	// 345 bytes of a gzipped FileDescriptorProto
	0x1f, 0x8b, 0x08, 0x00, 0x00, 0x00, 0x00, 0x00, 0x02, 0xff, 0xe2, 0x72, 0x48, 0xcf, 0xcf, 0x4f,
	0xcf, 0x49, 0xd5, 0x4f, 0xce, 0xc9, 0x2f, 0x4d, 0xd1, 0x2f, 0xc8, 0xc8, 0x2c, 0xce, 0xc8, 0xcc,
	0x4b, 0x2f, 0x28, 0xca, 0x2f, 0x49, 0x4d, 0x2e, 0xc9, 0xcc, 0xcf, 0xd3, 0x2f, 0x33, 0x4c, 0x4a,
	0x2d, 0x49, 0x34, 0xc4, 0x22, 0xa5, 0x07, 0x62, 0xe6, 0x0b, 0xa9, 0x43, 0x4c, 0xd0, 0x03, 0x9b,
	0xa0, 0x87, 0x45, 0x19, 0xd4, 0x04, 0x29, 0x19, 0xa8, 0x55, 0x89, 0x05, 0x99, 0xfa, 0x89, 0x79,
	0x79, 0xf9, 0x25, 0x89, 0x20, 0xe9, 0x62, 0x88, 0x31, 0x4a, 0x8e, 0x5c, 0xa2, 0x41, 0xa9, 0x05,
	0xf9, 0x45, 0x25, 0x01, 0x50, 0x13, 0x82, 0x52, 0x0b, 0x4b, 0x53, 0x8b, 0x4b, 0x84, 0xc4, 0xb8,
	0xd8, 0x0a, 0x12, 0x8b, 0x52, 0xf3, 0x4a, 0x24, 0x18, 0x15, 0x18, 0x35, 0x38, 0x83, 0xa0, 0x3c,
	0x21, 0x01, 0x2e, 0xe6, 0xd2, 0xa2, 0x4c, 0x09, 0x26, 0xb0, 0x20, 0x88, 0xa9, 0x24, 0xc1, 0x25,
	0x86, 0x6e, 0x44, 0x71, 0x41, 0x7e, 0x5e, 0x71, 0xaa, 0xd1, 0x7b, 0x46, 0x2e, 0x05, 0x98, 0x60,
	0x00, 0xdc, 0x65, 0xc1, 0xa9, 0x45, 0x65, 0x99, 0xc9, 0xa9, 0x61, 0x86, 0x4e, 0x20, 0xf7, 0x09,
	0x9d, 0x62, 0xe4, 0xe2, 0x43, 0xd5, 0x2f, 0x64, 0xa7, 0x47, 0xa4, 0xe7, 0xf4, 0xb0, 0xba, 0x5d,
	0xca, 0x9e, 0x6c, 0xfd, 0x10, 0x87, 0x2b, 0x99, 0x37, 0x5d, 0x7e, 0x32, 0x99, 0xc9, 0x50, 0x49,
	0x07, 0x1e, 0x0f, 0xd5, 0x10, 0xef, 0xdb, 0x16, 0x14, 0xe5, 0x67, 0xa5, 0x26, 0x97, 0x14, 0xeb,
	0x6b, 0xd5, 0xc2, 0xe3, 0xc6, 0xaa, 0x08, 0x6c, 0x8a, 0x15, 0xa3, 0x96, 0xd3, 0x0f, 0x46, 0x2e,
	0xd5, 0xe4, 0xfc, 0x5c, 0x98, 0xfd, 0xb8, 0x6d, 0x76, 0x12, 0xc7, 0x0c, 0x18, 0x10, 0x2b, 0x3f,
	0x80, 0x31, 0x2a, 0x12, 0xaa, 0x3b, 0x3d, 0x3f, 0x27, 0x31, 0x2f, 0x5d, 0x2f, 0xbf, 0x28, 0x5d,
	0x3f, 0x3d, 0x35, 0x0f, 0x1c, 0x5f, 0xfa, 0x10, 0xa9, 0xc4, 0x82, 0xcc, 0x62, 0x82, 0x69, 0xc7,
	0x1a, 0x53, 0x6a, 0x11, 0x13, 0x8b, 0xbb, 0x73, 0x40, 0xc0, 0x2a, 0x26, 0x75, 0x77, 0x88, 0x15,
	0xce, 0xe0, 0x00, 0xc2, 0x74, 0x8a, 0x1e, 0x34, 0x76, 0x4e, 0xc1, 0x54, 0xc6, 0x80, 0x55, 0xc6,
	0x60, 0xaa, 0x8c, 0x09, 0x83, 0xd8, 0x96, 0xc4, 0x06, 0x76, 0xa0, 0x31, 0x20, 0x00, 0x00, 0xff,
	0xff, 0xf7, 0x8f, 0x06, 0xd9, 0xdb, 0x02, 0x00, 0x00,
}

// Reference imports to suppress errors if they are not otherwise used.
var _ context.Context
var _ grpc.ClientConn

// This is a compile-time assertion to ensure that this generated file
// is compatible with the grpc package it is being compiled against.
const _ = grpc.SupportPackageIsVersion4

// PhishingProtectionServiceV1Beta1Client is the client API for PhishingProtectionServiceV1Beta1 service.
//
// For semantics around ctx use and closing/ending streaming RPCs, please refer to https://godoc.org/google.golang.org/grpc#ClientConn.NewStream.
type PhishingProtectionServiceV1Beta1Client interface {
	// Reports a URI suspected of containing phishing content to be reviewed. Once
	// the report review is completed, if its result verifies the existince of
	// malicious phishing content, the site will be added the to [Google's Social
	// Engineering lists](https://support.google.com/webmasters/answer/6350487/)
	// in order to protect users that could get exposed to this threat in
	// the future.
	ReportPhishing(ctx context.Context, in *ReportPhishingRequest, opts ...grpc.CallOption) (*ReportPhishingResponse, error)
}

type phishingProtectionServiceV1Beta1Client struct {
	cc *grpc.ClientConn
}

func NewPhishingProtectionServiceV1Beta1Client(cc *grpc.ClientConn) PhishingProtectionServiceV1Beta1Client {
	return &phishingProtectionServiceV1Beta1Client{cc}
}

func (c *phishingProtectionServiceV1Beta1Client) ReportPhishing(ctx context.Context, in *ReportPhishingRequest, opts ...grpc.CallOption) (*ReportPhishingResponse, error) {
	out := new(ReportPhishingResponse)
	err := c.cc.Invoke(ctx, "/google.cloud.phishingprotection.v1beta1.PhishingProtectionServiceV1Beta1/ReportPhishing", in, out, opts...)
	if err != nil {
		return nil, err
	}
	return out, nil
}

// PhishingProtectionServiceV1Beta1Server is the server API for PhishingProtectionServiceV1Beta1 service.
type PhishingProtectionServiceV1Beta1Server interface {
	// Reports a URI suspected of containing phishing content to be reviewed. Once
	// the report review is completed, if its result verifies the existince of
	// malicious phishing content, the site will be added the to [Google's Social
	// Engineering lists](https://support.google.com/webmasters/answer/6350487/)
	// in order to protect users that could get exposed to this threat in
	// the future.
	ReportPhishing(context.Context, *ReportPhishingRequest) (*ReportPhishingResponse, error)
}

func RegisterPhishingProtectionServiceV1Beta1Server(s *grpc.Server, srv PhishingProtectionServiceV1Beta1Server) {
	s.RegisterService(&_PhishingProtectionServiceV1Beta1_serviceDesc, srv)
}

func _PhishingProtectionServiceV1Beta1_ReportPhishing_Handler(srv interface{}, ctx context.Context, dec func(interface{}) error, interceptor grpc.UnaryServerInterceptor) (interface{}, error) {
	in := new(ReportPhishingRequest)
	if err := dec(in); err != nil {
		return nil, err
	}
	if interceptor == nil {
		return srv.(PhishingProtectionServiceV1Beta1Server).ReportPhishing(ctx, in)
	}
	info := &grpc.UnaryServerInfo{
		Server:     srv,
		FullMethod: "/google.cloud.phishingprotection.v1beta1.PhishingProtectionServiceV1Beta1/ReportPhishing",
	}
	handler := func(ctx context.Context, req interface{}) (interface{}, error) {
		return srv.(PhishingProtectionServiceV1Beta1Server).ReportPhishing(ctx, req.(*ReportPhishingRequest))
	}
	return interceptor(ctx, in, info, handler)
}

var _PhishingProtectionServiceV1Beta1_serviceDesc = grpc.ServiceDesc{
	ServiceName: "google.cloud.phishingprotection.v1beta1.PhishingProtectionServiceV1Beta1",
	HandlerType: (*PhishingProtectionServiceV1Beta1Server)(nil),
	Methods: []grpc.MethodDesc{
		{
			MethodName: "ReportPhishing",
			Handler:    _PhishingProtectionServiceV1Beta1_ReportPhishing_Handler,
		},
	},
	Streams:  []grpc.StreamDesc{},
	Metadata: "google/cloud/phishingprotection/v1beta1/phishingprotection.proto",
}
