// Code generated by protoc-gen-go. DO NOT EDIT.
// source: google/ads/googleads/v1/enums/simulation_modification_method.proto

package enums

import (
	fmt "fmt"
	math "math"

	proto "github.com/golang/protobuf/proto"
	_ "google.golang.org/genproto/googleapis/api/annotations"
)

// Reference imports to suppress errors if they are not otherwise used.
var _ = proto.Marshal
var _ = fmt.Errorf
var _ = math.Inf

// This is a compile-time assertion to ensure that this generated file
// is compatible with the proto package it is being compiled against.
// A compilation error at this line likely means your copy of the
// proto package needs to be updated.
const _ = proto.ProtoPackageIsVersion3 // please upgrade the proto package

// Enum describing the method by which a simulation modifies a field.
type SimulationModificationMethodEnum_SimulationModificationMethod int32

const (
	// Not specified.
	SimulationModificationMethodEnum_UNSPECIFIED SimulationModificationMethodEnum_SimulationModificationMethod = 0
	// Used for return value only. Represents value unknown in this version.
	SimulationModificationMethodEnum_UNKNOWN SimulationModificationMethodEnum_SimulationModificationMethod = 1
	// The values in a simulation were applied to all children of a given
	// resource uniformly. Overrides on child resources were not respected.
	SimulationModificationMethodEnum_UNIFORM SimulationModificationMethodEnum_SimulationModificationMethod = 2
	// The values in a simulation were applied to the given resource.
	// Overrides on child resources were respected, and traffic estimates
	// do not include these resources.
	SimulationModificationMethodEnum_DEFAULT SimulationModificationMethodEnum_SimulationModificationMethod = 3
)

var SimulationModificationMethodEnum_SimulationModificationMethod_name = map[int32]string{
	0: "UNSPECIFIED",
	1: "UNKNOWN",
	2: "UNIFORM",
	3: "DEFAULT",
}

var SimulationModificationMethodEnum_SimulationModificationMethod_value = map[string]int32{
	"UNSPECIFIED": 0,
	"UNKNOWN":     1,
	"UNIFORM":     2,
	"DEFAULT":     3,
}

func (x SimulationModificationMethodEnum_SimulationModificationMethod) String() string {
	return proto.EnumName(SimulationModificationMethodEnum_SimulationModificationMethod_name, int32(x))
}

func (SimulationModificationMethodEnum_SimulationModificationMethod) EnumDescriptor() ([]byte, []int) {
	return fileDescriptor_ecdf62786c8f64e4, []int{0, 0}
}

// Container for enum describing the method by which a simulation modifies
// a field.
type SimulationModificationMethodEnum struct {
	XXX_NoUnkeyedLiteral struct{} `json:"-"`
	XXX_unrecognized     []byte   `json:"-"`
	XXX_sizecache        int32    `json:"-"`
}

func (m *SimulationModificationMethodEnum) Reset()         { *m = SimulationModificationMethodEnum{} }
func (m *SimulationModificationMethodEnum) String() string { return proto.CompactTextString(m) }
func (*SimulationModificationMethodEnum) ProtoMessage()    {}
func (*SimulationModificationMethodEnum) Descriptor() ([]byte, []int) {
	return fileDescriptor_ecdf62786c8f64e4, []int{0}
}

func (m *SimulationModificationMethodEnum) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_SimulationModificationMethodEnum.Unmarshal(m, b)
}
func (m *SimulationModificationMethodEnum) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_SimulationModificationMethodEnum.Marshal(b, m, deterministic)
}
func (m *SimulationModificationMethodEnum) XXX_Merge(src proto.Message) {
	xxx_messageInfo_SimulationModificationMethodEnum.Merge(m, src)
}
func (m *SimulationModificationMethodEnum) XXX_Size() int {
	return xxx_messageInfo_SimulationModificationMethodEnum.Size(m)
}
func (m *SimulationModificationMethodEnum) XXX_DiscardUnknown() {
	xxx_messageInfo_SimulationModificationMethodEnum.DiscardUnknown(m)
}

var xxx_messageInfo_SimulationModificationMethodEnum proto.InternalMessageInfo

func init() {
	proto.RegisterEnum("google.ads.googleads.v1.enums.SimulationModificationMethodEnum_SimulationModificationMethod", SimulationModificationMethodEnum_SimulationModificationMethod_name, SimulationModificationMethodEnum_SimulationModificationMethod_value)
	proto.RegisterType((*SimulationModificationMethodEnum)(nil), "google.ads.googleads.v1.enums.SimulationModificationMethodEnum")
}

func init() {
	proto.RegisterFile("google/ads/googleads/v1/enums/simulation_modification_method.proto", fileDescriptor_ecdf62786c8f64e4)
}

var fileDescriptor_ecdf62786c8f64e4 = []byte{
	// 308 bytes of a gzipped FileDescriptorProto
	0x1f, 0x8b, 0x08, 0x00, 0x00, 0x00, 0x00, 0x00, 0x02, 0xff, 0x7c, 0x50, 0xd1, 0x4a, 0xc3, 0x30,
	0x14, 0x75, 0x1d, 0x28, 0x64, 0x0f, 0x96, 0x3d, 0xca, 0x06, 0x6e, 0x1f, 0x90, 0x50, 0x7c, 0x8b,
	0x4f, 0x99, 0xeb, 0x46, 0xd1, 0x76, 0xc5, 0xd9, 0x0a, 0x52, 0x90, 0xba, 0xd4, 0x18, 0x68, 0x93,
	0xb2, 0xb4, 0x7b, 0xf0, 0x73, 0x7c, 0xf4, 0x53, 0xfc, 0x14, 0x3f, 0xc0, 0x67, 0x69, 0xb2, 0x16,
	0x5f, 0xec, 0x4b, 0x38, 0x37, 0xf7, 0xdc, 0x73, 0xee, 0x3d, 0x60, 0xc1, 0xa4, 0x64, 0x79, 0x86,
	0x52, 0xaa, 0x90, 0x81, 0x0d, 0x3a, 0x38, 0x28, 0x13, 0x75, 0xa1, 0x90, 0xe2, 0x45, 0x9d, 0xa7,
	0x15, 0x97, 0xe2, 0xb9, 0x90, 0x94, 0xbf, 0xf2, 0xdd, 0xb1, 0xc8, 0xaa, 0x37, 0x49, 0x61, 0xb9,
	0x97, 0x95, 0x1c, 0x4f, 0xcd, 0x20, 0x4c, 0xa9, 0x82, 0x9d, 0x06, 0x3c, 0x38, 0x50, 0x6b, 0x5c,
	0x4c, 0x5a, 0x8b, 0x92, 0xa3, 0x54, 0x08, 0x59, 0x69, 0x09, 0x65, 0x86, 0xe7, 0xef, 0xe0, 0x72,
	0xdb, 0x99, 0xf8, 0x7f, 0x3c, 0x7c, 0x6d, 0xe1, 0x8a, 0xba, 0x98, 0xc7, 0x60, 0xd2, 0xc7, 0x19,
	0x9f, 0x83, 0x51, 0x14, 0x6c, 0x43, 0xf7, 0xc6, 0x5b, 0x79, 0xee, 0xd2, 0x3e, 0x19, 0x8f, 0xc0,
	0x59, 0x14, 0xdc, 0x06, 0x9b, 0xc7, 0xc0, 0x1e, 0x98, 0xc2, 0x5b, 0x6d, 0xee, 0x7d, 0xdb, 0x6a,
	0x8a, 0xa5, 0xbb, 0x22, 0xd1, 0xdd, 0x83, 0x3d, 0x5c, 0xfc, 0x0c, 0xc0, 0x6c, 0x27, 0x0b, 0xd8,
	0xbb, 0xff, 0x62, 0xd6, 0xe7, 0x1d, 0x36, 0x47, 0x84, 0x83, 0xa7, 0x63, 0x8e, 0x90, 0xc9, 0x3c,
	0x15, 0x0c, 0xca, 0x3d, 0x43, 0x2c, 0x13, 0xfa, 0xc4, 0x36, 0xd7, 0x92, 0xab, 0x7f, 0x62, 0xbe,
	0xd6, 0xef, 0x87, 0x35, 0x5c, 0x13, 0xf2, 0x69, 0x4d, 0xd7, 0x46, 0x8a, 0x50, 0x05, 0x0d, 0x6c,
	0x50, 0xec, 0xc0, 0x26, 0x0b, 0xf5, 0xd5, 0xf6, 0x13, 0x42, 0x55, 0xd2, 0xf5, 0x93, 0xd8, 0x49,
	0x74, 0xff, 0xdb, 0x9a, 0x99, 0x4f, 0x8c, 0x09, 0x55, 0x18, 0x77, 0x0c, 0x8c, 0x63, 0x07, 0x63,
	0xcd, 0x79, 0x39, 0xd5, 0x8b, 0x5d, 0xfd, 0x06, 0x00, 0x00, 0xff, 0xff, 0x27, 0x6c, 0xf2, 0x63,
	0xfe, 0x01, 0x00, 0x00,
}
