// Code generated by protoc-gen-go. DO NOT EDIT.
// source: google/ads/googleads/v1/enums/ad_group_type.proto

package enums

import (
	fmt "fmt"
	math "math"

	proto "github.com/golang/protobuf/proto"
	_ "google.golang.org/genproto/googleapis/api/annotations"
)

// Reference imports to suppress errors if they are not otherwise used.
var _ = proto.Marshal
var _ = fmt.Errorf
var _ = math.Inf

// This is a compile-time assertion to ensure that this generated file
// is compatible with the proto package it is being compiled against.
// A compilation error at this line likely means your copy of the
// proto package needs to be updated.
const _ = proto.ProtoPackageIsVersion3 // please upgrade the proto package

// Enum listing the possible types of an ad group.
type AdGroupTypeEnum_AdGroupType int32

const (
	// The type has not been specified.
	AdGroupTypeEnum_UNSPECIFIED AdGroupTypeEnum_AdGroupType = 0
	// The received value is not known in this version.
	//
	// This is a response-only value.
	AdGroupTypeEnum_UNKNOWN AdGroupTypeEnum_AdGroupType = 1
	// The default ad group type for Search campaigns.
	AdGroupTypeEnum_SEARCH_STANDARD AdGroupTypeEnum_AdGroupType = 2
	// The default ad group type for Display campaigns.
	AdGroupTypeEnum_DISPLAY_STANDARD AdGroupTypeEnum_AdGroupType = 3
	// The ad group type for Shopping campaigns serving standard product ads.
	AdGroupTypeEnum_SHOPPING_PRODUCT_ADS AdGroupTypeEnum_AdGroupType = 4
	// The default ad group type for Hotel campaigns.
	AdGroupTypeEnum_HOTEL_ADS AdGroupTypeEnum_AdGroupType = 6
	// The type for ad groups in Smart Shopping campaigns.
	AdGroupTypeEnum_SHOPPING_SMART_ADS AdGroupTypeEnum_AdGroupType = 7
	// Short unskippable in-stream video ads.
	AdGroupTypeEnum_VIDEO_BUMPER AdGroupTypeEnum_AdGroupType = 8
	// TrueView (skippable) in-stream video ads.
	AdGroupTypeEnum_VIDEO_TRUE_VIEW_IN_STREAM AdGroupTypeEnum_AdGroupType = 9
	// TrueView in-display video ads.
	AdGroupTypeEnum_VIDEO_TRUE_VIEW_IN_DISPLAY AdGroupTypeEnum_AdGroupType = 10
	// Unskippable in-stream video ads.
	AdGroupTypeEnum_VIDEO_NON_SKIPPABLE_IN_STREAM AdGroupTypeEnum_AdGroupType = 11
	// Outstream video ads.
	AdGroupTypeEnum_VIDEO_OUTSTREAM AdGroupTypeEnum_AdGroupType = 12
	// Ad group type for Dynamic Search Ads ad groups.
	AdGroupTypeEnum_SEARCH_DYNAMIC_ADS AdGroupTypeEnum_AdGroupType = 13
	// The type for ad groups in Shopping Comparison Listing campaigns.
	AdGroupTypeEnum_SHOPPING_COMPARISON_LISTING_ADS AdGroupTypeEnum_AdGroupType = 14
)

var AdGroupTypeEnum_AdGroupType_name = map[int32]string{
	0:  "UNSPECIFIED",
	1:  "UNKNOWN",
	2:  "SEARCH_STANDARD",
	3:  "DISPLAY_STANDARD",
	4:  "SHOPPING_PRODUCT_ADS",
	6:  "HOTEL_ADS",
	7:  "SHOPPING_SMART_ADS",
	8:  "VIDEO_BUMPER",
	9:  "VIDEO_TRUE_VIEW_IN_STREAM",
	10: "VIDEO_TRUE_VIEW_IN_DISPLAY",
	11: "VIDEO_NON_SKIPPABLE_IN_STREAM",
	12: "VIDEO_OUTSTREAM",
	13: "SEARCH_DYNAMIC_ADS",
	14: "SHOPPING_COMPARISON_LISTING_ADS",
}

var AdGroupTypeEnum_AdGroupType_value = map[string]int32{
	"UNSPECIFIED":                     0,
	"UNKNOWN":                         1,
	"SEARCH_STANDARD":                 2,
	"DISPLAY_STANDARD":                3,
	"SHOPPING_PRODUCT_ADS":            4,
	"HOTEL_ADS":                       6,
	"SHOPPING_SMART_ADS":              7,
	"VIDEO_BUMPER":                    8,
	"VIDEO_TRUE_VIEW_IN_STREAM":       9,
	"VIDEO_TRUE_VIEW_IN_DISPLAY":      10,
	"VIDEO_NON_SKIPPABLE_IN_STREAM":   11,
	"VIDEO_OUTSTREAM":                 12,
	"SEARCH_DYNAMIC_ADS":              13,
	"SHOPPING_COMPARISON_LISTING_ADS": 14,
}

func (x AdGroupTypeEnum_AdGroupType) String() string {
	return proto.EnumName(AdGroupTypeEnum_AdGroupType_name, int32(x))
}

func (AdGroupTypeEnum_AdGroupType) EnumDescriptor() ([]byte, []int) {
	return fileDescriptor_07bc19b8ed4d56ed, []int{0, 0}
}

// Defines types of an ad group, specific to a particular campaign channel
// type. This type drives validations that restrict which entities can be
// added to the ad group.
type AdGroupTypeEnum struct {
	XXX_NoUnkeyedLiteral struct{} `json:"-"`
	XXX_unrecognized     []byte   `json:"-"`
	XXX_sizecache        int32    `json:"-"`
}

func (m *AdGroupTypeEnum) Reset()         { *m = AdGroupTypeEnum{} }
func (m *AdGroupTypeEnum) String() string { return proto.CompactTextString(m) }
func (*AdGroupTypeEnum) ProtoMessage()    {}
func (*AdGroupTypeEnum) Descriptor() ([]byte, []int) {
	return fileDescriptor_07bc19b8ed4d56ed, []int{0}
}

func (m *AdGroupTypeEnum) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_AdGroupTypeEnum.Unmarshal(m, b)
}
func (m *AdGroupTypeEnum) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_AdGroupTypeEnum.Marshal(b, m, deterministic)
}
func (m *AdGroupTypeEnum) XXX_Merge(src proto.Message) {
	xxx_messageInfo_AdGroupTypeEnum.Merge(m, src)
}
func (m *AdGroupTypeEnum) XXX_Size() int {
	return xxx_messageInfo_AdGroupTypeEnum.Size(m)
}
func (m *AdGroupTypeEnum) XXX_DiscardUnknown() {
	xxx_messageInfo_AdGroupTypeEnum.DiscardUnknown(m)
}

var xxx_messageInfo_AdGroupTypeEnum proto.InternalMessageInfo

func init() {
	proto.RegisterEnum("google.ads.googleads.v1.enums.AdGroupTypeEnum_AdGroupType", AdGroupTypeEnum_AdGroupType_name, AdGroupTypeEnum_AdGroupType_value)
	proto.RegisterType((*AdGroupTypeEnum)(nil), "google.ads.googleads.v1.enums.AdGroupTypeEnum")
}

func init() {
	proto.RegisterFile("google/ads/googleads/v1/enums/ad_group_type.proto", fileDescriptor_07bc19b8ed4d56ed)
}

var fileDescriptor_07bc19b8ed4d56ed = []byte{
	// 467 bytes of a gzipped FileDescriptorProto
	0x1f, 0x8b, 0x08, 0x00, 0x00, 0x00, 0x00, 0x00, 0x02, 0xff, 0x7c, 0x52, 0x41, 0x6f, 0xd3, 0x30,
	0x18, 0xa5, 0x19, 0xda, 0x98, 0xbb, 0x51, 0xcb, 0x4c, 0x08, 0x26, 0x0a, 0xea, 0xb8, 0x27, 0x8a,
	0xb8, 0x85, 0x93, 0x93, 0x98, 0xd6, 0x5a, 0xe3, 0x58, 0x71, 0x92, 0x69, 0xa8, 0x92, 0x15, 0x48,
	0x14, 0x55, 0x5a, 0xe3, 0xa8, 0x69, 0x27, 0xed, 0xef, 0x70, 0xe4, 0xa7, 0xf0, 0x1f, 0x38, 0x72,
	0xe1, 0xc6, 0x3f, 0x40, 0x89, 0xdb, 0xd0, 0x03, 0x70, 0x89, 0xbe, 0xbc, 0xf7, 0xbe, 0xa7, 0x67,
	0xbd, 0x0f, 0xd8, 0xa5, 0x52, 0xe5, 0x5d, 0x61, 0x65, 0x79, 0x63, 0xe9, 0xb1, 0x9d, 0xee, 0x6d,
	0xab, 0xa8, 0xb6, 0xab, 0xc6, 0xca, 0x72, 0x59, 0xae, 0xd5, 0xb6, 0x96, 0x9b, 0x87, 0xba, 0x30,
	0xeb, 0xb5, 0xda, 0x28, 0x34, 0xd6, 0x3a, 0x33, 0xcb, 0x1b, 0xb3, 0x5f, 0x31, 0xef, 0x6d, 0xb3,
	0x5b, 0xb9, 0x7c, 0xb5, 0x77, 0xac, 0x97, 0x56, 0x56, 0x55, 0x6a, 0x93, 0x6d, 0x96, 0xaa, 0x6a,
	0xf4, 0xf2, 0xd5, 0x2f, 0x03, 0x8c, 0x70, 0x3e, 0x6d, 0x3d, 0xe3, 0x87, 0xba, 0x20, 0xd5, 0x76,
	0x75, 0xf5, 0xdd, 0x00, 0xc3, 0x03, 0x0c, 0x8d, 0xc0, 0x30, 0x61, 0x82, 0x13, 0x8f, 0x7e, 0xa0,
	0xc4, 0x87, 0x8f, 0xd0, 0x10, 0x9c, 0x24, 0xec, 0x9a, 0x85, 0x37, 0x0c, 0x0e, 0xd0, 0x33, 0x30,
	0x12, 0x04, 0x47, 0xde, 0x4c, 0x8a, 0x18, 0x33, 0x1f, 0x47, 0x3e, 0x34, 0xd0, 0x05, 0x80, 0x3e,
	0x15, 0x7c, 0x8e, 0x6f, 0xff, 0xa0, 0x47, 0xe8, 0x05, 0xb8, 0x10, 0xb3, 0x90, 0x73, 0xca, 0xa6,
	0x92, 0x47, 0xa1, 0x9f, 0x78, 0xb1, 0xc4, 0xbe, 0x80, 0x8f, 0xd1, 0x39, 0x38, 0x9d, 0x85, 0x31,
	0x99, 0x77, 0xbf, 0xc7, 0xe8, 0x39, 0x40, 0xbd, 0x50, 0x04, 0x38, 0xd2, 0xb2, 0x13, 0x04, 0xc1,
	0x59, 0x4a, 0x7d, 0x12, 0x4a, 0x37, 0x09, 0x38, 0x89, 0xe0, 0x13, 0x34, 0x06, 0x2f, 0x35, 0x12,
	0x47, 0x09, 0x91, 0x29, 0x25, 0x37, 0x92, 0x32, 0x29, 0xe2, 0x88, 0xe0, 0x00, 0x9e, 0xa2, 0xd7,
	0xe0, 0xf2, 0x2f, 0xf4, 0x2e, 0x1a, 0x04, 0x68, 0x02, 0xc6, 0x9a, 0x67, 0x21, 0x93, 0xe2, 0x9a,
	0x72, 0x8e, 0xdd, 0x39, 0x39, 0xb0, 0x18, 0xb6, 0xef, 0xd3, 0x92, 0x30, 0x89, 0x77, 0xe0, 0x59,
	0x17, 0x50, 0x3f, 0xda, 0xbf, 0x65, 0x38, 0xa0, 0x5e, 0x17, 0xf0, 0x1c, 0xbd, 0x05, 0x6f, 0xfa,
	0xe0, 0x5e, 0x18, 0x70, 0x1c, 0x51, 0x11, 0x32, 0x39, 0xa7, 0x22, 0x6e, 0xa1, 0x56, 0xf4, 0xd4,
	0xfd, 0x31, 0x00, 0x93, 0xcf, 0x6a, 0x65, 0xfe, 0xb7, 0x37, 0x17, 0x1e, 0x54, 0xc0, 0xdb, 0xae,
	0xf8, 0xe0, 0xa3, 0xbb, 0x5b, 0x29, 0xd5, 0x5d, 0x56, 0x95, 0xa6, 0x5a, 0x97, 0x56, 0x59, 0x54,
	0x5d, 0x93, 0xfb, 0x6b, 0xa9, 0x97, 0xcd, 0x3f, 0x8e, 0xe7, 0x7d, 0xf7, 0xfd, 0x62, 0x1c, 0x4d,
	0x31, 0xfe, 0x6a, 0x8c, 0xa7, 0xda, 0x0a, 0xe7, 0x8d, 0xa9, 0xc7, 0x76, 0x4a, 0x6d, 0xb3, 0x3d,
	0x81, 0xe6, 0xdb, 0x9e, 0x5f, 0xe0, 0xbc, 0x59, 0xf4, 0xfc, 0x22, 0xb5, 0x17, 0x1d, 0xff, 0xd3,
	0x98, 0x68, 0xd0, 0x71, 0x70, 0xde, 0x38, 0x4e, 0xaf, 0x70, 0x9c, 0xd4, 0x76, 0x9c, 0x4e, 0xf3,
	0xe9, 0xb8, 0x0b, 0xf6, 0xee, 0x77, 0x00, 0x00, 0x00, 0xff, 0xff, 0x6e, 0x9f, 0xf2, 0xee, 0xd4,
	0x02, 0x00, 0x00,
}
