// Code generated by protoc-gen-go. DO NOT EDIT.
// source: google/ads/googleads/v1/errors/ad_group_error.proto

package errors

import (
	fmt "fmt"
	math "math"

	proto "github.com/golang/protobuf/proto"
	_ "google.golang.org/genproto/googleapis/api/annotations"
)

// Reference imports to suppress errors if they are not otherwise used.
var _ = proto.Marshal
var _ = fmt.Errorf
var _ = math.Inf

// This is a compile-time assertion to ensure that this generated file
// is compatible with the proto package it is being compiled against.
// A compilation error at this line likely means your copy of the
// proto package needs to be updated.
const _ = proto.ProtoPackageIsVersion3 // please upgrade the proto package

// Enum describing possible ad group errors.
type AdGroupErrorEnum_AdGroupError int32

const (
	// Enum unspecified.
	AdGroupErrorEnum_UNSPECIFIED AdGroupErrorEnum_AdGroupError = 0
	// The received error code is not known in this version.
	AdGroupErrorEnum_UNKNOWN AdGroupErrorEnum_AdGroupError = 1
	// AdGroup with the same name already exists for the campaign.
	AdGroupErrorEnum_DUPLICATE_ADGROUP_NAME AdGroupErrorEnum_AdGroupError = 2
	// AdGroup name is not valid.
	AdGroupErrorEnum_INVALID_ADGROUP_NAME AdGroupErrorEnum_AdGroupError = 3
	// Advertiser is not allowed to target sites or set site bids that are not
	// on the Google Search Network.
	AdGroupErrorEnum_ADVERTISER_NOT_ON_CONTENT_NETWORK AdGroupErrorEnum_AdGroupError = 5
	// Bid amount is too big.
	AdGroupErrorEnum_BID_TOO_BIG AdGroupErrorEnum_AdGroupError = 6
	// AdGroup bid does not match the campaign's bidding strategy.
	AdGroupErrorEnum_BID_TYPE_AND_BIDDING_STRATEGY_MISMATCH AdGroupErrorEnum_AdGroupError = 7
	// AdGroup name is required for Add.
	AdGroupErrorEnum_MISSING_ADGROUP_NAME AdGroupErrorEnum_AdGroupError = 8
	// No link found between the ad group and the label.
	AdGroupErrorEnum_ADGROUP_LABEL_DOES_NOT_EXIST AdGroupErrorEnum_AdGroupError = 9
	// The label has already been attached to the ad group.
	AdGroupErrorEnum_ADGROUP_LABEL_ALREADY_EXISTS AdGroupErrorEnum_AdGroupError = 10
	// The CriterionTypeGroup is not supported for the content bid dimension.
	AdGroupErrorEnum_INVALID_CONTENT_BID_CRITERION_TYPE_GROUP AdGroupErrorEnum_AdGroupError = 11
	// The ad group type is not compatible with the campaign channel type.
	AdGroupErrorEnum_AD_GROUP_TYPE_NOT_VALID_FOR_ADVERTISING_CHANNEL_TYPE AdGroupErrorEnum_AdGroupError = 12
	// The ad group type is not supported in the country of sale of the
	// campaign.
	AdGroupErrorEnum_ADGROUP_TYPE_NOT_SUPPORTED_FOR_CAMPAIGN_SALES_COUNTRY AdGroupErrorEnum_AdGroupError = 13
	// Ad groups of AdGroupType.SEARCH_DYNAMIC_ADS can only be added to
	// campaigns that have DynamicSearchAdsSetting attached.
	AdGroupErrorEnum_CANNOT_ADD_ADGROUP_OF_TYPE_DSA_TO_CAMPAIGN_WITHOUT_DSA_SETTING AdGroupErrorEnum_AdGroupError = 14
)

var AdGroupErrorEnum_AdGroupError_name = map[int32]string{
	0:  "UNSPECIFIED",
	1:  "UNKNOWN",
	2:  "DUPLICATE_ADGROUP_NAME",
	3:  "INVALID_ADGROUP_NAME",
	5:  "ADVERTISER_NOT_ON_CONTENT_NETWORK",
	6:  "BID_TOO_BIG",
	7:  "BID_TYPE_AND_BIDDING_STRATEGY_MISMATCH",
	8:  "MISSING_ADGROUP_NAME",
	9:  "ADGROUP_LABEL_DOES_NOT_EXIST",
	10: "ADGROUP_LABEL_ALREADY_EXISTS",
	11: "INVALID_CONTENT_BID_CRITERION_TYPE_GROUP",
	12: "AD_GROUP_TYPE_NOT_VALID_FOR_ADVERTISING_CHANNEL_TYPE",
	13: "ADGROUP_TYPE_NOT_SUPPORTED_FOR_CAMPAIGN_SALES_COUNTRY",
	14: "CANNOT_ADD_ADGROUP_OF_TYPE_DSA_TO_CAMPAIGN_WITHOUT_DSA_SETTING",
}

var AdGroupErrorEnum_AdGroupError_value = map[string]int32{
	"UNSPECIFIED":                                                    0,
	"UNKNOWN":                                                        1,
	"DUPLICATE_ADGROUP_NAME":                                         2,
	"INVALID_ADGROUP_NAME":                                           3,
	"ADVERTISER_NOT_ON_CONTENT_NETWORK":                              5,
	"BID_TOO_BIG":                                                    6,
	"BID_TYPE_AND_BIDDING_STRATEGY_MISMATCH":                         7,
	"MISSING_ADGROUP_NAME":                                           8,
	"ADGROUP_LABEL_DOES_NOT_EXIST":                                   9,
	"ADGROUP_LABEL_ALREADY_EXISTS":                                   10,
	"INVALID_CONTENT_BID_CRITERION_TYPE_GROUP":                       11,
	"AD_GROUP_TYPE_NOT_VALID_FOR_ADVERTISING_CHANNEL_TYPE":           12,
	"ADGROUP_TYPE_NOT_SUPPORTED_FOR_CAMPAIGN_SALES_COUNTRY":          13,
	"CANNOT_ADD_ADGROUP_OF_TYPE_DSA_TO_CAMPAIGN_WITHOUT_DSA_SETTING": 14,
}

func (x AdGroupErrorEnum_AdGroupError) String() string {
	return proto.EnumName(AdGroupErrorEnum_AdGroupError_name, int32(x))
}

func (AdGroupErrorEnum_AdGroupError) EnumDescriptor() ([]byte, []int) {
	return fileDescriptor_8e0068e691513cbe, []int{0, 0}
}

// Container for enum describing possible ad group errors.
type AdGroupErrorEnum struct {
	XXX_NoUnkeyedLiteral struct{} `json:"-"`
	XXX_unrecognized     []byte   `json:"-"`
	XXX_sizecache        int32    `json:"-"`
}

func (m *AdGroupErrorEnum) Reset()         { *m = AdGroupErrorEnum{} }
func (m *AdGroupErrorEnum) String() string { return proto.CompactTextString(m) }
func (*AdGroupErrorEnum) ProtoMessage()    {}
func (*AdGroupErrorEnum) Descriptor() ([]byte, []int) {
	return fileDescriptor_8e0068e691513cbe, []int{0}
}

func (m *AdGroupErrorEnum) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_AdGroupErrorEnum.Unmarshal(m, b)
}
func (m *AdGroupErrorEnum) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_AdGroupErrorEnum.Marshal(b, m, deterministic)
}
func (m *AdGroupErrorEnum) XXX_Merge(src proto.Message) {
	xxx_messageInfo_AdGroupErrorEnum.Merge(m, src)
}
func (m *AdGroupErrorEnum) XXX_Size() int {
	return xxx_messageInfo_AdGroupErrorEnum.Size(m)
}
func (m *AdGroupErrorEnum) XXX_DiscardUnknown() {
	xxx_messageInfo_AdGroupErrorEnum.DiscardUnknown(m)
}

var xxx_messageInfo_AdGroupErrorEnum proto.InternalMessageInfo

func init() {
	proto.RegisterEnum("google.ads.googleads.v1.errors.AdGroupErrorEnum_AdGroupError", AdGroupErrorEnum_AdGroupError_name, AdGroupErrorEnum_AdGroupError_value)
	proto.RegisterType((*AdGroupErrorEnum)(nil), "google.ads.googleads.v1.errors.AdGroupErrorEnum")
}

func init() {
	proto.RegisterFile("google/ads/googleads/v1/errors/ad_group_error.proto", fileDescriptor_8e0068e691513cbe)
}

var fileDescriptor_8e0068e691513cbe = []byte{
	// 554 bytes of a gzipped FileDescriptorProto
	0x1f, 0x8b, 0x08, 0x00, 0x00, 0x00, 0x00, 0x00, 0x02, 0xff, 0x7c, 0x92, 0xe1, 0x6a, 0xd4, 0x40,
	0x14, 0x85, 0xed, 0xb6, 0xb6, 0x3a, 0xad, 0x3a, 0x0e, 0x22, 0x52, 0x4a, 0xd1, 0x05, 0x45, 0x44,
	0xb2, 0x2c, 0x55, 0xd0, 0x08, 0xc2, 0x4d, 0x66, 0x9a, 0x0e, 0xcd, 0xce, 0x84, 0xcc, 0x64, 0xeb,
	0xca, 0xc2, 0xb0, 0x9a, 0x12, 0x0a, 0x6d, 0xb2, 0x24, 0xdb, 0xbe, 0x84, 0x2f, 0x21, 0xfe, 0xf4,
	0x51, 0x7c, 0x14, 0xf1, 0x21, 0x64, 0x32, 0x66, 0xdb, 0x22, 0xfa, 0x2b, 0x77, 0xee, 0x7c, 0xe7,
	0xde, 0x93, 0xe4, 0xa0, 0xbd, 0xa2, 0xaa, 0x8a, 0xd3, 0xe3, 0xc1, 0x2c, 0x6f, 0x06, 0xae, 0xb4,
	0xd5, 0xc5, 0x70, 0x70, 0x5c, 0xd7, 0x55, 0xdd, 0x0c, 0x66, 0xb9, 0x29, 0xea, 0xea, 0x7c, 0x6e,
	0xda, 0xb3, 0x37, 0xaf, 0xab, 0x45, 0x45, 0x76, 0x1d, 0xe9, 0xcd, 0xf2, 0xc6, 0x5b, 0x8a, 0xbc,
	0x8b, 0xa1, 0xe7, 0x44, 0xdb, 0x3b, 0xdd, 0xd0, 0xf9, 0xc9, 0x60, 0x56, 0x96, 0xd5, 0x62, 0xb6,
	0x38, 0xa9, 0xca, 0xc6, 0xa9, 0xfb, 0x5f, 0xd7, 0x10, 0x86, 0x3c, 0xb2, 0x53, 0x99, 0xe5, 0x59,
	0x79, 0x7e, 0xd6, 0xff, 0xb2, 0x86, 0xb6, 0xae, 0x36, 0xc9, 0x3d, 0xb4, 0x99, 0x09, 0x95, 0xb0,
	0x90, 0xef, 0x73, 0x46, 0xf1, 0x0d, 0xb2, 0x89, 0x36, 0x32, 0x71, 0x28, 0xe4, 0x91, 0xc0, 0x2b,
	0x64, 0x1b, 0x3d, 0xa4, 0x59, 0x12, 0xf3, 0x10, 0x34, 0x33, 0x40, 0xa3, 0x54, 0x66, 0x89, 0x11,
	0x30, 0x62, 0xb8, 0x47, 0x1e, 0xa1, 0x07, 0x5c, 0x8c, 0x21, 0xe6, 0xf4, 0xfa, 0xcd, 0x2a, 0x79,
	0x8a, 0x9e, 0x00, 0x1d, 0xb3, 0x54, 0x73, 0xc5, 0x52, 0x23, 0xa4, 0x36, 0x52, 0x98, 0x50, 0x0a,
	0xcd, 0x84, 0x36, 0x82, 0xe9, 0x23, 0x99, 0x1e, 0xe2, 0x9b, 0x76, 0x75, 0xc0, 0xa9, 0xd1, 0x52,
	0x9a, 0x80, 0x47, 0x78, 0x9d, 0xbc, 0x40, 0xcf, 0xda, 0xc6, 0x24, 0x61, 0x06, 0x04, 0x35, 0x01,
	0xa7, 0x94, 0x8b, 0xc8, 0x28, 0x9d, 0x82, 0x66, 0xd1, 0xc4, 0x8c, 0xb8, 0x1a, 0x81, 0x0e, 0x0f,
	0xf0, 0x86, 0xdd, 0x3e, 0xe2, 0x4a, 0xd9, 0xeb, 0x6b, 0xdb, 0x6f, 0x91, 0xc7, 0x68, 0xa7, 0xeb,
	0xc4, 0x10, 0xb0, 0xd8, 0x50, 0xc9, 0x54, 0xeb, 0x82, 0x7d, 0xe0, 0x4a, 0xe3, 0xdb, 0x7f, 0x13,
	0x10, 0xa7, 0x0c, 0xe8, 0xc4, 0x01, 0x0a, 0x23, 0xf2, 0x12, 0x3d, 0xef, 0xde, 0xad, 0xf3, 0x6d,
	0x9d, 0x85, 0x29, 0xd7, 0x2c, 0xe5, 0x52, 0x38, 0x8f, 0xed, 0x08, 0xbc, 0x49, 0xde, 0xa0, 0x57,
	0x40, 0xdd, 0xc9, 0x5d, 0xd8, 0x65, 0x4e, 0xbd, 0x2f, 0x53, 0xd3, 0x7d, 0x0b, 0xeb, 0x35, 0x3c,
	0x00, 0x21, 0x58, 0xdc, 0x62, 0x78, 0x8b, 0xbc, 0x45, 0xaf, 0x3b, 0x27, 0x4b, 0xa1, 0xca, 0x92,
	0x44, 0xa6, 0x9a, 0x39, 0x71, 0x08, 0xa3, 0x04, 0x78, 0x24, 0x8c, 0x82, 0x98, 0x29, 0x13, 0xca,
	0x4c, 0xe8, 0x74, 0x82, 0xef, 0x90, 0x00, 0xbd, 0x0f, 0x41, 0x58, 0x01, 0xd0, 0xcb, 0x3f, 0x20,
	0xf7, 0xdd, 0x20, 0xaa, 0xc0, 0x68, 0x79, 0xa9, 0x3e, 0xe2, 0xfa, 0x40, 0x66, 0xba, 0xed, 0x2b,
	0xa6, 0x35, 0x17, 0x11, 0xbe, 0x1b, 0xfc, 0x5a, 0x41, 0xfd, 0xcf, 0xd5, 0x99, 0xf7, 0xff, 0x9c,
	0x05, 0xf7, 0xaf, 0x26, 0x26, 0xb1, 0xe1, 0x4a, 0x56, 0x3e, 0xd2, 0x3f, 0xa2, 0xa2, 0x3a, 0x9d,
	0x95, 0x85, 0x57, 0xd5, 0xc5, 0xa0, 0x38, 0x2e, 0xdb, 0xe8, 0x75, 0x09, 0x9f, 0x9f, 0x34, 0xff,
	0x0a, 0xfc, 0x3b, 0xf7, 0xf8, 0xd6, 0x5b, 0x8d, 0x00, 0xbe, 0xf7, 0x76, 0x23, 0x37, 0x0c, 0xf2,
	0xc6, 0x73, 0xa5, 0xad, 0xc6, 0x43, 0xaf, 0x5d, 0xd9, 0xfc, 0xe8, 0x80, 0x29, 0xe4, 0xcd, 0x74,
	0x09, 0x4c, 0xc7, 0xc3, 0xa9, 0x03, 0x7e, 0xf6, 0xfa, 0xae, 0xeb, 0xfb, 0x90, 0x37, 0xbe, 0xbf,
	0x44, 0x7c, 0x7f, 0x3c, 0xf4, 0x7d, 0x07, 0x7d, 0x5a, 0x6f, 0xdd, 0xed, 0xfd, 0x0e, 0x00, 0x00,
	0xff, 0xff, 0x3e, 0x57, 0xba, 0x3d, 0x8d, 0x03, 0x00, 0x00,
}
