// Code generated by protoc-gen-go. DO NOT EDIT.
// source: google/ads/googleads/v1/common/segments.proto

package common

import (
	fmt "fmt"
	math "math"

	proto "github.com/golang/protobuf/proto"
	wrappers "github.com/golang/protobuf/ptypes/wrappers"
	enums "google.golang.org/genproto/googleapis/ads/googleads/v1/enums"
	_ "google.golang.org/genproto/googleapis/api/annotations"
)

// Reference imports to suppress errors if they are not otherwise used.
var _ = proto.Marshal
var _ = fmt.Errorf
var _ = math.Inf

// This is a compile-time assertion to ensure that this generated file
// is compatible with the proto package it is being compiled against.
// A compilation error at this line likely means your copy of the
// proto package needs to be updated.
const _ = proto.ProtoPackageIsVersion3 // please upgrade the proto package

// Segment only fields.
type Segments struct {
	// Ad network type.
	AdNetworkType enums.AdNetworkTypeEnum_AdNetworkType `protobuf:"varint,3,opt,name=ad_network_type,json=adNetworkType,proto3,enum=google.ads.googleads.v1.enums.AdNetworkTypeEnum_AdNetworkType" json:"ad_network_type,omitempty"`
	// Click type.
	ClickType enums.ClickTypeEnum_ClickType `protobuf:"varint,26,opt,name=click_type,json=clickType,proto3,enum=google.ads.googleads.v1.enums.ClickTypeEnum_ClickType" json:"click_type,omitempty"`
	// Resource name of the conversion action.
	ConversionAction *wrappers.StringValue `protobuf:"bytes,52,opt,name=conversion_action,json=conversionAction,proto3" json:"conversion_action,omitempty"`
	// Conversion action category.
	ConversionActionCategory enums.ConversionActionCategoryEnum_ConversionActionCategory `protobuf:"varint,53,opt,name=conversion_action_category,json=conversionActionCategory,proto3,enum=google.ads.googleads.v1.enums.ConversionActionCategoryEnum_ConversionActionCategory" json:"conversion_action_category,omitempty"`
	// Conversion action name.
	ConversionActionName *wrappers.StringValue `protobuf:"bytes,54,opt,name=conversion_action_name,json=conversionActionName,proto3" json:"conversion_action_name,omitempty"`
	// This segments your conversion columns by the original conversion and
	// conversion value vs. the delta if conversions were adjusted. False row has
	// the data as originally stated; While true row has the delta between data
	// now and the data as originally stated. Summing the two together results
	// post-adjustment data.
	ConversionAdjustment *wrappers.BoolValue `protobuf:"bytes,27,opt,name=conversion_adjustment,json=conversionAdjustment,proto3" json:"conversion_adjustment,omitempty"`
	// Conversion attribution event type.
	ConversionAttributionEventType enums.ConversionAttributionEventTypeEnum_ConversionAttributionEventType `protobuf:"varint,2,opt,name=conversion_attribution_event_type,json=conversionAttributionEventType,proto3,enum=google.ads.googleads.v1.enums.ConversionAttributionEventTypeEnum_ConversionAttributionEventType" json:"conversion_attribution_event_type,omitempty"`
	// An enum value representing the number of days between the impression and
	// the conversion.
	ConversionLagBucket enums.ConversionLagBucketEnum_ConversionLagBucket `protobuf:"varint,50,opt,name=conversion_lag_bucket,json=conversionLagBucket,proto3,enum=google.ads.googleads.v1.enums.ConversionLagBucketEnum_ConversionLagBucket" json:"conversion_lag_bucket,omitempty"`
	// An enum value representing the number of days between the impression and
	// the conversion or between the impression and adjustments to the conversion.
	ConversionOrAdjustmentLagBucket enums.ConversionOrAdjustmentLagBucketEnum_ConversionOrAdjustmentLagBucket `protobuf:"varint,51,opt,name=conversion_or_adjustment_lag_bucket,json=conversionOrAdjustmentLagBucket,proto3,enum=google.ads.googleads.v1.enums.ConversionOrAdjustmentLagBucketEnum_ConversionOrAdjustmentLagBucket" json:"conversion_or_adjustment_lag_bucket,omitempty"`
	// Date to which metrics apply.
	// yyyy-MM-dd format, e.g., 2018-04-17.
	Date *wrappers.StringValue `protobuf:"bytes,4,opt,name=date,proto3" json:"date,omitempty"`
	// Day of the week, e.g., MONDAY.
	DayOfWeek enums.DayOfWeekEnum_DayOfWeek `protobuf:"varint,5,opt,name=day_of_week,json=dayOfWeek,proto3,enum=google.ads.googleads.v1.enums.DayOfWeekEnum_DayOfWeek" json:"day_of_week,omitempty"`
	// Device to which metrics apply.
	Device enums.DeviceEnum_Device `protobuf:"varint,1,opt,name=device,proto3,enum=google.ads.googleads.v1.enums.DeviceEnum_Device" json:"device,omitempty"`
	// External conversion source.
	ExternalConversionSource enums.ExternalConversionSourceEnum_ExternalConversionSource `protobuf:"varint,55,opt,name=external_conversion_source,json=externalConversionSource,proto3,enum=google.ads.googleads.v1.enums.ExternalConversionSourceEnum_ExternalConversionSource" json:"external_conversion_source,omitempty"`
	// Resource name of the geo target constant that represents an airport.
	GeoTargetAirport *wrappers.StringValue `protobuf:"bytes,65,opt,name=geo_target_airport,json=geoTargetAirport,proto3" json:"geo_target_airport,omitempty"`
	// Resource name of the geo target constant that represents a city.
	GeoTargetCity *wrappers.StringValue `protobuf:"bytes,62,opt,name=geo_target_city,json=geoTargetCity,proto3" json:"geo_target_city,omitempty"`
	// Resource name of the geo target constant that represents a county.
	GeoTargetCounty *wrappers.StringValue `protobuf:"bytes,68,opt,name=geo_target_county,json=geoTargetCounty,proto3" json:"geo_target_county,omitempty"`
	// Resource name of the geo target constant that represents a district.
	GeoTargetDistrict *wrappers.StringValue `protobuf:"bytes,69,opt,name=geo_target_district,json=geoTargetDistrict,proto3" json:"geo_target_district,omitempty"`
	// Resource name of the geo target constant that represents a metro.
	GeoTargetMetro *wrappers.StringValue `protobuf:"bytes,63,opt,name=geo_target_metro,json=geoTargetMetro,proto3" json:"geo_target_metro,omitempty"`
	// Resource name of the geo target constant that represents the most
	// specific location.
	GeoTargetMostSpecificLocation *wrappers.StringValue `protobuf:"bytes,72,opt,name=geo_target_most_specific_location,json=geoTargetMostSpecificLocation,proto3" json:"geo_target_most_specific_location,omitempty"`
	// Resource name of the geo target constant that represents a postal code.
	GeoTargetPostalCode *wrappers.StringValue `protobuf:"bytes,71,opt,name=geo_target_postal_code,json=geoTargetPostalCode,proto3" json:"geo_target_postal_code,omitempty"`
	// Resource name of the geo target constant that represents a province.
	GeoTargetProvince *wrappers.StringValue `protobuf:"bytes,75,opt,name=geo_target_province,json=geoTargetProvince,proto3" json:"geo_target_province,omitempty"`
	// Resource name of the geo target constant that represents a region.
	GeoTargetRegion *wrappers.StringValue `protobuf:"bytes,64,opt,name=geo_target_region,json=geoTargetRegion,proto3" json:"geo_target_region,omitempty"`
	// Resource name of the geo target constant that represents a state.
	GeoTargetState *wrappers.StringValue `protobuf:"bytes,67,opt,name=geo_target_state,json=geoTargetState,proto3" json:"geo_target_state,omitempty"`
	// Hotel booking window in days.
	HotelBookingWindowDays *wrappers.Int64Value `protobuf:"bytes,6,opt,name=hotel_booking_window_days,json=hotelBookingWindowDays,proto3" json:"hotel_booking_window_days,omitempty"`
	// Hotel center ID.
	HotelCenterId *wrappers.Int64Value `protobuf:"bytes,7,opt,name=hotel_center_id,json=hotelCenterId,proto3" json:"hotel_center_id,omitempty"`
	// Hotel check-in date. Formatted as yyyy-MM-dd.
	HotelCheckInDate *wrappers.StringValue `protobuf:"bytes,8,opt,name=hotel_check_in_date,json=hotelCheckInDate,proto3" json:"hotel_check_in_date,omitempty"`
	// Hotel check-in day of week.
	HotelCheckInDayOfWeek enums.DayOfWeekEnum_DayOfWeek `protobuf:"varint,9,opt,name=hotel_check_in_day_of_week,json=hotelCheckInDayOfWeek,proto3,enum=google.ads.googleads.v1.enums.DayOfWeekEnum_DayOfWeek" json:"hotel_check_in_day_of_week,omitempty"`
	// Hotel city.
	HotelCity *wrappers.StringValue `protobuf:"bytes,10,opt,name=hotel_city,json=hotelCity,proto3" json:"hotel_city,omitempty"`
	// Hotel class.
	HotelClass *wrappers.Int32Value `protobuf:"bytes,11,opt,name=hotel_class,json=hotelClass,proto3" json:"hotel_class,omitempty"`
	// Hotel country.
	HotelCountry *wrappers.StringValue `protobuf:"bytes,12,opt,name=hotel_country,json=hotelCountry,proto3" json:"hotel_country,omitempty"`
	// Hotel date selection type.
	HotelDateSelectionType enums.HotelDateSelectionTypeEnum_HotelDateSelectionType `protobuf:"varint,13,opt,name=hotel_date_selection_type,json=hotelDateSelectionType,proto3,enum=google.ads.googleads.v1.enums.HotelDateSelectionTypeEnum_HotelDateSelectionType" json:"hotel_date_selection_type,omitempty"`
	// Hotel length of stay.
	HotelLengthOfStay *wrappers.Int32Value `protobuf:"bytes,14,opt,name=hotel_length_of_stay,json=hotelLengthOfStay,proto3" json:"hotel_length_of_stay,omitempty"`
	// Hotel rate rule ID.
	HotelRateRuleId *wrappers.StringValue `protobuf:"bytes,73,opt,name=hotel_rate_rule_id,json=hotelRateRuleId,proto3" json:"hotel_rate_rule_id,omitempty"`
	// Hotel rate type.
	HotelRateType enums.HotelRateTypeEnum_HotelRateType `protobuf:"varint,74,opt,name=hotel_rate_type,json=hotelRateType,proto3,enum=google.ads.googleads.v1.enums.HotelRateTypeEnum_HotelRateType" json:"hotel_rate_type,omitempty"`
	// Hotel state.
	HotelState *wrappers.StringValue `protobuf:"bytes,15,opt,name=hotel_state,json=hotelState,proto3" json:"hotel_state,omitempty"`
	// Hour of day as a number between 0 and 23, inclusive.
	Hour *wrappers.Int32Value `protobuf:"bytes,16,opt,name=hour,proto3" json:"hour,omitempty"`
	// Only used with feed item metrics.
	// Indicates whether the interaction metrics occurred on the feed item itself
	// or a different extension or ad unit.
	InteractionOnThisExtension *wrappers.BoolValue `protobuf:"bytes,49,opt,name=interaction_on_this_extension,json=interactionOnThisExtension,proto3" json:"interaction_on_this_extension,omitempty"`
	// Keyword criterion.
	Keyword *Keyword `protobuf:"bytes,61,opt,name=keyword,proto3" json:"keyword,omitempty"`
	// Month as represented by the date of the first day of a month. Formatted as
	// yyyy-MM-dd.
	Month *wrappers.StringValue `protobuf:"bytes,17,opt,name=month,proto3" json:"month,omitempty"`
	// Month of the year, e.g., January.
	MonthOfYear enums.MonthOfYearEnum_MonthOfYear `protobuf:"varint,18,opt,name=month_of_year,json=monthOfYear,proto3,enum=google.ads.googleads.v1.enums.MonthOfYearEnum_MonthOfYear" json:"month_of_year,omitempty"`
	// Partner hotel ID.
	PartnerHotelId *wrappers.StringValue `protobuf:"bytes,19,opt,name=partner_hotel_id,json=partnerHotelId,proto3" json:"partner_hotel_id,omitempty"`
	// Placeholder type. This is only used with feed item metrics.
	PlaceholderType enums.PlaceholderTypeEnum_PlaceholderType `protobuf:"varint,20,opt,name=placeholder_type,json=placeholderType,proto3,enum=google.ads.googleads.v1.enums.PlaceholderTypeEnum_PlaceholderType" json:"placeholder_type,omitempty"`
	// Aggregator ID of the product.
	ProductAggregatorId *wrappers.UInt64Value `protobuf:"bytes,28,opt,name=product_aggregator_id,json=productAggregatorId,proto3" json:"product_aggregator_id,omitempty"`
	// Bidding category (level 1) of the product.
	ProductBiddingCategoryLevel1 *wrappers.StringValue `protobuf:"bytes,56,opt,name=product_bidding_category_level1,json=productBiddingCategoryLevel1,proto3" json:"product_bidding_category_level1,omitempty"`
	// Bidding category (level 2) of the product.
	ProductBiddingCategoryLevel2 *wrappers.StringValue `protobuf:"bytes,57,opt,name=product_bidding_category_level2,json=productBiddingCategoryLevel2,proto3" json:"product_bidding_category_level2,omitempty"`
	// Bidding category (level 3) of the product.
	ProductBiddingCategoryLevel3 *wrappers.StringValue `protobuf:"bytes,58,opt,name=product_bidding_category_level3,json=productBiddingCategoryLevel3,proto3" json:"product_bidding_category_level3,omitempty"`
	// Bidding category (level 4) of the product.
	ProductBiddingCategoryLevel4 *wrappers.StringValue `protobuf:"bytes,59,opt,name=product_bidding_category_level4,json=productBiddingCategoryLevel4,proto3" json:"product_bidding_category_level4,omitempty"`
	// Bidding category (level 5) of the product.
	ProductBiddingCategoryLevel5 *wrappers.StringValue `protobuf:"bytes,60,opt,name=product_bidding_category_level5,json=productBiddingCategoryLevel5,proto3" json:"product_bidding_category_level5,omitempty"`
	// Brand of the product.
	ProductBrand *wrappers.StringValue `protobuf:"bytes,29,opt,name=product_brand,json=productBrand,proto3" json:"product_brand,omitempty"`
	// Channel of the product.
	ProductChannel enums.ProductChannelEnum_ProductChannel `protobuf:"varint,30,opt,name=product_channel,json=productChannel,proto3,enum=google.ads.googleads.v1.enums.ProductChannelEnum_ProductChannel" json:"product_channel,omitempty"`
	// Channel exclusivity of the product.
	ProductChannelExclusivity enums.ProductChannelExclusivityEnum_ProductChannelExclusivity `protobuf:"varint,31,opt,name=product_channel_exclusivity,json=productChannelExclusivity,proto3,enum=google.ads.googleads.v1.enums.ProductChannelExclusivityEnum_ProductChannelExclusivity" json:"product_channel_exclusivity,omitempty"`
	// Condition of the product.
	ProductCondition enums.ProductConditionEnum_ProductCondition `protobuf:"varint,32,opt,name=product_condition,json=productCondition,proto3,enum=google.ads.googleads.v1.enums.ProductConditionEnum_ProductCondition" json:"product_condition,omitempty"`
	// Resource name of the geo target constant for the country of sale of the
	// product.
	ProductCountry *wrappers.StringValue `protobuf:"bytes,33,opt,name=product_country,json=productCountry,proto3" json:"product_country,omitempty"`
	// Custom attribute 0 of the product.
	ProductCustomAttribute0 *wrappers.StringValue `protobuf:"bytes,34,opt,name=product_custom_attribute0,json=productCustomAttribute0,proto3" json:"product_custom_attribute0,omitempty"`
	// Custom attribute 1 of the product.
	ProductCustomAttribute1 *wrappers.StringValue `protobuf:"bytes,35,opt,name=product_custom_attribute1,json=productCustomAttribute1,proto3" json:"product_custom_attribute1,omitempty"`
	// Custom attribute 2 of the product.
	ProductCustomAttribute2 *wrappers.StringValue `protobuf:"bytes,36,opt,name=product_custom_attribute2,json=productCustomAttribute2,proto3" json:"product_custom_attribute2,omitempty"`
	// Custom attribute 3 of the product.
	ProductCustomAttribute3 *wrappers.StringValue `protobuf:"bytes,37,opt,name=product_custom_attribute3,json=productCustomAttribute3,proto3" json:"product_custom_attribute3,omitempty"`
	// Custom attribute 4 of the product.
	ProductCustomAttribute4 *wrappers.StringValue `protobuf:"bytes,38,opt,name=product_custom_attribute4,json=productCustomAttribute4,proto3" json:"product_custom_attribute4,omitempty"`
	// Item ID of the product.
	ProductItemId *wrappers.StringValue `protobuf:"bytes,39,opt,name=product_item_id,json=productItemId,proto3" json:"product_item_id,omitempty"`
	// Resource name of the language constant for the language of the product.
	ProductLanguage *wrappers.StringValue `protobuf:"bytes,40,opt,name=product_language,json=productLanguage,proto3" json:"product_language,omitempty"`
	// Merchant ID of the product.
	ProductMerchantId *wrappers.UInt64Value `protobuf:"bytes,41,opt,name=product_merchant_id,json=productMerchantId,proto3" json:"product_merchant_id,omitempty"`
	// Store ID of the product.
	ProductStoreId *wrappers.StringValue `protobuf:"bytes,42,opt,name=product_store_id,json=productStoreId,proto3" json:"product_store_id,omitempty"`
	// Title of the product.
	ProductTitle *wrappers.StringValue `protobuf:"bytes,43,opt,name=product_title,json=productTitle,proto3" json:"product_title,omitempty"`
	// Type (level 1) of the product.
	ProductTypeL1 *wrappers.StringValue `protobuf:"bytes,44,opt,name=product_type_l1,json=productTypeL1,proto3" json:"product_type_l1,omitempty"`
	// Type (level 2) of the product.
	ProductTypeL2 *wrappers.StringValue `protobuf:"bytes,45,opt,name=product_type_l2,json=productTypeL2,proto3" json:"product_type_l2,omitempty"`
	// Type (level 3) of the product.
	ProductTypeL3 *wrappers.StringValue `protobuf:"bytes,46,opt,name=product_type_l3,json=productTypeL3,proto3" json:"product_type_l3,omitempty"`
	// Type (level 4) of the product.
	ProductTypeL4 *wrappers.StringValue `protobuf:"bytes,47,opt,name=product_type_l4,json=productTypeL4,proto3" json:"product_type_l4,omitempty"`
	// Type (level 5) of the product.
	ProductTypeL5 *wrappers.StringValue `protobuf:"bytes,48,opt,name=product_type_l5,json=productTypeL5,proto3" json:"product_type_l5,omitempty"`
	// Quarter as represented by the date of the first day of a quarter.
	// Uses the calendar year for quarters, e.g., the second quarter of 2018
	// starts on 2018-04-01. Formatted as yyyy-MM-dd.
	Quarter *wrappers.StringValue `protobuf:"bytes,21,opt,name=quarter,proto3" json:"quarter,omitempty"`
	// Type of the search engine results page.
	SearchEngineResultsPageType enums.SearchEngineResultsPageTypeEnum_SearchEngineResultsPageType `protobuf:"varint,70,opt,name=search_engine_results_page_type,json=searchEngineResultsPageType,proto3,enum=google.ads.googleads.v1.enums.SearchEngineResultsPageTypeEnum_SearchEngineResultsPageType" json:"search_engine_results_page_type,omitempty"`
	// Match type of the keyword that triggered the ad, including variants.
	SearchTermMatchType enums.SearchTermMatchTypeEnum_SearchTermMatchType `protobuf:"varint,22,opt,name=search_term_match_type,json=searchTermMatchType,proto3,enum=google.ads.googleads.v1.enums.SearchTermMatchTypeEnum_SearchTermMatchType" json:"search_term_match_type,omitempty"`
	// Position of the ad.
	Slot enums.SlotEnum_Slot `protobuf:"varint,23,opt,name=slot,proto3,enum=google.ads.googleads.v1.enums.SlotEnum_Slot" json:"slot,omitempty"`
	// Resource name of the ad group criterion that represents webpage criterion.
	Webpage *wrappers.StringValue `protobuf:"bytes,66,opt,name=webpage,proto3" json:"webpage,omitempty"`
	// Week as defined as Monday through Sunday, and represented by the date of
	// Monday. Formatted as yyyy-MM-dd.
	Week *wrappers.StringValue `protobuf:"bytes,24,opt,name=week,proto3" json:"week,omitempty"`
	// Year, formatted as yyyy.
	Year                 *wrappers.Int32Value `protobuf:"bytes,25,opt,name=year,proto3" json:"year,omitempty"`
	XXX_NoUnkeyedLiteral struct{}             `json:"-"`
	XXX_unrecognized     []byte               `json:"-"`
	XXX_sizecache        int32                `json:"-"`
}

func (m *Segments) Reset()         { *m = Segments{} }
func (m *Segments) String() string { return proto.CompactTextString(m) }
func (*Segments) ProtoMessage()    {}
func (*Segments) Descriptor() ([]byte, []int) {
	return fileDescriptor_e9c6876208f1817a, []int{0}
}

func (m *Segments) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_Segments.Unmarshal(m, b)
}
func (m *Segments) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_Segments.Marshal(b, m, deterministic)
}
func (m *Segments) XXX_Merge(src proto.Message) {
	xxx_messageInfo_Segments.Merge(m, src)
}
func (m *Segments) XXX_Size() int {
	return xxx_messageInfo_Segments.Size(m)
}
func (m *Segments) XXX_DiscardUnknown() {
	xxx_messageInfo_Segments.DiscardUnknown(m)
}

var xxx_messageInfo_Segments proto.InternalMessageInfo

func (m *Segments) GetAdNetworkType() enums.AdNetworkTypeEnum_AdNetworkType {
	if m != nil {
		return m.AdNetworkType
	}
	return enums.AdNetworkTypeEnum_UNSPECIFIED
}

func (m *Segments) GetClickType() enums.ClickTypeEnum_ClickType {
	if m != nil {
		return m.ClickType
	}
	return enums.ClickTypeEnum_UNSPECIFIED
}

func (m *Segments) GetConversionAction() *wrappers.StringValue {
	if m != nil {
		return m.ConversionAction
	}
	return nil
}

func (m *Segments) GetConversionActionCategory() enums.ConversionActionCategoryEnum_ConversionActionCategory {
	if m != nil {
		return m.ConversionActionCategory
	}
	return enums.ConversionActionCategoryEnum_UNSPECIFIED
}

func (m *Segments) GetConversionActionName() *wrappers.StringValue {
	if m != nil {
		return m.ConversionActionName
	}
	return nil
}

func (m *Segments) GetConversionAdjustment() *wrappers.BoolValue {
	if m != nil {
		return m.ConversionAdjustment
	}
	return nil
}

func (m *Segments) GetConversionAttributionEventType() enums.ConversionAttributionEventTypeEnum_ConversionAttributionEventType {
	if m != nil {
		return m.ConversionAttributionEventType
	}
	return enums.ConversionAttributionEventTypeEnum_UNSPECIFIED
}

func (m *Segments) GetConversionLagBucket() enums.ConversionLagBucketEnum_ConversionLagBucket {
	if m != nil {
		return m.ConversionLagBucket
	}
	return enums.ConversionLagBucketEnum_UNSPECIFIED
}

func (m *Segments) GetConversionOrAdjustmentLagBucket() enums.ConversionOrAdjustmentLagBucketEnum_ConversionOrAdjustmentLagBucket {
	if m != nil {
		return m.ConversionOrAdjustmentLagBucket
	}
	return enums.ConversionOrAdjustmentLagBucketEnum_UNSPECIFIED
}

func (m *Segments) GetDate() *wrappers.StringValue {
	if m != nil {
		return m.Date
	}
	return nil
}

func (m *Segments) GetDayOfWeek() enums.DayOfWeekEnum_DayOfWeek {
	if m != nil {
		return m.DayOfWeek
	}
	return enums.DayOfWeekEnum_UNSPECIFIED
}

func (m *Segments) GetDevice() enums.DeviceEnum_Device {
	if m != nil {
		return m.Device
	}
	return enums.DeviceEnum_UNSPECIFIED
}

func (m *Segments) GetExternalConversionSource() enums.ExternalConversionSourceEnum_ExternalConversionSource {
	if m != nil {
		return m.ExternalConversionSource
	}
	return enums.ExternalConversionSourceEnum_UNSPECIFIED
}

func (m *Segments) GetGeoTargetAirport() *wrappers.StringValue {
	if m != nil {
		return m.GeoTargetAirport
	}
	return nil
}

func (m *Segments) GetGeoTargetCity() *wrappers.StringValue {
	if m != nil {
		return m.GeoTargetCity
	}
	return nil
}

func (m *Segments) GetGeoTargetCounty() *wrappers.StringValue {
	if m != nil {
		return m.GeoTargetCounty
	}
	return nil
}

func (m *Segments) GetGeoTargetDistrict() *wrappers.StringValue {
	if m != nil {
		return m.GeoTargetDistrict
	}
	return nil
}

func (m *Segments) GetGeoTargetMetro() *wrappers.StringValue {
	if m != nil {
		return m.GeoTargetMetro
	}
	return nil
}

func (m *Segments) GetGeoTargetMostSpecificLocation() *wrappers.StringValue {
	if m != nil {
		return m.GeoTargetMostSpecificLocation
	}
	return nil
}

func (m *Segments) GetGeoTargetPostalCode() *wrappers.StringValue {
	if m != nil {
		return m.GeoTargetPostalCode
	}
	return nil
}

func (m *Segments) GetGeoTargetProvince() *wrappers.StringValue {
	if m != nil {
		return m.GeoTargetProvince
	}
	return nil
}

func (m *Segments) GetGeoTargetRegion() *wrappers.StringValue {
	if m != nil {
		return m.GeoTargetRegion
	}
	return nil
}

func (m *Segments) GetGeoTargetState() *wrappers.StringValue {
	if m != nil {
		return m.GeoTargetState
	}
	return nil
}

func (m *Segments) GetHotelBookingWindowDays() *wrappers.Int64Value {
	if m != nil {
		return m.HotelBookingWindowDays
	}
	return nil
}

func (m *Segments) GetHotelCenterId() *wrappers.Int64Value {
	if m != nil {
		return m.HotelCenterId
	}
	return nil
}

func (m *Segments) GetHotelCheckInDate() *wrappers.StringValue {
	if m != nil {
		return m.HotelCheckInDate
	}
	return nil
}

func (m *Segments) GetHotelCheckInDayOfWeek() enums.DayOfWeekEnum_DayOfWeek {
	if m != nil {
		return m.HotelCheckInDayOfWeek
	}
	return enums.DayOfWeekEnum_UNSPECIFIED
}

func (m *Segments) GetHotelCity() *wrappers.StringValue {
	if m != nil {
		return m.HotelCity
	}
	return nil
}

func (m *Segments) GetHotelClass() *wrappers.Int32Value {
	if m != nil {
		return m.HotelClass
	}
	return nil
}

func (m *Segments) GetHotelCountry() *wrappers.StringValue {
	if m != nil {
		return m.HotelCountry
	}
	return nil
}

func (m *Segments) GetHotelDateSelectionType() enums.HotelDateSelectionTypeEnum_HotelDateSelectionType {
	if m != nil {
		return m.HotelDateSelectionType
	}
	return enums.HotelDateSelectionTypeEnum_UNSPECIFIED
}

func (m *Segments) GetHotelLengthOfStay() *wrappers.Int32Value {
	if m != nil {
		return m.HotelLengthOfStay
	}
	return nil
}

func (m *Segments) GetHotelRateRuleId() *wrappers.StringValue {
	if m != nil {
		return m.HotelRateRuleId
	}
	return nil
}

func (m *Segments) GetHotelRateType() enums.HotelRateTypeEnum_HotelRateType {
	if m != nil {
		return m.HotelRateType
	}
	return enums.HotelRateTypeEnum_UNSPECIFIED
}

func (m *Segments) GetHotelState() *wrappers.StringValue {
	if m != nil {
		return m.HotelState
	}
	return nil
}

func (m *Segments) GetHour() *wrappers.Int32Value {
	if m != nil {
		return m.Hour
	}
	return nil
}

func (m *Segments) GetInteractionOnThisExtension() *wrappers.BoolValue {
	if m != nil {
		return m.InteractionOnThisExtension
	}
	return nil
}

func (m *Segments) GetKeyword() *Keyword {
	if m != nil {
		return m.Keyword
	}
	return nil
}

func (m *Segments) GetMonth() *wrappers.StringValue {
	if m != nil {
		return m.Month
	}
	return nil
}

func (m *Segments) GetMonthOfYear() enums.MonthOfYearEnum_MonthOfYear {
	if m != nil {
		return m.MonthOfYear
	}
	return enums.MonthOfYearEnum_UNSPECIFIED
}

func (m *Segments) GetPartnerHotelId() *wrappers.StringValue {
	if m != nil {
		return m.PartnerHotelId
	}
	return nil
}

func (m *Segments) GetPlaceholderType() enums.PlaceholderTypeEnum_PlaceholderType {
	if m != nil {
		return m.PlaceholderType
	}
	return enums.PlaceholderTypeEnum_UNSPECIFIED
}

func (m *Segments) GetProductAggregatorId() *wrappers.UInt64Value {
	if m != nil {
		return m.ProductAggregatorId
	}
	return nil
}

func (m *Segments) GetProductBiddingCategoryLevel1() *wrappers.StringValue {
	if m != nil {
		return m.ProductBiddingCategoryLevel1
	}
	return nil
}

func (m *Segments) GetProductBiddingCategoryLevel2() *wrappers.StringValue {
	if m != nil {
		return m.ProductBiddingCategoryLevel2
	}
	return nil
}

func (m *Segments) GetProductBiddingCategoryLevel3() *wrappers.StringValue {
	if m != nil {
		return m.ProductBiddingCategoryLevel3
	}
	return nil
}

func (m *Segments) GetProductBiddingCategoryLevel4() *wrappers.StringValue {
	if m != nil {
		return m.ProductBiddingCategoryLevel4
	}
	return nil
}

func (m *Segments) GetProductBiddingCategoryLevel5() *wrappers.StringValue {
	if m != nil {
		return m.ProductBiddingCategoryLevel5
	}
	return nil
}

func (m *Segments) GetProductBrand() *wrappers.StringValue {
	if m != nil {
		return m.ProductBrand
	}
	return nil
}

func (m *Segments) GetProductChannel() enums.ProductChannelEnum_ProductChannel {
	if m != nil {
		return m.ProductChannel
	}
	return enums.ProductChannelEnum_UNSPECIFIED
}

func (m *Segments) GetProductChannelExclusivity() enums.ProductChannelExclusivityEnum_ProductChannelExclusivity {
	if m != nil {
		return m.ProductChannelExclusivity
	}
	return enums.ProductChannelExclusivityEnum_UNSPECIFIED
}

func (m *Segments) GetProductCondition() enums.ProductConditionEnum_ProductCondition {
	if m != nil {
		return m.ProductCondition
	}
	return enums.ProductConditionEnum_UNSPECIFIED
}

func (m *Segments) GetProductCountry() *wrappers.StringValue {
	if m != nil {
		return m.ProductCountry
	}
	return nil
}

func (m *Segments) GetProductCustomAttribute0() *wrappers.StringValue {
	if m != nil {
		return m.ProductCustomAttribute0
	}
	return nil
}

func (m *Segments) GetProductCustomAttribute1() *wrappers.StringValue {
	if m != nil {
		return m.ProductCustomAttribute1
	}
	return nil
}

func (m *Segments) GetProductCustomAttribute2() *wrappers.StringValue {
	if m != nil {
		return m.ProductCustomAttribute2
	}
	return nil
}

func (m *Segments) GetProductCustomAttribute3() *wrappers.StringValue {
	if m != nil {
		return m.ProductCustomAttribute3
	}
	return nil
}

func (m *Segments) GetProductCustomAttribute4() *wrappers.StringValue {
	if m != nil {
		return m.ProductCustomAttribute4
	}
	return nil
}

func (m *Segments) GetProductItemId() *wrappers.StringValue {
	if m != nil {
		return m.ProductItemId
	}
	return nil
}

func (m *Segments) GetProductLanguage() *wrappers.StringValue {
	if m != nil {
		return m.ProductLanguage
	}
	return nil
}

func (m *Segments) GetProductMerchantId() *wrappers.UInt64Value {
	if m != nil {
		return m.ProductMerchantId
	}
	return nil
}

func (m *Segments) GetProductStoreId() *wrappers.StringValue {
	if m != nil {
		return m.ProductStoreId
	}
	return nil
}

func (m *Segments) GetProductTitle() *wrappers.StringValue {
	if m != nil {
		return m.ProductTitle
	}
	return nil
}

func (m *Segments) GetProductTypeL1() *wrappers.StringValue {
	if m != nil {
		return m.ProductTypeL1
	}
	return nil
}

func (m *Segments) GetProductTypeL2() *wrappers.StringValue {
	if m != nil {
		return m.ProductTypeL2
	}
	return nil
}

func (m *Segments) GetProductTypeL3() *wrappers.StringValue {
	if m != nil {
		return m.ProductTypeL3
	}
	return nil
}

func (m *Segments) GetProductTypeL4() *wrappers.StringValue {
	if m != nil {
		return m.ProductTypeL4
	}
	return nil
}

func (m *Segments) GetProductTypeL5() *wrappers.StringValue {
	if m != nil {
		return m.ProductTypeL5
	}
	return nil
}

func (m *Segments) GetQuarter() *wrappers.StringValue {
	if m != nil {
		return m.Quarter
	}
	return nil
}

func (m *Segments) GetSearchEngineResultsPageType() enums.SearchEngineResultsPageTypeEnum_SearchEngineResultsPageType {
	if m != nil {
		return m.SearchEngineResultsPageType
	}
	return enums.SearchEngineResultsPageTypeEnum_UNSPECIFIED
}

func (m *Segments) GetSearchTermMatchType() enums.SearchTermMatchTypeEnum_SearchTermMatchType {
	if m != nil {
		return m.SearchTermMatchType
	}
	return enums.SearchTermMatchTypeEnum_UNSPECIFIED
}

func (m *Segments) GetSlot() enums.SlotEnum_Slot {
	if m != nil {
		return m.Slot
	}
	return enums.SlotEnum_UNSPECIFIED
}

func (m *Segments) GetWebpage() *wrappers.StringValue {
	if m != nil {
		return m.Webpage
	}
	return nil
}

func (m *Segments) GetWeek() *wrappers.StringValue {
	if m != nil {
		return m.Week
	}
	return nil
}

func (m *Segments) GetYear() *wrappers.Int32Value {
	if m != nil {
		return m.Year
	}
	return nil
}

// A Keyword criterion segment.
type Keyword struct {
	// The AdGroupCriterion resource name.
	AdGroupCriterion *wrappers.StringValue `protobuf:"bytes,1,opt,name=ad_group_criterion,json=adGroupCriterion,proto3" json:"ad_group_criterion,omitempty"`
	// Keyword info.
	Info                 *KeywordInfo `protobuf:"bytes,2,opt,name=info,proto3" json:"info,omitempty"`
	XXX_NoUnkeyedLiteral struct{}     `json:"-"`
	XXX_unrecognized     []byte       `json:"-"`
	XXX_sizecache        int32        `json:"-"`
}

func (m *Keyword) Reset()         { *m = Keyword{} }
func (m *Keyword) String() string { return proto.CompactTextString(m) }
func (*Keyword) ProtoMessage()    {}
func (*Keyword) Descriptor() ([]byte, []int) {
	return fileDescriptor_e9c6876208f1817a, []int{1}
}

func (m *Keyword) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_Keyword.Unmarshal(m, b)
}
func (m *Keyword) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_Keyword.Marshal(b, m, deterministic)
}
func (m *Keyword) XXX_Merge(src proto.Message) {
	xxx_messageInfo_Keyword.Merge(m, src)
}
func (m *Keyword) XXX_Size() int {
	return xxx_messageInfo_Keyword.Size(m)
}
func (m *Keyword) XXX_DiscardUnknown() {
	xxx_messageInfo_Keyword.DiscardUnknown(m)
}

var xxx_messageInfo_Keyword proto.InternalMessageInfo

func (m *Keyword) GetAdGroupCriterion() *wrappers.StringValue {
	if m != nil {
		return m.AdGroupCriterion
	}
	return nil
}

func (m *Keyword) GetInfo() *KeywordInfo {
	if m != nil {
		return m.Info
	}
	return nil
}

func init() {
	proto.RegisterType((*Segments)(nil), "google.ads.googleads.v1.common.Segments")
	proto.RegisterType((*Keyword)(nil), "google.ads.googleads.v1.common.Keyword")
}

func init() {
	proto.RegisterFile("google/ads/googleads/v1/common/segments.proto", fileDescriptor_e9c6876208f1817a)
}

var fileDescriptor_e9c6876208f1817a = []byte{
	// 2097 bytes of a gzipped FileDescriptorProto
	0x1f, 0x8b, 0x08, 0x00, 0x00, 0x00, 0x00, 0x00, 0x02, 0xff, 0xa4, 0x99, 0x4b, 0x77, 0xdb, 0xc6,
	0x15, 0xc7, 0x0f, 0x1d, 0xc5, 0x8e, 0x47, 0x91, 0x65, 0x8d, 0x6c, 0x67, 0x2c, 0xbf, 0x9d, 0xb6,
	0x71, 0xf3, 0x20, 0x45, 0x52, 0x72, 0x1b, 0x3a, 0x7e, 0x50, 0x94, 0x22, 0xd1, 0x96, 0x23, 0x15,
	0x52, 0x94, 0x36, 0xc7, 0x2d, 0x3a, 0x02, 0x86, 0x10, 0x2a, 0x10, 0x03, 0x0f, 0x06, 0x52, 0xb8,
	0x69, 0x3f, 0x40, 0x77, 0x5d, 0x64, 0xdd, 0xd3, 0x65, 0xbb, 0xe9, 0xb6, 0x5f, 0xa1, 0x9f, 0xa4,
	0xa7, 0x9f, 0x22, 0x67, 0x1e, 0x00, 0x41, 0x52, 0x24, 0x86, 0xd6, 0x8a, 0xc0, 0xe0, 0xfe, 0x7f,
	0xf7, 0xf2, 0xce, 0xe0, 0xce, 0x03, 0xe0, 0x0b, 0x8f, 0x52, 0x2f, 0x20, 0x15, 0xec, 0xc6, 0x15,
	0x75, 0x29, 0xae, 0x4e, 0xaa, 0x15, 0x87, 0x76, 0xbb, 0x34, 0xac, 0xc4, 0xc4, 0xeb, 0x92, 0x90,
	0xc7, 0xe5, 0x88, 0x51, 0x4e, 0xe1, 0x5d, 0x65, 0x53, 0xc6, 0x6e, 0x5c, 0xce, 0xcc, 0xcb, 0x27,
	0xd5, 0xb2, 0x32, 0x5f, 0x2a, 0xc2, 0x39, 0xcc, 0xe7, 0x84, 0xf9, 0x58, 0xe1, 0x96, 0xea, 0xe3,
	0xcc, 0x49, 0x98, 0x74, 0xe3, 0x0a, 0x76, 0xed, 0x90, 0xf0, 0x53, 0xca, 0x8e, 0x6d, 0xde, 0x8b,
	0x88, 0x16, 0x95, 0x27, 0x8b, 0x9c, 0xc0, 0x77, 0x06, 0xec, 0x9f, 0x15, 0xd8, 0xd3, 0xf0, 0x84,
	0xb0, 0xd8, 0xa7, 0xa1, 0x8d, 0x1d, 0x2e, 0x7e, 0x1c, 0xcc, 0x89, 0x47, 0x59, 0x4f, 0xeb, 0x37,
	0xcc, 0xf5, 0x9c, 0x33, 0xff, 0x30, 0x91, 0x10, 0x72, 0x42, 0x42, 0x9e, 0x0f, 0xe3, 0x4b, 0x63,
	0x4c, 0x80, 0x3d, 0xfb, 0x30, 0x71, 0x8e, 0x09, 0xd7, 0xd2, 0x4d, 0x63, 0x29, 0x65, 0x36, 0x76,
	0xff, 0x94, 0xc4, 0x5c, 0x74, 0xda, 0x28, 0xa8, 0x32, 0x19, 0xe4, 0xe2, 0x9e, 0x4d, 0x3b, 0xf6,
	0x29, 0x21, 0xc7, 0x5a, 0xf0, 0x69, 0x81, 0x80, 0x9c, 0xf8, 0x8e, 0x61, 0x9e, 0xc9, 0x0f, 0x9c,
	0xb0, 0x10, 0x07, 0x76, 0x2e, 0xdc, 0x98, 0x26, 0x2c, 0xd3, 0x3f, 0x9d, 0xac, 0x3f, 0xa2, 0x9c,
	0x04, 0xb6, 0x8b, 0x39, 0xb1, 0x63, 0x12, 0x10, 0xd5, 0x55, 0xb9, 0xfc, 0xd6, 0x4d, 0xe4, 0x4c,
	0xc8, 0x73, 0xa2, 0xea, 0x64, 0x51, 0x97, 0x86, 0xfc, 0x48, 0xa4, 0xa4, 0x47, 0x30, 0xd3, 0x92,
	0x95, 0xc9, 0x92, 0x28, 0xc0, 0x0e, 0x39, 0xa2, 0x81, 0x4b, 0xd8, 0x14, 0xd1, 0x45, 0x8c, 0xba,
	0x89, 0xc3, 0x6d, 0xe7, 0x08, 0x87, 0x21, 0x09, 0xb4, 0xe8, 0xf9, 0x54, 0x22, 0x9b, 0xfc, 0xe0,
	0x04, 0x49, 0xec, 0x9f, 0xf8, 0x3c, 0x1d, 0xba, 0xab, 0x86, 0x00, 0x1a, 0xba, 0xbe, 0xc8, 0xa7,
	0x96, 0xb5, 0x26, 0xcb, 0x62, 0x82, 0x99, 0x73, 0x64, 0x93, 0xd0, 0xf3, 0x43, 0x62, 0x33, 0x12,
	0x27, 0x01, 0x8f, 0xed, 0x08, 0x7b, 0x03, 0xa9, 0x6d, 0x18, 0x41, 0x38, 0x61, 0x5d, 0xbb, 0x8b,
	0xb9, 0xb8, 0xec, 0x6b, 0x1f, 0x15, 0x68, 0x03, 0x9a, 0x8e, 0xe8, 0xdb, 0xa9, 0x65, 0xe4, 0x57,
	0x70, 0x18, 0x52, 0x8e, 0xc5, 0xff, 0xd0, 0xe5, 0x6a, 0x49, 0x97, 0xab, 0x8a, 0xbc, 0x3b, 0x4c,
	0x3a, 0x95, 0x53, 0x86, 0xa3, 0x88, 0x30, 0xfd, 0xfc, 0xe1, 0x7f, 0xea, 0xe0, 0x83, 0x3d, 0x5d,
	0xe1, 0x60, 0x07, 0xcc, 0x0f, 0x15, 0x1c, 0xf4, 0xde, 0xfd, 0xd2, 0xa3, 0x2b, 0xb5, 0x67, 0xe5,
	0x71, 0x55, 0x4f, 0x86, 0x53, 0x6e, 0xba, 0xdf, 0x28, 0xd1, 0x7e, 0x2f, 0x22, 0x1b, 0x61, 0xd2,
	0x1d, 0x6c, 0xb1, 0xe6, 0x70, 0xfe, 0x16, 0x7e, 0x0b, 0x40, 0xbf, 0x46, 0xa1, 0x25, 0xe9, 0xe2,
	0x71, 0x81, 0x8b, 0x96, 0x10, 0x64, 0xf8, 0xec, 0xce, 0xba, 0xec, 0xa4, 0x97, 0xb0, 0x0d, 0x16,
	0x46, 0x4a, 0x19, 0x5a, 0xb9, 0x5f, 0x7a, 0x34, 0x5b, 0xbb, 0x9d, 0xd2, 0xd3, 0x3c, 0x94, 0xf7,
	0x38, 0xf3, 0x43, 0xef, 0x00, 0x07, 0x09, 0xb1, 0xae, 0xf6, 0x65, 0x4d, 0xa9, 0x82, 0x7f, 0x2b,
	0x81, 0xa5, 0xf1, 0x65, 0x11, 0xad, 0xca, 0x90, 0xf7, 0x8b, 0x42, 0x1e, 0xa2, 0xb6, 0xb4, 0x5c,
	0xfd, 0x83, 0x31, 0x0f, 0x2d, 0xe4, 0x8c, 0x79, 0x02, 0x2d, 0x70, 0x63, 0x34, 0xa6, 0x10, 0x77,
	0x09, 0x7a, 0x6c, 0xf0, 0x27, 0xaf, 0x0d, 0x73, 0xbf, 0xc1, 0x5d, 0x02, 0x77, 0xc0, 0xf5, 0x3c,
	0x33, 0xab, 0x9c, 0xe8, 0x96, 0x44, 0x2e, 0x8d, 0x20, 0xd7, 0x28, 0x0d, 0x46, 0x81, 0x99, 0x0e,
	0xfe, 0xab, 0x04, 0x1e, 0x14, 0x4e, 0x08, 0xe8, 0x82, 0x4c, 0xe0, 0x1f, 0xcd, 0x13, 0xd8, 0xc7,
	0x6c, 0x08, 0x4a, 0x7f, 0x20, 0x4c, 0x34, 0xb1, 0xee, 0x3a, 0x13, 0x9f, 0xc3, 0x3f, 0x0f, 0xfc,
	0xfd, 0xfe, 0x6c, 0x81, 0x6a, 0x32, 0xc0, 0x97, 0xc6, 0x01, 0x6e, 0x63, 0x6f, 0x4d, 0x2a, 0x87,
	0xa2, 0xca, 0xda, 0xad, 0x45, 0x67, 0xb4, 0x11, 0xfe, 0xbb, 0x04, 0x3e, 0x36, 0x98, 0xbc, 0x50,
	0x5d, 0x86, 0x73, 0x68, 0x1c, 0xce, 0x0e, 0xeb, 0x77, 0xc9, 0xb8, 0xd0, 0xce, 0xb4, 0xb1, 0xee,
	0x39, 0x93, 0x0d, 0xe0, 0x32, 0x98, 0x11, 0x53, 0x10, 0x9a, 0x31, 0x18, 0x73, 0xd2, 0x12, 0x1e,
	0x80, 0xd9, 0xdc, 0xbc, 0x8a, 0xde, 0x37, 0x7a, 0xdf, 0xd7, 0x71, 0x6f, 0xa7, 0xf3, 0x1d, 0x21,
	0xc7, 0x32, 0xea, 0xec, 0xce, 0xba, 0xec, 0xa6, 0x97, 0x70, 0x0b, 0x5c, 0x54, 0xd3, 0x2f, 0x2a,
	0x49, 0xe4, 0x72, 0x11, 0x52, 0x1a, 0x2b, 0x9e, 0xbc, 0xb4, 0xb4, 0x5e, 0xbe, 0xee, 0xe3, 0x67,
	0x67, 0xf4, 0x2b, 0xa3, 0xd7, 0x7d, 0x43, 0x03, 0xfa, 0x19, 0xde, 0x93, 0x72, 0xe9, 0x70, 0xdc,
	0x43, 0x0b, 0x91, 0x31, 0x4f, 0xe0, 0x4b, 0x00, 0x3d, 0x42, 0x6d, 0x8e, 0x99, 0x47, 0xb8, 0x8d,
	0x7d, 0x16, 0x51, 0xc6, 0x51, 0xd3, 0xa4, 0x9e, 0x79, 0x84, 0xee, 0x4b, 0x59, 0x53, 0xa9, 0xe0,
	0x3a, 0x98, 0xcf, 0xb1, 0x1c, 0x9f, 0xf7, 0xd0, 0x33, 0x03, 0xd0, 0x5c, 0x06, 0x6a, 0xf9, 0xbc,
	0x07, 0xb7, 0xc0, 0x42, 0x9e, 0x42, 0x93, 0x90, 0xf7, 0xd0, 0xba, 0x01, 0x67, 0xbe, 0xcf, 0x91,
	0x22, 0xb8, 0x0d, 0x16, 0x73, 0x24, 0xd7, 0x8f, 0x39, 0xf3, 0x1d, 0x8e, 0x36, 0x0c, 0x58, 0x0b,
	0x19, 0x6b, 0x5d, 0xcb, 0xe0, 0xd7, 0xe0, 0x6a, 0x8e, 0xd6, 0x25, 0x9c, 0x51, 0xf4, 0xdc, 0x00,
	0x75, 0x25, 0x43, 0xbd, 0x16, 0x1a, 0xd8, 0x01, 0x0f, 0xf2, 0x1c, 0x1a, 0x73, 0x3b, 0x8e, 0x88,
	0xe3, 0x77, 0x7c, 0xc7, 0x0e, 0xa8, 0x23, 0x27, 0x56, 0xb4, 0x65, 0x00, 0xbe, 0xd3, 0x07, 0xd3,
	0x98, 0xef, 0x69, 0xc6, 0xb6, 0x46, 0xc0, 0xdf, 0x80, 0x1b, 0x39, 0x3f, 0x11, 0x8d, 0xb9, 0x1c,
	0x76, 0x2e, 0x41, 0x9b, 0x06, 0xf0, 0xc5, 0x0c, 0xbe, 0x2b, 0x95, 0x2d, 0xea, 0x92, 0xa1, 0x84,
	0x46, 0x8c, 0x9e, 0xf8, 0xa1, 0x43, 0xd0, 0xab, 0xa9, 0x12, 0xba, 0xab, 0x65, 0x43, 0x1d, 0xcd,
	0x88, 0x27, 0xfe, 0xf8, 0x8b, 0xa9, 0x3a, 0xda, 0x92, 0xa2, 0xa1, 0xae, 0x89, 0xb9, 0xa8, 0x1c,
	0xad, 0xa9, 0xba, 0x66, 0x8f, 0xab, 0x1a, 0x72, 0x53, 0xad, 0x5f, 0x0f, 0x29, 0x3d, 0xf6, 0x43,
	0xcf, 0x3e, 0xf5, 0x43, 0x97, 0x9e, 0xda, 0x2e, 0xee, 0xc5, 0xe8, 0xa2, 0x04, 0xde, 0x1a, 0x01,
	0xb6, 0x43, 0xfe, 0x78, 0x45, 0xf1, 0x6e, 0x48, 0xf5, 0x9a, 0x12, 0x7f, 0x27, 0xb5, 0xeb, 0xb8,
	0x17, 0xc3, 0x16, 0x98, 0x57, 0x5c, 0x87, 0x84, 0x9c, 0x30, 0xdb, 0x77, 0xd1, 0xa5, 0x62, 0xda,
	0x9c, 0xd4, 0xb4, 0xa4, 0xa4, 0xed, 0xc2, 0x57, 0x60, 0x51, 0x43, 0x8e, 0x88, 0x73, 0x6c, 0xfb,
	0xa1, 0x5c, 0xa4, 0xa3, 0x0f, 0x4c, 0x5e, 0x55, 0x45, 0x12, 0xba, 0x76, 0xb8, 0x2e, 0xfe, 0xe9,
	0x5b, 0xb0, 0x34, 0x02, 0xeb, 0x17, 0xcf, 0xcb, 0xe7, 0x2a, 0x9e, 0xd7, 0x07, 0xbd, 0xa5, 0x85,
	0xf4, 0x09, 0x00, 0xda, 0xa5, 0x28, 0x0c, 0xc0, 0x20, 0xec, 0xcb, 0x0a, 0x24, 0x8a, 0xc2, 0x57,
	0x60, 0x56, 0x8b, 0x03, 0x1c, 0xc7, 0x68, 0x76, 0x7c, 0xf6, 0xea, 0x35, 0x25, 0x56, 0xce, 0x5a,
	0xc2, 0x1c, 0x36, 0xc1, 0x9c, 0x56, 0x8b, 0xc2, 0xc0, 0x7a, 0xe8, 0x43, 0x03, 0xef, 0x1f, 0x2a,
	0x80, 0x52, 0xc0, 0xbf, 0x96, 0xd2, 0xb1, 0x71, 0xc6, 0xd6, 0x08, 0xcd, 0xc9, 0x84, 0xed, 0x16,
	0x24, 0x6c, 0x4b, 0xe8, 0x45, 0xfa, 0xf7, 0x52, 0x75, 0xb6, 0xc2, 0x38, 0xfb, 0x91, 0x1e, 0x50,
	0x23, 0xed, 0x70, 0x1b, 0x5c, 0x53, 0xc1, 0x04, 0x24, 0xf4, 0xd4, 0xd6, 0x29, 0xe6, 0xb8, 0x87,
	0xae, 0x14, 0xe7, 0x65, 0x41, 0x0a, 0xb7, 0xa5, 0x6e, 0xa7, 0xb3, 0xc7, 0x71, 0x0f, 0xb6, 0x01,
	0xcc, 0x6d, 0xdb, 0x58, 0x12, 0x10, 0x31, 0x42, 0xdb, 0x26, 0x6f, 0xa2, 0xd4, 0x59, 0x98, 0x13,
	0x2b, 0x09, 0x48, 0xdb, 0x15, 0x8b, 0xfb, 0xa1, 0x1d, 0x20, 0x7a, 0x69, 0xb4, 0xb8, 0xdf, 0x4a,
	0x41, 0x83, 0x29, 0x49, 0x5b, 0xf4, 0xcb, 0x90, 0xde, 0xc2, 0xa7, 0xe9, 0x78, 0x50, 0x2f, 0xfb,
	0xbc, 0x41, 0xac, 0x6a, 0x40, 0xa8, 0x17, 0xbd, 0x02, 0x66, 0x8e, 0x68, 0xc2, 0xd0, 0xd5, 0xe2,
	0x7c, 0x49, 0x43, 0xf8, 0x7b, 0x70, 0xc7, 0x17, 0xef, 0xa1, 0x5e, 0x0f, 0x8b, 0x7e, 0x3f, 0xf2,
	0x63, 0x5b, 0x4c, 0xab, 0xa1, 0x98, 0x4d, 0x51, 0xb5, 0x70, 0x25, 0xbb, 0x94, 0x03, 0xec, 0x84,
	0xfb, 0x47, 0x7e, 0xbc, 0x91, 0xaa, 0x61, 0x13, 0x5c, 0x3a, 0x26, 0xbd, 0x53, 0xca, 0x5c, 0xf4,
	0x54, 0x82, 0x3e, 0x29, 0x4f, 0x3e, 0x01, 0x2a, 0xbf, 0x52, 0xe6, 0x56, 0xaa, 0x83, 0x35, 0xf0,
	0xbe, 0xdc, 0x46, 0xa3, 0x05, 0x83, 0x5c, 0x28, 0x53, 0xf8, 0x07, 0x30, 0x37, 0xb0, 0xf5, 0x46,
	0x50, 0xf6, 0x55, 0xa3, 0xa0, 0xaf, 0x5e, 0x0b, 0xcd, 0x4e, 0xe7, 0x77, 0x04, 0x33, 0xd9, 0x53,
	0xb9, 0x7b, 0x6b, 0xb6, 0xdb, 0xbf, 0x11, 0x75, 0x39, 0xc2, 0x8c, 0x87, 0x84, 0xd9, 0xaa, 0xb7,
	0x7c, 0x17, 0x2d, 0x9a, 0xd4, 0x65, 0xad, 0x92, 0x43, 0xa0, 0xed, 0xc2, 0x2e, 0xb8, 0x3a, 0xbc,
	0xdf, 0x47, 0xd7, 0x64, 0xa8, 0x6b, 0x05, 0xa1, 0xee, 0xf6, 0x65, 0xd9, 0xc0, 0x1a, 0x6a, 0xb3,
	0xe6, 0xa3, 0xc1, 0x06, 0xb8, 0x0b, 0xae, 0xa7, 0x5b, 0x76, 0xec, 0x79, 0x8c, 0x78, 0x98, 0x53,
	0x59, 0xb4, 0x6f, 0x8f, 0x89, 0xfd, 0xdb, 0x5c, 0xd5, 0x5e, 0xd4, 0xd2, 0x66, 0xa6, 0x6c, 0xbb,
	0xd0, 0x01, 0xf7, 0x52, 0xe2, 0xa1, 0xef, 0xba, 0x62, 0x6a, 0x49, 0xb7, 0x79, 0x76, 0x40, 0x4e,
	0x48, 0x50, 0x45, 0xbf, 0x36, 0xc8, 0xcb, 0x6d, 0x0d, 0x59, 0x53, 0x8c, 0x74, 0xcf, 0xb6, 0x2d,
	0x09, 0xc5, 0x4e, 0x6a, 0xe8, 0xcb, 0x73, 0x3a, 0xa9, 0x15, 0x3b, 0xa9, 0xa3, 0xc6, 0x39, 0x9d,
	0xd4, 0x8b, 0x9d, 0xac, 0xa0, 0x27, 0xe7, 0x74, 0xb2, 0x52, 0xec, 0x64, 0x15, 0x7d, 0x75, 0x4e,
	0x27, 0xab, 0x62, 0xe6, 0xc9, 0x9c, 0x30, 0x1c, 0xba, 0xe8, 0x8e, 0xc9, 0xcc, 0x93, 0x22, 0x85,
	0x02, 0xfa, 0x60, 0x7e, 0xe8, 0x04, 0x0a, 0xdd, 0x95, 0x63, 0xff, 0x45, 0xd1, 0xd8, 0x57, 0xaa,
	0x96, 0x12, 0xa9, 0xa1, 0x3f, 0xd0, 0x64, 0x5d, 0x89, 0x06, 0xee, 0xe1, 0x8f, 0x25, 0x70, 0x6b,
	0xc2, 0x69, 0x17, 0xba, 0x27, 0xfd, 0x1e, 0x4c, 0xe7, 0xb7, 0xaf, 0x3f, 0x23, 0x84, 0xdc, 0x53,
	0xeb, 0x66, 0x34, 0xee, 0x11, 0x7c, 0x0b, 0x16, 0x46, 0x0e, 0xd1, 0xd0, 0x7d, 0x19, 0xcd, 0xba,
	0x61, 0x34, 0xa9, 0x6c, 0x20, 0x88, 0xb4, 0xd1, 0xba, 0x1a, 0x0d, 0xb5, 0xc0, 0x8d, 0x5c, 0xda,
	0xf5, 0xaa, 0xe1, 0x81, 0x51, 0xe9, 0x4a, 0x41, 0x6a, 0xdd, 0xf0, 0x5b, 0x70, 0x33, 0xc3, 0x24,
	0x31, 0xa7, 0xdd, 0xec, 0xb0, 0x82, 0x2c, 0xa3, 0x87, 0x06, 0xc0, 0x8f, 0x52, 0xa0, 0x54, 0x37,
	0x33, 0xf1, 0x24, 0x72, 0x15, 0x7d, 0xfc, 0xee, 0xe4, 0xea, 0x24, 0x72, 0x0d, 0xfd, 0xec, 0xdd,
	0xc9, 0xb5, 0x49, 0xe4, 0x3a, 0xfa, 0xf9, 0xbb, 0x93, 0xeb, 0x93, 0xc8, 0x2b, 0xe8, 0x17, 0xef,
	0x4e, 0x5e, 0x11, 0xbb, 0xda, 0x94, 0xec, 0x73, 0xd2, 0x15, 0xf3, 0xc0, 0x27, 0x26, 0xbb, 0x5a,
	0x2d, 0x6a, 0x73, 0xd2, 0x6d, 0xbb, 0x70, 0x13, 0xa4, 0x43, 0xcc, 0x0e, 0x70, 0xe8, 0x25, 0xd8,
	0x23, 0xe8, 0x91, 0xc9, 0x0a, 0x4b, 0xab, 0xb6, 0xb5, 0x48, 0xec, 0xc1, 0x52, 0x50, 0x97, 0x30,
	0xf1, 0x96, 0x72, 0x11, 0xd2, 0x2f, 0x0d, 0xa6, 0xa6, 0xf4, 0x1d, 0x7a, 0xad, 0x75, 0x6d, 0x57,
	0xce, 0xd0, 0x9a, 0x16, 0x73, 0xca, 0xe4, 0xc2, 0xef, 0xd3, 0x29, 0x86, 0xf9, 0x9e, 0x10, 0xb5,
	0xdd, 0x7c, 0x9d, 0xe3, 0x3e, 0x0f, 0x08, 0xfa, 0x6c, 0x8a, 0x3a, 0xb7, 0x2f, 0x14, 0xf9, 0x3c,
	0x8b, 0x09, 0xde, 0x0e, 0xaa, 0xe8, 0xf3, 0x29, 0xf2, 0x2c, 0x66, 0xee, 0xed, 0xea, 0x28, 0xa5,
	0x86, 0xbe, 0x98, 0x96, 0x52, 0x1b, 0xa5, 0xd4, 0x51, 0x79, 0x5a, 0x4a, 0x7d, 0x94, 0xb2, 0x82,
	0x2a, 0xd3, 0x52, 0x56, 0x46, 0x29, 0xab, 0x68, 0x79, 0x5a, 0xca, 0x2a, 0x7c, 0x0c, 0x2e, 0xbd,
	0x4d, 0x30, 0xe3, 0x84, 0xa1, 0xeb, 0x06, 0xea, 0xd4, 0x18, 0xfe, 0xbd, 0x04, 0xee, 0x15, 0x7c,
	0x88, 0x40, 0x5f, 0xcb, 0x42, 0xfc, 0x7d, 0x41, 0x21, 0xde, 0x93, 0x94, 0x0d, 0x09, 0xb1, 0x14,
	0x63, 0x17, 0x7b, 0xfd, 0xf5, 0xfe, 0x84, 0xe7, 0xd6, 0xad, 0x78, 0xfc, 0x43, 0xf8, 0x17, 0x70,
	0xe3, 0xec, 0xaf, 0x1c, 0xe8, 0x86, 0xd1, 0xf9, 0xaa, 0x72, 0xbc, 0x4f, 0x58, 0xf7, 0xb5, 0x90,
	0x0e, 0x05, 0x34, 0xd0, 0x6e, 0x2d, 0xc6, 0xa3, 0x8d, 0xf0, 0x05, 0x98, 0x89, 0x03, 0xca, 0xd1,
	0x47, 0xd2, 0xdd, 0xe7, 0x45, 0xee, 0x02, 0xaa, 0x0e, 0x49, 0xc5, 0x85, 0x25, 0x95, 0xa2, 0x77,
	0x4e, 0xc9, 0xa1, 0xc8, 0x28, 0x5a, 0x33, 0xe9, 0x1d, 0x6d, 0x0c, 0x97, 0xc1, 0x8c, 0xdc, 0xb0,
	0x23, 0x93, 0x63, 0x52, 0x61, 0x29, 0x76, 0x3e, 0x72, 0xa5, 0x7f, 0xd3, 0x60, 0xe7, 0x23, 0x0c,
	0x1f, 0xfe, 0x58, 0x02, 0x97, 0xf4, 0x66, 0x03, 0xbe, 0x04, 0x10, 0xbb, 0xb6, 0xc7, 0x68, 0x12,
	0xd9, 0xfa, 0x13, 0x33, 0x0d, 0xe5, 0xb9, 0x68, 0xe1, 0x09, 0x04, 0x76, 0x37, 0x85, 0xac, 0x95,
	0xaa, 0xe0, 0x73, 0x30, 0xe3, 0x87, 0x1d, 0x2a, 0x0f, 0xe9, 0x67, 0x6b, 0x9f, 0x19, 0xee, 0x77,
	0xda, 0x61, 0x87, 0x5a, 0x52, 0xb8, 0xf6, 0xbf, 0x12, 0x78, 0xe8, 0xd0, 0x6e, 0x81, 0x70, 0x6d,
	0x2e, 0xfd, 0xf0, 0xb4, 0x2b, 0xe2, 0xda, 0x2d, 0x7d, 0xbf, 0xae, 0x05, 0x1e, 0x15, 0x85, 0xb8,
	0x4c, 0x99, 0x57, 0xf1, 0x48, 0x28, 0xa3, 0x4e, 0x3f, 0x82, 0x45, 0x7e, 0x3c, 0xee, 0xd3, 0xfa,
	0x13, 0xf5, 0xf3, 0x8f, 0x0b, 0xef, 0x6d, 0x36, 0x9b, 0xff, 0xbc, 0x70, 0x77, 0x53, 0xc1, 0x9a,
	0x6e, 0x5c, 0x56, 0x97, 0xe2, 0xea, 0xa0, 0x5a, 0x6e, 0x49, 0xb3, 0xff, 0xa6, 0x06, 0x6f, 0x9a,
	0x6e, 0xfc, 0x26, 0x33, 0x78, 0x73, 0x50, 0x7d, 0xa3, 0x0c, 0xfe, 0x7f, 0xe1, 0xa1, 0x6a, 0x6d,
	0x34, 0x9a, 0x6e, 0xdc, 0x68, 0x64, 0x26, 0x8d, 0xc6, 0x41, 0xb5, 0xd1, 0x50, 0x46, 0x87, 0x17,
	0x65, 0x74, 0xf5, 0x9f, 0x02, 0x00, 0x00, 0xff, 0xff, 0x13, 0x98, 0xee, 0x2d, 0x46, 0x20, 0x00,
	0x00,
}
