// Code generated by protoc-gen-go. DO NOT EDIT.
// source: google/ads/googleads/v1/errors/function_parsing_error.proto

package errors

import (
	fmt "fmt"
	math "math"

	proto "github.com/golang/protobuf/proto"
	_ "google.golang.org/genproto/googleapis/api/annotations"
)

// Reference imports to suppress errors if they are not otherwise used.
var _ = proto.Marshal
var _ = fmt.Errorf
var _ = math.Inf

// This is a compile-time assertion to ensure that this generated file
// is compatible with the proto package it is being compiled against.
// A compilation error at this line likely means your copy of the
// proto package needs to be updated.
const _ = proto.ProtoPackageIsVersion3 // please upgrade the proto package

// Enum describing possible function parsing errors.
type FunctionParsingErrorEnum_FunctionParsingError int32

const (
	// Enum unspecified.
	FunctionParsingErrorEnum_UNSPECIFIED FunctionParsingErrorEnum_FunctionParsingError = 0
	// The received error code is not known in this version.
	FunctionParsingErrorEnum_UNKNOWN FunctionParsingErrorEnum_FunctionParsingError = 1
	// Unexpected end of function string.
	FunctionParsingErrorEnum_NO_MORE_INPUT FunctionParsingErrorEnum_FunctionParsingError = 2
	// Could not find an expected character.
	FunctionParsingErrorEnum_EXPECTED_CHARACTER FunctionParsingErrorEnum_FunctionParsingError = 3
	// Unexpected separator character.
	FunctionParsingErrorEnum_UNEXPECTED_SEPARATOR FunctionParsingErrorEnum_FunctionParsingError = 4
	// Unmatched left bracket or parenthesis.
	FunctionParsingErrorEnum_UNMATCHED_LEFT_BRACKET FunctionParsingErrorEnum_FunctionParsingError = 5
	// Unmatched right bracket or parenthesis.
	FunctionParsingErrorEnum_UNMATCHED_RIGHT_BRACKET FunctionParsingErrorEnum_FunctionParsingError = 6
	// Functions are nested too deeply.
	FunctionParsingErrorEnum_TOO_MANY_NESTED_FUNCTIONS FunctionParsingErrorEnum_FunctionParsingError = 7
	// Missing right-hand-side operand.
	FunctionParsingErrorEnum_MISSING_RIGHT_HAND_OPERAND FunctionParsingErrorEnum_FunctionParsingError = 8
	// Invalid operator/function name.
	FunctionParsingErrorEnum_INVALID_OPERATOR_NAME FunctionParsingErrorEnum_FunctionParsingError = 9
	// Feed attribute operand's argument is not an integer.
	FunctionParsingErrorEnum_FEED_ATTRIBUTE_OPERAND_ARGUMENT_NOT_INTEGER FunctionParsingErrorEnum_FunctionParsingError = 10
	// Missing function operands.
	FunctionParsingErrorEnum_NO_OPERANDS FunctionParsingErrorEnum_FunctionParsingError = 11
	// Function had too many operands.
	FunctionParsingErrorEnum_TOO_MANY_OPERANDS FunctionParsingErrorEnum_FunctionParsingError = 12
)

var FunctionParsingErrorEnum_FunctionParsingError_name = map[int32]string{
	0:  "UNSPECIFIED",
	1:  "UNKNOWN",
	2:  "NO_MORE_INPUT",
	3:  "EXPECTED_CHARACTER",
	4:  "UNEXPECTED_SEPARATOR",
	5:  "UNMATCHED_LEFT_BRACKET",
	6:  "UNMATCHED_RIGHT_BRACKET",
	7:  "TOO_MANY_NESTED_FUNCTIONS",
	8:  "MISSING_RIGHT_HAND_OPERAND",
	9:  "INVALID_OPERATOR_NAME",
	10: "FEED_ATTRIBUTE_OPERAND_ARGUMENT_NOT_INTEGER",
	11: "NO_OPERANDS",
	12: "TOO_MANY_OPERANDS",
}

var FunctionParsingErrorEnum_FunctionParsingError_value = map[string]int32{
	"UNSPECIFIED":                                 0,
	"UNKNOWN":                                     1,
	"NO_MORE_INPUT":                               2,
	"EXPECTED_CHARACTER":                          3,
	"UNEXPECTED_SEPARATOR":                        4,
	"UNMATCHED_LEFT_BRACKET":                      5,
	"UNMATCHED_RIGHT_BRACKET":                     6,
	"TOO_MANY_NESTED_FUNCTIONS":                   7,
	"MISSING_RIGHT_HAND_OPERAND":                  8,
	"INVALID_OPERATOR_NAME":                       9,
	"FEED_ATTRIBUTE_OPERAND_ARGUMENT_NOT_INTEGER": 10,
	"NO_OPERANDS":                                 11,
	"TOO_MANY_OPERANDS":                           12,
}

func (x FunctionParsingErrorEnum_FunctionParsingError) String() string {
	return proto.EnumName(FunctionParsingErrorEnum_FunctionParsingError_name, int32(x))
}

func (FunctionParsingErrorEnum_FunctionParsingError) EnumDescriptor() ([]byte, []int) {
	return fileDescriptor_452dbf0b9f7b0cf9, []int{0, 0}
}

// Container for enum describing possible function parsing errors.
type FunctionParsingErrorEnum struct {
	XXX_NoUnkeyedLiteral struct{} `json:"-"`
	XXX_unrecognized     []byte   `json:"-"`
	XXX_sizecache        int32    `json:"-"`
}

func (m *FunctionParsingErrorEnum) Reset()         { *m = FunctionParsingErrorEnum{} }
func (m *FunctionParsingErrorEnum) String() string { return proto.CompactTextString(m) }
func (*FunctionParsingErrorEnum) ProtoMessage()    {}
func (*FunctionParsingErrorEnum) Descriptor() ([]byte, []int) {
	return fileDescriptor_452dbf0b9f7b0cf9, []int{0}
}

func (m *FunctionParsingErrorEnum) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_FunctionParsingErrorEnum.Unmarshal(m, b)
}
func (m *FunctionParsingErrorEnum) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_FunctionParsingErrorEnum.Marshal(b, m, deterministic)
}
func (m *FunctionParsingErrorEnum) XXX_Merge(src proto.Message) {
	xxx_messageInfo_FunctionParsingErrorEnum.Merge(m, src)
}
func (m *FunctionParsingErrorEnum) XXX_Size() int {
	return xxx_messageInfo_FunctionParsingErrorEnum.Size(m)
}
func (m *FunctionParsingErrorEnum) XXX_DiscardUnknown() {
	xxx_messageInfo_FunctionParsingErrorEnum.DiscardUnknown(m)
}

var xxx_messageInfo_FunctionParsingErrorEnum proto.InternalMessageInfo

func init() {
	proto.RegisterEnum("google.ads.googleads.v1.errors.FunctionParsingErrorEnum_FunctionParsingError", FunctionParsingErrorEnum_FunctionParsingError_name, FunctionParsingErrorEnum_FunctionParsingError_value)
	proto.RegisterType((*FunctionParsingErrorEnum)(nil), "google.ads.googleads.v1.errors.FunctionParsingErrorEnum")
}

func init() {
	proto.RegisterFile("google/ads/googleads/v1/errors/function_parsing_error.proto", fileDescriptor_452dbf0b9f7b0cf9)
}

var fileDescriptor_452dbf0b9f7b0cf9 = []byte{
	// 488 bytes of a gzipped FileDescriptorProto
	0x1f, 0x8b, 0x08, 0x00, 0x00, 0x00, 0x00, 0x00, 0x02, 0xff, 0x7c, 0x92, 0xcd, 0x6e, 0xd3, 0x40,
	0x14, 0x85, 0x49, 0x02, 0x2d, 0x4c, 0x40, 0xb8, 0xa3, 0xb6, 0x34, 0x01, 0xb2, 0xc8, 0x16, 0xc9,
	0x56, 0xc4, 0xce, 0x5d, 0x4d, 0xec, 0x1b, 0x67, 0xd4, 0xfa, 0x8e, 0x35, 0x1e, 0x87, 0x1f, 0x45,
	0x1a, 0x99, 0x26, 0x58, 0x91, 0x5a, 0x3b, 0xb2, 0xd3, 0x3e, 0x00, 0x8f, 0xc2, 0x92, 0x47, 0xe1,
	0x3d, 0xd8, 0xb0, 0xe6, 0x01, 0x90, 0x33, 0x89, 0xbb, 0x29, 0xac, 0x7c, 0x75, 0xcf, 0xf9, 0x8e,
	0x47, 0x73, 0x86, 0x9c, 0x67, 0x45, 0x91, 0x5d, 0x2f, 0x9d, 0x74, 0x51, 0x39, 0x66, 0xac, 0xa7,
	0xbb, 0x91, 0xb3, 0x2c, 0xcb, 0xa2, 0xac, 0x9c, 0xaf, 0xb7, 0xf9, 0xd5, 0x66, 0x55, 0xe4, 0x7a,
	0x9d, 0x96, 0xd5, 0x2a, 0xcf, 0xf4, 0x76, 0x6f, 0xaf, 0xcb, 0x62, 0x53, 0xd0, 0x81, 0x21, 0xec,
	0x74, 0x51, 0xd9, 0x0d, 0x6c, 0xdf, 0x8d, 0x6c, 0x03, 0xf7, 0xdf, 0xec, 0xc3, 0xd7, 0x2b, 0x27,
	0xcd, 0xf3, 0x62, 0x93, 0xd6, 0x51, 0x95, 0xa1, 0x87, 0xdf, 0x3a, 0xe4, 0x6c, 0xb2, 0x8b, 0x8f,
	0x4c, 0x3a, 0xd4, 0x1c, 0xe4, 0xb7, 0x37, 0xc3, 0x5f, 0x6d, 0x72, 0xfc, 0x90, 0x48, 0x5f, 0x92,
	0x6e, 0x82, 0x71, 0x04, 0x1e, 0x9f, 0x70, 0xf0, 0xad, 0x47, 0xb4, 0x4b, 0x0e, 0x13, 0xbc, 0x40,
	0xf1, 0x01, 0xad, 0x16, 0x3d, 0x22, 0x2f, 0x50, 0xe8, 0x50, 0x48, 0xd0, 0x1c, 0xa3, 0x44, 0x59,
	0x6d, 0x7a, 0x4a, 0x28, 0x7c, 0x8c, 0xc0, 0x53, 0xe0, 0x6b, 0x6f, 0xca, 0x24, 0xf3, 0x14, 0x48,
	0xab, 0x43, 0xcf, 0xc8, 0x71, 0x82, 0x8d, 0x12, 0x43, 0xc4, 0x24, 0x53, 0x42, 0x5a, 0x8f, 0x69,
	0x9f, 0x9c, 0x26, 0x18, 0x32, 0xe5, 0x4d, 0xc1, 0xd7, 0x97, 0x30, 0x51, 0x7a, 0x2c, 0x99, 0x77,
	0x01, 0xca, 0x7a, 0x42, 0x5f, 0x93, 0x57, 0xf7, 0x9a, 0xe4, 0xc1, 0xf4, 0x5e, 0x3c, 0xa0, 0x6f,
	0x49, 0x4f, 0x09, 0xa1, 0x43, 0x86, 0x9f, 0x34, 0x42, 0x5c, 0xe7, 0x4e, 0x12, 0xf4, 0x14, 0x17,
	0x18, 0x5b, 0x87, 0x74, 0x40, 0xfa, 0x21, 0x8f, 0x63, 0x8e, 0xc1, 0x8e, 0x9c, 0x32, 0xf4, 0xb5,
	0x88, 0x40, 0x32, 0xf4, 0xad, 0xa7, 0xb4, 0x47, 0x4e, 0x38, 0xce, 0xd8, 0x25, 0xdf, 0x2d, 0x95,
	0x90, 0x1a, 0x59, 0x08, 0xd6, 0x33, 0xea, 0x90, 0x77, 0x13, 0x00, 0x5f, 0x33, 0xa5, 0x24, 0x1f,
	0x27, 0x0a, 0xf6, 0x98, 0x66, 0x32, 0x48, 0x42, 0x40, 0xa5, 0x51, 0x28, 0xcd, 0x51, 0x41, 0x00,
	0xd2, 0x22, 0xf5, 0x35, 0xa1, 0xd8, 0x9b, 0x62, 0xab, 0x4b, 0x4f, 0xc8, 0x51, 0x73, 0xb6, 0x66,
	0xfd, 0x7c, 0xfc, 0xa7, 0x45, 0x86, 0x57, 0xc5, 0x8d, 0xfd, 0xff, 0x26, 0xc7, 0xbd, 0x87, 0xba,
	0x88, 0xea, 0x1a, 0xa3, 0xd6, 0x67, 0x7f, 0x07, 0x67, 0xc5, 0x75, 0x9a, 0x67, 0x76, 0x51, 0x66,
	0x4e, 0xb6, 0xcc, 0xb7, 0x25, 0xef, 0xdf, 0xd4, 0x7a, 0x55, 0xfd, 0xeb, 0x89, 0x9d, 0x9b, 0xcf,
	0xf7, 0x76, 0x27, 0x60, 0xec, 0x47, 0x7b, 0x10, 0x98, 0x30, 0xb6, 0xa8, 0x6c, 0x33, 0xd6, 0xd3,
	0x6c, 0x64, 0x6f, 0x7f, 0x59, 0xfd, 0xdc, 0x1b, 0xe6, 0x6c, 0x51, 0xcd, 0x1b, 0xc3, 0x7c, 0x36,
	0x9a, 0x1b, 0xc3, 0xef, 0xf6, 0xd0, 0x6c, 0x5d, 0x97, 0x2d, 0x2a, 0xd7, 0x6d, 0x2c, 0xae, 0x3b,
	0x1b, 0xb9, 0xae, 0x31, 0x7d, 0x39, 0xd8, 0x9e, 0xee, 0xfd, 0xdf, 0x00, 0x00, 0x00, 0xff, 0xff,
	0xc2, 0x4d, 0xd3, 0x1f, 0xff, 0x02, 0x00, 0x00,
}
