// Code generated by protoc-gen-go. DO NOT EDIT.
// source: google/ads/googleads/v1/enums/brand_safety_suitability.proto

package enums

import (
	fmt "fmt"
	math "math"

	proto "github.com/golang/protobuf/proto"
	_ "google.golang.org/genproto/googleapis/api/annotations"
)

// Reference imports to suppress errors if they are not otherwise used.
var _ = proto.Marshal
var _ = fmt.Errorf
var _ = math.Inf

// This is a compile-time assertion to ensure that this generated file
// is compatible with the proto package it is being compiled against.
// A compilation error at this line likely means your copy of the
// proto package needs to be updated.
const _ = proto.ProtoPackageIsVersion3 // please upgrade the proto package

// 3-Tier brand safety suitability control.
type BrandSafetySuitabilityEnum_BrandSafetySuitability int32

const (
	// Not specified.
	BrandSafetySuitabilityEnum_UNSPECIFIED BrandSafetySuitabilityEnum_BrandSafetySuitability = 0
	// Used for return value only. Represents value unknown in this version.
	BrandSafetySuitabilityEnum_UNKNOWN BrandSafetySuitabilityEnum_BrandSafetySuitability = 1
	// This option lets you show ads across all inventory on YouTube and video
	// partners that meet our standards for monetization. This option may be an
	// appropriate choice for brands that want maximum access to the full
	// breadth of videos eligible for ads, including, for example, videos that
	// have strong profanity in the context of comedy or a documentary, or
	// excessive violence as featured in video games.
	BrandSafetySuitabilityEnum_EXPANDED_INVENTORY BrandSafetySuitabilityEnum_BrandSafetySuitability = 2
	// This option lets you show ads across a wide range of content that's
	// appropriate for most brands, such as popular music videos, documentaries,
	// and movie trailers. The content you can show ads on is based on YouTube's
	// advertiser-friendly content guidelines that take into account, for
	// example, the strength or frequency of profanity, or the appropriateness
	// of subject matter like sensitive events. Ads won't show, for example, on
	// content with repeated strong profanity, strong sexual content, or graphic
	// violence.
	BrandSafetySuitabilityEnum_STANDARD_INVENTORY BrandSafetySuitabilityEnum_BrandSafetySuitability = 3
	// This option lets you show ads on a reduced range of content that's
	// appropriate for brands with particularly strict guidelines around
	// inappropriate language and sexual suggestiveness; above and beyond what
	// YouTube's advertiser-friendly content guidelines address. The videos
	// accessible in this sensitive category meet heightened requirements,
	// especially for inappropriate language and sexual suggestiveness. For
	// example, your ads will be excluded from showing on some of YouTube's most
	// popular music videos and other pop culture content across YouTube and
	// Google video partners.
	BrandSafetySuitabilityEnum_LIMITED_INVENTORY BrandSafetySuitabilityEnum_BrandSafetySuitability = 4
)

var BrandSafetySuitabilityEnum_BrandSafetySuitability_name = map[int32]string{
	0: "UNSPECIFIED",
	1: "UNKNOWN",
	2: "EXPANDED_INVENTORY",
	3: "STANDARD_INVENTORY",
	4: "LIMITED_INVENTORY",
}

var BrandSafetySuitabilityEnum_BrandSafetySuitability_value = map[string]int32{
	"UNSPECIFIED":        0,
	"UNKNOWN":            1,
	"EXPANDED_INVENTORY": 2,
	"STANDARD_INVENTORY": 3,
	"LIMITED_INVENTORY":  4,
}

func (x BrandSafetySuitabilityEnum_BrandSafetySuitability) String() string {
	return proto.EnumName(BrandSafetySuitabilityEnum_BrandSafetySuitability_name, int32(x))
}

func (BrandSafetySuitabilityEnum_BrandSafetySuitability) EnumDescriptor() ([]byte, []int) {
	return fileDescriptor_924c6c9918cc5552, []int{0, 0}
}

// Container for enum with 3-Tier brand safety suitability control.
type BrandSafetySuitabilityEnum struct {
	XXX_NoUnkeyedLiteral struct{} `json:"-"`
	XXX_unrecognized     []byte   `json:"-"`
	XXX_sizecache        int32    `json:"-"`
}

func (m *BrandSafetySuitabilityEnum) Reset()         { *m = BrandSafetySuitabilityEnum{} }
func (m *BrandSafetySuitabilityEnum) String() string { return proto.CompactTextString(m) }
func (*BrandSafetySuitabilityEnum) ProtoMessage()    {}
func (*BrandSafetySuitabilityEnum) Descriptor() ([]byte, []int) {
	return fileDescriptor_924c6c9918cc5552, []int{0}
}

func (m *BrandSafetySuitabilityEnum) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_BrandSafetySuitabilityEnum.Unmarshal(m, b)
}
func (m *BrandSafetySuitabilityEnum) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_BrandSafetySuitabilityEnum.Marshal(b, m, deterministic)
}
func (m *BrandSafetySuitabilityEnum) XXX_Merge(src proto.Message) {
	xxx_messageInfo_BrandSafetySuitabilityEnum.Merge(m, src)
}
func (m *BrandSafetySuitabilityEnum) XXX_Size() int {
	return xxx_messageInfo_BrandSafetySuitabilityEnum.Size(m)
}
func (m *BrandSafetySuitabilityEnum) XXX_DiscardUnknown() {
	xxx_messageInfo_BrandSafetySuitabilityEnum.DiscardUnknown(m)
}

var xxx_messageInfo_BrandSafetySuitabilityEnum proto.InternalMessageInfo

func init() {
	proto.RegisterEnum("google.ads.googleads.v1.enums.BrandSafetySuitabilityEnum_BrandSafetySuitability", BrandSafetySuitabilityEnum_BrandSafetySuitability_name, BrandSafetySuitabilityEnum_BrandSafetySuitability_value)
	proto.RegisterType((*BrandSafetySuitabilityEnum)(nil), "google.ads.googleads.v1.enums.BrandSafetySuitabilityEnum")
}

func init() {
	proto.RegisterFile("google/ads/googleads/v1/enums/brand_safety_suitability.proto", fileDescriptor_924c6c9918cc5552)
}

var fileDescriptor_924c6c9918cc5552 = []byte{
	// 339 bytes of a gzipped FileDescriptorProto
	0x1f, 0x8b, 0x08, 0x00, 0x00, 0x00, 0x00, 0x00, 0x02, 0xff, 0x7c, 0x50, 0x4d, 0x4b, 0xfb, 0x30,
	0x1c, 0xfe, 0xb7, 0xfb, 0xa3, 0x90, 0x1d, 0x9c, 0x05, 0x77, 0x98, 0xee, 0xb0, 0x7d, 0x80, 0x94,
	0xe2, 0x2d, 0x7a, 0x49, 0x6d, 0x1d, 0x45, 0xcd, 0xca, 0xba, 0xd5, 0x17, 0x0a, 0x23, 0xb3, 0xb5,
	0x14, 0xb6, 0x64, 0x2c, 0xdd, 0x60, 0x07, 0x3f, 0x89, 0x37, 0x8f, 0x7e, 0x14, 0x3f, 0x8a, 0x27,
	0x3f, 0x82, 0x24, 0x71, 0x55, 0x61, 0x7a, 0x09, 0x0f, 0xbf, 0xe7, 0x85, 0x3c, 0x0f, 0x38, 0xcd,
	0x39, 0xcf, 0xa7, 0x99, 0x4d, 0x53, 0x61, 0x6b, 0x28, 0xd1, 0xca, 0xb1, 0x33, 0xb6, 0x9c, 0x09,
	0x7b, 0xb2, 0xa0, 0x2c, 0x1d, 0x0b, 0xfa, 0x90, 0x95, 0xeb, 0xb1, 0x58, 0x16, 0x25, 0x9d, 0x14,
	0xd3, 0xa2, 0x5c, 0xc3, 0xf9, 0x82, 0x97, 0xdc, 0x6a, 0x6b, 0x0b, 0xa4, 0xa9, 0x80, 0x95, 0x1b,
	0xae, 0x1c, 0xa8, 0xdc, 0xad, 0xa3, 0x4d, 0xf8, 0xbc, 0xb0, 0x29, 0x63, 0xbc, 0xa4, 0x65, 0xc1,
	0x99, 0xd0, 0xe6, 0xee, 0x93, 0x01, 0x5a, 0xae, 0xcc, 0x8f, 0x54, 0x7c, 0xf4, 0x95, 0xee, 0xb3,
	0xe5, 0xac, 0xfb, 0x08, 0x9a, 0xdb, 0x59, 0x6b, 0x0f, 0xd4, 0x47, 0x24, 0x0a, 0xfd, 0xb3, 0xe0,
	0x3c, 0xf0, 0xbd, 0xc6, 0x3f, 0xab, 0x0e, 0x76, 0x47, 0xe4, 0x82, 0xf4, 0xaf, 0x49, 0xc3, 0xb0,
	0x9a, 0xc0, 0xf2, 0x6f, 0x42, 0x4c, 0x3c, 0xdf, 0x1b, 0x07, 0x24, 0xf6, 0xc9, 0xb0, 0x3f, 0xb8,
	0x6d, 0x98, 0xf2, 0x1e, 0x0d, 0x31, 0xf1, 0xf0, 0xe0, 0xfb, 0xbd, 0x66, 0x1d, 0x80, 0xfd, 0xcb,
	0xe0, 0x2a, 0x18, 0xfe, 0x90, 0xff, 0x77, 0xdf, 0x0d, 0xd0, 0xb9, 0xe7, 0x33, 0xf8, 0x67, 0x43,
	0xf7, 0x70, 0xfb, 0x17, 0x43, 0x59, 0x30, 0x34, 0xee, 0xdc, 0x4f, 0x77, 0xce, 0xa7, 0x94, 0xe5,
	0x90, 0x2f, 0x72, 0x3b, 0xcf, 0x98, 0xaa, 0xbf, 0x59, 0x7b, 0x5e, 0x88, 0x5f, 0xc6, 0x3f, 0x51,
	0xef, 0xb3, 0x59, 0xeb, 0x61, 0xfc, 0x62, 0xb6, 0x7b, 0x3a, 0x0a, 0xa7, 0x02, 0x6a, 0x28, 0x51,
	0xec, 0x40, 0x39, 0x96, 0x78, 0xdd, 0xf0, 0x09, 0x4e, 0x45, 0x52, 0xf1, 0x49, 0xec, 0x24, 0x8a,
	0x7f, 0x33, 0x3b, 0xfa, 0x88, 0x10, 0x4e, 0x05, 0x42, 0x95, 0x02, 0xa1, 0xd8, 0x41, 0x48, 0x69,
	0x26, 0x3b, 0xea, 0x63, 0xc7, 0x1f, 0x01, 0x00, 0x00, 0xff, 0xff, 0x21, 0x5e, 0x5b, 0x6e, 0x14,
	0x02, 0x00, 0x00,
}
