// Code generated by protoc-gen-go. DO NOT EDIT.
// source: google/ads/googleads/v2/resources/conversion_action.proto

package resources

import (
	fmt "fmt"
	math "math"

	proto "github.com/golang/protobuf/proto"
	wrappers "github.com/golang/protobuf/ptypes/wrappers"
	common "google.golang.org/genproto/googleapis/ads/googleads/v2/common"
	enums "google.golang.org/genproto/googleapis/ads/googleads/v2/enums"
	_ "google.golang.org/genproto/googleapis/api/annotations"
)

// Reference imports to suppress errors if they are not otherwise used.
var _ = proto.Marshal
var _ = fmt.Errorf
var _ = math.Inf

// This is a compile-time assertion to ensure that this generated file
// is compatible with the proto package it is being compiled against.
// A compilation error at this line likely means your copy of the
// proto package needs to be updated.
const _ = proto.ProtoPackageIsVersion3 // please upgrade the proto package

// A conversion action.
type ConversionAction struct {
	// The resource name of the conversion action.
	// Conversion action resource names have the form:
	//
	// `customers/{customer_id}/conversionActions/{conversion_action_id}`
	ResourceName string `protobuf:"bytes,1,opt,name=resource_name,json=resourceName,proto3" json:"resource_name,omitempty"`
	// The ID of the conversion action.
	Id *wrappers.Int64Value `protobuf:"bytes,2,opt,name=id,proto3" json:"id,omitempty"`
	// The name of the conversion action.
	//
	// This field is required and should not be empty when creating new
	// conversion actions.
	Name *wrappers.StringValue `protobuf:"bytes,3,opt,name=name,proto3" json:"name,omitempty"`
	// The status of this conversion action for conversion event accrual.
	Status enums.ConversionActionStatusEnum_ConversionActionStatus `protobuf:"varint,4,opt,name=status,proto3,enum=google.ads.googleads.v2.enums.ConversionActionStatusEnum_ConversionActionStatus" json:"status,omitempty"`
	// The type of this conversion action.
	Type enums.ConversionActionTypeEnum_ConversionActionType `protobuf:"varint,5,opt,name=type,proto3,enum=google.ads.googleads.v2.enums.ConversionActionTypeEnum_ConversionActionType" json:"type,omitempty"`
	// The category of conversions reported for this conversion action.
	Category enums.ConversionActionCategoryEnum_ConversionActionCategory `protobuf:"varint,6,opt,name=category,proto3,enum=google.ads.googleads.v2.enums.ConversionActionCategoryEnum_ConversionActionCategory" json:"category,omitempty"`
	// The resource name of the conversion action owner customer, or null if this
	// is a system-defined conversion action.
	OwnerCustomer *wrappers.StringValue `protobuf:"bytes,7,opt,name=owner_customer,json=ownerCustomer,proto3" json:"owner_customer,omitempty"`
	// Whether this conversion action should be included in the "conversions"
	// metric.
	IncludeInConversionsMetric *wrappers.BoolValue `protobuf:"bytes,8,opt,name=include_in_conversions_metric,json=includeInConversionsMetric,proto3" json:"include_in_conversions_metric,omitempty"`
	// The maximum number of days that may elapse between an interaction
	// (e.g., a click) and a conversion event.
	ClickThroughLookbackWindowDays *wrappers.Int64Value `protobuf:"bytes,9,opt,name=click_through_lookback_window_days,json=clickThroughLookbackWindowDays,proto3" json:"click_through_lookback_window_days,omitempty"`
	// The maximum number of days which may elapse between an impression and a
	// conversion without an interaction.
	ViewThroughLookbackWindowDays *wrappers.Int64Value `protobuf:"bytes,10,opt,name=view_through_lookback_window_days,json=viewThroughLookbackWindowDays,proto3" json:"view_through_lookback_window_days,omitempty"`
	// Settings related to the value for conversion events associated with this
	// conversion action.
	ValueSettings *ConversionAction_ValueSettings `protobuf:"bytes,11,opt,name=value_settings,json=valueSettings,proto3" json:"value_settings,omitempty"`
	// How to count conversion events for the conversion action.
	CountingType enums.ConversionActionCountingTypeEnum_ConversionActionCountingType `protobuf:"varint,12,opt,name=counting_type,json=countingType,proto3,enum=google.ads.googleads.v2.enums.ConversionActionCountingTypeEnum_ConversionActionCountingType" json:"counting_type,omitempty"`
	// Settings related to this conversion action's attribution model.
	AttributionModelSettings *ConversionAction_AttributionModelSettings `protobuf:"bytes,13,opt,name=attribution_model_settings,json=attributionModelSettings,proto3" json:"attribution_model_settings,omitempty"`
	// The snippets used for tracking conversions.
	TagSnippets []*common.TagSnippet `protobuf:"bytes,14,rep,name=tag_snippets,json=tagSnippets,proto3" json:"tag_snippets,omitempty"`
	// The phone call duration in seconds after which a conversion should be
	// reported for this conversion action.
	//
	// The value must be between 0 and 10000, inclusive.
	PhoneCallDurationSeconds *wrappers.Int64Value `protobuf:"bytes,15,opt,name=phone_call_duration_seconds,json=phoneCallDurationSeconds,proto3" json:"phone_call_duration_seconds,omitempty"`
	// App ID for an app conversion action.
	AppId                *wrappers.StringValue `protobuf:"bytes,16,opt,name=app_id,json=appId,proto3" json:"app_id,omitempty"`
	XXX_NoUnkeyedLiteral struct{}              `json:"-"`
	XXX_unrecognized     []byte                `json:"-"`
	XXX_sizecache        int32                 `json:"-"`
}

func (m *ConversionAction) Reset()         { *m = ConversionAction{} }
func (m *ConversionAction) String() string { return proto.CompactTextString(m) }
func (*ConversionAction) ProtoMessage()    {}
func (*ConversionAction) Descriptor() ([]byte, []int) {
	return fileDescriptor_1dd684865abc1516, []int{0}
}

func (m *ConversionAction) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_ConversionAction.Unmarshal(m, b)
}
func (m *ConversionAction) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_ConversionAction.Marshal(b, m, deterministic)
}
func (m *ConversionAction) XXX_Merge(src proto.Message) {
	xxx_messageInfo_ConversionAction.Merge(m, src)
}
func (m *ConversionAction) XXX_Size() int {
	return xxx_messageInfo_ConversionAction.Size(m)
}
func (m *ConversionAction) XXX_DiscardUnknown() {
	xxx_messageInfo_ConversionAction.DiscardUnknown(m)
}

var xxx_messageInfo_ConversionAction proto.InternalMessageInfo

func (m *ConversionAction) GetResourceName() string {
	if m != nil {
		return m.ResourceName
	}
	return ""
}

func (m *ConversionAction) GetId() *wrappers.Int64Value {
	if m != nil {
		return m.Id
	}
	return nil
}

func (m *ConversionAction) GetName() *wrappers.StringValue {
	if m != nil {
		return m.Name
	}
	return nil
}

func (m *ConversionAction) GetStatus() enums.ConversionActionStatusEnum_ConversionActionStatus {
	if m != nil {
		return m.Status
	}
	return enums.ConversionActionStatusEnum_UNSPECIFIED
}

func (m *ConversionAction) GetType() enums.ConversionActionTypeEnum_ConversionActionType {
	if m != nil {
		return m.Type
	}
	return enums.ConversionActionTypeEnum_UNSPECIFIED
}

func (m *ConversionAction) GetCategory() enums.ConversionActionCategoryEnum_ConversionActionCategory {
	if m != nil {
		return m.Category
	}
	return enums.ConversionActionCategoryEnum_UNSPECIFIED
}

func (m *ConversionAction) GetOwnerCustomer() *wrappers.StringValue {
	if m != nil {
		return m.OwnerCustomer
	}
	return nil
}

func (m *ConversionAction) GetIncludeInConversionsMetric() *wrappers.BoolValue {
	if m != nil {
		return m.IncludeInConversionsMetric
	}
	return nil
}

func (m *ConversionAction) GetClickThroughLookbackWindowDays() *wrappers.Int64Value {
	if m != nil {
		return m.ClickThroughLookbackWindowDays
	}
	return nil
}

func (m *ConversionAction) GetViewThroughLookbackWindowDays() *wrappers.Int64Value {
	if m != nil {
		return m.ViewThroughLookbackWindowDays
	}
	return nil
}

func (m *ConversionAction) GetValueSettings() *ConversionAction_ValueSettings {
	if m != nil {
		return m.ValueSettings
	}
	return nil
}

func (m *ConversionAction) GetCountingType() enums.ConversionActionCountingTypeEnum_ConversionActionCountingType {
	if m != nil {
		return m.CountingType
	}
	return enums.ConversionActionCountingTypeEnum_UNSPECIFIED
}

func (m *ConversionAction) GetAttributionModelSettings() *ConversionAction_AttributionModelSettings {
	if m != nil {
		return m.AttributionModelSettings
	}
	return nil
}

func (m *ConversionAction) GetTagSnippets() []*common.TagSnippet {
	if m != nil {
		return m.TagSnippets
	}
	return nil
}

func (m *ConversionAction) GetPhoneCallDurationSeconds() *wrappers.Int64Value {
	if m != nil {
		return m.PhoneCallDurationSeconds
	}
	return nil
}

func (m *ConversionAction) GetAppId() *wrappers.StringValue {
	if m != nil {
		return m.AppId
	}
	return nil
}

// Settings related to this conversion action's attribution model.
type ConversionAction_AttributionModelSettings struct {
	// The attribution model type of this conversion action.
	AttributionModel enums.AttributionModelEnum_AttributionModel `protobuf:"varint,1,opt,name=attribution_model,json=attributionModel,proto3,enum=google.ads.googleads.v2.enums.AttributionModelEnum_AttributionModel" json:"attribution_model,omitempty"`
	// The status of the data-driven attribution model for the conversion
	// action.
	DataDrivenModelStatus enums.DataDrivenModelStatusEnum_DataDrivenModelStatus `protobuf:"varint,2,opt,name=data_driven_model_status,json=dataDrivenModelStatus,proto3,enum=google.ads.googleads.v2.enums.DataDrivenModelStatusEnum_DataDrivenModelStatus" json:"data_driven_model_status,omitempty"`
	XXX_NoUnkeyedLiteral  struct{}                                              `json:"-"`
	XXX_unrecognized      []byte                                                `json:"-"`
	XXX_sizecache         int32                                                 `json:"-"`
}

func (m *ConversionAction_AttributionModelSettings) Reset() {
	*m = ConversionAction_AttributionModelSettings{}
}
func (m *ConversionAction_AttributionModelSettings) String() string { return proto.CompactTextString(m) }
func (*ConversionAction_AttributionModelSettings) ProtoMessage()    {}
func (*ConversionAction_AttributionModelSettings) Descriptor() ([]byte, []int) {
	return fileDescriptor_1dd684865abc1516, []int{0, 0}
}

func (m *ConversionAction_AttributionModelSettings) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_ConversionAction_AttributionModelSettings.Unmarshal(m, b)
}
func (m *ConversionAction_AttributionModelSettings) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_ConversionAction_AttributionModelSettings.Marshal(b, m, deterministic)
}
func (m *ConversionAction_AttributionModelSettings) XXX_Merge(src proto.Message) {
	xxx_messageInfo_ConversionAction_AttributionModelSettings.Merge(m, src)
}
func (m *ConversionAction_AttributionModelSettings) XXX_Size() int {
	return xxx_messageInfo_ConversionAction_AttributionModelSettings.Size(m)
}
func (m *ConversionAction_AttributionModelSettings) XXX_DiscardUnknown() {
	xxx_messageInfo_ConversionAction_AttributionModelSettings.DiscardUnknown(m)
}

var xxx_messageInfo_ConversionAction_AttributionModelSettings proto.InternalMessageInfo

func (m *ConversionAction_AttributionModelSettings) GetAttributionModel() enums.AttributionModelEnum_AttributionModel {
	if m != nil {
		return m.AttributionModel
	}
	return enums.AttributionModelEnum_UNSPECIFIED
}

func (m *ConversionAction_AttributionModelSettings) GetDataDrivenModelStatus() enums.DataDrivenModelStatusEnum_DataDrivenModelStatus {
	if m != nil {
		return m.DataDrivenModelStatus
	}
	return enums.DataDrivenModelStatusEnum_UNSPECIFIED
}

// Settings related to the value for conversion events associated with this
// conversion action.
type ConversionAction_ValueSettings struct {
	// The value to use when conversion events for this conversion action are
	// sent with an invalid, disallowed or missing value, or when
	// this conversion action is configured to always use the default value.
	DefaultValue *wrappers.DoubleValue `protobuf:"bytes,1,opt,name=default_value,json=defaultValue,proto3" json:"default_value,omitempty"`
	// The currency code to use when conversion events for this conversion
	// action are sent with an invalid or missing currency code, or when this
	// conversion action is configured to always use the default value.
	DefaultCurrencyCode *wrappers.StringValue `protobuf:"bytes,2,opt,name=default_currency_code,json=defaultCurrencyCode,proto3" json:"default_currency_code,omitempty"`
	// Controls whether the default value and default currency code are used in
	// place of the value and currency code specified in conversion events for
	// this conversion action.
	AlwaysUseDefaultValue *wrappers.BoolValue `protobuf:"bytes,3,opt,name=always_use_default_value,json=alwaysUseDefaultValue,proto3" json:"always_use_default_value,omitempty"`
	XXX_NoUnkeyedLiteral  struct{}            `json:"-"`
	XXX_unrecognized      []byte              `json:"-"`
	XXX_sizecache         int32               `json:"-"`
}

func (m *ConversionAction_ValueSettings) Reset()         { *m = ConversionAction_ValueSettings{} }
func (m *ConversionAction_ValueSettings) String() string { return proto.CompactTextString(m) }
func (*ConversionAction_ValueSettings) ProtoMessage()    {}
func (*ConversionAction_ValueSettings) Descriptor() ([]byte, []int) {
	return fileDescriptor_1dd684865abc1516, []int{0, 1}
}

func (m *ConversionAction_ValueSettings) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_ConversionAction_ValueSettings.Unmarshal(m, b)
}
func (m *ConversionAction_ValueSettings) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_ConversionAction_ValueSettings.Marshal(b, m, deterministic)
}
func (m *ConversionAction_ValueSettings) XXX_Merge(src proto.Message) {
	xxx_messageInfo_ConversionAction_ValueSettings.Merge(m, src)
}
func (m *ConversionAction_ValueSettings) XXX_Size() int {
	return xxx_messageInfo_ConversionAction_ValueSettings.Size(m)
}
func (m *ConversionAction_ValueSettings) XXX_DiscardUnknown() {
	xxx_messageInfo_ConversionAction_ValueSettings.DiscardUnknown(m)
}

var xxx_messageInfo_ConversionAction_ValueSettings proto.InternalMessageInfo

func (m *ConversionAction_ValueSettings) GetDefaultValue() *wrappers.DoubleValue {
	if m != nil {
		return m.DefaultValue
	}
	return nil
}

func (m *ConversionAction_ValueSettings) GetDefaultCurrencyCode() *wrappers.StringValue {
	if m != nil {
		return m.DefaultCurrencyCode
	}
	return nil
}

func (m *ConversionAction_ValueSettings) GetAlwaysUseDefaultValue() *wrappers.BoolValue {
	if m != nil {
		return m.AlwaysUseDefaultValue
	}
	return nil
}

func init() {
	proto.RegisterType((*ConversionAction)(nil), "google.ads.googleads.v2.resources.ConversionAction")
	proto.RegisterType((*ConversionAction_AttributionModelSettings)(nil), "google.ads.googleads.v2.resources.ConversionAction.AttributionModelSettings")
	proto.RegisterType((*ConversionAction_ValueSettings)(nil), "google.ads.googleads.v2.resources.ConversionAction.ValueSettings")
}

func init() {
	proto.RegisterFile("google/ads/googleads/v2/resources/conversion_action.proto", fileDescriptor_1dd684865abc1516)
}

var fileDescriptor_1dd684865abc1516 = []byte{
	// 970 bytes of a gzipped FileDescriptorProto
	0x1f, 0x8b, 0x08, 0x00, 0x00, 0x00, 0x00, 0x00, 0x02, 0xff, 0x9c, 0x56, 0xdd, 0x6e, 0xe3, 0x44,
	0x14, 0x56, 0xd2, 0x6e, 0xd9, 0x9d, 0x26, 0xd9, 0x32, 0xa8, 0x92, 0x95, 0xfd, 0x51, 0xbb, 0x68,
	0xa5, 0x0a, 0x24, 0x67, 0xe5, 0x05, 0x24, 0x02, 0x42, 0x72, 0x13, 0xb4, 0x2a, 0x6a, 0x57, 0x95,
	0x53, 0x8a, 0xb4, 0x0a, 0x1a, 0x26, 0x9e, 0xa9, 0x63, 0xd5, 0x9e, 0x31, 0x33, 0xe3, 0x44, 0xb9,
	0x84, 0x1b, 0x24, 0x5e, 0x80, 0x7b, 0x2e, 0x79, 0x03, 0x5e, 0x81, 0x47, 0xe1, 0x0d, 0xb8, 0x43,
	0x1e, 0x8f, 0xdd, 0x34, 0x89, 0x9b, 0x66, 0xef, 0x66, 0x7c, 0xce, 0xf7, 0x7d, 0xe7, 0x9c, 0x39,
	0x73, 0xc6, 0xe0, 0xcb, 0x80, 0xf3, 0x20, 0xa2, 0x1d, 0x4c, 0x64, 0x27, 0x5f, 0x66, 0xab, 0x89,
	0xd3, 0x11, 0x54, 0xf2, 0x54, 0xf8, 0x54, 0x76, 0x7c, 0xce, 0x26, 0x54, 0xc8, 0x90, 0x33, 0x84,
	0x7d, 0x15, 0x72, 0x66, 0x27, 0x82, 0x2b, 0x0e, 0x0f, 0x73, 0x7f, 0x1b, 0x13, 0x69, 0x97, 0x50,
	0x7b, 0xe2, 0xd8, 0x25, 0xb4, 0xfd, 0xaa, 0x8a, 0xdd, 0xe7, 0x71, 0xcc, 0x59, 0x47, 0xe1, 0x00,
	0x49, 0x16, 0x26, 0x09, 0x55, 0x39, 0x69, 0xfb, 0xf3, 0x2a, 0x04, 0x65, 0x69, 0x2c, 0x3b, 0x58,
	0x29, 0x11, 0x8e, 0xd2, 0x2c, 0x0a, 0x14, 0x73, 0x42, 0x23, 0x03, 0xfb, 0xe6, 0x6e, 0xd8, 0x52,
	0x0a, 0xc8, 0xc7, 0x8a, 0x06, 0x5c, 0xcc, 0x0c, 0xbe, 0xb7, 0x31, 0x9e, 0xa7, 0x4c, 0x85, 0x2c,
	0x40, 0x6a, 0x96, 0x50, 0x43, 0xf2, 0xf5, 0xa6, 0x24, 0x52, 0x61, 0x95, 0x4a, 0x83, 0xee, 0x6e,
	0x8a, 0xbe, 0xbf, 0x32, 0xc1, 0x0a, 0x23, 0x22, 0xc2, 0x09, 0x35, 0x55, 0xbb, 0xad, 0xfc, 0xdc,
	0xa0, 0xf5, 0x6e, 0x94, 0x5e, 0x75, 0xa6, 0x02, 0x27, 0x09, 0x15, 0x85, 0xfd, 0x69, 0xc1, 0x9e,
	0x84, 0x1d, 0xcc, 0x18, 0x57, 0x38, 0xd3, 0x37, 0xd6, 0x17, 0x7f, 0x3f, 0x06, 0x7b, 0xbd, 0x32,
	0x38, 0x57, 0xc7, 0x06, 0x3f, 0x06, 0xcd, 0xa2, 0x0b, 0x10, 0xc3, 0x31, 0xb5, 0x6a, 0x07, 0xb5,
	0xa3, 0x47, 0x5e, 0xa3, 0xf8, 0xf8, 0x16, 0xc7, 0x14, 0x7e, 0x0a, 0xea, 0x21, 0xb1, 0xea, 0x07,
	0xb5, 0xa3, 0x5d, 0xe7, 0x89, 0x69, 0x21, 0xbb, 0x08, 0xc2, 0x3e, 0x61, 0xea, 0x8b, 0xcf, 0x2e,
	0x71, 0x94, 0x52, 0xaf, 0x1e, 0x12, 0xf8, 0x0a, 0x6c, 0x6b, 0xa2, 0x2d, 0xed, 0xfe, 0x74, 0xc9,
	0x7d, 0xa0, 0x44, 0xc8, 0x82, 0xdc, 0x5f, 0x7b, 0xc2, 0x31, 0xd8, 0xc9, 0xd3, 0xb4, 0xb6, 0x0f,
	0x6a, 0x47, 0x2d, 0xe7, 0xdc, 0xae, 0x6a, 0x58, 0x5d, 0x25, 0x7b, 0x31, 0x89, 0x81, 0x06, 0x7f,
	0xcb, 0xd2, 0xb8, 0xc2, 0xe4, 0x19, 0x7e, 0xf8, 0x13, 0xd8, 0xce, 0x0e, 0xc3, 0x7a, 0xa0, 0x75,
	0x4e, 0x37, 0xd4, 0xb9, 0x98, 0x25, 0x74, 0xa5, 0x4a, 0x66, 0xf0, 0x34, 0x33, 0x4c, 0xc0, 0xc3,
	0xa2, 0x63, 0xad, 0x1d, 0xad, 0x72, 0xb1, 0xa1, 0x4a, 0xcf, 0xc0, 0x57, 0x2a, 0x15, 0x46, 0xaf,
	0x54, 0x81, 0x3d, 0xd0, 0xe2, 0x53, 0x46, 0x05, 0xf2, 0x53, 0xa9, 0x78, 0x4c, 0x85, 0xf5, 0xc1,
	0x3d, 0x2a, 0xdf, 0xd4, 0x98, 0x9e, 0x81, 0xc0, 0x1f, 0xc1, 0xb3, 0x90, 0xf9, 0x51, 0x4a, 0x28,
	0x0a, 0xb3, 0x3b, 0x53, 0xa8, 0x4a, 0x14, 0x53, 0x25, 0x42, 0xdf, 0x7a, 0xa8, 0x39, 0xdb, 0x4b,
	0x9c, 0xc7, 0x9c, 0x47, 0x39, 0x63, 0xdb, 0x10, 0x9c, 0xb0, 0x9b, 0xa0, 0xe5, 0x99, 0x46, 0xc3,
	0x00, 0xbc, 0xf0, 0xa3, 0xd0, 0xbf, 0x46, 0x6a, 0x2c, 0x78, 0x1a, 0x8c, 0x51, 0xc4, 0xf9, 0xf5,
	0x08, 0xfb, 0xd7, 0x68, 0x1a, 0x32, 0xc2, 0xa7, 0x88, 0xe0, 0x99, 0xb4, 0x1e, 0xad, 0x6f, 0xb0,
	0xe7, 0x9a, 0xe6, 0x22, 0x67, 0x39, 0x35, 0x24, 0x3f, 0x68, 0x8e, 0x3e, 0x9e, 0x49, 0x48, 0xc1,
	0xe1, 0x24, 0xa4, 0xd3, 0xbb, 0x75, 0xc0, 0x7a, 0x9d, 0x67, 0x19, 0x4b, 0xb5, 0xcc, 0x18, 0xb4,
	0x26, 0x99, 0x1f, 0x92, 0x54, 0x65, 0xc3, 0x45, 0x5a, 0xbb, 0x9a, 0xd3, 0xb5, 0xd7, 0x8e, 0xda,
	0xa5, 0x23, 0xb5, 0xb5, 0xe2, 0xc0, 0x10, 0x79, 0xcd, 0xc9, 0xfc, 0x16, 0xfe, 0x52, 0x03, 0xcd,
	0x5b, 0x23, 0xcc, 0x6a, 0xe8, 0xae, 0x1a, 0x6e, 0xda, 0x55, 0x86, 0xa3, 0xb2, 0x87, 0xe7, 0x1d,
	0xbc, 0x86, 0x3f, 0xb7, 0x83, 0xbf, 0xd7, 0x40, 0x7b, 0x69, 0x9e, 0xdf, 0xa4, 0xde, 0xd4, 0xa9,
	0x9f, 0xbe, 0x4f, 0xea, 0xee, 0x0d, 0xeb, 0x59, 0x46, 0x5a, 0x56, 0xc1, 0xc2, 0x15, 0x16, 0x78,
	0x06, 0x1a, 0x73, 0x8f, 0x91, 0xb4, 0x5a, 0x07, 0x5b, 0x47, 0xbb, 0xce, 0x27, 0x95, 0xea, 0xf9,
	0x03, 0x66, 0x5f, 0xe0, 0x60, 0x90, 0x43, 0xbc, 0x5d, 0x55, 0xae, 0x25, 0x7c, 0x07, 0x9e, 0x24,
	0x63, 0xce, 0x28, 0xf2, 0x71, 0x14, 0x21, 0x92, 0x0a, 0x9c, 0x0f, 0x7c, 0xea, 0x73, 0x46, 0xa4,
	0xf5, 0x78, 0x7d, 0xab, 0x58, 0x1a, 0xdf, 0xc3, 0x51, 0xd4, 0x37, 0xe8, 0x41, 0x0e, 0x86, 0xaf,
	0xc1, 0x0e, 0x4e, 0x12, 0x14, 0x12, 0x6b, 0xef, 0x1e, 0x37, 0xf2, 0x01, 0x4e, 0x92, 0x13, 0xd2,
	0xfe, 0xa3, 0x0e, 0xac, 0xaa, 0xb2, 0xc0, 0x9f, 0xc1, 0x87, 0x4b, 0x07, 0xa1, 0x27, 0x76, 0xcb,
	0xe9, 0xaf, 0x69, 0x88, 0x45, 0x4e, 0xdd, 0x04, 0x8b, 0x1f, 0xbd, 0xbd, 0xc5, 0xba, 0xc3, 0xdf,
	0x6a, 0xc0, 0xaa, 0x7a, 0x96, 0xf4, 0x93, 0xd0, 0x72, 0xde, 0xae, 0x91, 0xee, 0x63, 0x85, 0xfb,
	0x1a, 0x9d, 0x67, 0x73, 0x33, 0xae, 0x57, 0x5a, 0xbc, 0x7d, 0xb2, 0xea, 0x73, 0xfb, 0xbf, 0x1a,
	0x68, 0xde, 0xba, 0x2b, 0xd0, 0x05, 0x4d, 0x42, 0xaf, 0x70, 0x1a, 0x29, 0xa4, 0x6f, 0x8d, 0x2e,
	0xc5, 0xaa, 0x3a, 0xf7, 0x79, 0x3a, 0x8a, 0x68, 0x5e, 0xe7, 0x86, 0x81, 0xe8, 0x1d, 0x3c, 0x07,
	0xfb, 0x05, 0x85, 0x9f, 0x0a, 0x41, 0x99, 0x3f, 0x43, 0x3e, 0x27, 0xd4, 0xbc, 0x76, 0x77, 0x1f,
	0xd9, 0x47, 0x06, 0xda, 0x33, 0xc8, 0x1e, 0x27, 0x14, 0x0e, 0x80, 0x85, 0xa3, 0x29, 0x9e, 0x49,
	0x94, 0x4a, 0x8a, 0x6e, 0xc7, 0xb7, 0xb5, 0x76, 0x8a, 0xee, 0xe7, 0xd8, 0xef, 0x25, 0xed, 0xcf,
	0x85, 0x79, 0xfc, 0x6b, 0x1d, 0xbc, 0xf4, 0x79, 0xbc, 0xfe, 0x8e, 0x1d, 0xef, 0x2f, 0x5e, 0xb2,
	0xf3, 0x4c, 0xe4, 0xbc, 0xf6, 0xee, 0x3b, 0x83, 0x0d, 0x78, 0x84, 0x59, 0x60, 0x73, 0x11, 0x74,
	0x02, 0xca, 0x74, 0x08, 0xc5, 0xaf, 0x48, 0x12, 0xca, 0x3b, 0xfe, 0x2f, 0xbf, 0x2a, 0x57, 0x7f,
	0xd6, 0xb7, 0xde, 0xb8, 0xee, 0x5f, 0xf5, 0xc3, 0x37, 0x39, 0xa5, 0x4b, 0xa4, 0x9d, 0x2f, 0xb3,
	0xd5, 0xa5, 0x63, 0x7b, 0x85, 0xe7, 0x3f, 0x85, 0xcf, 0xd0, 0x25, 0x72, 0x58, 0xfa, 0x0c, 0x2f,
	0x9d, 0x61, 0xe9, 0xf3, 0x6f, 0xfd, 0x65, 0x6e, 0xe8, 0x76, 0x5d, 0x22, 0xbb, 0xdd, 0xd2, 0xab,
	0xdb, 0xbd, 0x74, 0xba, 0xdd, 0xd2, 0x6f, 0xb4, 0xa3, 0x83, 0x7d, 0xfd, 0x7f, 0x00, 0x00, 0x00,
	0xff, 0xff, 0x76, 0x4a, 0x7a, 0x0f, 0x0b, 0x0b, 0x00, 0x00,
}
