// Code generated by protoc-gen-go. DO NOT EDIT.
// source: google/ads/googleads/v1/enums/user_list_closing_reason.proto

package enums

import (
	fmt "fmt"
	math "math"

	proto "github.com/golang/protobuf/proto"
	_ "google.golang.org/genproto/googleapis/api/annotations"
)

// Reference imports to suppress errors if they are not otherwise used.
var _ = proto.Marshal
var _ = fmt.Errorf
var _ = math.Inf

// This is a compile-time assertion to ensure that this generated file
// is compatible with the proto package it is being compiled against.
// A compilation error at this line likely means your copy of the
// proto package needs to be updated.
const _ = proto.ProtoPackageIsVersion3 // please upgrade the proto package

// Enum describing possible user list closing reasons.
type UserListClosingReasonEnum_UserListClosingReason int32

const (
	// Not specified.
	UserListClosingReasonEnum_UNSPECIFIED UserListClosingReasonEnum_UserListClosingReason = 0
	// Used for return value only. Represents value unknown in this version.
	UserListClosingReasonEnum_UNKNOWN UserListClosingReasonEnum_UserListClosingReason = 1
	// The userlist was closed because of not being used for over one year.
	UserListClosingReasonEnum_UNUSED UserListClosingReasonEnum_UserListClosingReason = 2
)

var UserListClosingReasonEnum_UserListClosingReason_name = map[int32]string{
	0: "UNSPECIFIED",
	1: "UNKNOWN",
	2: "UNUSED",
}

var UserListClosingReasonEnum_UserListClosingReason_value = map[string]int32{
	"UNSPECIFIED": 0,
	"UNKNOWN":     1,
	"UNUSED":      2,
}

func (x UserListClosingReasonEnum_UserListClosingReason) String() string {
	return proto.EnumName(UserListClosingReasonEnum_UserListClosingReason_name, int32(x))
}

func (UserListClosingReasonEnum_UserListClosingReason) EnumDescriptor() ([]byte, []int) {
	return fileDescriptor_9586aee4ba6d2ca2, []int{0, 0}
}

// Indicates the reason why the userlist was closed.
// This enum is only used when a list is auto-closed by the system.
type UserListClosingReasonEnum struct {
	XXX_NoUnkeyedLiteral struct{} `json:"-"`
	XXX_unrecognized     []byte   `json:"-"`
	XXX_sizecache        int32    `json:"-"`
}

func (m *UserListClosingReasonEnum) Reset()         { *m = UserListClosingReasonEnum{} }
func (m *UserListClosingReasonEnum) String() string { return proto.CompactTextString(m) }
func (*UserListClosingReasonEnum) ProtoMessage()    {}
func (*UserListClosingReasonEnum) Descriptor() ([]byte, []int) {
	return fileDescriptor_9586aee4ba6d2ca2, []int{0}
}

func (m *UserListClosingReasonEnum) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_UserListClosingReasonEnum.Unmarshal(m, b)
}
func (m *UserListClosingReasonEnum) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_UserListClosingReasonEnum.Marshal(b, m, deterministic)
}
func (m *UserListClosingReasonEnum) XXX_Merge(src proto.Message) {
	xxx_messageInfo_UserListClosingReasonEnum.Merge(m, src)
}
func (m *UserListClosingReasonEnum) XXX_Size() int {
	return xxx_messageInfo_UserListClosingReasonEnum.Size(m)
}
func (m *UserListClosingReasonEnum) XXX_DiscardUnknown() {
	xxx_messageInfo_UserListClosingReasonEnum.DiscardUnknown(m)
}

var xxx_messageInfo_UserListClosingReasonEnum proto.InternalMessageInfo

func init() {
	proto.RegisterEnum("google.ads.googleads.v1.enums.UserListClosingReasonEnum_UserListClosingReason", UserListClosingReasonEnum_UserListClosingReason_name, UserListClosingReasonEnum_UserListClosingReason_value)
	proto.RegisterType((*UserListClosingReasonEnum)(nil), "google.ads.googleads.v1.enums.UserListClosingReasonEnum")
}

func init() {
	proto.RegisterFile("google/ads/googleads/v1/enums/user_list_closing_reason.proto", fileDescriptor_9586aee4ba6d2ca2)
}

var fileDescriptor_9586aee4ba6d2ca2 = []byte{
	// 302 bytes of a gzipped FileDescriptorProto
	0x1f, 0x8b, 0x08, 0x00, 0x00, 0x00, 0x00, 0x00, 0x02, 0xff, 0x7c, 0x90, 0xc1, 0x4a, 0xc3, 0x30,
	0x1c, 0xc6, 0x5d, 0x85, 0x09, 0xd9, 0xc1, 0x51, 0xf0, 0xe0, 0x70, 0x87, 0xed, 0x01, 0x12, 0x8a,
	0xb7, 0xe8, 0x25, 0xdb, 0xea, 0x18, 0x4a, 0x1d, 0x8e, 0x4e, 0x90, 0xe2, 0x88, 0x6b, 0x08, 0x81,
	0x36, 0x29, 0xfd, 0xb7, 0x7b, 0x20, 0x8f, 0x3e, 0x8a, 0x8f, 0xe2, 0xc5, 0x57, 0x90, 0x26, 0xb6,
	0xa7, 0xe9, 0x25, 0x7c, 0xe4, 0xfb, 0xff, 0xbe, 0x7c, 0xf9, 0xa3, 0x5b, 0x69, 0x8c, 0xcc, 0x04,
	0xe1, 0x29, 0x10, 0x27, 0x1b, 0x75, 0x08, 0x88, 0xd0, 0x75, 0x0e, 0xa4, 0x06, 0x51, 0xee, 0x32,
	0x05, 0xd5, 0x6e, 0x9f, 0x19, 0x50, 0x5a, 0xee, 0x4a, 0xc1, 0xc1, 0x68, 0x5c, 0x94, 0xa6, 0x32,
	0xfe, 0xd8, 0x21, 0x98, 0xa7, 0x80, 0x3b, 0x1a, 0x1f, 0x02, 0x6c, 0xe9, 0xd1, 0x55, 0x1b, 0x5e,
	0x28, 0xc2, 0xb5, 0x36, 0x15, 0xaf, 0x94, 0xd1, 0xe0, 0xe0, 0xe9, 0x2b, 0xba, 0x8c, 0x41, 0x94,
	0x0f, 0x0a, 0xaa, 0xb9, 0x0b, 0x7f, 0xb2, 0xd9, 0xa1, 0xae, 0xf3, 0x29, 0x43, 0x17, 0x47, 0x4d,
	0xff, 0x1c, 0x0d, 0xe2, 0x68, 0xb3, 0x0e, 0xe7, 0xab, 0xbb, 0x55, 0xb8, 0x18, 0x9e, 0xf8, 0x03,
	0x74, 0x16, 0x47, 0xf7, 0xd1, 0xe3, 0x73, 0x34, 0xec, 0xf9, 0x08, 0xf5, 0xe3, 0x28, 0xde, 0x84,
	0x8b, 0xa1, 0x37, 0xfb, 0xee, 0xa1, 0xc9, 0xde, 0xe4, 0xf8, 0xdf, 0x8e, 0xb3, 0xd1, 0xd1, 0x67,
	0xd6, 0x4d, 0xc3, 0x75, 0xef, 0x65, 0xf6, 0x0b, 0x4b, 0x93, 0x71, 0x2d, 0xb1, 0x29, 0x25, 0x91,
	0x42, 0xdb, 0xfe, 0xed, 0xba, 0x0a, 0x05, 0x7f, 0x6c, 0xef, 0xc6, 0x9e, 0xef, 0xde, 0xe9, 0x92,
	0xb1, 0x0f, 0x6f, 0xbc, 0x74, 0x51, 0x2c, 0x05, 0xec, 0x64, 0xa3, 0xb6, 0x01, 0x6e, 0xfe, 0x0b,
	0x9f, 0xad, 0x9f, 0xb0, 0x14, 0x92, 0xce, 0x4f, 0xb6, 0x41, 0x62, 0xfd, 0x2f, 0x6f, 0xe2, 0x2e,
	0x29, 0x65, 0x29, 0x50, 0xda, 0x4d, 0x50, 0xba, 0x0d, 0x28, 0xb5, 0x33, 0x6f, 0x7d, 0x5b, 0xec,
	0xfa, 0x27, 0x00, 0x00, 0xff, 0xff, 0xa6, 0x92, 0x92, 0x02, 0xd5, 0x01, 0x00, 0x00,
}
