// Code generated by protoc-gen-go. DO NOT EDIT.
// source: google/ads/googleads/v1/errors/billing_setup_error.proto

package errors

import (
	fmt "fmt"
	math "math"

	proto "github.com/golang/protobuf/proto"
	_ "google.golang.org/genproto/googleapis/api/annotations"
)

// Reference imports to suppress errors if they are not otherwise used.
var _ = proto.Marshal
var _ = fmt.Errorf
var _ = math.Inf

// This is a compile-time assertion to ensure that this generated file
// is compatible with the proto package it is being compiled against.
// A compilation error at this line likely means your copy of the
// proto package needs to be updated.
const _ = proto.ProtoPackageIsVersion3 // please upgrade the proto package

// Enum describing possible billing setup errors.
type BillingSetupErrorEnum_BillingSetupError int32

const (
	// Enum unspecified.
	BillingSetupErrorEnum_UNSPECIFIED BillingSetupErrorEnum_BillingSetupError = 0
	// The received error code is not known in this version.
	BillingSetupErrorEnum_UNKNOWN BillingSetupErrorEnum_BillingSetupError = 1
	// Cannot use both an existing Payments account and a new Payments account
	// when setting up billing.
	BillingSetupErrorEnum_CANNOT_USE_EXISTING_AND_NEW_ACCOUNT BillingSetupErrorEnum_BillingSetupError = 2
	// Cannot cancel an APPROVED billing setup whose start time has passed.
	BillingSetupErrorEnum_CANNOT_REMOVE_STARTED_BILLING_SETUP BillingSetupErrorEnum_BillingSetupError = 3
	// Cannot perform a Change of Bill-To (CBT) to the same Payments account.
	BillingSetupErrorEnum_CANNOT_CHANGE_BILLING_TO_SAME_PAYMENTS_ACCOUNT BillingSetupErrorEnum_BillingSetupError = 4
	// Billing Setups can only be used by customers with ENABLED or DRAFT
	// status.
	BillingSetupErrorEnum_BILLING_SETUP_NOT_PERMITTED_FOR_CUSTOMER_STATUS BillingSetupErrorEnum_BillingSetupError = 5
	// Billing Setups must either include a correctly formatted existing
	// Payments account id, or a non-empty new Payments account name.
	BillingSetupErrorEnum_INVALID_PAYMENTS_ACCOUNT BillingSetupErrorEnum_BillingSetupError = 6
	// Only billable and third-party customers can create billing setups.
	BillingSetupErrorEnum_BILLING_SETUP_NOT_PERMITTED_FOR_CUSTOMER_CATEGORY BillingSetupErrorEnum_BillingSetupError = 7
	// Billing Setup creations can only use NOW for start time type.
	BillingSetupErrorEnum_INVALID_START_TIME_TYPE BillingSetupErrorEnum_BillingSetupError = 8
	// Billing Setups can only be created for a third-party customer if they do
	// not already have a setup.
	BillingSetupErrorEnum_THIRD_PARTY_ALREADY_HAS_BILLING BillingSetupErrorEnum_BillingSetupError = 9
	// Billing Setups cannot be created if there is already a pending billing in
	// progress, ie. a billing known to Payments.
	BillingSetupErrorEnum_BILLING_SETUP_IN_PROGRESS BillingSetupErrorEnum_BillingSetupError = 10
	// Billing Setups can only be created by customers who have permission to
	// setup billings. Users can contact a representative for help setting up
	// permissions.
	BillingSetupErrorEnum_NO_SIGNUP_PERMISSION BillingSetupErrorEnum_BillingSetupError = 11
	// Billing Setups cannot be created if there is already a future-approved
	// billing.
	BillingSetupErrorEnum_CHANGE_OF_BILL_TO_IN_PROGRESS BillingSetupErrorEnum_BillingSetupError = 12
	// Billing Setup creation failed because Payments could not find the
	// requested Payments profile.
	BillingSetupErrorEnum_PAYMENTS_PROFILE_NOT_FOUND BillingSetupErrorEnum_BillingSetupError = 13
	// Billing Setup creation failed because Payments could not find the
	// requested Payments account.
	BillingSetupErrorEnum_PAYMENTS_ACCOUNT_NOT_FOUND BillingSetupErrorEnum_BillingSetupError = 14
	// Billing Setup creation failed because Payments considers requested
	// Payments profile ineligible.
	BillingSetupErrorEnum_PAYMENTS_PROFILE_INELIGIBLE BillingSetupErrorEnum_BillingSetupError = 15
	// Billing Setup creation failed because Payments considers requested
	// Payments account ineligible.
	BillingSetupErrorEnum_PAYMENTS_ACCOUNT_INELIGIBLE BillingSetupErrorEnum_BillingSetupError = 16
)

var BillingSetupErrorEnum_BillingSetupError_name = map[int32]string{
	0:  "UNSPECIFIED",
	1:  "UNKNOWN",
	2:  "CANNOT_USE_EXISTING_AND_NEW_ACCOUNT",
	3:  "CANNOT_REMOVE_STARTED_BILLING_SETUP",
	4:  "CANNOT_CHANGE_BILLING_TO_SAME_PAYMENTS_ACCOUNT",
	5:  "BILLING_SETUP_NOT_PERMITTED_FOR_CUSTOMER_STATUS",
	6:  "INVALID_PAYMENTS_ACCOUNT",
	7:  "BILLING_SETUP_NOT_PERMITTED_FOR_CUSTOMER_CATEGORY",
	8:  "INVALID_START_TIME_TYPE",
	9:  "THIRD_PARTY_ALREADY_HAS_BILLING",
	10: "BILLING_SETUP_IN_PROGRESS",
	11: "NO_SIGNUP_PERMISSION",
	12: "CHANGE_OF_BILL_TO_IN_PROGRESS",
	13: "PAYMENTS_PROFILE_NOT_FOUND",
	14: "PAYMENTS_ACCOUNT_NOT_FOUND",
	15: "PAYMENTS_PROFILE_INELIGIBLE",
	16: "PAYMENTS_ACCOUNT_INELIGIBLE",
}

var BillingSetupErrorEnum_BillingSetupError_value = map[string]int32{
	"UNSPECIFIED":                                       0,
	"UNKNOWN":                                           1,
	"CANNOT_USE_EXISTING_AND_NEW_ACCOUNT":               2,
	"CANNOT_REMOVE_STARTED_BILLING_SETUP":               3,
	"CANNOT_CHANGE_BILLING_TO_SAME_PAYMENTS_ACCOUNT":    4,
	"BILLING_SETUP_NOT_PERMITTED_FOR_CUSTOMER_STATUS":   5,
	"INVALID_PAYMENTS_ACCOUNT":                          6,
	"BILLING_SETUP_NOT_PERMITTED_FOR_CUSTOMER_CATEGORY": 7,
	"INVALID_START_TIME_TYPE":                           8,
	"THIRD_PARTY_ALREADY_HAS_BILLING":                   9,
	"BILLING_SETUP_IN_PROGRESS":                         10,
	"NO_SIGNUP_PERMISSION":                              11,
	"CHANGE_OF_BILL_TO_IN_PROGRESS":                     12,
	"PAYMENTS_PROFILE_NOT_FOUND":                        13,
	"PAYMENTS_ACCOUNT_NOT_FOUND":                        14,
	"PAYMENTS_PROFILE_INELIGIBLE":                       15,
	"PAYMENTS_ACCOUNT_INELIGIBLE":                       16,
}

func (x BillingSetupErrorEnum_BillingSetupError) String() string {
	return proto.EnumName(BillingSetupErrorEnum_BillingSetupError_name, int32(x))
}

func (BillingSetupErrorEnum_BillingSetupError) EnumDescriptor() ([]byte, []int) {
	return fileDescriptor_be69d6086d69218d, []int{0, 0}
}

// Container for enum describing possible billing setup errors.
type BillingSetupErrorEnum struct {
	XXX_NoUnkeyedLiteral struct{} `json:"-"`
	XXX_unrecognized     []byte   `json:"-"`
	XXX_sizecache        int32    `json:"-"`
}

func (m *BillingSetupErrorEnum) Reset()         { *m = BillingSetupErrorEnum{} }
func (m *BillingSetupErrorEnum) String() string { return proto.CompactTextString(m) }
func (*BillingSetupErrorEnum) ProtoMessage()    {}
func (*BillingSetupErrorEnum) Descriptor() ([]byte, []int) {
	return fileDescriptor_be69d6086d69218d, []int{0}
}

func (m *BillingSetupErrorEnum) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_BillingSetupErrorEnum.Unmarshal(m, b)
}
func (m *BillingSetupErrorEnum) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_BillingSetupErrorEnum.Marshal(b, m, deterministic)
}
func (m *BillingSetupErrorEnum) XXX_Merge(src proto.Message) {
	xxx_messageInfo_BillingSetupErrorEnum.Merge(m, src)
}
func (m *BillingSetupErrorEnum) XXX_Size() int {
	return xxx_messageInfo_BillingSetupErrorEnum.Size(m)
}
func (m *BillingSetupErrorEnum) XXX_DiscardUnknown() {
	xxx_messageInfo_BillingSetupErrorEnum.DiscardUnknown(m)
}

var xxx_messageInfo_BillingSetupErrorEnum proto.InternalMessageInfo

func init() {
	proto.RegisterEnum("google.ads.googleads.v1.errors.BillingSetupErrorEnum_BillingSetupError", BillingSetupErrorEnum_BillingSetupError_name, BillingSetupErrorEnum_BillingSetupError_value)
	proto.RegisterType((*BillingSetupErrorEnum)(nil), "google.ads.googleads.v1.errors.BillingSetupErrorEnum")
}

func init() {
	proto.RegisterFile("google/ads/googleads/v1/errors/billing_setup_error.proto", fileDescriptor_be69d6086d69218d)
}

var fileDescriptor_be69d6086d69218d = []byte{
	// 568 bytes of a gzipped FileDescriptorProto
	0x1f, 0x8b, 0x08, 0x00, 0x00, 0x00, 0x00, 0x00, 0x02, 0xff, 0x8c, 0x93, 0xcf, 0x6f, 0xd3, 0x30,
	0x14, 0xc7, 0x59, 0x37, 0x36, 0xf0, 0x80, 0x19, 0x8b, 0x1f, 0x63, 0x3f, 0x45, 0x77, 0xe0, 0x96,
	0xa8, 0x4c, 0x48, 0x28, 0x9c, 0xdc, 0xe4, 0x35, 0xb5, 0x48, 0xed, 0x28, 0x76, 0x3a, 0x8a, 0x2a,
	0x59, 0x1d, 0xad, 0xa2, 0x4a, 0x5d, 0x52, 0x35, 0xdd, 0xfe, 0x20, 0x8e, 0xfc, 0x29, 0xfc, 0x17,
	0x5c, 0xb9, 0x71, 0xe6, 0x82, 0x12, 0xb7, 0x51, 0xab, 0x0a, 0xc4, 0xc9, 0x4f, 0x7e, 0xdf, 0xef,
	0xe7, 0xf9, 0x3d, 0x3d, 0xa3, 0xf7, 0x49, 0x96, 0x25, 0x93, 0x91, 0x3d, 0x18, 0xe6, 0xb6, 0x09,
	0x8b, 0xe8, 0xae, 0x61, 0x8f, 0x66, 0xb3, 0x6c, 0x96, 0xdb, 0xd7, 0xe3, 0xc9, 0x64, 0x9c, 0x26,
	0x3a, 0x1f, 0xcd, 0x6f, 0xa7, 0xba, 0xbc, 0xb4, 0xa6, 0xb3, 0x6c, 0x9e, 0x91, 0x33, 0x23, 0xb7,
	0x06, 0xc3, 0xdc, 0xaa, 0x9c, 0xd6, 0x5d, 0xc3, 0x32, 0xce, 0xa3, 0x93, 0x25, 0x79, 0x3a, 0xb6,
	0x07, 0x69, 0x9a, 0xcd, 0x07, 0xf3, 0x71, 0x96, 0xe6, 0xc6, 0x5d, 0xff, 0xbd, 0x83, 0x9e, 0x37,
	0x0d, 0x5b, 0x16, 0x68, 0x28, 0x4c, 0x90, 0xde, 0xde, 0xd4, 0x7f, 0xec, 0xa0, 0xa7, 0x1b, 0x19,
	0x72, 0x80, 0xf6, 0x63, 0x2e, 0x43, 0x70, 0x59, 0x8b, 0x81, 0x87, 0xef, 0x91, 0x7d, 0xb4, 0x17,
	0xf3, 0x8f, 0x5c, 0x5c, 0x71, 0xbc, 0x45, 0xde, 0xa0, 0x0b, 0x97, 0x72, 0x2e, 0x94, 0x8e, 0x25,
	0x68, 0xf8, 0xc4, 0xa4, 0x62, 0xdc, 0xd7, 0x94, 0x7b, 0x9a, 0xc3, 0x95, 0xa6, 0xae, 0x2b, 0x62,
	0xae, 0x70, 0x6d, 0x45, 0x18, 0x41, 0x47, 0x74, 0x41, 0x4b, 0x45, 0x23, 0x05, 0x9e, 0x6e, 0xb2,
	0x20, 0x28, 0x2c, 0x12, 0x54, 0x1c, 0xe2, 0x6d, 0xf2, 0x16, 0x59, 0x0b, 0xa1, 0xdb, 0xa6, 0xdc,
	0x87, 0x4a, 0xa0, 0x84, 0x96, 0xb4, 0x03, 0x3a, 0xa4, 0xbd, 0x0e, 0x70, 0x25, 0x2b, 0xf8, 0x0e,
	0xb9, 0x44, 0xf6, 0x1a, 0x46, 0x17, 0xf6, 0x10, 0xa2, 0x0e, 0x53, 0x45, 0x89, 0x96, 0x88, 0xb4,
	0x1b, 0x4b, 0x25, 0x3a, 0x10, 0x15, 0x75, 0x55, 0x2c, 0xf1, 0x7d, 0x72, 0x82, 0x0e, 0x19, 0xef,
	0xd2, 0x80, 0x79, 0x9b, 0xc8, 0x5d, 0xf2, 0x0e, 0x35, 0xfe, 0x1b, 0xe9, 0x52, 0x05, 0xbe, 0x88,
	0x7a, 0x78, 0x8f, 0x1c, 0xa3, 0x97, 0x4b, 0x68, 0xd9, 0xa0, 0x56, 0xac, 0x03, 0x5a, 0xf5, 0x42,
	0xc0, 0x0f, 0xc8, 0x05, 0x3a, 0x57, 0x6d, 0x16, 0x15, 0xf5, 0x22, 0xd5, 0xd3, 0x34, 0x88, 0x80,
	0x7a, 0x3d, 0xdd, 0xa6, 0x72, 0xd9, 0x24, 0x7e, 0x48, 0x4e, 0xd1, 0xab, 0xf5, 0xc2, 0x8c, 0xeb,
	0x30, 0x12, 0x7e, 0x04, 0x52, 0x62, 0x44, 0x0e, 0xd1, 0x33, 0x2e, 0xb4, 0x64, 0x3e, 0x8f, 0x43,
	0xf3, 0x1e, 0x29, 0x99, 0xe0, 0x78, 0x9f, 0xbc, 0x46, 0xa7, 0x8b, 0x89, 0x89, 0x56, 0xc9, 0x2b,
	0x26, 0xb6, 0x6a, 0x7e, 0x44, 0xce, 0xd0, 0x51, 0xd5, 0x6a, 0x18, 0x89, 0x16, 0x0b, 0xa0, 0xec,
	0xab, 0x25, 0x62, 0xee, 0xe1, 0xc7, 0x6b, 0xf9, 0xc5, 0x28, 0x56, 0xf2, 0x4f, 0xc8, 0x39, 0x3a,
	0xde, 0xf0, 0x33, 0x0e, 0x01, 0xf3, 0x59, 0x33, 0x00, 0x7c, 0xb0, 0x26, 0x58, 0x02, 0x56, 0x04,
	0xb8, 0xf9, 0x6b, 0x0b, 0xd5, 0xbf, 0x64, 0x37, 0xd6, 0xbf, 0x57, 0xb8, 0xf9, 0x62, 0x63, 0x0f,
	0xc3, 0x62, 0x79, 0xc3, 0xad, 0xcf, 0xde, 0xc2, 0x99, 0x64, 0x93, 0x41, 0x9a, 0x58, 0xd9, 0x2c,
	0xb1, 0x93, 0x51, 0x5a, 0xae, 0xf6, 0xf2, 0x1b, 0x4d, 0xc7, 0xf9, 0xdf, 0x7e, 0xd5, 0x07, 0x73,
	0x7c, 0xad, 0x6d, 0xfb, 0x94, 0x7e, 0xab, 0x9d, 0xf9, 0x06, 0x46, 0x87, 0xb9, 0x65, 0xc2, 0x22,
	0xea, 0x36, 0xac, 0xb2, 0x64, 0xfe, 0x7d, 0x29, 0xe8, 0xd3, 0x61, 0xde, 0xaf, 0x04, 0xfd, 0x6e,
	0xa3, 0x6f, 0x04, 0x3f, 0x6b, 0x75, 0x73, 0xeb, 0x38, 0x74, 0x98, 0x3b, 0x4e, 0x25, 0x71, 0x9c,
	0x6e, 0xc3, 0x71, 0x8c, 0xe8, 0x7a, 0xb7, 0x7c, 0xdd, 0xe5, 0x9f, 0x00, 0x00, 0x00, 0xff, 0xff,
	0x29, 0x15, 0x51, 0x97, 0xf2, 0x03, 0x00, 0x00,
}
