// Code generated by protoc-gen-go. DO NOT EDIT.
// source: google/ads/googleads/v2/resources/mobile_device_constant.proto

package resources

import (
	fmt "fmt"
	math "math"

	proto "github.com/golang/protobuf/proto"
	wrappers "github.com/golang/protobuf/ptypes/wrappers"
	enums "google.golang.org/genproto/googleapis/ads/googleads/v2/enums"
	_ "google.golang.org/genproto/googleapis/api/annotations"
)

// Reference imports to suppress errors if they are not otherwise used.
var _ = proto.Marshal
var _ = fmt.Errorf
var _ = math.Inf

// This is a compile-time assertion to ensure that this generated file
// is compatible with the proto package it is being compiled against.
// A compilation error at this line likely means your copy of the
// proto package needs to be updated.
const _ = proto.ProtoPackageIsVersion3 // please upgrade the proto package

// A mobile device constant.
type MobileDeviceConstant struct {
	// The resource name of the mobile device constant.
	// Mobile device constant resource names have the form:
	//
	// `mobileDeviceConstants/{criterion_id}`
	ResourceName string `protobuf:"bytes,1,opt,name=resource_name,json=resourceName,proto3" json:"resource_name,omitempty"`
	// The ID of the mobile device constant.
	Id *wrappers.Int64Value `protobuf:"bytes,2,opt,name=id,proto3" json:"id,omitempty"`
	// The name of the mobile device.
	Name *wrappers.StringValue `protobuf:"bytes,3,opt,name=name,proto3" json:"name,omitempty"`
	// The manufacturer of the mobile device.
	ManufacturerName *wrappers.StringValue `protobuf:"bytes,4,opt,name=manufacturer_name,json=manufacturerName,proto3" json:"manufacturer_name,omitempty"`
	// The operating system of the mobile device.
	OperatingSystemName *wrappers.StringValue `protobuf:"bytes,5,opt,name=operating_system_name,json=operatingSystemName,proto3" json:"operating_system_name,omitempty"`
	// The type of mobile device.
	Type                 enums.MobileDeviceTypeEnum_MobileDeviceType `protobuf:"varint,6,opt,name=type,proto3,enum=google.ads.googleads.v2.enums.MobileDeviceTypeEnum_MobileDeviceType" json:"type,omitempty"`
	XXX_NoUnkeyedLiteral struct{}                                    `json:"-"`
	XXX_unrecognized     []byte                                      `json:"-"`
	XXX_sizecache        int32                                       `json:"-"`
}

func (m *MobileDeviceConstant) Reset()         { *m = MobileDeviceConstant{} }
func (m *MobileDeviceConstant) String() string { return proto.CompactTextString(m) }
func (*MobileDeviceConstant) ProtoMessage()    {}
func (*MobileDeviceConstant) Descriptor() ([]byte, []int) {
	return fileDescriptor_fd7b28684cab8625, []int{0}
}

func (m *MobileDeviceConstant) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_MobileDeviceConstant.Unmarshal(m, b)
}
func (m *MobileDeviceConstant) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_MobileDeviceConstant.Marshal(b, m, deterministic)
}
func (m *MobileDeviceConstant) XXX_Merge(src proto.Message) {
	xxx_messageInfo_MobileDeviceConstant.Merge(m, src)
}
func (m *MobileDeviceConstant) XXX_Size() int {
	return xxx_messageInfo_MobileDeviceConstant.Size(m)
}
func (m *MobileDeviceConstant) XXX_DiscardUnknown() {
	xxx_messageInfo_MobileDeviceConstant.DiscardUnknown(m)
}

var xxx_messageInfo_MobileDeviceConstant proto.InternalMessageInfo

func (m *MobileDeviceConstant) GetResourceName() string {
	if m != nil {
		return m.ResourceName
	}
	return ""
}

func (m *MobileDeviceConstant) GetId() *wrappers.Int64Value {
	if m != nil {
		return m.Id
	}
	return nil
}

func (m *MobileDeviceConstant) GetName() *wrappers.StringValue {
	if m != nil {
		return m.Name
	}
	return nil
}

func (m *MobileDeviceConstant) GetManufacturerName() *wrappers.StringValue {
	if m != nil {
		return m.ManufacturerName
	}
	return nil
}

func (m *MobileDeviceConstant) GetOperatingSystemName() *wrappers.StringValue {
	if m != nil {
		return m.OperatingSystemName
	}
	return nil
}

func (m *MobileDeviceConstant) GetType() enums.MobileDeviceTypeEnum_MobileDeviceType {
	if m != nil {
		return m.Type
	}
	return enums.MobileDeviceTypeEnum_UNSPECIFIED
}

func init() {
	proto.RegisterType((*MobileDeviceConstant)(nil), "google.ads.googleads.v2.resources.MobileDeviceConstant")
}

func init() {
	proto.RegisterFile("google/ads/googleads/v2/resources/mobile_device_constant.proto", fileDescriptor_fd7b28684cab8625)
}

var fileDescriptor_fd7b28684cab8625 = []byte{
	// 447 bytes of a gzipped FileDescriptorProto
	0x1f, 0x8b, 0x08, 0x00, 0x00, 0x00, 0x00, 0x00, 0x02, 0xff, 0x8c, 0x92, 0xdf, 0x6a, 0x13, 0x41,
	0x14, 0xc6, 0xd9, 0x4d, 0x2c, 0x38, 0xfe, 0x41, 0x57, 0x85, 0x58, 0x8b, 0xa4, 0x4a, 0x21, 0x20,
	0xcc, 0xca, 0x2a, 0xbd, 0x58, 0x41, 0xd8, 0x5a, 0x29, 0x15, 0x94, 0x90, 0x4a, 0x10, 0x09, 0x84,
	0xc9, 0xce, 0xe9, 0x30, 0x90, 0xf9, 0xc3, 0xcc, 0x6c, 0x24, 0x2f, 0xe0, 0xbd, 0xaf, 0xe0, 0xa5,
	0x8f, 0xe2, 0xa3, 0xf8, 0x14, 0x92, 0x99, 0xdd, 0xa1, 0x58, 0xab, 0xb9, 0x3b, 0x99, 0xf3, 0x7d,
	0xbf, 0x7c, 0x67, 0xcf, 0x41, 0xaf, 0x99, 0x52, 0x6c, 0x09, 0x39, 0xa1, 0x36, 0x0f, 0xe5, 0xa6,
	0x5a, 0x15, 0xb9, 0x01, 0xab, 0x1a, 0x53, 0x83, 0xcd, 0x85, 0x5a, 0xf0, 0x25, 0xcc, 0x29, 0xac,
	0x78, 0x0d, 0xf3, 0x5a, 0x49, 0xeb, 0x88, 0x74, 0x58, 0x1b, 0xe5, 0x54, 0xb6, 0x1f, 0x4c, 0x98,
	0x50, 0x8b, 0xa3, 0x1f, 0xaf, 0x0a, 0x1c, 0xfd, 0xbb, 0x87, 0x57, 0xfd, 0x05, 0xc8, 0x46, 0xfc,
	0x89, 0x77, 0x6b, 0x0d, 0x01, 0xbd, 0xfb, 0xb8, 0xf5, 0xf9, 0x5f, 0x8b, 0xe6, 0x3c, 0xff, 0x62,
	0x88, 0xd6, 0x60, 0x6c, 0xdb, 0xdf, 0xeb, 0xb8, 0x9a, 0xe7, 0x44, 0x4a, 0xe5, 0x88, 0xe3, 0x4a,
	0xb6, 0xdd, 0x27, 0xdf, 0x7a, 0xe8, 0xfe, 0x7b, 0x8f, 0x3e, 0xf6, 0xe4, 0x37, 0x6d, 0xee, 0xec,
	0x29, 0xba, 0xd5, 0x65, 0x9b, 0x4b, 0x22, 0x60, 0x90, 0x0c, 0x93, 0xd1, 0xf5, 0xc9, 0xcd, 0xee,
	0xf1, 0x03, 0x11, 0x90, 0x3d, 0x43, 0x29, 0xa7, 0x83, 0x74, 0x98, 0x8c, 0x6e, 0x14, 0x8f, 0xda,
	0xc1, 0x70, 0x17, 0x04, 0x9f, 0x4a, 0x77, 0xf8, 0x72, 0x4a, 0x96, 0x0d, 0x4c, 0x52, 0x4e, 0xb3,
	0xe7, 0xa8, 0xef, 0x41, 0x3d, 0x2f, 0xdf, 0xbb, 0x24, 0x3f, 0x73, 0x86, 0x4b, 0x16, 0xf4, 0x5e,
	0x99, 0x9d, 0xa2, 0xbb, 0x82, 0xc8, 0xe6, 0x9c, 0xd4, 0xae, 0x31, 0x60, 0x42, 0x8e, 0xfe, 0x16,
	0xf6, 0x3b, 0x17, 0x6d, 0x3e, 0xe9, 0x18, 0x3d, 0x50, 0x1a, 0x0c, 0x71, 0x5c, 0xb2, 0xb9, 0x5d,
	0x5b, 0x07, 0x22, 0xe0, 0xae, 0x6d, 0x81, 0xbb, 0x17, 0xad, 0x67, 0xde, 0xe9, 0x89, 0x9f, 0x50,
	0x7f, 0xb3, 0x85, 0xc1, 0xce, 0x30, 0x19, 0xdd, 0x2e, 0x8e, 0xf1, 0x55, 0x1b, 0xf6, 0xeb, 0xc3,
	0x17, 0xbf, 0xf1, 0xc7, 0xb5, 0x86, 0xb7, 0xb2, 0x11, 0x97, 0x1e, 0x27, 0x9e, 0x78, 0xf4, 0x35,
	0x45, 0x07, 0xb5, 0x12, 0xf8, 0xbf, 0x37, 0x73, 0xf4, 0xf0, 0x6f, 0xab, 0x1b, 0x6f, 0x46, 0x18,
	0x27, 0x9f, 0xdf, 0xb5, 0x7e, 0xa6, 0x96, 0x44, 0x32, 0xac, 0x0c, 0xcb, 0x19, 0x48, 0x3f, 0x60,
	0x77, 0x60, 0x9a, 0xdb, 0x7f, 0x9c, 0xf4, 0xab, 0x58, 0x7d, 0x4f, 0x7b, 0x27, 0x55, 0xf5, 0x23,
	0xdd, 0x3f, 0x09, 0xc8, 0x8a, 0x5a, 0x1c, 0xca, 0x4d, 0x35, 0x2d, 0xf0, 0xa4, 0x53, 0xfe, 0xec,
	0x34, 0xb3, 0x8a, 0xda, 0x59, 0xd4, 0xcc, 0xa6, 0xc5, 0x2c, 0x6a, 0x7e, 0xa5, 0x07, 0xa1, 0x51,
	0x96, 0x15, 0xb5, 0x65, 0x19, 0x55, 0x65, 0x39, 0x2d, 0xca, 0x32, 0xea, 0x16, 0x3b, 0x3e, 0xec,
	0x8b, 0xdf, 0x01, 0x00, 0x00, 0xff, 0xff, 0xb6, 0x6c, 0xde, 0x8c, 0x7e, 0x03, 0x00, 0x00,
}
