// Code generated by protoc-gen-go. DO NOT EDIT.
// source: google/ads/googleads/v2/services/group_placement_view_service.proto

package services

import (
	context "context"
	fmt "fmt"
	math "math"

	proto "github.com/golang/protobuf/proto"
	resources "google.golang.org/genproto/googleapis/ads/googleads/v2/resources"
	_ "google.golang.org/genproto/googleapis/api/annotations"
	grpc "google.golang.org/grpc"
)

// Reference imports to suppress errors if they are not otherwise used.
var _ = proto.Marshal
var _ = fmt.Errorf
var _ = math.Inf

// This is a compile-time assertion to ensure that this generated file
// is compatible with the proto package it is being compiled against.
// A compilation error at this line likely means your copy of the
// proto package needs to be updated.
const _ = proto.ProtoPackageIsVersion3 // please upgrade the proto package

// Request message for [GroupPlacementViewService.GetGroupPlacementView][google.ads.googleads.v2.services.GroupPlacementViewService.GetGroupPlacementView].
type GetGroupPlacementViewRequest struct {
	// The resource name of the Group Placement view to fetch.
	ResourceName         string   `protobuf:"bytes,1,opt,name=resource_name,json=resourceName,proto3" json:"resource_name,omitempty"`
	XXX_NoUnkeyedLiteral struct{} `json:"-"`
	XXX_unrecognized     []byte   `json:"-"`
	XXX_sizecache        int32    `json:"-"`
}

func (m *GetGroupPlacementViewRequest) Reset()         { *m = GetGroupPlacementViewRequest{} }
func (m *GetGroupPlacementViewRequest) String() string { return proto.CompactTextString(m) }
func (*GetGroupPlacementViewRequest) ProtoMessage()    {}
func (*GetGroupPlacementViewRequest) Descriptor() ([]byte, []int) {
	return fileDescriptor_3fd8b1c75e923f6a, []int{0}
}

func (m *GetGroupPlacementViewRequest) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_GetGroupPlacementViewRequest.Unmarshal(m, b)
}
func (m *GetGroupPlacementViewRequest) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_GetGroupPlacementViewRequest.Marshal(b, m, deterministic)
}
func (m *GetGroupPlacementViewRequest) XXX_Merge(src proto.Message) {
	xxx_messageInfo_GetGroupPlacementViewRequest.Merge(m, src)
}
func (m *GetGroupPlacementViewRequest) XXX_Size() int {
	return xxx_messageInfo_GetGroupPlacementViewRequest.Size(m)
}
func (m *GetGroupPlacementViewRequest) XXX_DiscardUnknown() {
	xxx_messageInfo_GetGroupPlacementViewRequest.DiscardUnknown(m)
}

var xxx_messageInfo_GetGroupPlacementViewRequest proto.InternalMessageInfo

func (m *GetGroupPlacementViewRequest) GetResourceName() string {
	if m != nil {
		return m.ResourceName
	}
	return ""
}

func init() {
	proto.RegisterType((*GetGroupPlacementViewRequest)(nil), "google.ads.googleads.v2.services.GetGroupPlacementViewRequest")
}

func init() {
	proto.RegisterFile("google/ads/googleads/v2/services/group_placement_view_service.proto", fileDescriptor_3fd8b1c75e923f6a)
}

var fileDescriptor_3fd8b1c75e923f6a = []byte{
	// 395 bytes of a gzipped FileDescriptorProto
	0x1f, 0x8b, 0x08, 0x00, 0x00, 0x00, 0x00, 0x00, 0x02, 0xff, 0x84, 0x52, 0xcd, 0xaa, 0xd3, 0x40,
	0x14, 0x26, 0x11, 0x04, 0x83, 0x6e, 0x02, 0x62, 0x8d, 0x45, 0x4a, 0xed, 0x42, 0xba, 0x98, 0x81,
	0x48, 0x11, 0x46, 0x2b, 0xa4, 0x5d, 0xc4, 0x95, 0x94, 0x0a, 0x59, 0x48, 0x20, 0x8c, 0xc9, 0x21,
	0x04, 0x92, 0x99, 0x98, 0x99, 0xa4, 0x0b, 0x71, 0x23, 0x08, 0xee, 0x7d, 0x03, 0x97, 0x3e, 0x4a,
	0xc1, 0x95, 0xaf, 0xe0, 0xea, 0x3e, 0xc5, 0x25, 0x9d, 0x4c, 0x7a, 0x4b, 0x6f, 0x6e, 0x77, 0x1f,
	0x73, 0xbe, 0x9f, 0x39, 0xdf, 0x8c, 0xb5, 0x4e, 0x39, 0x4f, 0x73, 0xc0, 0x34, 0x11, 0x58, 0xc1,
	0x16, 0x35, 0x2e, 0x16, 0x50, 0x35, 0x59, 0x0c, 0x02, 0xa7, 0x15, 0xaf, 0xcb, 0xa8, 0xcc, 0x69,
	0x0c, 0x05, 0x30, 0x19, 0x35, 0x19, 0xec, 0xa2, 0x6e, 0x8a, 0xca, 0x8a, 0x4b, 0x6e, 0x4f, 0x94,
	0x12, 0xd1, 0x44, 0xa0, 0xde, 0x04, 0x35, 0x2e, 0xd2, 0x26, 0xce, 0xdb, 0xa1, 0x98, 0x0a, 0x04,
	0xaf, 0xab, 0xa1, 0x1c, 0xe5, 0xef, 0x8c, 0xb5, 0xba, 0xcc, 0x30, 0x65, 0x8c, 0x4b, 0x2a, 0x33,
	0xce, 0x44, 0x37, 0x7d, 0x72, 0x63, 0x1a, 0xe7, 0x19, 0x30, 0xa9, 0x06, 0xd3, 0xb5, 0x35, 0xf6,
	0x41, 0xfa, 0xad, 0xef, 0x46, 0xdb, 0x06, 0x19, 0xec, 0xb6, 0xf0, 0xa5, 0x06, 0x21, 0xed, 0x17,
	0xd6, 0x23, 0x1d, 0x1f, 0x31, 0x5a, 0xc0, 0xc8, 0x98, 0x18, 0x2f, 0x1f, 0x6c, 0x1f, 0xea, 0xc3,
	0x0f, 0xb4, 0x00, 0xf7, 0xa7, 0x69, 0x3d, 0x3d, 0xb7, 0xf8, 0xa8, 0x16, 0xb3, 0xff, 0x1a, 0xd6,
	0xe3, 0x5b, 0x33, 0xec, 0x77, 0xe8, 0x52, 0x29, 0xe8, 0xae, 0xcb, 0x39, 0x8b, 0x41, 0x7d, 0x5f,
	0x19, 0x3a, 0x57, 0x4f, 0x97, 0xdf, 0xff, 0xfd, 0xff, 0x65, 0xbe, 0xb6, 0x17, 0x6d, 0xb9, 0x5f,
	0x4f, 0xd6, 0x5b, 0xc6, 0xb5, 0x90, 0xbc, 0x80, 0x4a, 0xe0, 0xb9, 0x6a, 0xfb, 0x44, 0x2a, 0xf0,
	0xfc, 0x9b, 0xf3, 0x6c, 0xef, 0x8d, 0x8e, 0x61, 0x1d, 0x2a, 0x33, 0x81, 0x62, 0x5e, 0xac, 0x7e,
	0x98, 0xd6, 0x2c, 0xe6, 0xc5, 0xc5, 0xc5, 0x56, 0xcf, 0x07, 0x0b, 0xdb, 0xb4, 0x0f, 0xb3, 0x31,
	0x3e, 0xbd, 0xef, 0x3c, 0x52, 0x9e, 0x53, 0x96, 0x22, 0x5e, 0xa5, 0x38, 0x05, 0x76, 0x78, 0x36,
	0x7c, 0x4c, 0x1d, 0xfe, 0x95, 0x6f, 0x34, 0xf8, 0x6d, 0xde, 0xf3, 0x3d, 0xef, 0x8f, 0x39, 0xf1,
	0x95, 0xa1, 0x97, 0x08, 0xa4, 0x60, 0x8b, 0x02, 0x17, 0x75, 0xc1, 0x62, 0xaf, 0x29, 0xa1, 0x97,
	0x88, 0xb0, 0xa7, 0x84, 0x81, 0x1b, 0x6a, 0xca, 0x95, 0x39, 0x53, 0xe7, 0x84, 0x78, 0x89, 0x20,
	0xa4, 0x27, 0x11, 0x12, 0xb8, 0x84, 0x68, 0xda, 0xe7, 0xfb, 0x87, 0x7b, 0xbe, 0xba, 0x0e, 0x00,
	0x00, 0xff, 0xff, 0x93, 0x4b, 0x6c, 0xa8, 0x3c, 0x03, 0x00, 0x00,
}

// Reference imports to suppress errors if they are not otherwise used.
var _ context.Context
var _ grpc.ClientConn

// This is a compile-time assertion to ensure that this generated file
// is compatible with the grpc package it is being compiled against.
const _ = grpc.SupportPackageIsVersion4

// GroupPlacementViewServiceClient is the client API for GroupPlacementViewService service.
//
// For semantics around ctx use and closing/ending streaming RPCs, please refer to https://godoc.org/google.golang.org/grpc#ClientConn.NewStream.
type GroupPlacementViewServiceClient interface {
	// Returns the requested Group Placement view in full detail.
	GetGroupPlacementView(ctx context.Context, in *GetGroupPlacementViewRequest, opts ...grpc.CallOption) (*resources.GroupPlacementView, error)
}

type groupPlacementViewServiceClient struct {
	cc *grpc.ClientConn
}

func NewGroupPlacementViewServiceClient(cc *grpc.ClientConn) GroupPlacementViewServiceClient {
	return &groupPlacementViewServiceClient{cc}
}

func (c *groupPlacementViewServiceClient) GetGroupPlacementView(ctx context.Context, in *GetGroupPlacementViewRequest, opts ...grpc.CallOption) (*resources.GroupPlacementView, error) {
	out := new(resources.GroupPlacementView)
	err := c.cc.Invoke(ctx, "/google.ads.googleads.v2.services.GroupPlacementViewService/GetGroupPlacementView", in, out, opts...)
	if err != nil {
		return nil, err
	}
	return out, nil
}

// GroupPlacementViewServiceServer is the server API for GroupPlacementViewService service.
type GroupPlacementViewServiceServer interface {
	// Returns the requested Group Placement view in full detail.
	GetGroupPlacementView(context.Context, *GetGroupPlacementViewRequest) (*resources.GroupPlacementView, error)
}

func RegisterGroupPlacementViewServiceServer(s *grpc.Server, srv GroupPlacementViewServiceServer) {
	s.RegisterService(&_GroupPlacementViewService_serviceDesc, srv)
}

func _GroupPlacementViewService_GetGroupPlacementView_Handler(srv interface{}, ctx context.Context, dec func(interface{}) error, interceptor grpc.UnaryServerInterceptor) (interface{}, error) {
	in := new(GetGroupPlacementViewRequest)
	if err := dec(in); err != nil {
		return nil, err
	}
	if interceptor == nil {
		return srv.(GroupPlacementViewServiceServer).GetGroupPlacementView(ctx, in)
	}
	info := &grpc.UnaryServerInfo{
		Server:     srv,
		FullMethod: "/google.ads.googleads.v2.services.GroupPlacementViewService/GetGroupPlacementView",
	}
	handler := func(ctx context.Context, req interface{}) (interface{}, error) {
		return srv.(GroupPlacementViewServiceServer).GetGroupPlacementView(ctx, req.(*GetGroupPlacementViewRequest))
	}
	return interceptor(ctx, in, info, handler)
}

var _GroupPlacementViewService_serviceDesc = grpc.ServiceDesc{
	ServiceName: "google.ads.googleads.v2.services.GroupPlacementViewService",
	HandlerType: (*GroupPlacementViewServiceServer)(nil),
	Methods: []grpc.MethodDesc{
		{
			MethodName: "GetGroupPlacementView",
			Handler:    _GroupPlacementViewService_GetGroupPlacementView_Handler,
		},
	},
	Streams:  []grpc.StreamDesc{},
	Metadata: "google/ads/googleads/v2/services/group_placement_view_service.proto",
}
