// Code generated by protoc-gen-go. DO NOT EDIT.
// source: google/ads/googleads/v1/resources/mutate_job.proto

package resources

import (
	fmt "fmt"
	math "math"

	proto "github.com/golang/protobuf/proto"
	wrappers "github.com/golang/protobuf/ptypes/wrappers"
	enums "google.golang.org/genproto/googleapis/ads/googleads/v1/enums"
	_ "google.golang.org/genproto/googleapis/api/annotations"
)

// Reference imports to suppress errors if they are not otherwise used.
var _ = proto.Marshal
var _ = fmt.Errorf
var _ = math.Inf

// This is a compile-time assertion to ensure that this generated file
// is compatible with the proto package it is being compiled against.
// A compilation error at this line likely means your copy of the
// proto package needs to be updated.
const _ = proto.ProtoPackageIsVersion3 // please upgrade the proto package

// A list of mutates being processed asynchronously. The mutates are uploaded
// by the user. The mutates themselves aren’t readable and the results of the
// job can only be read using MutateJobService.ListMutateJobResults.
type MutateJob struct {
	// The resource name of the mutate job.
	// Mutate job resource names have the form:
	//
	// `customers/{customer_id}/mutateJobs/{mutate_job_id}`
	ResourceName string `protobuf:"bytes,1,opt,name=resource_name,json=resourceName,proto3" json:"resource_name,omitempty"`
	// ID of this mutate job.
	Id *wrappers.Int64Value `protobuf:"bytes,2,opt,name=id,proto3" json:"id,omitempty"`
	// The next sequence token to use when adding operations. Only set when the
	// mutate job status is PENDING.
	NextAddSequenceToken *wrappers.StringValue `protobuf:"bytes,3,opt,name=next_add_sequence_token,json=nextAddSequenceToken,proto3" json:"next_add_sequence_token,omitempty"`
	// Contains additional information about this mutate job.
	Metadata *MutateJob_MutateJobMetadata `protobuf:"bytes,4,opt,name=metadata,proto3" json:"metadata,omitempty"`
	// Status of this mutate job.
	Status enums.MutateJobStatusEnum_MutateJobStatus `protobuf:"varint,5,opt,name=status,proto3,enum=google.ads.googleads.v1.enums.MutateJobStatusEnum_MutateJobStatus" json:"status,omitempty"`
	// The resource name of the long-running operation that can be used to poll
	// for completion. Only set when the mutate job status is RUNNING or DONE.
	LongRunningOperation *wrappers.StringValue `protobuf:"bytes,6,opt,name=long_running_operation,json=longRunningOperation,proto3" json:"long_running_operation,omitempty"`
	XXX_NoUnkeyedLiteral struct{}              `json:"-"`
	XXX_unrecognized     []byte                `json:"-"`
	XXX_sizecache        int32                 `json:"-"`
}

func (m *MutateJob) Reset()         { *m = MutateJob{} }
func (m *MutateJob) String() string { return proto.CompactTextString(m) }
func (*MutateJob) ProtoMessage()    {}
func (*MutateJob) Descriptor() ([]byte, []int) {
	return fileDescriptor_a5e8cce5a5c605aa, []int{0}
}

func (m *MutateJob) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_MutateJob.Unmarshal(m, b)
}
func (m *MutateJob) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_MutateJob.Marshal(b, m, deterministic)
}
func (m *MutateJob) XXX_Merge(src proto.Message) {
	xxx_messageInfo_MutateJob.Merge(m, src)
}
func (m *MutateJob) XXX_Size() int {
	return xxx_messageInfo_MutateJob.Size(m)
}
func (m *MutateJob) XXX_DiscardUnknown() {
	xxx_messageInfo_MutateJob.DiscardUnknown(m)
}

var xxx_messageInfo_MutateJob proto.InternalMessageInfo

func (m *MutateJob) GetResourceName() string {
	if m != nil {
		return m.ResourceName
	}
	return ""
}

func (m *MutateJob) GetId() *wrappers.Int64Value {
	if m != nil {
		return m.Id
	}
	return nil
}

func (m *MutateJob) GetNextAddSequenceToken() *wrappers.StringValue {
	if m != nil {
		return m.NextAddSequenceToken
	}
	return nil
}

func (m *MutateJob) GetMetadata() *MutateJob_MutateJobMetadata {
	if m != nil {
		return m.Metadata
	}
	return nil
}

func (m *MutateJob) GetStatus() enums.MutateJobStatusEnum_MutateJobStatus {
	if m != nil {
		return m.Status
	}
	return enums.MutateJobStatusEnum_UNSPECIFIED
}

func (m *MutateJob) GetLongRunningOperation() *wrappers.StringValue {
	if m != nil {
		return m.LongRunningOperation
	}
	return nil
}

// Additional information about the mutate job. This message is also used as
// metadata returned in mutate job Long Running Operations.
type MutateJob_MutateJobMetadata struct {
	// The time when this mutate job was created.
	// Formatted as yyyy-mm-dd hh:mm:ss. Example: "2018-03-05 09:15:00"
	CreationDateTime *wrappers.StringValue `protobuf:"bytes,1,opt,name=creation_date_time,json=creationDateTime,proto3" json:"creation_date_time,omitempty"`
	// The time when this mutate job was completed.
	// Formatted as yyyy-MM-dd HH:mm:ss. Example: "2018-03-05 09:16:00"
	CompletionDateTime *wrappers.StringValue `protobuf:"bytes,2,opt,name=completion_date_time,json=completionDateTime,proto3" json:"completion_date_time,omitempty"`
	// The fraction (between 0.0 and 1.0) of mutates that have been processed.
	// This is empty if the job hasn't started running yet.
	EstimatedCompletionRatio *wrappers.DoubleValue `protobuf:"bytes,3,opt,name=estimated_completion_ratio,json=estimatedCompletionRatio,proto3" json:"estimated_completion_ratio,omitempty"`
	// The number of mutate operations in the mutate job.
	OperationCount *wrappers.Int64Value `protobuf:"bytes,4,opt,name=operation_count,json=operationCount,proto3" json:"operation_count,omitempty"`
	// The number of mutate operations executed by the mutate job.
	// Present only if the job has started running.
	ExecutedOperationCount *wrappers.Int64Value `protobuf:"bytes,5,opt,name=executed_operation_count,json=executedOperationCount,proto3" json:"executed_operation_count,omitempty"`
	XXX_NoUnkeyedLiteral   struct{}             `json:"-"`
	XXX_unrecognized       []byte               `json:"-"`
	XXX_sizecache          int32                `json:"-"`
}

func (m *MutateJob_MutateJobMetadata) Reset()         { *m = MutateJob_MutateJobMetadata{} }
func (m *MutateJob_MutateJobMetadata) String() string { return proto.CompactTextString(m) }
func (*MutateJob_MutateJobMetadata) ProtoMessage()    {}
func (*MutateJob_MutateJobMetadata) Descriptor() ([]byte, []int) {
	return fileDescriptor_a5e8cce5a5c605aa, []int{0, 0}
}

func (m *MutateJob_MutateJobMetadata) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_MutateJob_MutateJobMetadata.Unmarshal(m, b)
}
func (m *MutateJob_MutateJobMetadata) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_MutateJob_MutateJobMetadata.Marshal(b, m, deterministic)
}
func (m *MutateJob_MutateJobMetadata) XXX_Merge(src proto.Message) {
	xxx_messageInfo_MutateJob_MutateJobMetadata.Merge(m, src)
}
func (m *MutateJob_MutateJobMetadata) XXX_Size() int {
	return xxx_messageInfo_MutateJob_MutateJobMetadata.Size(m)
}
func (m *MutateJob_MutateJobMetadata) XXX_DiscardUnknown() {
	xxx_messageInfo_MutateJob_MutateJobMetadata.DiscardUnknown(m)
}

var xxx_messageInfo_MutateJob_MutateJobMetadata proto.InternalMessageInfo

func (m *MutateJob_MutateJobMetadata) GetCreationDateTime() *wrappers.StringValue {
	if m != nil {
		return m.CreationDateTime
	}
	return nil
}

func (m *MutateJob_MutateJobMetadata) GetCompletionDateTime() *wrappers.StringValue {
	if m != nil {
		return m.CompletionDateTime
	}
	return nil
}

func (m *MutateJob_MutateJobMetadata) GetEstimatedCompletionRatio() *wrappers.DoubleValue {
	if m != nil {
		return m.EstimatedCompletionRatio
	}
	return nil
}

func (m *MutateJob_MutateJobMetadata) GetOperationCount() *wrappers.Int64Value {
	if m != nil {
		return m.OperationCount
	}
	return nil
}

func (m *MutateJob_MutateJobMetadata) GetExecutedOperationCount() *wrappers.Int64Value {
	if m != nil {
		return m.ExecutedOperationCount
	}
	return nil
}

func init() {
	proto.RegisterType((*MutateJob)(nil), "google.ads.googleads.v1.resources.MutateJob")
	proto.RegisterType((*MutateJob_MutateJobMetadata)(nil), "google.ads.googleads.v1.resources.MutateJob.MutateJobMetadata")
}

func init() {
	proto.RegisterFile("google/ads/googleads/v1/resources/mutate_job.proto", fileDescriptor_a5e8cce5a5c605aa)
}

var fileDescriptor_a5e8cce5a5c605aa = []byte{
	// 582 bytes of a gzipped FileDescriptorProto
	0x1f, 0x8b, 0x08, 0x00, 0x00, 0x00, 0x00, 0x00, 0x02, 0xff, 0x8c, 0x94, 0xdd, 0x6a, 0xd4, 0x4c,
	0x18, 0xc7, 0x49, 0xfa, 0x76, 0x79, 0x3b, 0x6a, 0xd5, 0xa1, 0xd4, 0xb0, 0x16, 0x69, 0x95, 0x42,
	0x41, 0x98, 0xb0, 0xf5, 0xe3, 0x20, 0x82, 0x90, 0x76, 0xa5, 0xb8, 0xd0, 0x0f, 0xb2, 0x75, 0x0f,
	0x96, 0x85, 0x30, 0x9b, 0x79, 0x0c, 0xd1, 0x64, 0x26, 0x66, 0x66, 0x6a, 0xaf, 0xc7, 0x23, 0xf1,
	0x52, 0xbc, 0x13, 0xbd, 0x05, 0x4f, 0x24, 0x5f, 0xb3, 0x75, 0xcb, 0x76, 0x7b, 0xf6, 0x24, 0xf3,
	0xff, 0xfd, 0x32, 0x33, 0xcf, 0x43, 0xd0, 0x7e, 0x2c, 0x44, 0x9c, 0x82, 0x4b, 0x99, 0x74, 0xeb,
	0xb2, 0xac, 0x2e, 0x7a, 0x6e, 0x01, 0x52, 0xe8, 0x22, 0x02, 0xe9, 0x66, 0x5a, 0x51, 0x05, 0xe1,
	0x27, 0x31, 0x25, 0x79, 0x21, 0x94, 0xc0, 0x3b, 0x75, 0x90, 0x50, 0x26, 0x89, 0x61, 0xc8, 0x45,
	0x8f, 0x18, 0xa6, 0xfb, 0x6a, 0x91, 0x16, 0xb8, 0xce, 0xae, 0x2a, 0x43, 0xa9, 0xa8, 0xd2, 0xb2,
	0x36, 0x77, 0xb7, 0x5a, 0x2c, 0x4f, 0x5c, 0xca, 0xb9, 0x50, 0x54, 0x25, 0x82, 0xb7, 0xab, 0x4f,
	0x9a, 0xd5, 0xea, 0x69, 0xaa, 0x3f, 0xba, 0x5f, 0x0b, 0x9a, 0xe7, 0x50, 0x34, 0xeb, 0x4f, 0x7f,
	0x75, 0xd0, 0xda, 0x71, 0x65, 0x1e, 0x88, 0x29, 0x7e, 0x86, 0xee, 0xb5, 0xfb, 0x09, 0x39, 0xcd,
	0xc0, 0xb1, 0xb6, 0xad, 0xbd, 0xb5, 0xe0, 0x6e, 0xfb, 0xf2, 0x84, 0x66, 0x80, 0x9f, 0x23, 0x3b,
	0x61, 0x8e, 0xbd, 0x6d, 0xed, 0xdd, 0xd9, 0x7f, 0xdc, 0x1c, 0x86, 0xb4, 0x7e, 0xf2, 0x9e, 0xab,
	0xd7, 0x2f, 0x47, 0x34, 0xd5, 0x10, 0xd8, 0x09, 0xc3, 0x43, 0xf4, 0x88, 0xc3, 0xa5, 0x0a, 0x29,
	0x63, 0xa1, 0x84, 0x2f, 0x1a, 0x78, 0x04, 0xa1, 0x12, 0x9f, 0x81, 0x3b, 0x2b, 0x95, 0x61, 0xeb,
	0x9a, 0x61, 0xa8, 0x8a, 0x84, 0xc7, 0xb5, 0x62, 0xa3, 0x84, 0x7d, 0xc6, 0x86, 0x0d, 0x7a, 0x5e,
	0x92, 0x78, 0x8c, 0xfe, 0xcf, 0x40, 0x51, 0x46, 0x15, 0x75, 0xfe, 0xab, 0x2c, 0x6f, 0xc9, 0xd2,
	0xfb, 0x25, 0xe6, 0x98, 0xb3, 0xea, 0xb8, 0xb1, 0x04, 0xc6, 0x87, 0xc7, 0xa8, 0x53, 0x5f, 0xaf,
	0xb3, 0xba, 0x6d, 0xed, 0xad, 0xef, 0x1f, 0x2c, 0x34, 0x57, 0x6d, 0x99, 0xb9, 0x86, 0x15, 0xf5,
	0x8e, 0xeb, 0x6c, 0xfe, 0x5d, 0xd0, 0x18, 0x71, 0x80, 0x36, 0x53, 0xc1, 0xe3, 0xb0, 0xd0, 0x9c,
	0x27, 0x3c, 0x0e, 0x45, 0x0e, 0x45, 0xd5, 0x2d, 0xa7, 0x73, 0x9b, 0xbb, 0x28, 0xd9, 0xa0, 0x46,
	0x4f, 0x5b, 0xb2, 0xfb, 0x7d, 0x05, 0x3d, 0xbc, 0x76, 0x1e, 0x3c, 0x40, 0x38, 0x2a, 0xa0, 0x4a,
	0x84, 0xac, 0x1c, 0x1b, 0x95, 0x34, 0xdd, 0x5c, 0xf6, 0x95, 0x07, 0x2d, 0xd7, 0xa7, 0x0a, 0xce,
	0x93, 0x0c, 0xf0, 0x09, 0xda, 0x88, 0x44, 0x96, 0xa7, 0x30, 0x67, 0xb3, 0x6f, 0x61, 0xc3, 0x33,
	0xd2, 0xf8, 0xc6, 0xa8, 0x0b, 0x52, 0x25, 0x19, 0x55, 0xc0, 0xc2, 0x2b, 0xe6, 0xea, 0x40, 0x0b,
	0xa7, 0xa2, 0x2f, 0xf4, 0x34, 0x85, 0xda, 0xea, 0x18, 0xfe, 0xd0, 0xe0, 0x41, 0x49, 0xe3, 0x3e,
	0xba, 0x6f, 0x2e, 0x35, 0x8c, 0x84, 0xe6, 0xaa, 0x19, 0x90, 0x1b, 0x07, 0x75, 0xdd, 0x30, 0x87,
	0x25, 0x82, 0x3f, 0x20, 0x07, 0x2e, 0x21, 0xd2, 0xe5, 0x06, 0xe7, 0x75, 0xab, 0xcb, 0x75, 0x9b,
	0x2d, 0x7c, 0xfa, 0x8f, 0xf6, 0xe0, 0x8f, 0x85, 0x76, 0x23, 0x91, 0x2d, 0x1f, 0xd5, 0x83, 0x75,
	0xd3, 0xd1, 0xb3, 0xd2, 0x7f, 0x66, 0x8d, 0x07, 0x0d, 0x14, 0x8b, 0x94, 0xf2, 0x98, 0x88, 0x22,
	0x76, 0x63, 0xe0, 0xd5, 0xd7, 0xdb, 0x9f, 0x45, 0x9e, 0xc8, 0x1b, 0x7e, 0x49, 0x6f, 0x4c, 0xf5,
	0xcd, 0x5e, 0x39, 0xf2, 0xfd, 0x1f, 0xf6, 0xce, 0x51, 0xad, 0xf4, 0x99, 0x24, 0x75, 0x59, 0x56,
	0xa3, 0x1e, 0x09, 0xda, 0xe4, 0xcf, 0x36, 0x33, 0xf1, 0x99, 0x9c, 0x98, 0xcc, 0x64, 0xd4, 0x9b,
	0x98, 0xcc, 0x6f, 0x7b, 0xb7, 0x5e, 0xf0, 0x3c, 0x9f, 0x49, 0xcf, 0x33, 0x29, 0xcf, 0x1b, 0xf5,
	0x3c, 0xcf, 0xe4, 0xa6, 0x9d, 0x6a, 0xb3, 0x2f, 0xfe, 0x06, 0x00, 0x00, 0xff, 0xff, 0x5f, 0xed,
	0x32, 0xf1, 0x3e, 0x05, 0x00, 0x00,
}
