// Code generated by protoc-gen-go. DO NOT EDIT.
// source: google/ads/googleads/v2/resources/user_list.proto

package resources

import (
	fmt "fmt"
	math "math"

	proto "github.com/golang/protobuf/proto"
	wrappers "github.com/golang/protobuf/ptypes/wrappers"
	common "google.golang.org/genproto/googleapis/ads/googleads/v2/common"
	enums "google.golang.org/genproto/googleapis/ads/googleads/v2/enums"
	_ "google.golang.org/genproto/googleapis/api/annotations"
)

// Reference imports to suppress errors if they are not otherwise used.
var _ = proto.Marshal
var _ = fmt.Errorf
var _ = math.Inf

// This is a compile-time assertion to ensure that this generated file
// is compatible with the proto package it is being compiled against.
// A compilation error at this line likely means your copy of the
// proto package needs to be updated.
const _ = proto.ProtoPackageIsVersion3 // please upgrade the proto package

// A user list. This is a list of users a customer may target.
type UserList struct {
	// The resource name of the user list.
	// User list resource names have the form:
	//
	// `customers/{customer_id}/userLists/{user_list_id}`
	ResourceName string `protobuf:"bytes,1,opt,name=resource_name,json=resourceName,proto3" json:"resource_name,omitempty"`
	// Id of the user list.
	Id *wrappers.Int64Value `protobuf:"bytes,2,opt,name=id,proto3" json:"id,omitempty"`
	// A flag that indicates if a user may edit a list. Depends on the list
	// ownership and list type. For example, external remarketing user lists are
	// not editable.
	//
	// This field is read-only.
	ReadOnly *wrappers.BoolValue `protobuf:"bytes,3,opt,name=read_only,json=readOnly,proto3" json:"read_only,omitempty"`
	// Name of this user list. Depending on its access_reason, the user list name
	// may not be unique (e.g. if access_reason=SHARED)
	Name *wrappers.StringValue `protobuf:"bytes,4,opt,name=name,proto3" json:"name,omitempty"`
	// Description of this user list.
	Description *wrappers.StringValue `protobuf:"bytes,5,opt,name=description,proto3" json:"description,omitempty"`
	// Membership status of this user list. Indicates whether a user list is open
	// or active. Only open user lists can accumulate more users and can be
	// targeted to.
	MembershipStatus enums.UserListMembershipStatusEnum_UserListMembershipStatus `protobuf:"varint,6,opt,name=membership_status,json=membershipStatus,proto3,enum=google.ads.googleads.v2.enums.UserListMembershipStatusEnum_UserListMembershipStatus" json:"membership_status,omitempty"`
	// An ID from external system. It is used by user list sellers to correlate
	// IDs on their systems.
	IntegrationCode *wrappers.StringValue `protobuf:"bytes,7,opt,name=integration_code,json=integrationCode,proto3" json:"integration_code,omitempty"`
	// Number of days a user's cookie stays on your list since its most recent
	// addition to the list. This field must be between 0 and 540 inclusive.
	// However, for CRM based userlists, this field can be set to 10000 which
	// means no expiration.
	//
	// It'll be ignored for logical_user_list.
	MembershipLifeSpan *wrappers.Int64Value `protobuf:"bytes,8,opt,name=membership_life_span,json=membershipLifeSpan,proto3" json:"membership_life_span,omitempty"`
	// Estimated number of users in this user list, on the Google Display Network.
	// This value is null if the number of users has not yet been determined.
	//
	// This field is read-only.
	SizeForDisplay *wrappers.Int64Value `protobuf:"bytes,9,opt,name=size_for_display,json=sizeForDisplay,proto3" json:"size_for_display,omitempty"`
	// Size range in terms of number of users of the UserList, on the Google
	// Display Network.
	//
	// This field is read-only.
	SizeRangeForDisplay enums.UserListSizeRangeEnum_UserListSizeRange `protobuf:"varint,10,opt,name=size_range_for_display,json=sizeRangeForDisplay,proto3,enum=google.ads.googleads.v2.enums.UserListSizeRangeEnum_UserListSizeRange" json:"size_range_for_display,omitempty"`
	// Estimated number of users in this user list in the google.com domain.
	// These are the users available for targeting in Search campaigns.
	// This value is null if the number of users has not yet been determined.
	//
	// This field is read-only.
	SizeForSearch *wrappers.Int64Value `protobuf:"bytes,11,opt,name=size_for_search,json=sizeForSearch,proto3" json:"size_for_search,omitempty"`
	// Size range in terms of number of users of the UserList, for Search ads.
	//
	// This field is read-only.
	SizeRangeForSearch enums.UserListSizeRangeEnum_UserListSizeRange `protobuf:"varint,12,opt,name=size_range_for_search,json=sizeRangeForSearch,proto3,enum=google.ads.googleads.v2.enums.UserListSizeRangeEnum_UserListSizeRange" json:"size_range_for_search,omitempty"`
	// Type of this list.
	//
	// This field is read-only.
	Type enums.UserListTypeEnum_UserListType `protobuf:"varint,13,opt,name=type,proto3,enum=google.ads.googleads.v2.enums.UserListTypeEnum_UserListType" json:"type,omitempty"`
	// Indicating the reason why this user list membership status is closed. It is
	// only populated on lists that were automatically closed due to inactivity,
	// and will be cleared once the list membership status becomes open.
	ClosingReason enums.UserListClosingReasonEnum_UserListClosingReason `protobuf:"varint,14,opt,name=closing_reason,json=closingReason,proto3,enum=google.ads.googleads.v2.enums.UserListClosingReasonEnum_UserListClosingReason" json:"closing_reason,omitempty"`
	// Indicates the reason this account has been granted access to the list.
	// The reason can be SHARED, OWNED, LICENSED or SUBSCRIBED.
	//
	// This field is read-only.
	AccessReason enums.AccessReasonEnum_AccessReason `protobuf:"varint,15,opt,name=access_reason,json=accessReason,proto3,enum=google.ads.googleads.v2.enums.AccessReasonEnum_AccessReason" json:"access_reason,omitempty"`
	// Indicates if this share is still enabled. When a UserList is shared with
	// the user this field is set to ENABLED. Later the userList owner can decide
	// to revoke the share and make it DISABLED.
	// The default value of this field is set to ENABLED.
	AccountUserListStatus enums.UserListAccessStatusEnum_UserListAccessStatus `protobuf:"varint,16,opt,name=account_user_list_status,json=accountUserListStatus,proto3,enum=google.ads.googleads.v2.enums.UserListAccessStatusEnum_UserListAccessStatus" json:"account_user_list_status,omitempty"`
	// Indicates if this user list is eligible for Google Search Network.
	EligibleForSearch *wrappers.BoolValue `protobuf:"bytes,17,opt,name=eligible_for_search,json=eligibleForSearch,proto3" json:"eligible_for_search,omitempty"`
	// Indicates this user list is eligible for Google Display Network.
	//
	// This field is read-only.
	EligibleForDisplay *wrappers.BoolValue `protobuf:"bytes,18,opt,name=eligible_for_display,json=eligibleForDisplay,proto3" json:"eligible_for_display,omitempty"`
	// The user list.
	//
	// Exactly one must be set.
	//
	// Types that are valid to be assigned to UserList:
	//	*UserList_CrmBasedUserList
	//	*UserList_SimilarUserList
	//	*UserList_RuleBasedUserList
	//	*UserList_LogicalUserList
	//	*UserList_BasicUserList
	UserList             isUserList_UserList `protobuf_oneof:"user_list"`
	XXX_NoUnkeyedLiteral struct{}            `json:"-"`
	XXX_unrecognized     []byte              `json:"-"`
	XXX_sizecache        int32               `json:"-"`
}

func (m *UserList) Reset()         { *m = UserList{} }
func (m *UserList) String() string { return proto.CompactTextString(m) }
func (*UserList) ProtoMessage()    {}
func (*UserList) Descriptor() ([]byte, []int) {
	return fileDescriptor_4e9e9b976e83eeb7, []int{0}
}

func (m *UserList) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_UserList.Unmarshal(m, b)
}
func (m *UserList) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_UserList.Marshal(b, m, deterministic)
}
func (m *UserList) XXX_Merge(src proto.Message) {
	xxx_messageInfo_UserList.Merge(m, src)
}
func (m *UserList) XXX_Size() int {
	return xxx_messageInfo_UserList.Size(m)
}
func (m *UserList) XXX_DiscardUnknown() {
	xxx_messageInfo_UserList.DiscardUnknown(m)
}

var xxx_messageInfo_UserList proto.InternalMessageInfo

func (m *UserList) GetResourceName() string {
	if m != nil {
		return m.ResourceName
	}
	return ""
}

func (m *UserList) GetId() *wrappers.Int64Value {
	if m != nil {
		return m.Id
	}
	return nil
}

func (m *UserList) GetReadOnly() *wrappers.BoolValue {
	if m != nil {
		return m.ReadOnly
	}
	return nil
}

func (m *UserList) GetName() *wrappers.StringValue {
	if m != nil {
		return m.Name
	}
	return nil
}

func (m *UserList) GetDescription() *wrappers.StringValue {
	if m != nil {
		return m.Description
	}
	return nil
}

func (m *UserList) GetMembershipStatus() enums.UserListMembershipStatusEnum_UserListMembershipStatus {
	if m != nil {
		return m.MembershipStatus
	}
	return enums.UserListMembershipStatusEnum_UNSPECIFIED
}

func (m *UserList) GetIntegrationCode() *wrappers.StringValue {
	if m != nil {
		return m.IntegrationCode
	}
	return nil
}

func (m *UserList) GetMembershipLifeSpan() *wrappers.Int64Value {
	if m != nil {
		return m.MembershipLifeSpan
	}
	return nil
}

func (m *UserList) GetSizeForDisplay() *wrappers.Int64Value {
	if m != nil {
		return m.SizeForDisplay
	}
	return nil
}

func (m *UserList) GetSizeRangeForDisplay() enums.UserListSizeRangeEnum_UserListSizeRange {
	if m != nil {
		return m.SizeRangeForDisplay
	}
	return enums.UserListSizeRangeEnum_UNSPECIFIED
}

func (m *UserList) GetSizeForSearch() *wrappers.Int64Value {
	if m != nil {
		return m.SizeForSearch
	}
	return nil
}

func (m *UserList) GetSizeRangeForSearch() enums.UserListSizeRangeEnum_UserListSizeRange {
	if m != nil {
		return m.SizeRangeForSearch
	}
	return enums.UserListSizeRangeEnum_UNSPECIFIED
}

func (m *UserList) GetType() enums.UserListTypeEnum_UserListType {
	if m != nil {
		return m.Type
	}
	return enums.UserListTypeEnum_UNSPECIFIED
}

func (m *UserList) GetClosingReason() enums.UserListClosingReasonEnum_UserListClosingReason {
	if m != nil {
		return m.ClosingReason
	}
	return enums.UserListClosingReasonEnum_UNSPECIFIED
}

func (m *UserList) GetAccessReason() enums.AccessReasonEnum_AccessReason {
	if m != nil {
		return m.AccessReason
	}
	return enums.AccessReasonEnum_UNSPECIFIED
}

func (m *UserList) GetAccountUserListStatus() enums.UserListAccessStatusEnum_UserListAccessStatus {
	if m != nil {
		return m.AccountUserListStatus
	}
	return enums.UserListAccessStatusEnum_UNSPECIFIED
}

func (m *UserList) GetEligibleForSearch() *wrappers.BoolValue {
	if m != nil {
		return m.EligibleForSearch
	}
	return nil
}

func (m *UserList) GetEligibleForDisplay() *wrappers.BoolValue {
	if m != nil {
		return m.EligibleForDisplay
	}
	return nil
}

type isUserList_UserList interface {
	isUserList_UserList()
}

type UserList_CrmBasedUserList struct {
	CrmBasedUserList *common.CrmBasedUserListInfo `protobuf:"bytes,19,opt,name=crm_based_user_list,json=crmBasedUserList,proto3,oneof"`
}

type UserList_SimilarUserList struct {
	SimilarUserList *common.SimilarUserListInfo `protobuf:"bytes,20,opt,name=similar_user_list,json=similarUserList,proto3,oneof"`
}

type UserList_RuleBasedUserList struct {
	RuleBasedUserList *common.RuleBasedUserListInfo `protobuf:"bytes,21,opt,name=rule_based_user_list,json=ruleBasedUserList,proto3,oneof"`
}

type UserList_LogicalUserList struct {
	LogicalUserList *common.LogicalUserListInfo `protobuf:"bytes,22,opt,name=logical_user_list,json=logicalUserList,proto3,oneof"`
}

type UserList_BasicUserList struct {
	BasicUserList *common.BasicUserListInfo `protobuf:"bytes,23,opt,name=basic_user_list,json=basicUserList,proto3,oneof"`
}

func (*UserList_CrmBasedUserList) isUserList_UserList() {}

func (*UserList_SimilarUserList) isUserList_UserList() {}

func (*UserList_RuleBasedUserList) isUserList_UserList() {}

func (*UserList_LogicalUserList) isUserList_UserList() {}

func (*UserList_BasicUserList) isUserList_UserList() {}

func (m *UserList) GetUserList() isUserList_UserList {
	if m != nil {
		return m.UserList
	}
	return nil
}

func (m *UserList) GetCrmBasedUserList() *common.CrmBasedUserListInfo {
	if x, ok := m.GetUserList().(*UserList_CrmBasedUserList); ok {
		return x.CrmBasedUserList
	}
	return nil
}

func (m *UserList) GetSimilarUserList() *common.SimilarUserListInfo {
	if x, ok := m.GetUserList().(*UserList_SimilarUserList); ok {
		return x.SimilarUserList
	}
	return nil
}

func (m *UserList) GetRuleBasedUserList() *common.RuleBasedUserListInfo {
	if x, ok := m.GetUserList().(*UserList_RuleBasedUserList); ok {
		return x.RuleBasedUserList
	}
	return nil
}

func (m *UserList) GetLogicalUserList() *common.LogicalUserListInfo {
	if x, ok := m.GetUserList().(*UserList_LogicalUserList); ok {
		return x.LogicalUserList
	}
	return nil
}

func (m *UserList) GetBasicUserList() *common.BasicUserListInfo {
	if x, ok := m.GetUserList().(*UserList_BasicUserList); ok {
		return x.BasicUserList
	}
	return nil
}

// XXX_OneofWrappers is for the internal use of the proto package.
func (*UserList) XXX_OneofWrappers() []interface{} {
	return []interface{}{
		(*UserList_CrmBasedUserList)(nil),
		(*UserList_SimilarUserList)(nil),
		(*UserList_RuleBasedUserList)(nil),
		(*UserList_LogicalUserList)(nil),
		(*UserList_BasicUserList)(nil),
	}
}

func init() {
	proto.RegisterType((*UserList)(nil), "google.ads.googleads.v2.resources.UserList")
}

func init() {
	proto.RegisterFile("google/ads/googleads/v2/resources/user_list.proto", fileDescriptor_4e9e9b976e83eeb7)
}

var fileDescriptor_4e9e9b976e83eeb7 = []byte{
	// 927 bytes of a gzipped FileDescriptorProto
	0x1f, 0x8b, 0x08, 0x00, 0x00, 0x00, 0x00, 0x00, 0x02, 0xff, 0xac, 0x96, 0x4d, 0x6f, 0xdb, 0x36,
	0x1c, 0xc6, 0x67, 0x37, 0xeb, 0x12, 0x26, 0x8e, 0x6d, 0x26, 0xe9, 0x84, 0xac, 0x18, 0xd2, 0x0d,
	0x05, 0x02, 0x0c, 0x90, 0x56, 0xb7, 0x7b, 0x81, 0x5b, 0x6c, 0xb0, 0xb3, 0x36, 0x6b, 0xe1, 0x76,
	0x81, 0xdc, 0xe5, 0xb0, 0x05, 0x10, 0x68, 0x89, 0x56, 0x08, 0x50, 0xa4, 0x40, 0x4a, 0x1d, 0xdc,
	0x9d, 0x76, 0xd8, 0x17, 0xd9, 0x71, 0x1f, 0x65, 0x1f, 0x65, 0x1f, 0x60, 0x87, 0x9d, 0x06, 0x51,
	0xa2, 0x4c, 0xd9, 0x75, 0xa4, 0xc3, 0x6e, 0xf4, 0x9f, 0xff, 0xdf, 0xf3, 0xe8, 0xe1, 0x8b, 0x2c,
	0xf0, 0x20, 0xe4, 0x3c, 0xa4, 0xd8, 0x41, 0x81, 0x74, 0xf2, 0x61, 0x36, 0x7a, 0x33, 0x70, 0x04,
	0x96, 0x3c, 0x15, 0x3e, 0x96, 0x4e, 0x2a, 0xb1, 0xf0, 0x28, 0x91, 0x89, 0x1d, 0x0b, 0x9e, 0x70,
	0x78, 0x2f, 0xef, 0xb3, 0x51, 0x20, 0xed, 0x12, 0xb1, 0xdf, 0x0c, 0xec, 0x12, 0x39, 0x76, 0x36,
	0xa9, 0xfa, 0x3c, 0x8a, 0x38, 0x5b, 0x4a, 0xca, 0x5c, 0xf3, 0x78, 0xe3, 0x63, 0x60, 0x96, 0x46,
	0xd2, 0x41, 0xbe, 0x8f, 0xa5, 0xf4, 0x04, 0x46, 0x92, 0xb3, 0x02, 0x79, 0x7c, 0x33, 0x52, 0x5a,
	0x78, 0x05, 0x2c, 0x13, 0x94, 0xa4, 0xda, 0xef, 0x49, 0x53, 0xd8, 0xa7, 0x5c, 0x12, 0x16, 0x56,
	0xad, 0xbf, 0x6d, 0x4a, 0x47, 0x38, 0x9a, 0x61, 0x21, 0xaf, 0x49, 0x5c, 0xb5, 0xff, 0xba, 0xa9,
	0x80, 0x24, 0x6f, 0xb1, 0x27, 0x10, 0x0b, 0x71, 0x41, 0x0e, 0x9a, 0x92, 0xc9, 0x22, 0xd6, 0xcc,
	0xc7, 0x05, 0xa3, 0x7e, 0xcd, 0xd2, 0xb9, 0xf3, 0x8b, 0x40, 0x71, 0x8c, 0x85, 0x7e, 0x9a, 0xbb,
	0x5a, 0x33, 0x26, 0x0e, 0x62, 0x8c, 0x27, 0x28, 0x21, 0x9c, 0x15, 0xb3, 0x9f, 0xfc, 0xd3, 0x05,
	0xdb, 0x3f, 0x4a, 0x2c, 0x26, 0x44, 0x26, 0xf0, 0x53, 0xd0, 0xd1, 0xbb, 0xec, 0x31, 0x14, 0x61,
	0xab, 0x75, 0xd2, 0x3a, 0xdd, 0x71, 0xf7, 0x74, 0xf1, 0x15, 0x8a, 0x30, 0xfc, 0x0c, 0xb4, 0x49,
	0x60, 0xb5, 0x4f, 0x5a, 0xa7, 0xbb, 0x83, 0x8f, 0x8a, 0x23, 0x62, 0x6b, 0x73, 0xfb, 0x39, 0x4b,
	0xbe, 0x7c, 0x74, 0x89, 0x68, 0x8a, 0xdd, 0x36, 0x09, 0xe0, 0x57, 0x60, 0x47, 0x60, 0x14, 0x78,
	0x9c, 0xd1, 0x85, 0x75, 0x4b, 0x31, 0xc7, 0x6b, 0xcc, 0x98, 0x73, 0x9a, 0x23, 0xdb, 0x59, 0xf3,
	0x0f, 0x8c, 0x2e, 0xe0, 0xe7, 0x60, 0x4b, 0x3d, 0xc1, 0x96, 0x62, 0xee, 0xae, 0x31, 0xd3, 0x44,
	0x10, 0x16, 0xe6, 0x94, 0xea, 0x84, 0xdf, 0x80, 0xdd, 0x00, 0x4b, 0x5f, 0x90, 0x38, 0xcb, 0x67,
	0xbd, 0xdf, 0x00, 0x34, 0x01, 0xf8, 0x5b, 0x0b, 0xf4, 0xd7, 0x76, 0xd4, 0xba, 0x7d, 0xd2, 0x3a,
	0xdd, 0x1f, 0xbc, 0xb6, 0x37, 0xdd, 0x0a, 0xb5, 0x31, 0xb6, 0x5e, 0xc1, 0x97, 0x25, 0x3f, 0x55,
	0xf8, 0x53, 0x96, 0x46, 0x1b, 0x27, 0xdd, 0x5e, 0xb4, 0x52, 0x81, 0xe7, 0xa0, 0x47, 0x58, 0x82,
	0x43, 0xa1, 0xf6, 0xc8, 0xf3, 0x79, 0x80, 0xad, 0x0f, 0x1a, 0x04, 0xe9, 0x1a, 0xd4, 0x19, 0x0f,
	0x30, 0x7c, 0x09, 0x0e, 0x8d, 0x2c, 0x94, 0xcc, 0xb1, 0x27, 0x63, 0xc4, 0xac, 0xed, 0xfa, 0x6d,
	0x83, 0x4b, 0x70, 0x42, 0xe6, 0x78, 0x1a, 0x23, 0x06, 0x9f, 0x82, 0x9e, 0x3a, 0xab, 0x73, 0x2e,
	0xbc, 0x80, 0xc8, 0x98, 0xa2, 0x85, 0xb5, 0x53, 0x2f, 0xb5, 0x9f, 0x41, 0xcf, 0xb8, 0xf8, 0x2e,
	0x47, 0xe0, 0xaf, 0xe0, 0xce, 0xf2, 0xc8, 0x57, 0xc4, 0x80, 0x5a, 0xe6, 0x67, 0x0d, 0x97, 0x79,
	0x4a, 0xde, 0x62, 0x37, 0xd3, 0xa8, 0xac, 0x6f, 0x59, 0x75, 0x0f, 0xa4, 0x1e, 0x1a, 0xe6, 0x67,
	0xa0, 0x5b, 0x66, 0x90, 0x18, 0x09, 0xff, 0xda, 0xda, 0xad, 0x8f, 0xd0, 0x29, 0x22, 0x4c, 0x15,
	0x01, 0x17, 0xe0, 0x68, 0x25, 0x41, 0x21, 0xb5, 0xf7, 0xbf, 0x06, 0x80, 0x66, 0x80, 0xc2, 0xfa,
	0x02, 0x6c, 0x65, 0xb7, 0xde, 0xea, 0x28, 0xa7, 0x27, 0x0d, 0x9d, 0x5e, 0x2f, 0xe2, 0xaa, 0x49,
	0x56, 0x70, 0x95, 0x12, 0x4c, 0xc1, 0x7e, 0xf5, 0x05, 0x68, 0xed, 0x2b, 0xed, 0x57, 0x0d, 0xb5,
	0xcf, 0x72, 0xd8, 0x55, 0x6c, 0xc5, 0xa4, 0x32, 0xe3, 0x76, 0x7c, 0xf3, 0x27, 0x44, 0xa0, 0x53,
	0x79, 0xe3, 0x5b, 0xdd, 0x46, 0x89, 0x46, 0x8a, 0x31, 0xcc, 0xcc, 0x82, 0xbb, 0x87, 0x8c, 0x5f,
	0xf0, 0xf7, 0x16, 0xb0, 0x90, 0xef, 0xf3, 0x94, 0x25, 0x9e, 0xf1, 0xba, 0xcd, 0xaf, 0x74, 0x4f,
	0xd9, 0x4d, 0x1a, 0x86, 0xcc, 0x5d, 0xde, 0x71, 0x9d, 0xcd, 0x09, 0xf7, 0xa8, 0x70, 0x2b, 0xb7,
	0x32, 0xbf, 0xcf, 0x2f, 0xc0, 0x01, 0xa6, 0x24, 0x24, 0x33, 0x5a, 0x39, 0x2c, 0xfd, 0xda, 0x17,
	0x61, 0x5f, 0x63, 0xcb, 0xfd, 0x9f, 0x80, 0xc3, 0x8a, 0x96, 0xbe, 0x3a, 0xb0, 0x56, 0x0c, 0x1a,
	0x62, 0xfa, 0x36, 0x60, 0x70, 0xe0, 0x8b, 0xc8, 0x9b, 0x21, 0x89, 0x83, 0xe5, 0x12, 0x59, 0x07,
	0x4a, 0xec, 0xd1, 0xc6, 0xb5, 0xc9, 0xff, 0xe1, 0xed, 0x33, 0x11, 0x8d, 0x33, 0x52, 0xc7, 0x7d,
	0xce, 0xe6, 0xfc, 0xfb, 0xf7, 0xdc, 0x9e, 0xbf, 0x52, 0x87, 0x08, 0xf4, 0x25, 0x89, 0x08, 0x45,
	0xc2, 0x30, 0x39, 0x54, 0x26, 0x0f, 0xeb, 0x4c, 0xa6, 0x39, 0xb8, 0xe2, 0xd1, 0x95, 0xd5, 0x32,
	0xbc, 0x06, 0x87, 0x22, 0xa5, 0x78, 0x2d, 0xca, 0x91, 0x72, 0xf9, 0xa2, 0xce, 0xc5, 0x4d, 0x29,
	0x7e, 0x57, 0x96, 0xbe, 0x58, 0x9d, 0xc8, 0xc2, 0x50, 0x1e, 0x12, 0x1f, 0x51, 0xc3, 0xe6, 0x4e,
	0xb3, 0x30, 0x93, 0x1c, 0x5c, 0x0d, 0x43, 0xab, 0x65, 0xf8, 0x33, 0xe8, 0xce, 0x90, 0x24, 0xbe,
	0x61, 0xf0, 0xa1, 0x32, 0x78, 0x50, 0x67, 0x30, 0xce, 0xb0, 0x15, 0xf9, 0xce, 0xcc, 0x2c, 0x8e,
	0x77, 0xc1, 0x4e, 0x29, 0x3b, 0xfe, 0xb7, 0x05, 0xee, 0xfb, 0x3c, 0xb2, 0x6b, 0x3f, 0xf7, 0xc6,
	0x1d, 0x2d, 0x70, 0x91, 0x1d, 0xad, 0x8b, 0xd6, 0x4f, 0x2f, 0x0a, 0x26, 0xe4, 0x14, 0xb1, 0xd0,
	0xe6, 0x22, 0x74, 0x42, 0xcc, 0xd4, 0xc1, 0xd3, 0x5f, 0x2d, 0x31, 0x91, 0x37, 0x7c, 0x74, 0x3e,
	0x2e, 0x47, 0x7f, 0xb4, 0x6f, 0x9d, 0x8f, 0x46, 0x7f, 0xb6, 0xef, 0x9d, 0xe7, 0x92, 0xa3, 0x40,
	0xda, 0xf9, 0x30, 0x1b, 0x5d, 0x0e, 0x6c, 0x57, 0x77, 0xfe, 0xa5, 0x7b, 0xae, 0x46, 0x81, 0xbc,
	0x2a, 0x7b, 0xae, 0x2e, 0x07, 0x57, 0x65, 0xcf, 0xdf, 0xed, 0xfb, 0xf9, 0xc4, 0x70, 0x38, 0x0a,
	0xe4, 0x70, 0x58, 0x76, 0x0d, 0x87, 0x97, 0x83, 0xe1, 0xb0, 0xec, 0x9b, 0xdd, 0x56, 0x0f, 0xfb,
	0xf0, 0xbf, 0x00, 0x00, 0x00, 0xff, 0xff, 0x92, 0x7c, 0x0c, 0x2c, 0x20, 0x0b, 0x00, 0x00,
}
