// Code generated by protoc-gen-go. DO NOT EDIT.
// source: google/ads/googleads/v1/errors/manager_link_error.proto

package errors

import (
	fmt "fmt"
	math "math"

	proto "github.com/golang/protobuf/proto"
	_ "google.golang.org/genproto/googleapis/api/annotations"
)

// Reference imports to suppress errors if they are not otherwise used.
var _ = proto.Marshal
var _ = fmt.Errorf
var _ = math.Inf

// This is a compile-time assertion to ensure that this generated file
// is compatible with the proto package it is being compiled against.
// A compilation error at this line likely means your copy of the
// proto package needs to be updated.
const _ = proto.ProtoPackageIsVersion3 // please upgrade the proto package

// Enum describing possible ManagerLink errors.
type ManagerLinkErrorEnum_ManagerLinkError int32

const (
	// Enum unspecified.
	ManagerLinkErrorEnum_UNSPECIFIED ManagerLinkErrorEnum_ManagerLinkError = 0
	// The received error code is not known in this version.
	ManagerLinkErrorEnum_UNKNOWN ManagerLinkErrorEnum_ManagerLinkError = 1
	// The manager and client have incompatible account types.
	ManagerLinkErrorEnum_ACCOUNTS_NOT_COMPATIBLE_FOR_LINKING ManagerLinkErrorEnum_ManagerLinkError = 2
	// Client is already linked to too many managers.
	ManagerLinkErrorEnum_TOO_MANY_MANAGERS ManagerLinkErrorEnum_ManagerLinkError = 3
	// Manager has too many pending invitations.
	ManagerLinkErrorEnum_TOO_MANY_INVITES ManagerLinkErrorEnum_ManagerLinkError = 4
	// Client is already invited by this manager.
	ManagerLinkErrorEnum_ALREADY_INVITED_BY_THIS_MANAGER ManagerLinkErrorEnum_ManagerLinkError = 5
	// The client is already managed by this manager.
	ManagerLinkErrorEnum_ALREADY_MANAGED_BY_THIS_MANAGER ManagerLinkErrorEnum_ManagerLinkError = 6
	// Client is already managed in hierarchy.
	ManagerLinkErrorEnum_ALREADY_MANAGED_IN_HIERARCHY ManagerLinkErrorEnum_ManagerLinkError = 7
	// Manger and sub-manager to be linked have duplicate client.
	ManagerLinkErrorEnum_DUPLICATE_CHILD_FOUND ManagerLinkErrorEnum_ManagerLinkError = 8
	// Client has no active user that can access the client account.
	ManagerLinkErrorEnum_CLIENT_HAS_NO_ADMIN_USER ManagerLinkErrorEnum_ManagerLinkError = 9
	// Adding this link would exceed the maximum hierarchy depth.
	ManagerLinkErrorEnum_MAX_DEPTH_EXCEEDED ManagerLinkErrorEnum_ManagerLinkError = 10
	// Adding this link will create a cycle.
	ManagerLinkErrorEnum_CYCLE_NOT_ALLOWED ManagerLinkErrorEnum_ManagerLinkError = 11
	// Manager account has the maximum number of linked clients.
	ManagerLinkErrorEnum_TOO_MANY_ACCOUNTS ManagerLinkErrorEnum_ManagerLinkError = 12
	// Parent manager account has the maximum number of linked clients.
	ManagerLinkErrorEnum_TOO_MANY_ACCOUNTS_AT_MANAGER ManagerLinkErrorEnum_ManagerLinkError = 13
	// The account is not authorized owner.
	ManagerLinkErrorEnum_NON_OWNER_USER_CANNOT_MODIFY_LINK ManagerLinkErrorEnum_ManagerLinkError = 14
	// Your manager account is suspended, and you are no longer allowed to link
	// to clients.
	ManagerLinkErrorEnum_SUSPENDED_ACCOUNT_CANNOT_ADD_CLIENTS ManagerLinkErrorEnum_ManagerLinkError = 15
)

var ManagerLinkErrorEnum_ManagerLinkError_name = map[int32]string{
	0:  "UNSPECIFIED",
	1:  "UNKNOWN",
	2:  "ACCOUNTS_NOT_COMPATIBLE_FOR_LINKING",
	3:  "TOO_MANY_MANAGERS",
	4:  "TOO_MANY_INVITES",
	5:  "ALREADY_INVITED_BY_THIS_MANAGER",
	6:  "ALREADY_MANAGED_BY_THIS_MANAGER",
	7:  "ALREADY_MANAGED_IN_HIERARCHY",
	8:  "DUPLICATE_CHILD_FOUND",
	9:  "CLIENT_HAS_NO_ADMIN_USER",
	10: "MAX_DEPTH_EXCEEDED",
	11: "CYCLE_NOT_ALLOWED",
	12: "TOO_MANY_ACCOUNTS",
	13: "TOO_MANY_ACCOUNTS_AT_MANAGER",
	14: "NON_OWNER_USER_CANNOT_MODIFY_LINK",
	15: "SUSPENDED_ACCOUNT_CANNOT_ADD_CLIENTS",
}

var ManagerLinkErrorEnum_ManagerLinkError_value = map[string]int32{
	"UNSPECIFIED":                          0,
	"UNKNOWN":                              1,
	"ACCOUNTS_NOT_COMPATIBLE_FOR_LINKING":  2,
	"TOO_MANY_MANAGERS":                    3,
	"TOO_MANY_INVITES":                     4,
	"ALREADY_INVITED_BY_THIS_MANAGER":      5,
	"ALREADY_MANAGED_BY_THIS_MANAGER":      6,
	"ALREADY_MANAGED_IN_HIERARCHY":         7,
	"DUPLICATE_CHILD_FOUND":                8,
	"CLIENT_HAS_NO_ADMIN_USER":             9,
	"MAX_DEPTH_EXCEEDED":                   10,
	"CYCLE_NOT_ALLOWED":                    11,
	"TOO_MANY_ACCOUNTS":                    12,
	"TOO_MANY_ACCOUNTS_AT_MANAGER":         13,
	"NON_OWNER_USER_CANNOT_MODIFY_LINK":    14,
	"SUSPENDED_ACCOUNT_CANNOT_ADD_CLIENTS": 15,
}

func (x ManagerLinkErrorEnum_ManagerLinkError) String() string {
	return proto.EnumName(ManagerLinkErrorEnum_ManagerLinkError_name, int32(x))
}

func (ManagerLinkErrorEnum_ManagerLinkError) EnumDescriptor() ([]byte, []int) {
	return fileDescriptor_7d072fd0281d8377, []int{0, 0}
}

// Container for enum describing possible ManagerLink errors.
type ManagerLinkErrorEnum struct {
	XXX_NoUnkeyedLiteral struct{} `json:"-"`
	XXX_unrecognized     []byte   `json:"-"`
	XXX_sizecache        int32    `json:"-"`
}

func (m *ManagerLinkErrorEnum) Reset()         { *m = ManagerLinkErrorEnum{} }
func (m *ManagerLinkErrorEnum) String() string { return proto.CompactTextString(m) }
func (*ManagerLinkErrorEnum) ProtoMessage()    {}
func (*ManagerLinkErrorEnum) Descriptor() ([]byte, []int) {
	return fileDescriptor_7d072fd0281d8377, []int{0}
}

func (m *ManagerLinkErrorEnum) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_ManagerLinkErrorEnum.Unmarshal(m, b)
}
func (m *ManagerLinkErrorEnum) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_ManagerLinkErrorEnum.Marshal(b, m, deterministic)
}
func (m *ManagerLinkErrorEnum) XXX_Merge(src proto.Message) {
	xxx_messageInfo_ManagerLinkErrorEnum.Merge(m, src)
}
func (m *ManagerLinkErrorEnum) XXX_Size() int {
	return xxx_messageInfo_ManagerLinkErrorEnum.Size(m)
}
func (m *ManagerLinkErrorEnum) XXX_DiscardUnknown() {
	xxx_messageInfo_ManagerLinkErrorEnum.DiscardUnknown(m)
}

var xxx_messageInfo_ManagerLinkErrorEnum proto.InternalMessageInfo

func init() {
	proto.RegisterEnum("google.ads.googleads.v1.errors.ManagerLinkErrorEnum_ManagerLinkError", ManagerLinkErrorEnum_ManagerLinkError_name, ManagerLinkErrorEnum_ManagerLinkError_value)
	proto.RegisterType((*ManagerLinkErrorEnum)(nil), "google.ads.googleads.v1.errors.ManagerLinkErrorEnum")
}

func init() {
	proto.RegisterFile("google/ads/googleads/v1/errors/manager_link_error.proto", fileDescriptor_7d072fd0281d8377)
}

var fileDescriptor_7d072fd0281d8377 = []byte{
	// 538 bytes of a gzipped FileDescriptorProto
	0x1f, 0x8b, 0x08, 0x00, 0x00, 0x00, 0x00, 0x00, 0x02, 0xff, 0x7c, 0x92, 0xdf, 0x6e, 0xd3, 0x30,
	0x14, 0xc6, 0x59, 0x0b, 0x1b, 0xb8, 0xc0, 0x8c, 0xb5, 0x22, 0x40, 0xd5, 0x80, 0x0e, 0x04, 0x57,
	0x89, 0x2a, 0x2e, 0x90, 0xc2, 0x95, 0x6b, 0xbb, 0x8d, 0xb5, 0xc4, 0x8e, 0xf2, 0xa7, 0x5d, 0x51,
	0x25, 0x2b, 0xd0, 0x2a, 0xaa, 0xd6, 0x26, 0x55, 0x52, 0xf6, 0x40, 0x5c, 0xf2, 0x28, 0x3c, 0x07,
	0x57, 0x5c, 0xf1, 0x02, 0x48, 0x28, 0x31, 0x89, 0xa0, 0x13, 0xdc, 0x24, 0x47, 0x9f, 0x7f, 0xdf,
	0xb1, 0xcf, 0xd1, 0x07, 0xde, 0x26, 0x59, 0x96, 0xac, 0x97, 0x66, 0xbc, 0x28, 0x4c, 0x5d, 0x96,
	0xd5, 0xd5, 0xc0, 0x5c, 0xe6, 0x79, 0x96, 0x17, 0xe6, 0x26, 0x4e, 0xe3, 0x64, 0x99, 0xab, 0xf5,
	0x2a, 0xbd, 0x54, 0x95, 0x66, 0x6c, 0xf3, 0x6c, 0x97, 0xa1, 0x53, 0x4d, 0x1b, 0xf1, 0xa2, 0x30,
	0x1a, 0xa3, 0x71, 0x35, 0x30, 0xb4, 0xf1, 0x49, 0xaf, 0x6e, 0xbc, 0x5d, 0x99, 0x71, 0x9a, 0x66,
	0xbb, 0x78, 0xb7, 0xca, 0xd2, 0x42, 0xbb, 0xfb, 0x3f, 0xdb, 0xe0, 0xc4, 0xd5, 0xad, 0x9d, 0x55,
	0x7a, 0xc9, 0x4a, 0x0f, 0x4b, 0x3f, 0x6d, 0xfa, 0xdf, 0xda, 0x00, 0xee, 0x1f, 0xa0, 0x63, 0xd0,
	0x89, 0x44, 0xe0, 0x31, 0xc2, 0x47, 0x9c, 0x51, 0x78, 0x03, 0x75, 0xc0, 0x51, 0x24, 0xce, 0x85,
	0x9c, 0x0a, 0x78, 0x80, 0x5e, 0x81, 0x33, 0x4c, 0x88, 0x8c, 0x44, 0x18, 0x28, 0x21, 0x43, 0x45,
	0xa4, 0xeb, 0xe1, 0x90, 0x0f, 0x1d, 0xa6, 0x46, 0xd2, 0x57, 0x0e, 0x17, 0xe7, 0x5c, 0x8c, 0x61,
	0x0b, 0x75, 0xc1, 0x83, 0x50, 0x4a, 0xe5, 0x62, 0x31, 0x2b, 0x3f, 0x78, 0xcc, 0xfc, 0x00, 0xb6,
	0xd1, 0x09, 0x80, 0x8d, 0xcc, 0xc5, 0x84, 0x87, 0x2c, 0x80, 0x37, 0xd1, 0x19, 0x78, 0x8a, 0x1d,
	0x9f, 0x61, 0x5a, 0x8b, 0x54, 0x0d, 0x67, 0x2a, 0xb4, 0x79, 0x50, 0x7b, 0xe1, 0xad, 0x3f, 0x21,
	0x2d, 0x5e, 0x87, 0x0e, 0xd1, 0x33, 0xd0, 0xdb, 0x87, 0xb8, 0x50, 0x36, 0x67, 0x3e, 0xf6, 0x89,
	0x3d, 0x83, 0x47, 0xe8, 0x31, 0xe8, 0xd2, 0xc8, 0x73, 0x38, 0xc1, 0x21, 0x53, 0xc4, 0xe6, 0x0e,
	0x55, 0x23, 0x19, 0x09, 0x0a, 0x6f, 0xa3, 0x1e, 0x78, 0x44, 0x1c, 0xce, 0x44, 0xa8, 0x6c, 0x5c,
	0x8e, 0xa7, 0x30, 0x75, 0xb9, 0x50, 0x51, 0xc0, 0x7c, 0x78, 0x07, 0x3d, 0x04, 0xc8, 0xc5, 0x17,
	0x8a, 0x32, 0x2f, 0xb4, 0x15, 0xbb, 0x20, 0x8c, 0x51, 0x46, 0x21, 0x28, 0x27, 0x25, 0x33, 0xe2,
	0xb0, 0x6a, 0x1f, 0xd8, 0x71, 0xe4, 0x94, 0x51, 0xd8, 0xf9, 0x6b, 0x01, 0xf5, 0xca, 0xe0, 0xdd,
	0xf2, 0x81, 0xd7, 0x64, 0x85, 0xc3, 0x66, 0x84, 0x7b, 0xe8, 0x25, 0x78, 0x2e, 0xa4, 0x50, 0x72,
	0x2a, 0x98, 0x5f, 0xdd, 0xad, 0x08, 0x16, 0x65, 0x6f, 0x57, 0x52, 0x3e, 0x9a, 0x55, 0x3b, 0x86,
	0xf7, 0xd1, 0x6b, 0xf0, 0x22, 0x88, 0x02, 0x8f, 0x09, 0xca, 0x68, 0xdd, 0xa9, 0x26, 0x31, 0xa5,
	0x4a, 0x4f, 0x12, 0xc0, 0xe3, 0xe1, 0x8f, 0x03, 0xd0, 0xff, 0x98, 0x6d, 0x8c, 0xff, 0x87, 0x68,
	0xd8, 0xdd, 0x8f, 0x82, 0x57, 0xa6, 0xc7, 0x3b, 0x78, 0x4f, 0x7f, 0x1b, 0x93, 0x6c, 0x1d, 0xa7,
	0x89, 0x91, 0xe5, 0x89, 0x99, 0x2c, 0xd3, 0x2a, 0x5b, 0x75, 0x8c, 0xb7, 0xab, 0xe2, 0x5f, 0xa9,
	0x7e, 0xa7, 0x7f, 0x9f, 0x5b, 0xed, 0x31, 0xc6, 0x5f, 0x5a, 0xa7, 0x63, 0xdd, 0x0c, 0x2f, 0x0a,
	0x43, 0x97, 0x65, 0x35, 0x19, 0x18, 0xd5, 0x95, 0xc5, 0xd7, 0x1a, 0x98, 0xe3, 0x45, 0x31, 0x6f,
	0x80, 0xf9, 0x64, 0x30, 0xd7, 0xc0, 0xf7, 0x56, 0x5f, 0xab, 0x96, 0x85, 0x17, 0x85, 0x65, 0x35,
	0x88, 0x65, 0x4d, 0x06, 0x96, 0xa5, 0xa1, 0x0f, 0x87, 0xd5, 0xeb, 0xde, 0xfc, 0x0a, 0x00, 0x00,
	0xff, 0xff, 0x90, 0x81, 0x99, 0x8c, 0x72, 0x03, 0x00, 0x00,
}
