// Code generated by protoc-gen-go. DO NOT EDIT.
// source: google/ads/googleads/v2/resources/customer_client.proto

package resources

import (
	fmt "fmt"
	math "math"

	proto "github.com/golang/protobuf/proto"
	wrappers "github.com/golang/protobuf/ptypes/wrappers"
	_ "google.golang.org/genproto/googleapis/api/annotations"
)

// Reference imports to suppress errors if they are not otherwise used.
var _ = proto.Marshal
var _ = fmt.Errorf
var _ = math.Inf

// This is a compile-time assertion to ensure that this generated file
// is compatible with the proto package it is being compiled against.
// A compilation error at this line likely means your copy of the
// proto package needs to be updated.
const _ = proto.ProtoPackageIsVersion3 // please upgrade the proto package

// A link between the given customer and a client customer. CustomerClients only
// exist for manager customers. All direct and indirect client customers are
// included, as well as the manager itself.
type CustomerClient struct {
	// The resource name of the customer client.
	// CustomerClient resource names have the form:
	// `customers/{customer_id}/customerClients/{client_customer_id}`
	ResourceName string `protobuf:"bytes,1,opt,name=resource_name,json=resourceName,proto3" json:"resource_name,omitempty"`
	// The resource name of the client-customer which is linked to
	// the given customer. Read only.
	ClientCustomer *wrappers.StringValue `protobuf:"bytes,3,opt,name=client_customer,json=clientCustomer,proto3" json:"client_customer,omitempty"`
	// Specifies whether this is a
	// [hidden account](https://support.google.com/google-ads/answer/7519830).
	// Read only.
	Hidden *wrappers.BoolValue `protobuf:"bytes,4,opt,name=hidden,proto3" json:"hidden,omitempty"`
	// Distance between given customer and client. For self link, the level value
	// will be 0. Read only.
	Level                *wrappers.Int64Value `protobuf:"bytes,5,opt,name=level,proto3" json:"level,omitempty"`
	XXX_NoUnkeyedLiteral struct{}             `json:"-"`
	XXX_unrecognized     []byte               `json:"-"`
	XXX_sizecache        int32                `json:"-"`
}

func (m *CustomerClient) Reset()         { *m = CustomerClient{} }
func (m *CustomerClient) String() string { return proto.CompactTextString(m) }
func (*CustomerClient) ProtoMessage()    {}
func (*CustomerClient) Descriptor() ([]byte, []int) {
	return fileDescriptor_463452e1d1f19c18, []int{0}
}

func (m *CustomerClient) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_CustomerClient.Unmarshal(m, b)
}
func (m *CustomerClient) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_CustomerClient.Marshal(b, m, deterministic)
}
func (m *CustomerClient) XXX_Merge(src proto.Message) {
	xxx_messageInfo_CustomerClient.Merge(m, src)
}
func (m *CustomerClient) XXX_Size() int {
	return xxx_messageInfo_CustomerClient.Size(m)
}
func (m *CustomerClient) XXX_DiscardUnknown() {
	xxx_messageInfo_CustomerClient.DiscardUnknown(m)
}

var xxx_messageInfo_CustomerClient proto.InternalMessageInfo

func (m *CustomerClient) GetResourceName() string {
	if m != nil {
		return m.ResourceName
	}
	return ""
}

func (m *CustomerClient) GetClientCustomer() *wrappers.StringValue {
	if m != nil {
		return m.ClientCustomer
	}
	return nil
}

func (m *CustomerClient) GetHidden() *wrappers.BoolValue {
	if m != nil {
		return m.Hidden
	}
	return nil
}

func (m *CustomerClient) GetLevel() *wrappers.Int64Value {
	if m != nil {
		return m.Level
	}
	return nil
}

func init() {
	proto.RegisterType((*CustomerClient)(nil), "google.ads.googleads.v2.resources.CustomerClient")
}

func init() {
	proto.RegisterFile("google/ads/googleads/v2/resources/customer_client.proto", fileDescriptor_463452e1d1f19c18)
}

var fileDescriptor_463452e1d1f19c18 = []byte{
	// 362 bytes of a gzipped FileDescriptorProto
	0x1f, 0x8b, 0x08, 0x00, 0x00, 0x00, 0x00, 0x00, 0x02, 0xff, 0x84, 0x91, 0x41, 0x4b, 0xc3, 0x30,
	0x00, 0x85, 0x69, 0xe7, 0x06, 0x56, 0x9d, 0x50, 0x2f, 0x65, 0x0e, 0xd9, 0x94, 0xc1, 0x4e, 0x29,
	0x56, 0x51, 0x88, 0xa7, 0x6e, 0xc8, 0xd0, 0x83, 0x8c, 0x09, 0x3d, 0x48, 0x61, 0x64, 0x6d, 0xac,
	0x85, 0x34, 0x29, 0x49, 0x3a, 0xaf, 0xfe, 0x16, 0x8f, 0xfe, 0x14, 0xff, 0x86, 0x37, 0x7f, 0x85,
	0xac, 0x69, 0x02, 0x32, 0xd0, 0xdb, 0x23, 0x79, 0xdf, 0x7b, 0x8f, 0xc4, 0xb9, 0xce, 0x18, 0xcb,
	0x08, 0xf6, 0x51, 0x2a, 0x7c, 0x25, 0x37, 0x6a, 0x1d, 0xf8, 0x1c, 0x0b, 0x56, 0xf1, 0x04, 0x0b,
	0x3f, 0xa9, 0x84, 0x64, 0x05, 0xe6, 0xcb, 0x84, 0xe4, 0x98, 0x4a, 0x50, 0x72, 0x26, 0x99, 0x3b,
	0x54, 0x6e, 0x80, 0x52, 0x01, 0x0c, 0x08, 0xd6, 0x01, 0x30, 0x60, 0xef, 0xa4, 0xc9, 0xae, 0x81,
	0x55, 0xf5, 0xec, 0xbf, 0x72, 0x54, 0x96, 0x98, 0x0b, 0x15, 0xd1, 0xeb, 0xeb, 0xee, 0x32, 0xf7,
	0x11, 0xa5, 0x4c, 0x22, 0x99, 0x33, 0xda, 0xdc, 0x9e, 0x7e, 0x59, 0x4e, 0x77, 0xda, 0x54, 0x4f,
	0xeb, 0x66, 0xf7, 0xcc, 0x39, 0xd0, 0xe9, 0x4b, 0x8a, 0x0a, 0xec, 0x59, 0x03, 0x6b, 0xbc, 0xbb,
	0xd8, 0xd7, 0x87, 0x0f, 0xa8, 0xc0, 0xee, 0xad, 0x73, 0xa8, 0x86, 0x2e, 0xf5, 0x70, 0xaf, 0x35,
	0xb0, 0xc6, 0x7b, 0x41, 0xbf, 0xd9, 0x09, 0xf4, 0x1e, 0xf0, 0x28, 0x79, 0x4e, 0xb3, 0x08, 0x91,
	0x0a, 0x2f, 0xba, 0x0a, 0xd2, 0x8d, 0x6e, 0xe0, 0x74, 0x5e, 0xf2, 0x34, 0xc5, 0xd4, 0xdb, 0xa9,
	0xe9, 0xde, 0x16, 0x3d, 0x61, 0x8c, 0x28, 0xb6, 0x71, 0xba, 0xe7, 0x4e, 0x9b, 0xe0, 0x35, 0x26,
	0x5e, 0xbb, 0x46, 0x8e, 0xb7, 0x90, 0x3b, 0x2a, 0xaf, 0x2e, 0x15, 0xa3, 0x9c, 0x93, 0x37, 0xdb,
	0x19, 0x25, 0xac, 0x00, 0xff, 0xbe, 0xe6, 0xe4, 0xe8, 0xf7, 0x63, 0xcc, 0x37, 0x99, 0x73, 0xeb,
	0xe9, 0xbe, 0x21, 0x33, 0x46, 0x10, 0xcd, 0x00, 0xe3, 0x99, 0x9f, 0x61, 0x5a, 0x37, 0xea, 0x0f,
	0x2d, 0x73, 0xf1, 0xc7, 0xff, 0xde, 0x18, 0xf5, 0x6e, 0xb7, 0x66, 0x61, 0xf8, 0x61, 0x0f, 0x67,
	0x2a, 0x32, 0x4c, 0x05, 0x50, 0x72, 0xa3, 0xa2, 0x00, 0x2c, 0xb4, 0xf3, 0x53, 0x7b, 0xe2, 0x30,
	0x15, 0xb1, 0xf1, 0xc4, 0x51, 0x10, 0x1b, 0xcf, 0xb7, 0x3d, 0x52, 0x17, 0x10, 0x86, 0xa9, 0x80,
	0xd0, 0xb8, 0x20, 0x8c, 0x02, 0x08, 0x8d, 0x6f, 0xd5, 0xa9, 0xc7, 0x5e, 0xfc, 0x04, 0x00, 0x00,
	0xff, 0xff, 0xe5, 0x64, 0xaf, 0x16, 0x8b, 0x02, 0x00, 0x00,
}
