// Code generated by protoc-gen-go. DO NOT EDIT.
// source: google/ads/googleads/v2/enums/gender_type.proto

package enums

import (
	fmt "fmt"
	math "math"

	proto "github.com/golang/protobuf/proto"
	_ "google.golang.org/genproto/googleapis/api/annotations"
)

// Reference imports to suppress errors if they are not otherwise used.
var _ = proto.Marshal
var _ = fmt.Errorf
var _ = math.Inf

// This is a compile-time assertion to ensure that this generated file
// is compatible with the proto package it is being compiled against.
// A compilation error at this line likely means your copy of the
// proto package needs to be updated.
const _ = proto.ProtoPackageIsVersion3 // please upgrade the proto package

// The type of demographic genders (e.g. female).
type GenderTypeEnum_GenderType int32

const (
	// Not specified.
	GenderTypeEnum_UNSPECIFIED GenderTypeEnum_GenderType = 0
	// Used for return value only. Represents value unknown in this version.
	GenderTypeEnum_UNKNOWN GenderTypeEnum_GenderType = 1
	// Male.
	GenderTypeEnum_MALE GenderTypeEnum_GenderType = 10
	// Female.
	GenderTypeEnum_FEMALE GenderTypeEnum_GenderType = 11
	// Undetermined gender.
	GenderTypeEnum_UNDETERMINED GenderTypeEnum_GenderType = 20
)

var GenderTypeEnum_GenderType_name = map[int32]string{
	0:  "UNSPECIFIED",
	1:  "UNKNOWN",
	10: "MALE",
	11: "FEMALE",
	20: "UNDETERMINED",
}

var GenderTypeEnum_GenderType_value = map[string]int32{
	"UNSPECIFIED":  0,
	"UNKNOWN":      1,
	"MALE":         10,
	"FEMALE":       11,
	"UNDETERMINED": 20,
}

func (x GenderTypeEnum_GenderType) String() string {
	return proto.EnumName(GenderTypeEnum_GenderType_name, int32(x))
}

func (GenderTypeEnum_GenderType) EnumDescriptor() ([]byte, []int) {
	return fileDescriptor_159d7a4fdd5ef73b, []int{0, 0}
}

// Container for enum describing the type of demographic genders.
type GenderTypeEnum struct {
	XXX_NoUnkeyedLiteral struct{} `json:"-"`
	XXX_unrecognized     []byte   `json:"-"`
	XXX_sizecache        int32    `json:"-"`
}

func (m *GenderTypeEnum) Reset()         { *m = GenderTypeEnum{} }
func (m *GenderTypeEnum) String() string { return proto.CompactTextString(m) }
func (*GenderTypeEnum) ProtoMessage()    {}
func (*GenderTypeEnum) Descriptor() ([]byte, []int) {
	return fileDescriptor_159d7a4fdd5ef73b, []int{0}
}

func (m *GenderTypeEnum) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_GenderTypeEnum.Unmarshal(m, b)
}
func (m *GenderTypeEnum) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_GenderTypeEnum.Marshal(b, m, deterministic)
}
func (m *GenderTypeEnum) XXX_Merge(src proto.Message) {
	xxx_messageInfo_GenderTypeEnum.Merge(m, src)
}
func (m *GenderTypeEnum) XXX_Size() int {
	return xxx_messageInfo_GenderTypeEnum.Size(m)
}
func (m *GenderTypeEnum) XXX_DiscardUnknown() {
	xxx_messageInfo_GenderTypeEnum.DiscardUnknown(m)
}

var xxx_messageInfo_GenderTypeEnum proto.InternalMessageInfo

func init() {
	proto.RegisterEnum("google.ads.googleads.v2.enums.GenderTypeEnum_GenderType", GenderTypeEnum_GenderType_name, GenderTypeEnum_GenderType_value)
	proto.RegisterType((*GenderTypeEnum)(nil), "google.ads.googleads.v2.enums.GenderTypeEnum")
}

func init() {
	proto.RegisterFile("google/ads/googleads/v2/enums/gender_type.proto", fileDescriptor_159d7a4fdd5ef73b)
}

var fileDescriptor_159d7a4fdd5ef73b = []byte{
	// 305 bytes of a gzipped FileDescriptorProto
	0x1f, 0x8b, 0x08, 0x00, 0x00, 0x00, 0x00, 0x00, 0x02, 0xff, 0x7c, 0x50, 0xcf, 0x4a, 0xc3, 0x30,
	0x1c, 0x76, 0x53, 0xa6, 0xfc, 0x26, 0xae, 0x04, 0x4f, 0xe2, 0x0e, 0xdb, 0x03, 0xa4, 0x50, 0x6f,
	0xf1, 0x94, 0xb9, 0x6c, 0x0c, 0x5d, 0x1c, 0x73, 0x9b, 0x20, 0x05, 0xa9, 0x26, 0x84, 0xc2, 0x9a,
	0x94, 0xa6, 0x1b, 0xec, 0x75, 0x3c, 0xfa, 0x28, 0x3e, 0x87, 0x27, 0x9f, 0x42, 0x9a, 0xae, 0xdd,
	0x49, 0x2f, 0xe5, 0xe3, 0xf7, 0xfd, 0xe9, 0x97, 0x0f, 0x7c, 0x65, 0x8c, 0x5a, 0x4b, 0x3f, 0x12,
	0x76, 0x0f, 0x0b, 0xb4, 0x0d, 0x7c, 0xa9, 0x37, 0x89, 0xf5, 0x95, 0xd4, 0x42, 0x66, 0xaf, 0xf9,
	0x2e, 0x95, 0x38, 0xcd, 0x4c, 0x6e, 0x50, 0xb7, 0x54, 0xe1, 0x48, 0x58, 0x5c, 0x1b, 0xf0, 0x36,
	0xc0, 0xce, 0x70, 0x75, 0x5d, 0xe5, 0xa5, 0xb1, 0x1f, 0x69, 0x6d, 0xf2, 0x28, 0x8f, 0x8d, 0xb6,
	0xa5, 0xb9, 0x2f, 0xe0, 0x62, 0xec, 0x12, 0x17, 0xbb, 0x54, 0x32, 0xbd, 0x49, 0xfa, 0x73, 0x80,
	0xc3, 0x05, 0x75, 0xa0, 0xbd, 0xe4, 0x4f, 0x33, 0x76, 0x37, 0x19, 0x4d, 0xd8, 0xd0, 0x3b, 0x42,
	0x6d, 0x38, 0x5d, 0xf2, 0x7b, 0xfe, 0xf8, 0xcc, 0xbd, 0x06, 0x3a, 0x83, 0x93, 0x29, 0x7d, 0x60,
	0x1e, 0x20, 0x80, 0xd6, 0x88, 0x39, 0xdc, 0x46, 0x1e, 0x9c, 0x2f, 0xf9, 0x90, 0x2d, 0xd8, 0x7c,
	0x3a, 0xe1, 0x6c, 0xe8, 0x5d, 0x0e, 0xbe, 0x1b, 0xd0, 0x7b, 0x37, 0x09, 0xfe, 0xb7, 0xe9, 0xa0,
	0x73, 0xf8, 0xef, 0xac, 0x28, 0x37, 0x6b, 0xbc, 0x0c, 0xf6, 0x0e, 0x65, 0xd6, 0x91, 0x56, 0xd8,
	0x64, 0xaa, 0x18, 0xc0, 0x55, 0xaf, 0xc6, 0x49, 0x63, 0xfb, 0xc7, 0x56, 0xb7, 0xee, 0xfb, 0xd1,
	0x3c, 0x1e, 0x53, 0xfa, 0xd9, 0xec, 0x8e, 0xcb, 0x28, 0x2a, 0x2c, 0x2e, 0x61, 0x81, 0x56, 0x01,
	0x2e, 0x5e, 0x6d, 0xbf, 0x2a, 0x3e, 0xa4, 0xc2, 0x86, 0x35, 0x1f, 0xae, 0x82, 0xd0, 0xf1, 0x3f,
	0xcd, 0x5e, 0x79, 0x24, 0x84, 0x0a, 0x4b, 0x48, 0xad, 0x20, 0x64, 0x15, 0x10, 0xe2, 0x34, 0x6f,
	0x2d, 0x57, 0xec, 0xe6, 0x37, 0x00, 0x00, 0xff, 0xff, 0xbc, 0x1c, 0x53, 0x3c, 0xc3, 0x01, 0x00,
	0x00,
}
