// Code generated by protoc-gen-go. DO NOT EDIT.
// source: google/ads/googleads/v2/enums/recommendation_type.proto

package enums

import (
	fmt "fmt"
	math "math"

	proto "github.com/golang/protobuf/proto"
	_ "google.golang.org/genproto/googleapis/api/annotations"
)

// Reference imports to suppress errors if they are not otherwise used.
var _ = proto.Marshal
var _ = fmt.Errorf
var _ = math.Inf

// This is a compile-time assertion to ensure that this generated file
// is compatible with the proto package it is being compiled against.
// A compilation error at this line likely means your copy of the
// proto package needs to be updated.
const _ = proto.ProtoPackageIsVersion3 // please upgrade the proto package

// Types of recommendations.
type RecommendationTypeEnum_RecommendationType int32

const (
	// Not specified.
	RecommendationTypeEnum_UNSPECIFIED RecommendationTypeEnum_RecommendationType = 0
	// Used for return value only. Represents value unknown in this version.
	RecommendationTypeEnum_UNKNOWN RecommendationTypeEnum_RecommendationType = 1
	// Budget recommendation for budget constrained campaigns.
	RecommendationTypeEnum_CAMPAIGN_BUDGET RecommendationTypeEnum_RecommendationType = 2
	// Keyword recommendation.
	RecommendationTypeEnum_KEYWORD RecommendationTypeEnum_RecommendationType = 3
	// Recommendation to add a new text ad.
	RecommendationTypeEnum_TEXT_AD RecommendationTypeEnum_RecommendationType = 4
	// Recommendation to update a campaign to use a Target CPA bidding strategy.
	RecommendationTypeEnum_TARGET_CPA_OPT_IN RecommendationTypeEnum_RecommendationType = 5
	// Recommendation to update a campaign to use the Maximize Conversions
	// bidding strategy.
	RecommendationTypeEnum_MAXIMIZE_CONVERSIONS_OPT_IN RecommendationTypeEnum_RecommendationType = 6
	// Recommendation to enable Enhanced Cost Per Click for a campaign.
	RecommendationTypeEnum_ENHANCED_CPC_OPT_IN RecommendationTypeEnum_RecommendationType = 7
	// Recommendation to start showing your campaign's ads on Google Search
	// Partners Websites.
	RecommendationTypeEnum_SEARCH_PARTNERS_OPT_IN RecommendationTypeEnum_RecommendationType = 8
	// Recommendation to update a campaign to use a Maximize Clicks bidding
	// strategy.
	RecommendationTypeEnum_MAXIMIZE_CLICKS_OPT_IN RecommendationTypeEnum_RecommendationType = 9
	// Recommendation to start using the "Optimize" ad rotation setting for the
	// given ad group.
	RecommendationTypeEnum_OPTIMIZE_AD_ROTATION RecommendationTypeEnum_RecommendationType = 10
	// Recommendation to add callout extensions to a campaign.
	RecommendationTypeEnum_CALLOUT_EXTENSION RecommendationTypeEnum_RecommendationType = 11
	// Recommendation to add sitelink extensions to a campaign.
	RecommendationTypeEnum_SITELINK_EXTENSION RecommendationTypeEnum_RecommendationType = 12
	// Recommendation to add call extensions to a campaign.
	RecommendationTypeEnum_CALL_EXTENSION RecommendationTypeEnum_RecommendationType = 13
	// Recommendation to change an existing keyword from one match type to a
	// broader match type.
	RecommendationTypeEnum_KEYWORD_MATCH_TYPE RecommendationTypeEnum_RecommendationType = 14
	// Recommendation to move unused budget from one budget to a constrained
	// budget.
	RecommendationTypeEnum_MOVE_UNUSED_BUDGET RecommendationTypeEnum_RecommendationType = 15
)

var RecommendationTypeEnum_RecommendationType_name = map[int32]string{
	0:  "UNSPECIFIED",
	1:  "UNKNOWN",
	2:  "CAMPAIGN_BUDGET",
	3:  "KEYWORD",
	4:  "TEXT_AD",
	5:  "TARGET_CPA_OPT_IN",
	6:  "MAXIMIZE_CONVERSIONS_OPT_IN",
	7:  "ENHANCED_CPC_OPT_IN",
	8:  "SEARCH_PARTNERS_OPT_IN",
	9:  "MAXIMIZE_CLICKS_OPT_IN",
	10: "OPTIMIZE_AD_ROTATION",
	11: "CALLOUT_EXTENSION",
	12: "SITELINK_EXTENSION",
	13: "CALL_EXTENSION",
	14: "KEYWORD_MATCH_TYPE",
	15: "MOVE_UNUSED_BUDGET",
}

var RecommendationTypeEnum_RecommendationType_value = map[string]int32{
	"UNSPECIFIED":                 0,
	"UNKNOWN":                     1,
	"CAMPAIGN_BUDGET":             2,
	"KEYWORD":                     3,
	"TEXT_AD":                     4,
	"TARGET_CPA_OPT_IN":           5,
	"MAXIMIZE_CONVERSIONS_OPT_IN": 6,
	"ENHANCED_CPC_OPT_IN":         7,
	"SEARCH_PARTNERS_OPT_IN":      8,
	"MAXIMIZE_CLICKS_OPT_IN":      9,
	"OPTIMIZE_AD_ROTATION":        10,
	"CALLOUT_EXTENSION":           11,
	"SITELINK_EXTENSION":          12,
	"CALL_EXTENSION":              13,
	"KEYWORD_MATCH_TYPE":          14,
	"MOVE_UNUSED_BUDGET":          15,
}

func (x RecommendationTypeEnum_RecommendationType) String() string {
	return proto.EnumName(RecommendationTypeEnum_RecommendationType_name, int32(x))
}

func (RecommendationTypeEnum_RecommendationType) EnumDescriptor() ([]byte, []int) {
	return fileDescriptor_5d57f4d4a21d6733, []int{0, 0}
}

// Container for enum describing types of recommendations.
type RecommendationTypeEnum struct {
	XXX_NoUnkeyedLiteral struct{} `json:"-"`
	XXX_unrecognized     []byte   `json:"-"`
	XXX_sizecache        int32    `json:"-"`
}

func (m *RecommendationTypeEnum) Reset()         { *m = RecommendationTypeEnum{} }
func (m *RecommendationTypeEnum) String() string { return proto.CompactTextString(m) }
func (*RecommendationTypeEnum) ProtoMessage()    {}
func (*RecommendationTypeEnum) Descriptor() ([]byte, []int) {
	return fileDescriptor_5d57f4d4a21d6733, []int{0}
}

func (m *RecommendationTypeEnum) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_RecommendationTypeEnum.Unmarshal(m, b)
}
func (m *RecommendationTypeEnum) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_RecommendationTypeEnum.Marshal(b, m, deterministic)
}
func (m *RecommendationTypeEnum) XXX_Merge(src proto.Message) {
	xxx_messageInfo_RecommendationTypeEnum.Merge(m, src)
}
func (m *RecommendationTypeEnum) XXX_Size() int {
	return xxx_messageInfo_RecommendationTypeEnum.Size(m)
}
func (m *RecommendationTypeEnum) XXX_DiscardUnknown() {
	xxx_messageInfo_RecommendationTypeEnum.DiscardUnknown(m)
}

var xxx_messageInfo_RecommendationTypeEnum proto.InternalMessageInfo

func init() {
	proto.RegisterEnum("google.ads.googleads.v2.enums.RecommendationTypeEnum_RecommendationType", RecommendationTypeEnum_RecommendationType_name, RecommendationTypeEnum_RecommendationType_value)
	proto.RegisterType((*RecommendationTypeEnum)(nil), "google.ads.googleads.v2.enums.RecommendationTypeEnum")
}

func init() {
	proto.RegisterFile("google/ads/googleads/v2/enums/recommendation_type.proto", fileDescriptor_5d57f4d4a21d6733)
}

var fileDescriptor_5d57f4d4a21d6733 = []byte{
	// 493 bytes of a gzipped FileDescriptorProto
	0x1f, 0x8b, 0x08, 0x00, 0x00, 0x00, 0x00, 0x00, 0x02, 0xff, 0x7c, 0x92, 0xd1, 0x6e, 0xd3, 0x30,
	0x14, 0x86, 0x69, 0x0b, 0x1b, 0xb8, 0xb0, 0x06, 0x0f, 0x3a, 0x34, 0x98, 0xd0, 0xf6, 0x00, 0x89,
	0x54, 0x2e, 0x90, 0xc2, 0x95, 0xeb, 0x98, 0xd6, 0x6a, 0x6b, 0x5b, 0x89, 0xd3, 0x75, 0x53, 0x25,
	0xab, 0x2c, 0x51, 0x54, 0x69, 0x89, 0xa3, 0xa6, 0x9b, 0xb4, 0xd7, 0xe0, 0x11, 0xb8, 0xe4, 0x51,
	0x78, 0x14, 0xc4, 0x3d, 0xb7, 0xc8, 0xc9, 0x12, 0x86, 0x26, 0x76, 0x13, 0x9d, 0x9c, 0xef, 0xff,
	0x7f, 0x9d, 0xe4, 0x1c, 0xf0, 0x31, 0xd1, 0x3a, 0xb9, 0x8c, 0x9d, 0x55, 0x54, 0x38, 0x55, 0x69,
	0xaa, 0xeb, 0x81, 0x13, 0x67, 0x57, 0x69, 0xe1, 0x6c, 0xe2, 0x0b, 0x9d, 0xa6, 0x71, 0x16, 0xad,
	0xb6, 0x6b, 0x9d, 0xa9, 0xed, 0x4d, 0x1e, 0xdb, 0xf9, 0x46, 0x6f, 0x35, 0x3c, 0xaa, 0xd4, 0xf6,
	0x2a, 0x2a, 0xec, 0xc6, 0x68, 0x5f, 0x0f, 0xec, 0xd2, 0x78, 0xf8, 0xae, 0xce, 0xcd, 0xd7, 0xce,
	0x2a, 0xcb, 0xf4, 0xb6, 0x0c, 0x28, 0x2a, 0xf3, 0xc9, 0xd7, 0x0e, 0xe8, 0xfb, 0xff, 0x44, 0xcb,
	0x9b, 0x3c, 0x26, 0xd9, 0x55, 0x7a, 0xf2, 0xbb, 0x0d, 0xe0, 0x7d, 0x04, 0x7b, 0xa0, 0x1b, 0xb2,
	0x40, 0x10, 0x4c, 0x3f, 0x53, 0xe2, 0x59, 0x8f, 0x60, 0x17, 0xec, 0x86, 0x6c, 0xc2, 0xf8, 0x29,
	0xb3, 0x5a, 0x70, 0x1f, 0xf4, 0x30, 0x9a, 0x09, 0x44, 0x47, 0x4c, 0x0d, 0x43, 0x6f, 0x44, 0xa4,
	0xd5, 0x36, 0x8a, 0x09, 0x39, 0x3b, 0xe5, 0xbe, 0x67, 0x75, 0xcc, 0x8b, 0x24, 0x0b, 0xa9, 0x90,
	0x67, 0x3d, 0x86, 0xaf, 0xc1, 0x4b, 0x89, 0xfc, 0x11, 0x91, 0x0a, 0x0b, 0xa4, 0xb8, 0x90, 0x8a,
	0x32, 0xeb, 0x09, 0x7c, 0x0f, 0xde, 0xce, 0xd0, 0x82, 0xce, 0xe8, 0x39, 0x51, 0x98, 0xb3, 0x39,
	0xf1, 0x03, 0xca, 0x59, 0x50, 0x0b, 0x76, 0xe0, 0x01, 0xd8, 0x27, 0x6c, 0x8c, 0x18, 0x26, 0x9e,
	0xc2, 0x02, 0xd7, 0x60, 0x17, 0x1e, 0x82, 0x7e, 0x40, 0x90, 0x8f, 0xc7, 0x4a, 0x20, 0x5f, 0x32,
	0xe2, 0x37, 0xa6, 0xa7, 0x86, 0xfd, 0x4d, 0x9d, 0x52, 0x3c, 0x69, 0xd8, 0x33, 0xf8, 0x06, 0xbc,
	0xe2, 0x42, 0x56, 0x0c, 0x79, 0xca, 0xe7, 0x12, 0x49, 0xca, 0x99, 0x05, 0xcc, 0x88, 0x18, 0x4d,
	0xa7, 0x3c, 0x94, 0x8a, 0x2c, 0x24, 0x61, 0x66, 0x12, 0xab, 0x0b, 0xfb, 0x00, 0x06, 0x54, 0x92,
	0x29, 0x65, 0x93, 0x3b, 0xfd, 0xe7, 0x10, 0x82, 0x3d, 0x23, 0xbf, 0xd3, 0x7b, 0x61, 0xb4, 0xb7,
	0xdf, 0xaf, 0x66, 0x48, 0xe2, 0xb1, 0x92, 0x67, 0x82, 0x58, 0x7b, 0xa6, 0x3f, 0xe3, 0x73, 0xa2,
	0x42, 0x16, 0x06, 0xc4, 0xab, 0xff, 0x57, 0x6f, 0xf8, 0xab, 0x05, 0x8e, 0x2f, 0x74, 0x6a, 0x3f,
	0xb8, 0xd8, 0xe1, 0xc1, 0xfd, 0xe5, 0x08, 0xb3, 0x53, 0xd1, 0x3a, 0x1f, 0xde, 0x3a, 0x13, 0x7d,
	0xb9, 0xca, 0x12, 0x5b, 0x6f, 0x12, 0x27, 0x89, 0xb3, 0x72, 0xe3, 0xf5, 0x6d, 0xe5, 0xeb, 0xe2,
	0x3f, 0xa7, 0xf6, 0xa9, 0x7c, 0x7e, 0x6b, 0x77, 0x46, 0x08, 0x7d, 0x6f, 0x1f, 0x8d, 0xaa, 0x28,
	0x14, 0x15, 0x76, 0x55, 0x9a, 0x6a, 0x3e, 0xb0, 0xcd, 0x8d, 0x14, 0x3f, 0x6a, 0xbe, 0x44, 0x51,
	0xb1, 0x6c, 0xf8, 0x72, 0x3e, 0x58, 0x96, 0xfc, 0x67, 0xfb, 0xb8, 0x6a, 0xba, 0x2e, 0x8a, 0x0a,
	0xd7, 0x6d, 0x14, 0xae, 0x3b, 0x1f, 0xb8, 0x6e, 0xa9, 0xf9, 0xb2, 0x53, 0x0e, 0xf6, 0xe1, 0x4f,
	0x00, 0x00, 0x00, 0xff, 0xff, 0xe2, 0x3a, 0xa3, 0x2e, 0x02, 0x03, 0x00, 0x00,
}
