// Code generated by protoc-gen-go. DO NOT EDIT.
// source: google/cloud/websecurityscanner/v1beta/finding_type_stats.proto

package websecurityscanner

import (
	fmt "fmt"
	math "math"

	proto "github.com/golang/protobuf/proto"
	_ "google.golang.org/genproto/googleapis/api/annotations"
)

// Reference imports to suppress errors if they are not otherwise used.
var _ = proto.Marshal
var _ = fmt.Errorf
var _ = math.Inf

// This is a compile-time assertion to ensure that this generated file
// is compatible with the proto package it is being compiled against.
// A compilation error at this line likely means your copy of the
// proto package needs to be updated.
const _ = proto.ProtoPackageIsVersion3 // please upgrade the proto package

// A FindingTypeStats resource represents stats regarding a specific FindingType
// of Findings under a given ScanRun.
type FindingTypeStats struct {
	// Output only.
	// The finding type associated with the stats.
	FindingType string `protobuf:"bytes,1,opt,name=finding_type,json=findingType,proto3" json:"finding_type,omitempty"`
	// Output only.
	// The count of findings belonging to this finding type.
	FindingCount         int32    `protobuf:"varint,2,opt,name=finding_count,json=findingCount,proto3" json:"finding_count,omitempty"`
	XXX_NoUnkeyedLiteral struct{} `json:"-"`
	XXX_unrecognized     []byte   `json:"-"`
	XXX_sizecache        int32    `json:"-"`
}

func (m *FindingTypeStats) Reset()         { *m = FindingTypeStats{} }
func (m *FindingTypeStats) String() string { return proto.CompactTextString(m) }
func (*FindingTypeStats) ProtoMessage()    {}
func (*FindingTypeStats) Descriptor() ([]byte, []int) {
	return fileDescriptor_2cd330f4bd03c930, []int{0}
}

func (m *FindingTypeStats) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_FindingTypeStats.Unmarshal(m, b)
}
func (m *FindingTypeStats) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_FindingTypeStats.Marshal(b, m, deterministic)
}
func (m *FindingTypeStats) XXX_Merge(src proto.Message) {
	xxx_messageInfo_FindingTypeStats.Merge(m, src)
}
func (m *FindingTypeStats) XXX_Size() int {
	return xxx_messageInfo_FindingTypeStats.Size(m)
}
func (m *FindingTypeStats) XXX_DiscardUnknown() {
	xxx_messageInfo_FindingTypeStats.DiscardUnknown(m)
}

var xxx_messageInfo_FindingTypeStats proto.InternalMessageInfo

func (m *FindingTypeStats) GetFindingType() string {
	if m != nil {
		return m.FindingType
	}
	return ""
}

func (m *FindingTypeStats) GetFindingCount() int32 {
	if m != nil {
		return m.FindingCount
	}
	return 0
}

func init() {
	proto.RegisterType((*FindingTypeStats)(nil), "google.cloud.websecurityscanner.v1beta.FindingTypeStats")
}

func init() {
	proto.RegisterFile("google/cloud/websecurityscanner/v1beta/finding_type_stats.proto", fileDescriptor_2cd330f4bd03c930)
}

var fileDescriptor_2cd330f4bd03c930 = []byte{
	// 259 bytes of a gzipped FileDescriptorProto
	0x1f, 0x8b, 0x08, 0x00, 0x00, 0x00, 0x00, 0x00, 0x02, 0xff, 0x8c, 0x90, 0xc1, 0x4a, 0x33, 0x31,
	0x14, 0x85, 0x49, 0xe1, 0xff, 0xc1, 0xa8, 0x20, 0x03, 0x42, 0x11, 0x17, 0x55, 0xa1, 0x14, 0x17,
	0x09, 0xe2, 0xd2, 0x85, 0xd0, 0x82, 0x6e, 0x4b, 0x47, 0x54, 0xca, 0x40, 0xc9, 0xa4, 0x69, 0x08,
	0x8c, 0xf7, 0x86, 0xc9, 0x1d, 0x65, 0xde, 0x50, 0x7c, 0x2a, 0x99, 0x64, 0x8a, 0x62, 0x17, 0xba,
	0xcd, 0x3d, 0xe7, 0x3b, 0x1f, 0xe1, 0xb7, 0x16, 0xd1, 0x56, 0x46, 0xea, 0x0a, 0x9b, 0xb5, 0x7c,
	0x33, 0x65, 0x30, 0xba, 0xa9, 0x1d, 0xb5, 0x41, 0x2b, 0x00, 0x53, 0xcb, 0xd7, 0xab, 0xd2, 0x90,
	0x92, 0x1b, 0x07, 0x6b, 0x07, 0x76, 0x45, 0xad, 0x37, 0xab, 0x40, 0x8a, 0x82, 0xf0, 0x35, 0x12,
	0x66, 0xe3, 0x04, 0x10, 0x11, 0x20, 0x76, 0x01, 0x22, 0x01, 0x4e, 0x4e, 0xfb, 0x21, 0xe5, 0x9d,
	0x54, 0x00, 0x48, 0x8a, 0x1c, 0x42, 0x4f, 0x39, 0x5f, 0xf2, 0xa3, 0xbb, 0xb4, 0xf0, 0xd0, 0x7a,
	0x93, 0x77, 0xfc, 0xec, 0x8c, 0x1f, 0x7c, 0x5f, 0x1d, 0xb2, 0x11, 0x9b, 0xec, 0x2d, 0xf6, 0x37,
	0x5f, 0xb9, 0xec, 0x82, 0x1f, 0x6e, 0x23, 0x1a, 0x1b, 0xa0, 0xe1, 0x60, 0xc4, 0x26, 0xff, 0x16,
	0xdb, 0xde, 0xac, 0x7b, 0x9b, 0xbe, 0x33, 0x7e, 0xa9, 0xf1, 0x45, 0xfc, 0x4d, 0x74, 0x7a, 0xfc,
	0x53, 0x64, 0xde, 0x19, 0xce, 0xd9, 0xf2, 0xb9, 0x07, 0x58, 0xac, 0x14, 0x58, 0x81, 0xb5, 0x95,
	0xd6, 0x40, 0xf4, 0x97, 0xe9, 0xa4, 0xbc, 0x0b, 0xbf, 0xfd, 0xe4, 0xcd, 0xee, 0xe5, 0x63, 0x30,
	0xbe, 0x8f, 0xfd, 0x62, 0xd6, 0x75, 0x8b, 0x27, 0x53, 0xe6, 0x7d, 0x22, 0x4f, 0x89, 0xe2, 0x31,
	0x76, 0xcb, 0xff, 0x71, 0xed, 0xfa, 0x33, 0x00, 0x00, 0xff, 0xff, 0xd9, 0x63, 0xc6, 0x2c, 0xb6,
	0x01, 0x00, 0x00,
}
