// Code generated by protoc-gen-go. DO NOT EDIT.
// source: google/ads/googleads/v2/enums/conversion_attribution_event_type.proto

package enums

import (
	fmt "fmt"
	math "math"

	proto "github.com/golang/protobuf/proto"
	_ "google.golang.org/genproto/googleapis/api/annotations"
)

// Reference imports to suppress errors if they are not otherwise used.
var _ = proto.Marshal
var _ = fmt.Errorf
var _ = math.Inf

// This is a compile-time assertion to ensure that this generated file
// is compatible with the proto package it is being compiled against.
// A compilation error at this line likely means your copy of the
// proto package needs to be updated.
const _ = proto.ProtoPackageIsVersion3 // please upgrade the proto package

// The event type of conversions that are attributed to.
type ConversionAttributionEventTypeEnum_ConversionAttributionEventType int32

const (
	// Not specified.
	ConversionAttributionEventTypeEnum_UNSPECIFIED ConversionAttributionEventTypeEnum_ConversionAttributionEventType = 0
	// Represents value unknown in this version.
	ConversionAttributionEventTypeEnum_UNKNOWN ConversionAttributionEventTypeEnum_ConversionAttributionEventType = 1
	// The conversion is attributed to an impression.
	ConversionAttributionEventTypeEnum_IMPRESSION ConversionAttributionEventTypeEnum_ConversionAttributionEventType = 2
	// The conversion is attributed to an interaction.
	ConversionAttributionEventTypeEnum_INTERACTION ConversionAttributionEventTypeEnum_ConversionAttributionEventType = 3
)

var ConversionAttributionEventTypeEnum_ConversionAttributionEventType_name = map[int32]string{
	0: "UNSPECIFIED",
	1: "UNKNOWN",
	2: "IMPRESSION",
	3: "INTERACTION",
}

var ConversionAttributionEventTypeEnum_ConversionAttributionEventType_value = map[string]int32{
	"UNSPECIFIED": 0,
	"UNKNOWN":     1,
	"IMPRESSION":  2,
	"INTERACTION": 3,
}

func (x ConversionAttributionEventTypeEnum_ConversionAttributionEventType) String() string {
	return proto.EnumName(ConversionAttributionEventTypeEnum_ConversionAttributionEventType_name, int32(x))
}

func (ConversionAttributionEventTypeEnum_ConversionAttributionEventType) EnumDescriptor() ([]byte, []int) {
	return fileDescriptor_e6acfd67e05fcab3, []int{0, 0}
}

// Container for enum indicating the event type the conversion is attributed to.
type ConversionAttributionEventTypeEnum struct {
	XXX_NoUnkeyedLiteral struct{} `json:"-"`
	XXX_unrecognized     []byte   `json:"-"`
	XXX_sizecache        int32    `json:"-"`
}

func (m *ConversionAttributionEventTypeEnum) Reset()         { *m = ConversionAttributionEventTypeEnum{} }
func (m *ConversionAttributionEventTypeEnum) String() string { return proto.CompactTextString(m) }
func (*ConversionAttributionEventTypeEnum) ProtoMessage()    {}
func (*ConversionAttributionEventTypeEnum) Descriptor() ([]byte, []int) {
	return fileDescriptor_e6acfd67e05fcab3, []int{0}
}

func (m *ConversionAttributionEventTypeEnum) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_ConversionAttributionEventTypeEnum.Unmarshal(m, b)
}
func (m *ConversionAttributionEventTypeEnum) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_ConversionAttributionEventTypeEnum.Marshal(b, m, deterministic)
}
func (m *ConversionAttributionEventTypeEnum) XXX_Merge(src proto.Message) {
	xxx_messageInfo_ConversionAttributionEventTypeEnum.Merge(m, src)
}
func (m *ConversionAttributionEventTypeEnum) XXX_Size() int {
	return xxx_messageInfo_ConversionAttributionEventTypeEnum.Size(m)
}
func (m *ConversionAttributionEventTypeEnum) XXX_DiscardUnknown() {
	xxx_messageInfo_ConversionAttributionEventTypeEnum.DiscardUnknown(m)
}

var xxx_messageInfo_ConversionAttributionEventTypeEnum proto.InternalMessageInfo

func init() {
	proto.RegisterEnum("google.ads.googleads.v2.enums.ConversionAttributionEventTypeEnum_ConversionAttributionEventType", ConversionAttributionEventTypeEnum_ConversionAttributionEventType_name, ConversionAttributionEventTypeEnum_ConversionAttributionEventType_value)
	proto.RegisterType((*ConversionAttributionEventTypeEnum)(nil), "google.ads.googleads.v2.enums.ConversionAttributionEventTypeEnum")
}

func init() {
	proto.RegisterFile("google/ads/googleads/v2/enums/conversion_attribution_event_type.proto", fileDescriptor_e6acfd67e05fcab3)
}

var fileDescriptor_e6acfd67e05fcab3 = []byte{
	// 325 bytes of a gzipped FileDescriptorProto
	0x1f, 0x8b, 0x08, 0x00, 0x00, 0x00, 0x00, 0x00, 0x02, 0xff, 0x7c, 0x50, 0xdf, 0x4a, 0xfb, 0x30,
	0x18, 0xfd, 0xb5, 0x83, 0x9f, 0x90, 0x81, 0x8e, 0x5e, 0x8a, 0x13, 0x36, 0xef, 0x53, 0xa8, 0x77,
	0xf1, 0x2a, 0x9b, 0x71, 0x14, 0xb1, 0x2b, 0xfb, 0x27, 0x48, 0x61, 0x64, 0x6b, 0x08, 0x85, 0x2d,
	0x29, 0x4d, 0x56, 0xd8, 0x03, 0xf8, 0x22, 0x5e, 0xfa, 0x28, 0x3e, 0x8a, 0x4f, 0xe0, 0xa5, 0x24,
	0x71, 0xf5, 0xca, 0xde, 0x84, 0x43, 0xbe, 0xf3, 0x9d, 0xf3, 0x9d, 0x03, 0x08, 0x97, 0x92, 0xef,
	0x58, 0x48, 0x73, 0x15, 0x3a, 0x68, 0x50, 0x1d, 0x85, 0x4c, 0x1c, 0xf6, 0x2a, 0xdc, 0x4a, 0x51,
	0xb3, 0x4a, 0x15, 0x52, 0xac, 0xa9, 0xd6, 0x55, 0xb1, 0x39, 0x68, 0x83, 0x59, 0xcd, 0x84, 0x5e,
	0xeb, 0x63, 0xc9, 0x60, 0x59, 0x49, 0x2d, 0x83, 0xbe, 0xdb, 0x85, 0x34, 0x57, 0xb0, 0x91, 0x81,
	0x75, 0x04, 0xad, 0xcc, 0xe5, 0xd5, 0xc9, 0xa5, 0x2c, 0x42, 0x2a, 0x84, 0xd4, 0xd4, 0xc8, 0x28,
	0xb7, 0x3c, 0x7c, 0xf5, 0xc0, 0x70, 0xdc, 0x18, 0xe1, 0x5f, 0x1f, 0x62, 0x6c, 0x16, 0xc7, 0x92,
	0x11, 0x71, 0xd8, 0x0f, 0xd7, 0xe0, 0xba, 0x9d, 0x15, 0x5c, 0x80, 0xee, 0x32, 0x99, 0xa7, 0x64,
	0x1c, 0x3f, 0xc4, 0xe4, 0xbe, 0xf7, 0x2f, 0xe8, 0x82, 0xb3, 0x65, 0xf2, 0x98, 0x4c, 0x9f, 0x93,
	0x9e, 0x17, 0x9c, 0x03, 0x10, 0x3f, 0xa5, 0x33, 0x32, 0x9f, 0xc7, 0xd3, 0xa4, 0xe7, 0x1b, 0x76,
	0x9c, 0x2c, 0xc8, 0x0c, 0x8f, 0x17, 0xe6, 0xa3, 0x33, 0xfa, 0xf2, 0xc0, 0x60, 0x2b, 0xf7, 0xb0,
	0x35, 0xcb, 0xe8, 0xa6, 0xfd, 0x88, 0xd4, 0x44, 0x4a, 0xbd, 0x97, 0xd1, 0x8f, 0x0a, 0x97, 0x3b,
	0x2a, 0x38, 0x94, 0x15, 0x0f, 0x39, 0x13, 0x36, 0xf0, 0xa9, 0xe8, 0xb2, 0x50, 0x7f, 0xf4, 0x7e,
	0x67, 0xdf, 0x37, 0xbf, 0x33, 0xc1, 0xf8, 0xdd, 0xef, 0x4f, 0x9c, 0x14, 0xce, 0x15, 0x74, 0xd0,
	0xa0, 0x55, 0x04, 0x4d, 0x2d, 0xea, 0xe3, 0x34, 0xcf, 0x70, 0xae, 0xb2, 0x66, 0x9e, 0xad, 0xa2,
	0xcc, 0xce, 0x3f, 0xfd, 0x81, 0xfb, 0x44, 0x08, 0xe7, 0x0a, 0xa1, 0x86, 0x81, 0xd0, 0x2a, 0x42,
	0xc8, 0x72, 0x36, 0xff, 0xed, 0x61, 0xb7, 0xdf, 0x01, 0x00, 0x00, 0xff, 0xff, 0xb8, 0x95, 0xe4,
	0x8d, 0x0f, 0x02, 0x00, 0x00,
}
