// Code generated by protoc-gen-go. DO NOT EDIT.
// source: google/ads/googleads/v2/common/ad_asset.proto

package common

import (
	fmt "fmt"
	math "math"

	proto "github.com/golang/protobuf/proto"
	wrappers "github.com/golang/protobuf/ptypes/wrappers"
	enums "google.golang.org/genproto/googleapis/ads/googleads/v2/enums"
	_ "google.golang.org/genproto/googleapis/api/annotations"
)

// Reference imports to suppress errors if they are not otherwise used.
var _ = proto.Marshal
var _ = fmt.Errorf
var _ = math.Inf

// This is a compile-time assertion to ensure that this generated file
// is compatible with the proto package it is being compiled against.
// A compilation error at this line likely means your copy of the
// proto package needs to be updated.
const _ = proto.ProtoPackageIsVersion3 // please upgrade the proto package

// A text asset used inside an ad.
type AdTextAsset struct {
	// Asset text.
	Text *wrappers.StringValue `protobuf:"bytes,1,opt,name=text,proto3" json:"text,omitempty"`
	// The pinned field of the asset. This restricts the asset to only serve
	// within this field. Multiple assets can be pinned to the same field. An
	// asset that is unpinned or pinned to a different field will not serve in a
	// field where some other asset has been pinned.
	PinnedField          enums.ServedAssetFieldTypeEnum_ServedAssetFieldType `protobuf:"varint,2,opt,name=pinned_field,json=pinnedField,proto3,enum=google.ads.googleads.v2.enums.ServedAssetFieldTypeEnum_ServedAssetFieldType" json:"pinned_field,omitempty"`
	XXX_NoUnkeyedLiteral struct{}                                            `json:"-"`
	XXX_unrecognized     []byte                                              `json:"-"`
	XXX_sizecache        int32                                               `json:"-"`
}

func (m *AdTextAsset) Reset()         { *m = AdTextAsset{} }
func (m *AdTextAsset) String() string { return proto.CompactTextString(m) }
func (*AdTextAsset) ProtoMessage()    {}
func (*AdTextAsset) Descriptor() ([]byte, []int) {
	return fileDescriptor_378f6eb6045fcad8, []int{0}
}

func (m *AdTextAsset) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_AdTextAsset.Unmarshal(m, b)
}
func (m *AdTextAsset) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_AdTextAsset.Marshal(b, m, deterministic)
}
func (m *AdTextAsset) XXX_Merge(src proto.Message) {
	xxx_messageInfo_AdTextAsset.Merge(m, src)
}
func (m *AdTextAsset) XXX_Size() int {
	return xxx_messageInfo_AdTextAsset.Size(m)
}
func (m *AdTextAsset) XXX_DiscardUnknown() {
	xxx_messageInfo_AdTextAsset.DiscardUnknown(m)
}

var xxx_messageInfo_AdTextAsset proto.InternalMessageInfo

func (m *AdTextAsset) GetText() *wrappers.StringValue {
	if m != nil {
		return m.Text
	}
	return nil
}

func (m *AdTextAsset) GetPinnedField() enums.ServedAssetFieldTypeEnum_ServedAssetFieldType {
	if m != nil {
		return m.PinnedField
	}
	return enums.ServedAssetFieldTypeEnum_UNSPECIFIED
}

// An image asset used inside an ad.
type AdImageAsset struct {
	// The Asset resource name of this image.
	Asset                *wrappers.StringValue `protobuf:"bytes,1,opt,name=asset,proto3" json:"asset,omitempty"`
	XXX_NoUnkeyedLiteral struct{}              `json:"-"`
	XXX_unrecognized     []byte                `json:"-"`
	XXX_sizecache        int32                 `json:"-"`
}

func (m *AdImageAsset) Reset()         { *m = AdImageAsset{} }
func (m *AdImageAsset) String() string { return proto.CompactTextString(m) }
func (*AdImageAsset) ProtoMessage()    {}
func (*AdImageAsset) Descriptor() ([]byte, []int) {
	return fileDescriptor_378f6eb6045fcad8, []int{1}
}

func (m *AdImageAsset) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_AdImageAsset.Unmarshal(m, b)
}
func (m *AdImageAsset) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_AdImageAsset.Marshal(b, m, deterministic)
}
func (m *AdImageAsset) XXX_Merge(src proto.Message) {
	xxx_messageInfo_AdImageAsset.Merge(m, src)
}
func (m *AdImageAsset) XXX_Size() int {
	return xxx_messageInfo_AdImageAsset.Size(m)
}
func (m *AdImageAsset) XXX_DiscardUnknown() {
	xxx_messageInfo_AdImageAsset.DiscardUnknown(m)
}

var xxx_messageInfo_AdImageAsset proto.InternalMessageInfo

func (m *AdImageAsset) GetAsset() *wrappers.StringValue {
	if m != nil {
		return m.Asset
	}
	return nil
}

// A video asset used inside an ad.
type AdVideoAsset struct {
	// The Asset resource name of this video.
	Asset                *wrappers.StringValue `protobuf:"bytes,1,opt,name=asset,proto3" json:"asset,omitempty"`
	XXX_NoUnkeyedLiteral struct{}              `json:"-"`
	XXX_unrecognized     []byte                `json:"-"`
	XXX_sizecache        int32                 `json:"-"`
}

func (m *AdVideoAsset) Reset()         { *m = AdVideoAsset{} }
func (m *AdVideoAsset) String() string { return proto.CompactTextString(m) }
func (*AdVideoAsset) ProtoMessage()    {}
func (*AdVideoAsset) Descriptor() ([]byte, []int) {
	return fileDescriptor_378f6eb6045fcad8, []int{2}
}

func (m *AdVideoAsset) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_AdVideoAsset.Unmarshal(m, b)
}
func (m *AdVideoAsset) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_AdVideoAsset.Marshal(b, m, deterministic)
}
func (m *AdVideoAsset) XXX_Merge(src proto.Message) {
	xxx_messageInfo_AdVideoAsset.Merge(m, src)
}
func (m *AdVideoAsset) XXX_Size() int {
	return xxx_messageInfo_AdVideoAsset.Size(m)
}
func (m *AdVideoAsset) XXX_DiscardUnknown() {
	xxx_messageInfo_AdVideoAsset.DiscardUnknown(m)
}

var xxx_messageInfo_AdVideoAsset proto.InternalMessageInfo

func (m *AdVideoAsset) GetAsset() *wrappers.StringValue {
	if m != nil {
		return m.Asset
	}
	return nil
}

// A media bundle asset used inside an ad.
type AdMediaBundleAsset struct {
	// The Asset resource name of this media bundle.
	Asset                *wrappers.StringValue `protobuf:"bytes,1,opt,name=asset,proto3" json:"asset,omitempty"`
	XXX_NoUnkeyedLiteral struct{}              `json:"-"`
	XXX_unrecognized     []byte                `json:"-"`
	XXX_sizecache        int32                 `json:"-"`
}

func (m *AdMediaBundleAsset) Reset()         { *m = AdMediaBundleAsset{} }
func (m *AdMediaBundleAsset) String() string { return proto.CompactTextString(m) }
func (*AdMediaBundleAsset) ProtoMessage()    {}
func (*AdMediaBundleAsset) Descriptor() ([]byte, []int) {
	return fileDescriptor_378f6eb6045fcad8, []int{3}
}

func (m *AdMediaBundleAsset) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_AdMediaBundleAsset.Unmarshal(m, b)
}
func (m *AdMediaBundleAsset) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_AdMediaBundleAsset.Marshal(b, m, deterministic)
}
func (m *AdMediaBundleAsset) XXX_Merge(src proto.Message) {
	xxx_messageInfo_AdMediaBundleAsset.Merge(m, src)
}
func (m *AdMediaBundleAsset) XXX_Size() int {
	return xxx_messageInfo_AdMediaBundleAsset.Size(m)
}
func (m *AdMediaBundleAsset) XXX_DiscardUnknown() {
	xxx_messageInfo_AdMediaBundleAsset.DiscardUnknown(m)
}

var xxx_messageInfo_AdMediaBundleAsset proto.InternalMessageInfo

func (m *AdMediaBundleAsset) GetAsset() *wrappers.StringValue {
	if m != nil {
		return m.Asset
	}
	return nil
}

func init() {
	proto.RegisterType((*AdTextAsset)(nil), "google.ads.googleads.v2.common.AdTextAsset")
	proto.RegisterType((*AdImageAsset)(nil), "google.ads.googleads.v2.common.AdImageAsset")
	proto.RegisterType((*AdVideoAsset)(nil), "google.ads.googleads.v2.common.AdVideoAsset")
	proto.RegisterType((*AdMediaBundleAsset)(nil), "google.ads.googleads.v2.common.AdMediaBundleAsset")
}

func init() {
	proto.RegisterFile("google/ads/googleads/v2/common/ad_asset.proto", fileDescriptor_378f6eb6045fcad8)
}

var fileDescriptor_378f6eb6045fcad8 = []byte{
	// 400 bytes of a gzipped FileDescriptorProto
	0x1f, 0x8b, 0x08, 0x00, 0x00, 0x00, 0x00, 0x00, 0x02, 0xff, 0x9c, 0x92, 0xcd, 0x6a, 0xdc, 0x30,
	0x10, 0xc7, 0xf1, 0xf6, 0xe3, 0xa0, 0x5d, 0x7a, 0xd8, 0x53, 0x08, 0x21, 0x04, 0x9f, 0x72, 0xa9,
	0x54, 0xd4, 0x9b, 0x72, 0x92, 0xfb, 0x91, 0x16, 0x5a, 0x08, 0x49, 0xf0, 0xa1, 0x18, 0x16, 0x25,
	0x9a, 0x08, 0x81, 0x2d, 0x09, 0x4b, 0xde, 0x26, 0xaf, 0xd3, 0x63, 0x4f, 0x7d, 0x8e, 0xbe, 0x48,
	0xa1, 0x4f, 0x51, 0xac, 0xb1, 0xf7, 0xd4, 0x2d, 0x25, 0xa7, 0x9d, 0x95, 0x7e, 0xfe, 0xcd, 0x7f,
	0xc4, 0x90, 0x97, 0xc6, 0x7b, 0xd3, 0x02, 0x53, 0x3a, 0x32, 0x2c, 0xc7, 0x6a, 0xcb, 0xd9, 0xad,
	0xef, 0x3a, 0xef, 0x98, 0xd2, 0x1b, 0x15, 0x23, 0x24, 0x1a, 0x7a, 0x9f, 0xfc, 0xfa, 0x18, 0x19,
	0xaa, 0x74, 0xa4, 0x3b, 0x9c, 0x6e, 0x39, 0x45, 0xfc, 0xf0, 0x6c, 0x9f, 0x0e, 0xdc, 0xd0, 0x45,
	0x16, 0xa1, 0xdf, 0xc2, 0x64, 0xdc, 0xdc, 0x59, 0x68, 0xf5, 0x26, 0x3d, 0x04, 0x40, 0xf9, 0xe1,
	0x24, 0x67, 0xf9, 0xdf, 0xcd, 0x70, 0xc7, 0xbe, 0xf6, 0x2a, 0x04, 0xe8, 0xe3, 0x74, 0x7f, 0x34,
	0xcb, 0x83, 0x65, 0xca, 0x39, 0x9f, 0x54, 0xb2, 0xde, 0x4d, 0xb7, 0xe5, 0x8f, 0x82, 0x2c, 0xa5,
	0xbe, 0x86, 0xfb, 0x24, 0x47, 0xfd, 0xfa, 0x15, 0x79, 0x9a, 0xe0, 0x3e, 0x1d, 0x14, 0x27, 0xc5,
	0xe9, 0x92, 0x1f, 0x4d, 0x71, 0xe9, 0x2c, 0xa7, 0x57, 0xa9, 0xb7, 0xce, 0xd4, 0xaa, 0x1d, 0xe0,
	0x32, 0x93, 0x6b, 0x4f, 0x56, 0xc1, 0x3a, 0x07, 0x1a, 0xa3, 0x1d, 0x2c, 0x4e, 0x8a, 0xd3, 0x17,
	0xfc, 0x13, 0xdd, 0x37, 0x73, 0x9e, 0x89, 0x5e, 0xe5, 0x99, 0x72, 0xcf, 0xf7, 0xe3, 0x67, 0xd7,
	0x0f, 0x01, 0xde, 0xb9, 0xa1, 0xfb, 0xeb, 0xc5, 0xe5, 0x12, 0x3b, 0xe4, 0x83, 0xb2, 0x22, 0x2b,
	0xa9, 0x3f, 0x76, 0xca, 0x00, 0x46, 0xe6, 0xe4, 0x59, 0x7e, 0x9a, 0xff, 0xca, 0x8c, 0x28, 0x3a,
	0x6a, 0xab, 0xc1, 0x3f, 0xde, 0xf1, 0x81, 0xac, 0xa5, 0xfe, 0x0c, 0xda, 0xaa, 0x6a, 0x70, 0xba,
	0x7d, 0x7c, 0x9a, 0xea, 0x57, 0x41, 0xca, 0x5b, 0xdf, 0xd1, 0x7f, 0xaf, 0x49, 0xb5, 0x92, 0xf8,
	0x2e, 0x17, 0xa3, 0xea, 0xa2, 0xf8, 0xf2, 0x76, 0xe2, 0x8d, 0x6f, 0x95, 0x33, 0xd4, 0xf7, 0x86,
	0x19, 0x70, 0xb9, 0xd1, 0xbc, 0x46, 0xc1, 0xc6, 0x7d, 0x4b, 0x7a, 0x86, 0x3f, 0xdf, 0x16, 0x4f,
	0xce, 0xa5, 0xfc, 0xbe, 0x38, 0x3e, 0x47, 0x99, 0xd4, 0x91, 0x62, 0x39, 0x56, 0x35, 0xa7, 0x6f,
	0x32, 0xf6, 0x73, 0x06, 0x1a, 0xa9, 0x63, 0xb3, 0x03, 0x9a, 0x9a, 0x37, 0x08, 0xfc, 0x5e, 0x94,
	0x78, 0x2a, 0x84, 0xd4, 0x51, 0x88, 0x1d, 0x22, 0x44, 0xcd, 0x85, 0x40, 0xe8, 0xe6, 0x79, 0x4e,
	0xf7, 0xfa, 0x4f, 0x00, 0x00, 0x00, 0xff, 0xff, 0x45, 0x44, 0xf9, 0x0b, 0x41, 0x03, 0x00, 0x00,
}
