// Code generated by protoc-gen-go. DO NOT EDIT.
// source: google/cloud/datalabeling/v1beta1/data_payloads.proto

package datalabeling

import (
	fmt "fmt"
	math "math"

	proto "github.com/golang/protobuf/proto"
	duration "github.com/golang/protobuf/ptypes/duration"
	_ "github.com/golang/protobuf/ptypes/timestamp"
	_ "google.golang.org/genproto/googleapis/api/annotations"
)

// Reference imports to suppress errors if they are not otherwise used.
var _ = proto.Marshal
var _ = fmt.Errorf
var _ = math.Inf

// This is a compile-time assertion to ensure that this generated file
// is compatible with the proto package it is being compiled against.
// A compilation error at this line likely means your copy of the
// proto package needs to be updated.
const _ = proto.ProtoPackageIsVersion3 // please upgrade the proto package

// Container of information about an image.
type ImagePayload struct {
	// Image format.
	MimeType string `protobuf:"bytes,1,opt,name=mime_type,json=mimeType,proto3" json:"mime_type,omitempty"`
	// A byte string of a thumbnail image.
	ImageThumbnail []byte `protobuf:"bytes,2,opt,name=image_thumbnail,json=imageThumbnail,proto3" json:"image_thumbnail,omitempty"`
	// Image uri from the user bucket.
	ImageUri string `protobuf:"bytes,3,opt,name=image_uri,json=imageUri,proto3" json:"image_uri,omitempty"`
	// Signed uri of the image file in the service bucket.
	SignedUri            string   `protobuf:"bytes,4,opt,name=signed_uri,json=signedUri,proto3" json:"signed_uri,omitempty"`
	XXX_NoUnkeyedLiteral struct{} `json:"-"`
	XXX_unrecognized     []byte   `json:"-"`
	XXX_sizecache        int32    `json:"-"`
}

func (m *ImagePayload) Reset()         { *m = ImagePayload{} }
func (m *ImagePayload) String() string { return proto.CompactTextString(m) }
func (*ImagePayload) ProtoMessage()    {}
func (*ImagePayload) Descriptor() ([]byte, []int) {
	return fileDescriptor_7d5088066040abfe, []int{0}
}

func (m *ImagePayload) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_ImagePayload.Unmarshal(m, b)
}
func (m *ImagePayload) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_ImagePayload.Marshal(b, m, deterministic)
}
func (m *ImagePayload) XXX_Merge(src proto.Message) {
	xxx_messageInfo_ImagePayload.Merge(m, src)
}
func (m *ImagePayload) XXX_Size() int {
	return xxx_messageInfo_ImagePayload.Size(m)
}
func (m *ImagePayload) XXX_DiscardUnknown() {
	xxx_messageInfo_ImagePayload.DiscardUnknown(m)
}

var xxx_messageInfo_ImagePayload proto.InternalMessageInfo

func (m *ImagePayload) GetMimeType() string {
	if m != nil {
		return m.MimeType
	}
	return ""
}

func (m *ImagePayload) GetImageThumbnail() []byte {
	if m != nil {
		return m.ImageThumbnail
	}
	return nil
}

func (m *ImagePayload) GetImageUri() string {
	if m != nil {
		return m.ImageUri
	}
	return ""
}

func (m *ImagePayload) GetSignedUri() string {
	if m != nil {
		return m.SignedUri
	}
	return ""
}

// Container of information about a piece of text.
type TextPayload struct {
	// Text content.
	TextContent          string   `protobuf:"bytes,1,opt,name=text_content,json=textContent,proto3" json:"text_content,omitempty"`
	XXX_NoUnkeyedLiteral struct{} `json:"-"`
	XXX_unrecognized     []byte   `json:"-"`
	XXX_sizecache        int32    `json:"-"`
}

func (m *TextPayload) Reset()         { *m = TextPayload{} }
func (m *TextPayload) String() string { return proto.CompactTextString(m) }
func (*TextPayload) ProtoMessage()    {}
func (*TextPayload) Descriptor() ([]byte, []int) {
	return fileDescriptor_7d5088066040abfe, []int{1}
}

func (m *TextPayload) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_TextPayload.Unmarshal(m, b)
}
func (m *TextPayload) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_TextPayload.Marshal(b, m, deterministic)
}
func (m *TextPayload) XXX_Merge(src proto.Message) {
	xxx_messageInfo_TextPayload.Merge(m, src)
}
func (m *TextPayload) XXX_Size() int {
	return xxx_messageInfo_TextPayload.Size(m)
}
func (m *TextPayload) XXX_DiscardUnknown() {
	xxx_messageInfo_TextPayload.DiscardUnknown(m)
}

var xxx_messageInfo_TextPayload proto.InternalMessageInfo

func (m *TextPayload) GetTextContent() string {
	if m != nil {
		return m.TextContent
	}
	return ""
}

// Container of information of a video thumbnail.
type VideoThumbnail struct {
	// A byte string of the video frame.
	Thumbnail []byte `protobuf:"bytes,1,opt,name=thumbnail,proto3" json:"thumbnail,omitempty"`
	// Time offset relative to the beginning of the video, corresponding to the
	// video frame where the thumbnail has been extracted from.
	TimeOffset           *duration.Duration `protobuf:"bytes,2,opt,name=time_offset,json=timeOffset,proto3" json:"time_offset,omitempty"`
	XXX_NoUnkeyedLiteral struct{}           `json:"-"`
	XXX_unrecognized     []byte             `json:"-"`
	XXX_sizecache        int32              `json:"-"`
}

func (m *VideoThumbnail) Reset()         { *m = VideoThumbnail{} }
func (m *VideoThumbnail) String() string { return proto.CompactTextString(m) }
func (*VideoThumbnail) ProtoMessage()    {}
func (*VideoThumbnail) Descriptor() ([]byte, []int) {
	return fileDescriptor_7d5088066040abfe, []int{2}
}

func (m *VideoThumbnail) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_VideoThumbnail.Unmarshal(m, b)
}
func (m *VideoThumbnail) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_VideoThumbnail.Marshal(b, m, deterministic)
}
func (m *VideoThumbnail) XXX_Merge(src proto.Message) {
	xxx_messageInfo_VideoThumbnail.Merge(m, src)
}
func (m *VideoThumbnail) XXX_Size() int {
	return xxx_messageInfo_VideoThumbnail.Size(m)
}
func (m *VideoThumbnail) XXX_DiscardUnknown() {
	xxx_messageInfo_VideoThumbnail.DiscardUnknown(m)
}

var xxx_messageInfo_VideoThumbnail proto.InternalMessageInfo

func (m *VideoThumbnail) GetThumbnail() []byte {
	if m != nil {
		return m.Thumbnail
	}
	return nil
}

func (m *VideoThumbnail) GetTimeOffset() *duration.Duration {
	if m != nil {
		return m.TimeOffset
	}
	return nil
}

// Container of information of a video.
type VideoPayload struct {
	// Video format.
	MimeType string `protobuf:"bytes,1,opt,name=mime_type,json=mimeType,proto3" json:"mime_type,omitempty"`
	// Video uri from the user bucket.
	VideoUri string `protobuf:"bytes,2,opt,name=video_uri,json=videoUri,proto3" json:"video_uri,omitempty"`
	// The list of video thumbnails.
	VideoThumbnails []*VideoThumbnail `protobuf:"bytes,3,rep,name=video_thumbnails,json=videoThumbnails,proto3" json:"video_thumbnails,omitempty"`
	// FPS of the video.
	FrameRate float32 `protobuf:"fixed32,4,opt,name=frame_rate,json=frameRate,proto3" json:"frame_rate,omitempty"`
	// Signed uri of the video file in the service bucket.
	SignedUri            string   `protobuf:"bytes,5,opt,name=signed_uri,json=signedUri,proto3" json:"signed_uri,omitempty"`
	XXX_NoUnkeyedLiteral struct{} `json:"-"`
	XXX_unrecognized     []byte   `json:"-"`
	XXX_sizecache        int32    `json:"-"`
}

func (m *VideoPayload) Reset()         { *m = VideoPayload{} }
func (m *VideoPayload) String() string { return proto.CompactTextString(m) }
func (*VideoPayload) ProtoMessage()    {}
func (*VideoPayload) Descriptor() ([]byte, []int) {
	return fileDescriptor_7d5088066040abfe, []int{3}
}

func (m *VideoPayload) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_VideoPayload.Unmarshal(m, b)
}
func (m *VideoPayload) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_VideoPayload.Marshal(b, m, deterministic)
}
func (m *VideoPayload) XXX_Merge(src proto.Message) {
	xxx_messageInfo_VideoPayload.Merge(m, src)
}
func (m *VideoPayload) XXX_Size() int {
	return xxx_messageInfo_VideoPayload.Size(m)
}
func (m *VideoPayload) XXX_DiscardUnknown() {
	xxx_messageInfo_VideoPayload.DiscardUnknown(m)
}

var xxx_messageInfo_VideoPayload proto.InternalMessageInfo

func (m *VideoPayload) GetMimeType() string {
	if m != nil {
		return m.MimeType
	}
	return ""
}

func (m *VideoPayload) GetVideoUri() string {
	if m != nil {
		return m.VideoUri
	}
	return ""
}

func (m *VideoPayload) GetVideoThumbnails() []*VideoThumbnail {
	if m != nil {
		return m.VideoThumbnails
	}
	return nil
}

func (m *VideoPayload) GetFrameRate() float32 {
	if m != nil {
		return m.FrameRate
	}
	return 0
}

func (m *VideoPayload) GetSignedUri() string {
	if m != nil {
		return m.SignedUri
	}
	return ""
}

func init() {
	proto.RegisterType((*ImagePayload)(nil), "google.cloud.datalabeling.v1beta1.ImagePayload")
	proto.RegisterType((*TextPayload)(nil), "google.cloud.datalabeling.v1beta1.TextPayload")
	proto.RegisterType((*VideoThumbnail)(nil), "google.cloud.datalabeling.v1beta1.VideoThumbnail")
	proto.RegisterType((*VideoPayload)(nil), "google.cloud.datalabeling.v1beta1.VideoPayload")
}

func init() {
	proto.RegisterFile("google/cloud/datalabeling/v1beta1/data_payloads.proto", fileDescriptor_7d5088066040abfe)
}

var fileDescriptor_7d5088066040abfe = []byte{
	// 434 bytes of a gzipped FileDescriptorProto
	0x1f, 0x8b, 0x08, 0x00, 0x00, 0x00, 0x00, 0x00, 0x02, 0xff, 0x8c, 0x93, 0x41, 0x6f, 0xd3, 0x40,
	0x10, 0x85, 0xe5, 0x04, 0x10, 0x5e, 0x47, 0x2d, 0xf2, 0x29, 0xb4, 0x05, 0xd2, 0x48, 0x88, 0x9c,
	0x6c, 0x52, 0xc4, 0x05, 0x6e, 0xc0, 0x85, 0x03, 0xa2, 0xb2, 0x52, 0x0e, 0x08, 0xc9, 0x1a, 0xc7,
	0x93, 0x65, 0x91, 0xbd, 0x6b, 0xd9, 0xe3, 0x28, 0xf9, 0x17, 0xfc, 0x48, 0x7e, 0x08, 0xda, 0xd9,
	0x0d, 0x69, 0x73, 0x20, 0x3d, 0xfa, 0x7b, 0x6f, 0x66, 0xdf, 0xbe, 0x4d, 0xc4, 0x5b, 0x69, 0x8c,
	0xac, 0x30, 0x5d, 0x56, 0xa6, 0x2f, 0xd3, 0x12, 0x08, 0x2a, 0x28, 0xb0, 0x52, 0x5a, 0xa6, 0xeb,
	0x79, 0x81, 0x04, 0x73, 0x86, 0x79, 0x03, 0xdb, 0xca, 0x40, 0xd9, 0x25, 0x4d, 0x6b, 0xc8, 0xc4,
	0x97, 0x6e, 0x2c, 0xe1, 0xb1, 0xe4, 0xf6, 0x58, 0xe2, 0xc7, 0xce, 0x2e, 0xfc, 0x66, 0x68, 0x54,
	0x0a, 0x5a, 0x1b, 0x02, 0x52, 0x46, 0xfb, 0x05, 0x67, 0xcf, 0xbd, 0xca, 0x5f, 0x45, 0xbf, 0x4a,
	0xcb, 0xbe, 0x65, 0x83, 0xd7, 0x5f, 0x1c, 0xea, 0xa4, 0x6a, 0xec, 0x08, 0xea, 0xc6, 0x19, 0xa6,
	0xbf, 0x03, 0x31, 0xfa, 0x5c, 0x83, 0xc4, 0x6b, 0x97, 0x2c, 0x3e, 0x17, 0x61, 0xad, 0x6a, 0xcc,
	0x69, 0xdb, 0xe0, 0x38, 0x98, 0x04, 0xb3, 0x30, 0x7b, 0x6c, 0xc1, 0x62, 0xdb, 0x60, 0xfc, 0x4a,
	0x9c, 0x2a, 0x6b, 0xce, 0xe9, 0x67, 0x5f, 0x17, 0x1a, 0x54, 0x35, 0x1e, 0x4c, 0x82, 0xd9, 0x28,
	0x3b, 0x61, 0xbc, 0xd8, 0x51, 0xbb, 0xc5, 0x19, 0xfb, 0x56, 0x8d, 0x87, 0x6e, 0x0b, 0x83, 0x9b,
	0x56, 0xc5, 0xcf, 0x84, 0xe8, 0x94, 0xd4, 0x58, 0xb2, 0xfa, 0x80, 0xd5, 0xd0, 0x91, 0x9b, 0x56,
	0x4d, 0x5f, 0x8b, 0x68, 0x81, 0x1b, 0xda, 0x05, 0xba, 0x14, 0x23, 0xc2, 0x0d, 0xe5, 0x4b, 0xa3,
	0x09, 0x35, 0xf9, 0x4c, 0x91, 0x65, 0x1f, 0x1d, 0x9a, 0xfe, 0x12, 0x27, 0xdf, 0x54, 0x89, 0x66,
	0x7f, 0xfe, 0x85, 0x08, 0xf7, 0x11, 0x03, 0x8e, 0xb8, 0x07, 0xf1, 0x3b, 0x11, 0xd9, 0x1e, 0x72,
	0xb3, 0x5a, 0x75, 0x48, 0x7c, 0x85, 0xe8, 0xea, 0x69, 0xe2, 0x1f, 0x63, 0xd7, 0x55, 0xf2, 0xc9,
	0x77, 0x99, 0x09, 0xeb, 0xfe, 0xca, 0xe6, 0xe9, 0x9f, 0x40, 0x8c, 0xf8, 0xb0, 0x7b, 0x15, 0x76,
	0x2e, 0xc2, 0xb5, 0x35, 0xf3, 0x4d, 0x07, 0x4e, 0x64, 0x60, 0x7b, 0xf8, 0x21, 0x9e, 0x38, 0xf1,
	0x5f, 0xb2, 0x6e, 0x3c, 0x9c, 0x0c, 0x67, 0xd1, 0xd5, 0x3c, 0x39, 0xfa, 0xc3, 0x48, 0xee, 0xde,
	0x38, 0x3b, 0x5d, 0xdf, 0xf9, 0xee, 0x6c, 0xcb, 0xab, 0x16, 0x6a, 0xcc, 0x5b, 0x20, 0xe4, 0x96,
	0x07, 0x59, 0xc8, 0x24, 0x03, 0xc2, 0x83, 0x47, 0x78, 0x78, 0xf0, 0x08, 0x1f, 0x36, 0xe2, 0xe5,
	0xd2, 0xd4, 0xc7, 0x63, 0x5c, 0x07, 0xdf, 0xbf, 0x78, 0x93, 0x34, 0x15, 0x68, 0x99, 0x98, 0x56,
	0xa6, 0x12, 0x35, 0xb7, 0x98, 0x3a, 0x09, 0x1a, 0xd5, 0xfd, 0xe7, 0xaf, 0xf1, 0xfe, 0x36, 0x2c,
	0x1e, 0xf1, 0xe4, 0x9b, 0xbf, 0x01, 0x00, 0x00, 0xff, 0xff, 0xb3, 0xb8, 0x19, 0x5a, 0x53, 0x03,
	0x00, 0x00,
}
