// Code generated by protoc-gen-go. DO NOT EDIT.
// source: google/ads/googleads/v2/resources/customer_negative_criterion.proto

package resources

import (
	fmt "fmt"
	math "math"

	proto "github.com/golang/protobuf/proto"
	wrappers "github.com/golang/protobuf/ptypes/wrappers"
	common "google.golang.org/genproto/googleapis/ads/googleads/v2/common"
	enums "google.golang.org/genproto/googleapis/ads/googleads/v2/enums"
	_ "google.golang.org/genproto/googleapis/api/annotations"
)

// Reference imports to suppress errors if they are not otherwise used.
var _ = proto.Marshal
var _ = fmt.Errorf
var _ = math.Inf

// This is a compile-time assertion to ensure that this generated file
// is compatible with the proto package it is being compiled against.
// A compilation error at this line likely means your copy of the
// proto package needs to be updated.
const _ = proto.ProtoPackageIsVersion3 // please upgrade the proto package

// A negative criterion for exclusions at the customer level.
type CustomerNegativeCriterion struct {
	// The resource name of the customer negative criterion.
	// Customer negative criterion resource names have the form:
	//
	// `customers/{customer_id}/customerNegativeCriteria/{criterion_id}`
	ResourceName string `protobuf:"bytes,1,opt,name=resource_name,json=resourceName,proto3" json:"resource_name,omitempty"`
	// The ID of the criterion.
	Id *wrappers.Int64Value `protobuf:"bytes,2,opt,name=id,proto3" json:"id,omitempty"`
	// The type of the criterion.
	Type enums.CriterionTypeEnum_CriterionType `protobuf:"varint,3,opt,name=type,proto3,enum=google.ads.googleads.v2.enums.CriterionTypeEnum_CriterionType" json:"type,omitempty"`
	// The customer negative criterion.
	//
	// Exactly one must be set.
	//
	// Types that are valid to be assigned to Criterion:
	//	*CustomerNegativeCriterion_ContentLabel
	//	*CustomerNegativeCriterion_MobileApplication
	//	*CustomerNegativeCriterion_MobileAppCategory
	//	*CustomerNegativeCriterion_Placement
	//	*CustomerNegativeCriterion_YoutubeVideo
	//	*CustomerNegativeCriterion_YoutubeChannel
	Criterion            isCustomerNegativeCriterion_Criterion `protobuf_oneof:"criterion"`
	XXX_NoUnkeyedLiteral struct{}                              `json:"-"`
	XXX_unrecognized     []byte                                `json:"-"`
	XXX_sizecache        int32                                 `json:"-"`
}

func (m *CustomerNegativeCriterion) Reset()         { *m = CustomerNegativeCriterion{} }
func (m *CustomerNegativeCriterion) String() string { return proto.CompactTextString(m) }
func (*CustomerNegativeCriterion) ProtoMessage()    {}
func (*CustomerNegativeCriterion) Descriptor() ([]byte, []int) {
	return fileDescriptor_831be6b79abdffa4, []int{0}
}

func (m *CustomerNegativeCriterion) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_CustomerNegativeCriterion.Unmarshal(m, b)
}
func (m *CustomerNegativeCriterion) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_CustomerNegativeCriterion.Marshal(b, m, deterministic)
}
func (m *CustomerNegativeCriterion) XXX_Merge(src proto.Message) {
	xxx_messageInfo_CustomerNegativeCriterion.Merge(m, src)
}
func (m *CustomerNegativeCriterion) XXX_Size() int {
	return xxx_messageInfo_CustomerNegativeCriterion.Size(m)
}
func (m *CustomerNegativeCriterion) XXX_DiscardUnknown() {
	xxx_messageInfo_CustomerNegativeCriterion.DiscardUnknown(m)
}

var xxx_messageInfo_CustomerNegativeCriterion proto.InternalMessageInfo

func (m *CustomerNegativeCriterion) GetResourceName() string {
	if m != nil {
		return m.ResourceName
	}
	return ""
}

func (m *CustomerNegativeCriterion) GetId() *wrappers.Int64Value {
	if m != nil {
		return m.Id
	}
	return nil
}

func (m *CustomerNegativeCriterion) GetType() enums.CriterionTypeEnum_CriterionType {
	if m != nil {
		return m.Type
	}
	return enums.CriterionTypeEnum_UNSPECIFIED
}

type isCustomerNegativeCriterion_Criterion interface {
	isCustomerNegativeCriterion_Criterion()
}

type CustomerNegativeCriterion_ContentLabel struct {
	ContentLabel *common.ContentLabelInfo `protobuf:"bytes,4,opt,name=content_label,json=contentLabel,proto3,oneof"`
}

type CustomerNegativeCriterion_MobileApplication struct {
	MobileApplication *common.MobileApplicationInfo `protobuf:"bytes,5,opt,name=mobile_application,json=mobileApplication,proto3,oneof"`
}

type CustomerNegativeCriterion_MobileAppCategory struct {
	MobileAppCategory *common.MobileAppCategoryInfo `protobuf:"bytes,6,opt,name=mobile_app_category,json=mobileAppCategory,proto3,oneof"`
}

type CustomerNegativeCriterion_Placement struct {
	Placement *common.PlacementInfo `protobuf:"bytes,7,opt,name=placement,proto3,oneof"`
}

type CustomerNegativeCriterion_YoutubeVideo struct {
	YoutubeVideo *common.YouTubeVideoInfo `protobuf:"bytes,8,opt,name=youtube_video,json=youtubeVideo,proto3,oneof"`
}

type CustomerNegativeCriterion_YoutubeChannel struct {
	YoutubeChannel *common.YouTubeChannelInfo `protobuf:"bytes,9,opt,name=youtube_channel,json=youtubeChannel,proto3,oneof"`
}

func (*CustomerNegativeCriterion_ContentLabel) isCustomerNegativeCriterion_Criterion() {}

func (*CustomerNegativeCriterion_MobileApplication) isCustomerNegativeCriterion_Criterion() {}

func (*CustomerNegativeCriterion_MobileAppCategory) isCustomerNegativeCriterion_Criterion() {}

func (*CustomerNegativeCriterion_Placement) isCustomerNegativeCriterion_Criterion() {}

func (*CustomerNegativeCriterion_YoutubeVideo) isCustomerNegativeCriterion_Criterion() {}

func (*CustomerNegativeCriterion_YoutubeChannel) isCustomerNegativeCriterion_Criterion() {}

func (m *CustomerNegativeCriterion) GetCriterion() isCustomerNegativeCriterion_Criterion {
	if m != nil {
		return m.Criterion
	}
	return nil
}

func (m *CustomerNegativeCriterion) GetContentLabel() *common.ContentLabelInfo {
	if x, ok := m.GetCriterion().(*CustomerNegativeCriterion_ContentLabel); ok {
		return x.ContentLabel
	}
	return nil
}

func (m *CustomerNegativeCriterion) GetMobileApplication() *common.MobileApplicationInfo {
	if x, ok := m.GetCriterion().(*CustomerNegativeCriterion_MobileApplication); ok {
		return x.MobileApplication
	}
	return nil
}

func (m *CustomerNegativeCriterion) GetMobileAppCategory() *common.MobileAppCategoryInfo {
	if x, ok := m.GetCriterion().(*CustomerNegativeCriterion_MobileAppCategory); ok {
		return x.MobileAppCategory
	}
	return nil
}

func (m *CustomerNegativeCriterion) GetPlacement() *common.PlacementInfo {
	if x, ok := m.GetCriterion().(*CustomerNegativeCriterion_Placement); ok {
		return x.Placement
	}
	return nil
}

func (m *CustomerNegativeCriterion) GetYoutubeVideo() *common.YouTubeVideoInfo {
	if x, ok := m.GetCriterion().(*CustomerNegativeCriterion_YoutubeVideo); ok {
		return x.YoutubeVideo
	}
	return nil
}

func (m *CustomerNegativeCriterion) GetYoutubeChannel() *common.YouTubeChannelInfo {
	if x, ok := m.GetCriterion().(*CustomerNegativeCriterion_YoutubeChannel); ok {
		return x.YoutubeChannel
	}
	return nil
}

// XXX_OneofWrappers is for the internal use of the proto package.
func (*CustomerNegativeCriterion) XXX_OneofWrappers() []interface{} {
	return []interface{}{
		(*CustomerNegativeCriterion_ContentLabel)(nil),
		(*CustomerNegativeCriterion_MobileApplication)(nil),
		(*CustomerNegativeCriterion_MobileAppCategory)(nil),
		(*CustomerNegativeCriterion_Placement)(nil),
		(*CustomerNegativeCriterion_YoutubeVideo)(nil),
		(*CustomerNegativeCriterion_YoutubeChannel)(nil),
	}
}

func init() {
	proto.RegisterType((*CustomerNegativeCriterion)(nil), "google.ads.googleads.v2.resources.CustomerNegativeCriterion")
}

func init() {
	proto.RegisterFile("google/ads/googleads/v2/resources/customer_negative_criterion.proto", fileDescriptor_831be6b79abdffa4)
}

var fileDescriptor_831be6b79abdffa4 = []byte{
	// 573 bytes of a gzipped FileDescriptorProto
	0x1f, 0x8b, 0x08, 0x00, 0x00, 0x00, 0x00, 0x00, 0x02, 0xff, 0x94, 0x94, 0xdd, 0x8a, 0xd3, 0x40,
	0x14, 0xc7, 0x6d, 0xf6, 0x43, 0x3b, 0xfb, 0x21, 0xc6, 0x9b, 0xb8, 0xca, 0xd2, 0x55, 0x16, 0x0a,
	0xb2, 0x13, 0x89, 0x1f, 0x17, 0x11, 0x84, 0x34, 0xc8, 0xba, 0xe2, 0x2e, 0x25, 0x2c, 0x15, 0xa5,
	0x12, 0x26, 0xc9, 0x69, 0x0c, 0x24, 0x33, 0x21, 0x33, 0xa9, 0xf4, 0x19, 0x7c, 0x0b, 0x2f, 0x7d,
	0x14, 0x1f, 0xc5, 0x97, 0x50, 0x32, 0x99, 0x49, 0xfd, 0xa0, 0x76, 0xbd, 0x3b, 0x3d, 0xe7, 0xfc,
	0x7f, 0xe7, 0xcc, 0x9f, 0x9e, 0x20, 0x3f, 0x65, 0x2c, 0xcd, 0xc1, 0x26, 0x09, 0xb7, 0xdb, 0xb0,
	0x89, 0xe6, 0x8e, 0x5d, 0x01, 0x67, 0x75, 0x15, 0x03, 0xb7, 0xe3, 0x9a, 0x0b, 0x56, 0x40, 0x15,
	0x52, 0x48, 0x89, 0xc8, 0xe6, 0x10, 0xc6, 0x55, 0x26, 0xa0, 0xca, 0x18, 0xc5, 0x65, 0xc5, 0x04,
	0x33, 0x8f, 0x5a, 0x25, 0x26, 0x09, 0xc7, 0x1d, 0x04, 0xcf, 0x1d, 0xdc, 0x41, 0x0e, 0x4e, 0x56,
	0xcd, 0x89, 0x59, 0x51, 0x30, 0x6a, 0x2b, 0x24, 0x69, 0x89, 0x07, 0xce, 0xaa, 0x76, 0xa0, 0x75,
	0xc1, 0xed, 0x6e, 0x81, 0x50, 0x2c, 0x4a, 0x50, 0x9a, 0x43, 0xa5, 0x91, 0xbf, 0xa2, 0x7a, 0x66,
	0x7f, 0xaa, 0x48, 0x59, 0x42, 0xc5, 0x55, 0xfd, 0x9e, 0x66, 0x96, 0x99, 0x4d, 0x28, 0x65, 0x82,
	0x88, 0x8c, 0x51, 0x55, 0xbd, 0xff, 0x63, 0x0b, 0xdd, 0xf1, 0xd5, 0x4b, 0x2f, 0xd4, 0x43, 0x7d,
	0x3d, 0xc6, 0x7c, 0x80, 0xf6, 0xf4, 0x5b, 0x42, 0x4a, 0x0a, 0xb0, 0x7a, 0x83, 0xde, 0xb0, 0x1f,
	0xec, 0xea, 0xe4, 0x05, 0x29, 0xc0, 0x7c, 0x88, 0x8c, 0x2c, 0xb1, 0x8c, 0x41, 0x6f, 0xb8, 0xe3,
	0xdc, 0x55, 0x46, 0x60, 0xbd, 0x0d, 0x3e, 0xa3, 0xe2, 0xd9, 0x93, 0x09, 0xc9, 0x6b, 0x08, 0x8c,
	0x2c, 0x31, 0x03, 0xb4, 0xd9, 0xec, 0x6e, 0x6d, 0x0c, 0x7a, 0xc3, 0x7d, 0xe7, 0x05, 0x5e, 0x65,
	0xa1, 0x7c, 0x30, 0xee, 0x36, 0xb9, 0x5c, 0x94, 0xf0, 0x92, 0xd6, 0xc5, 0xef, 0x99, 0x40, 0xb2,
	0xcc, 0xb7, 0x68, 0x2f, 0x66, 0x54, 0x00, 0x15, 0x61, 0x4e, 0x22, 0xc8, 0xad, 0x4d, 0xb9, 0xcb,
	0xa3, 0x95, 0xf0, 0xd6, 0x7c, 0xec, 0xb7, 0xa2, 0x37, 0x8d, 0xe6, 0x8c, 0xce, 0xd8, 0xab, 0x6b,
	0xc1, 0x6e, 0xfc, 0x4b, 0xce, 0x9c, 0x21, 0xb3, 0x60, 0x51, 0x96, 0x43, 0x48, 0xca, 0x32, 0xcf,
	0x62, 0xe9, 0x9c, 0xb5, 0x25, 0xe9, 0x4f, 0xd7, 0xd1, 0xcf, 0xa5, 0xd2, 0x5b, 0x0a, 0xd5, 0x88,
	0x5b, 0xc5, 0x9f, 0x05, 0x33, 0x45, 0xb7, 0x97, 0x73, 0xc2, 0x98, 0x08, 0x48, 0x59, 0xb5, 0xb0,
	0xb6, 0xff, 0x73, 0x90, 0xaf, 0x84, 0x7f, 0x0d, 0xd2, 0x05, 0xf3, 0x1c, 0xf5, 0xcb, 0x9c, 0xc4,
	0x50, 0x00, 0x15, 0xd6, 0x75, 0x89, 0x3f, 0x59, 0x87, 0x1f, 0x6b, 0x81, 0xc2, 0x2e, 0x09, 0x8d,
	0xf1, 0x0b, 0x56, 0x8b, 0x3a, 0x82, 0x70, 0x9e, 0x25, 0xc0, 0xac, 0x1b, 0x57, 0x33, 0xfe, 0x1d,
	0xab, 0x2f, 0xeb, 0x08, 0x26, 0x8d, 0x46, 0x1b, 0xaf, 0x40, 0x32, 0x67, 0x7e, 0x40, 0x37, 0x35,
	0x38, 0xfe, 0x48, 0x28, 0x85, 0xdc, 0xea, 0x4b, 0xb4, 0x73, 0x45, 0xb4, 0xdf, 0xaa, 0x14, 0x7c,
	0x5f, 0xc1, 0x54, 0x76, 0xb4, 0x83, 0xfa, 0xdd, 0x29, 0x8d, 0x3e, 0x1b, 0xe8, 0x38, 0x66, 0x05,
	0x5e, 0x7b, 0xcc, 0xa3, 0xc3, 0x95, 0x87, 0x32, 0x6e, 0xfe, 0xed, 0xe3, 0xde, 0xfb, 0xd7, 0x0a,
	0x92, 0xb2, 0x9c, 0xd0, 0x14, 0xb3, 0x2a, 0xb5, 0x53, 0xa0, 0xf2, 0x16, 0xf4, 0x3d, 0x97, 0x19,
	0xff, 0xc7, 0x57, 0xe7, 0x79, 0x17, 0x7d, 0x31, 0x36, 0x4e, 0x3d, 0xef, 0xab, 0x71, 0x74, 0xda,
	0x22, 0xbd, 0x84, 0xe3, 0x36, 0x6c, 0xa2, 0x89, 0x83, 0x03, 0xdd, 0xf9, 0x4d, 0xf7, 0x4c, 0xbd,
	0x84, 0x4f, 0xbb, 0x9e, 0xe9, 0xc4, 0x99, 0x76, 0x3d, 0xdf, 0x8d, 0xe3, 0xb6, 0xe0, 0xba, 0x5e,
	0xc2, 0x5d, 0xb7, 0xeb, 0x72, 0xdd, 0x89, 0xe3, 0xba, 0x5d, 0x5f, 0xb4, 0x2d, 0x97, 0x7d, 0xfc,
	0x33, 0x00, 0x00, 0xff, 0xff, 0x26, 0x03, 0xfb, 0x3c, 0x21, 0x05, 0x00, 0x00,
}
