// Code generated by protoc-gen-go. DO NOT EDIT.
// source: google/ads/googleads/v1/resources/geo_target_constant.proto

package resources

import (
	fmt "fmt"
	math "math"

	proto "github.com/golang/protobuf/proto"
	wrappers "github.com/golang/protobuf/ptypes/wrappers"
	enums "google.golang.org/genproto/googleapis/ads/googleads/v1/enums"
	_ "google.golang.org/genproto/googleapis/api/annotations"
)

// Reference imports to suppress errors if they are not otherwise used.
var _ = proto.Marshal
var _ = fmt.Errorf
var _ = math.Inf

// This is a compile-time assertion to ensure that this generated file
// is compatible with the proto package it is being compiled against.
// A compilation error at this line likely means your copy of the
// proto package needs to be updated.
const _ = proto.ProtoPackageIsVersion3 // please upgrade the proto package

// A geo target constant.
type GeoTargetConstant struct {
	// The resource name of the geo target constant.
	// Geo target constant resource names have the form:
	//
	// `geoTargetConstants/{geo_target_constant_id}`
	ResourceName string `protobuf:"bytes,1,opt,name=resource_name,json=resourceName,proto3" json:"resource_name,omitempty"`
	// The ID of the geo target constant.
	Id *wrappers.Int64Value `protobuf:"bytes,3,opt,name=id,proto3" json:"id,omitempty"`
	// Geo target constant English name.
	Name *wrappers.StringValue `protobuf:"bytes,4,opt,name=name,proto3" json:"name,omitempty"`
	// The ISO-3166-1 alpha-2 country code that is associated with the target.
	CountryCode *wrappers.StringValue `protobuf:"bytes,5,opt,name=country_code,json=countryCode,proto3" json:"country_code,omitempty"`
	// Geo target constant target type.
	TargetType *wrappers.StringValue `protobuf:"bytes,6,opt,name=target_type,json=targetType,proto3" json:"target_type,omitempty"`
	// Geo target constant status.
	Status enums.GeoTargetConstantStatusEnum_GeoTargetConstantStatus `protobuf:"varint,7,opt,name=status,proto3,enum=google.ads.googleads.v1.enums.GeoTargetConstantStatusEnum_GeoTargetConstantStatus" json:"status,omitempty"`
	// The fully qualified English name, consisting of the target's name and that
	// of its parent and country.
	CanonicalName        *wrappers.StringValue `protobuf:"bytes,8,opt,name=canonical_name,json=canonicalName,proto3" json:"canonical_name,omitempty"`
	XXX_NoUnkeyedLiteral struct{}              `json:"-"`
	XXX_unrecognized     []byte                `json:"-"`
	XXX_sizecache        int32                 `json:"-"`
}

func (m *GeoTargetConstant) Reset()         { *m = GeoTargetConstant{} }
func (m *GeoTargetConstant) String() string { return proto.CompactTextString(m) }
func (*GeoTargetConstant) ProtoMessage()    {}
func (*GeoTargetConstant) Descriptor() ([]byte, []int) {
	return fileDescriptor_e598a341d42b96a1, []int{0}
}

func (m *GeoTargetConstant) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_GeoTargetConstant.Unmarshal(m, b)
}
func (m *GeoTargetConstant) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_GeoTargetConstant.Marshal(b, m, deterministic)
}
func (m *GeoTargetConstant) XXX_Merge(src proto.Message) {
	xxx_messageInfo_GeoTargetConstant.Merge(m, src)
}
func (m *GeoTargetConstant) XXX_Size() int {
	return xxx_messageInfo_GeoTargetConstant.Size(m)
}
func (m *GeoTargetConstant) XXX_DiscardUnknown() {
	xxx_messageInfo_GeoTargetConstant.DiscardUnknown(m)
}

var xxx_messageInfo_GeoTargetConstant proto.InternalMessageInfo

func (m *GeoTargetConstant) GetResourceName() string {
	if m != nil {
		return m.ResourceName
	}
	return ""
}

func (m *GeoTargetConstant) GetId() *wrappers.Int64Value {
	if m != nil {
		return m.Id
	}
	return nil
}

func (m *GeoTargetConstant) GetName() *wrappers.StringValue {
	if m != nil {
		return m.Name
	}
	return nil
}

func (m *GeoTargetConstant) GetCountryCode() *wrappers.StringValue {
	if m != nil {
		return m.CountryCode
	}
	return nil
}

func (m *GeoTargetConstant) GetTargetType() *wrappers.StringValue {
	if m != nil {
		return m.TargetType
	}
	return nil
}

func (m *GeoTargetConstant) GetStatus() enums.GeoTargetConstantStatusEnum_GeoTargetConstantStatus {
	if m != nil {
		return m.Status
	}
	return enums.GeoTargetConstantStatusEnum_UNSPECIFIED
}

func (m *GeoTargetConstant) GetCanonicalName() *wrappers.StringValue {
	if m != nil {
		return m.CanonicalName
	}
	return nil
}

func init() {
	proto.RegisterType((*GeoTargetConstant)(nil), "google.ads.googleads.v1.resources.GeoTargetConstant")
}

func init() {
	proto.RegisterFile("google/ads/googleads/v1/resources/geo_target_constant.proto", fileDescriptor_e598a341d42b96a1)
}

var fileDescriptor_e598a341d42b96a1 = []byte{
	// 456 bytes of a gzipped FileDescriptorProto
	0x1f, 0x8b, 0x08, 0x00, 0x00, 0x00, 0x00, 0x00, 0x02, 0xff, 0x8c, 0x93, 0x41, 0x6b, 0xd4, 0x40,
	0x14, 0xc7, 0x49, 0xb6, 0xae, 0x3a, 0xdb, 0x16, 0xcc, 0x41, 0x42, 0x2d, 0xb2, 0x55, 0x0a, 0x0b,
	0xc2, 0xc4, 0x54, 0xf1, 0x90, 0xa2, 0x92, 0x2e, 0xb2, 0xe8, 0x41, 0x4a, 0x5a, 0xf6, 0x20, 0x0b,
	0x61, 0x9a, 0x79, 0x0e, 0x91, 0xcd, 0xbc, 0x30, 0x33, 0xa9, 0xec, 0xd9, 0x6f, 0xe2, 0xd1, 0x4f,
	0x22, 0x7e, 0x14, 0x3f, 0x85, 0xec, 0x4c, 0x92, 0xcb, 0xba, 0xba, 0xb7, 0x97, 0xbc, 0xff, 0xef,
	0xff, 0x7f, 0x79, 0x33, 0x21, 0xe7, 0x02, 0x51, 0x2c, 0x21, 0x62, 0x5c, 0x47, 0xae, 0x5c, 0x57,
	0xb7, 0x71, 0xa4, 0x40, 0x63, 0xa3, 0x0a, 0xd0, 0x91, 0x00, 0xcc, 0x0d, 0x53, 0x02, 0x4c, 0x5e,
	0xa0, 0xd4, 0x86, 0x49, 0x43, 0x6b, 0x85, 0x06, 0x83, 0x13, 0x47, 0x50, 0xc6, 0x35, 0xed, 0x61,
	0x7a, 0x1b, 0xd3, 0x1e, 0x3e, 0x7a, 0xb3, 0xcd, 0x1f, 0x64, 0x53, 0xfd, 0xd5, 0x3b, 0xd7, 0x86,
	0x99, 0x46, 0xbb, 0x88, 0xa3, 0xe3, 0x8e, 0xaf, 0xcb, 0x88, 0x49, 0x89, 0x86, 0x99, 0x12, 0x65,
	0xd7, 0x7d, 0xdc, 0x76, 0xed, 0xd3, 0x4d, 0xf3, 0x39, 0xfa, 0xaa, 0x58, 0x5d, 0x83, 0x6a, 0xfb,
	0x4f, 0x7e, 0x0e, 0xc8, 0x83, 0x19, 0xe0, 0xb5, 0x4d, 0x98, 0xb6, 0x01, 0xc1, 0x53, 0x72, 0xd0,
	0x0d, 0x98, 0x4b, 0x56, 0x41, 0xe8, 0x8d, 0xbd, 0xc9, 0xfd, 0x6c, 0xbf, 0x7b, 0xf9, 0x91, 0x55,
	0x10, 0x3c, 0x23, 0x7e, 0xc9, 0xc3, 0xc1, 0xd8, 0x9b, 0x8c, 0xce, 0x1e, 0xb5, 0x5f, 0x47, 0xbb,
	0x1c, 0xfa, 0x5e, 0x9a, 0x57, 0x2f, 0xe7, 0x6c, 0xd9, 0x40, 0xe6, 0x97, 0x3c, 0x78, 0x4e, 0xf6,
	0xac, 0xd1, 0x9e, 0x95, 0x1f, 0x6f, 0xc8, 0xaf, 0x8c, 0x2a, 0xa5, 0x70, 0x7a, 0xab, 0x0c, 0xde,
	0x92, 0xfd, 0x02, 0x1b, 0x69, 0xd4, 0x2a, 0x2f, 0x90, 0x43, 0x78, 0x67, 0x07, 0x72, 0xd4, 0x12,
	0x53, 0xe4, 0x10, 0xbc, 0x26, 0xa3, 0x76, 0x71, 0x66, 0x55, 0x43, 0x38, 0xdc, 0x81, 0x27, 0x0e,
	0xb8, 0x5e, 0xd5, 0x10, 0x7c, 0x21, 0x43, 0xb7, 0xe7, 0xf0, 0xee, 0xd8, 0x9b, 0x1c, 0x9e, 0x65,
	0x74, 0xdb, 0x59, 0xda, 0x83, 0xa2, 0x1b, 0x5b, 0xbc, 0xb2, 0xf4, 0x3b, 0xd9, 0x54, 0xdb, 0x7a,
	0x59, 0x9b, 0x10, 0x4c, 0xc9, 0x61, 0xc1, 0x24, 0xca, 0xb2, 0x60, 0x4b, 0xb7, 0xf0, 0x7b, 0x3b,
	0x4c, 0x7b, 0xd0, 0x33, 0xeb, 0xf3, 0xb8, 0xf8, 0xe6, 0x93, 0xd3, 0x02, 0x2b, 0xfa, 0xdf, 0x2b,
	0x77, 0xf1, 0x70, 0x63, 0x9e, 0xcb, 0xb5, 0xff, 0xa5, 0xf7, 0xe9, 0x43, 0x0b, 0x0b, 0x5c, 0x32,
	0x29, 0x28, 0x2a, 0x11, 0x09, 0x90, 0x36, 0xbd, 0xbb, 0x9c, 0x75, 0xa9, 0xff, 0xf1, 0x2f, 0x9c,
	0xf7, 0xd5, 0x77, 0x7f, 0x30, 0x4b, 0xd3, 0x1f, 0xfe, 0xc9, 0xcc, 0x59, 0xa6, 0x5c, 0x53, 0x57,
	0xae, 0xab, 0x79, 0x4c, 0xb3, 0x4e, 0xf9, 0xab, 0xd3, 0x2c, 0x52, 0xae, 0x17, 0xbd, 0x66, 0x31,
	0x8f, 0x17, 0xbd, 0xe6, 0xb7, 0x7f, 0xea, 0x1a, 0x49, 0x92, 0x72, 0x9d, 0x24, 0xbd, 0x2a, 0x49,
	0xe6, 0x71, 0x92, 0xf4, 0xba, 0x9b, 0xa1, 0x1d, 0xf6, 0xc5, 0x9f, 0x00, 0x00, 0x00, 0xff, 0xff,
	0xdf, 0xe1, 0xcd, 0x18, 0xb7, 0x03, 0x00, 0x00,
}
