// Code generated by protoc-gen-go. DO NOT EDIT.
// source: google/cloud/datalabeling/v1beta1/annotation_spec_set.proto

package datalabeling

import (
	fmt "fmt"
	math "math"

	proto "github.com/golang/protobuf/proto"
	_ "google.golang.org/genproto/googleapis/api/annotations"
)

// Reference imports to suppress errors if they are not otherwise used.
var _ = proto.Marshal
var _ = fmt.Errorf
var _ = math.Inf

// This is a compile-time assertion to ensure that this generated file
// is compatible with the proto package it is being compiled against.
// A compilation error at this line likely means your copy of the
// proto package needs to be updated.
const _ = proto.ProtoPackageIsVersion3 // please upgrade the proto package

// AnnotationSpecSet is a collection of label definitions. For example, in
// image classification tasks, we define a set of labels, this set is called
// AnnotationSpecSet. AnnotationSpecSet is immutable upon creation.
type AnnotationSpecSet struct {
	// Output only. AnnotationSpecSet resource name, format:
	// projects/{project_id}/annotationSpecSets/{annotation_spec_set_id}
	Name string `protobuf:"bytes,1,opt,name=name,proto3" json:"name,omitempty"`
	// Required. The display name for AnnotationSpecSet defined by user.
	// Maximum of 64 characters.
	DisplayName string `protobuf:"bytes,2,opt,name=display_name,json=displayName,proto3" json:"display_name,omitempty"`
	// Optional. User-provided description of the annotation specification set.
	// The description can be up to 10000 characters long.
	Description string `protobuf:"bytes,3,opt,name=description,proto3" json:"description,omitempty"`
	// Required. The actual spec set defined by the users.
	AnnotationSpecs []*AnnotationSpec `protobuf:"bytes,4,rep,name=annotation_specs,json=annotationSpecs,proto3" json:"annotation_specs,omitempty"`
	// Output only. The names of any related resources that are blocking changes
	// to the annotation spec set.
	BlockingResources    []string `protobuf:"bytes,5,rep,name=blocking_resources,json=blockingResources,proto3" json:"blocking_resources,omitempty"`
	XXX_NoUnkeyedLiteral struct{} `json:"-"`
	XXX_unrecognized     []byte   `json:"-"`
	XXX_sizecache        int32    `json:"-"`
}

func (m *AnnotationSpecSet) Reset()         { *m = AnnotationSpecSet{} }
func (m *AnnotationSpecSet) String() string { return proto.CompactTextString(m) }
func (*AnnotationSpecSet) ProtoMessage()    {}
func (*AnnotationSpecSet) Descriptor() ([]byte, []int) {
	return fileDescriptor_ee18bab2b343845e, []int{0}
}

func (m *AnnotationSpecSet) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_AnnotationSpecSet.Unmarshal(m, b)
}
func (m *AnnotationSpecSet) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_AnnotationSpecSet.Marshal(b, m, deterministic)
}
func (m *AnnotationSpecSet) XXX_Merge(src proto.Message) {
	xxx_messageInfo_AnnotationSpecSet.Merge(m, src)
}
func (m *AnnotationSpecSet) XXX_Size() int {
	return xxx_messageInfo_AnnotationSpecSet.Size(m)
}
func (m *AnnotationSpecSet) XXX_DiscardUnknown() {
	xxx_messageInfo_AnnotationSpecSet.DiscardUnknown(m)
}

var xxx_messageInfo_AnnotationSpecSet proto.InternalMessageInfo

func (m *AnnotationSpecSet) GetName() string {
	if m != nil {
		return m.Name
	}
	return ""
}

func (m *AnnotationSpecSet) GetDisplayName() string {
	if m != nil {
		return m.DisplayName
	}
	return ""
}

func (m *AnnotationSpecSet) GetDescription() string {
	if m != nil {
		return m.Description
	}
	return ""
}

func (m *AnnotationSpecSet) GetAnnotationSpecs() []*AnnotationSpec {
	if m != nil {
		return m.AnnotationSpecs
	}
	return nil
}

func (m *AnnotationSpecSet) GetBlockingResources() []string {
	if m != nil {
		return m.BlockingResources
	}
	return nil
}

// Container of information related to one annotation spec.
type AnnotationSpec struct {
	// Required. The display name of the AnnotationSpec. Maximum of 64 characters.
	DisplayName string `protobuf:"bytes,1,opt,name=display_name,json=displayName,proto3" json:"display_name,omitempty"`
	// Optional. User-provided description of the annotation specification.
	// The description can be up to 10000 characters long.
	Description          string   `protobuf:"bytes,2,opt,name=description,proto3" json:"description,omitempty"`
	XXX_NoUnkeyedLiteral struct{} `json:"-"`
	XXX_unrecognized     []byte   `json:"-"`
	XXX_sizecache        int32    `json:"-"`
}

func (m *AnnotationSpec) Reset()         { *m = AnnotationSpec{} }
func (m *AnnotationSpec) String() string { return proto.CompactTextString(m) }
func (*AnnotationSpec) ProtoMessage()    {}
func (*AnnotationSpec) Descriptor() ([]byte, []int) {
	return fileDescriptor_ee18bab2b343845e, []int{1}
}

func (m *AnnotationSpec) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_AnnotationSpec.Unmarshal(m, b)
}
func (m *AnnotationSpec) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_AnnotationSpec.Marshal(b, m, deterministic)
}
func (m *AnnotationSpec) XXX_Merge(src proto.Message) {
	xxx_messageInfo_AnnotationSpec.Merge(m, src)
}
func (m *AnnotationSpec) XXX_Size() int {
	return xxx_messageInfo_AnnotationSpec.Size(m)
}
func (m *AnnotationSpec) XXX_DiscardUnknown() {
	xxx_messageInfo_AnnotationSpec.DiscardUnknown(m)
}

var xxx_messageInfo_AnnotationSpec proto.InternalMessageInfo

func (m *AnnotationSpec) GetDisplayName() string {
	if m != nil {
		return m.DisplayName
	}
	return ""
}

func (m *AnnotationSpec) GetDescription() string {
	if m != nil {
		return m.Description
	}
	return ""
}

func init() {
	proto.RegisterType((*AnnotationSpecSet)(nil), "google.cloud.datalabeling.v1beta1.AnnotationSpecSet")
	proto.RegisterType((*AnnotationSpec)(nil), "google.cloud.datalabeling.v1beta1.AnnotationSpec")
}

func init() {
	proto.RegisterFile("google/cloud/datalabeling/v1beta1/annotation_spec_set.proto", fileDescriptor_ee18bab2b343845e)
}

var fileDescriptor_ee18bab2b343845e = []byte{
	// 293 bytes of a gzipped FileDescriptorProto
	0x1f, 0x8b, 0x08, 0x00, 0x00, 0x00, 0x00, 0x00, 0x02, 0xff, 0x84, 0x92, 0xcf, 0x4b, 0xc3, 0x30,
	0x14, 0xc7, 0xe9, 0x36, 0x85, 0x65, 0xa2, 0x2e, 0xa7, 0x22, 0x1e, 0xba, 0x81, 0xb0, 0x8b, 0x29,
	0xd3, 0xe3, 0x4e, 0x7a, 0x57, 0xa4, 0xc3, 0x8b, 0x08, 0xe5, 0x35, 0x7d, 0x84, 0x60, 0x96, 0x17,
	0x9a, 0x4c, 0xf4, 0x4f, 0xf7, 0x26, 0xcb, 0x3a, 0xdd, 0x1c, 0xb8, 0x5b, 0xfb, 0xfd, 0x45, 0x3e,
	0x24, 0x6c, 0xa6, 0x88, 0x94, 0xc1, 0x5c, 0x1a, 0x5a, 0xd6, 0x79, 0x0d, 0x01, 0x0c, 0x54, 0x68,
	0xb4, 0x55, 0xf9, 0xfb, 0xb4, 0xc2, 0x00, 0xd3, 0x1c, 0xac, 0xa5, 0x00, 0x41, 0x93, 0x2d, 0xbd,
	0x43, 0x59, 0x7a, 0x0c, 0xc2, 0x35, 0x14, 0x88, 0x8f, 0xd6, 0x65, 0x11, 0xcb, 0x62, 0xbb, 0x2c,
	0xda, 0xf2, 0xc5, 0x65, 0xbb, 0x0f, 0x4e, 0x6f, 0x0d, 0xf9, 0xf5, 0xc0, 0xf8, 0x2b, 0x61, 0xc3,
	0xbb, 0x1f, 0x75, 0xee, 0x50, 0xce, 0x31, 0x70, 0xce, 0x7a, 0x16, 0x16, 0x98, 0x26, 0x59, 0x32,
	0xe9, 0x17, 0xf1, 0x9b, 0x8f, 0xd8, 0x49, 0xad, 0xbd, 0x33, 0xf0, 0x59, 0x46, 0xaf, 0x13, 0xbd,
	0x41, 0xab, 0x3d, 0xae, 0x22, 0x19, 0x1b, 0xd4, 0xe8, 0x65, 0xa3, 0xdd, 0x6a, 0x2c, 0xed, 0xb6,
	0x89, 0x5f, 0x89, 0xbf, 0xb2, 0xf3, 0x3f, 0x30, 0x3e, 0xed, 0x65, 0xdd, 0xc9, 0xe0, 0x66, 0x2a,
	0x0e, 0xa2, 0x88, 0xdd, 0x83, 0x16, 0x67, 0xb0, 0xf3, 0xef, 0xf9, 0x35, 0xe3, 0x95, 0x21, 0xf9,
	0xa6, 0xad, 0x2a, 0x1b, 0xf4, 0xb4, 0x6c, 0x24, 0xfa, 0xf4, 0x28, 0xeb, 0x4e, 0xfa, 0xc5, 0x70,
	0xe3, 0x14, 0x1b, 0x63, 0xfc, 0xcc, 0x4e, 0x77, 0x17, 0xf7, 0x18, 0x93, 0x83, 0x8c, 0x9d, 0x3d,
	0xc6, 0xfb, 0x0f, 0x76, 0x25, 0x69, 0x71, 0x18, 0xe7, 0x29, 0x79, 0x79, 0x68, 0x43, 0x8a, 0x0c,
	0x58, 0x25, 0xa8, 0x51, 0xb9, 0x42, 0x1b, 0x6f, 0x26, 0x5f, 0x5b, 0xe0, 0xb4, 0xff, 0xe7, 0x69,
	0xcc, 0xb6, 0xc5, 0xea, 0x38, 0x36, 0x6f, 0xbf, 0x03, 0x00, 0x00, 0xff, 0xff, 0x1c, 0xe5, 0x00,
	0x70, 0x53, 0x02, 0x00, 0x00,
}
