// Code generated by protoc-gen-go. DO NOT EDIT.
// source: google/ads/googleads/v2/enums/asset_performance_label.proto

package enums

import (
	fmt "fmt"
	math "math"

	proto "github.com/golang/protobuf/proto"
	_ "google.golang.org/genproto/googleapis/api/annotations"
)

// Reference imports to suppress errors if they are not otherwise used.
var _ = proto.Marshal
var _ = fmt.Errorf
var _ = math.Inf

// This is a compile-time assertion to ensure that this generated file
// is compatible with the proto package it is being compiled against.
// A compilation error at this line likely means your copy of the
// proto package needs to be updated.
const _ = proto.ProtoPackageIsVersion3 // please upgrade the proto package

// Enum describing the possible performance labels of an asset, usually
// computed in the context of a linkage.
type AssetPerformanceLabelEnum_AssetPerformanceLabel int32

const (
	// Not specified.
	AssetPerformanceLabelEnum_UNSPECIFIED AssetPerformanceLabelEnum_AssetPerformanceLabel = 0
	// Used for return value only. Represents value unknown in this version.
	AssetPerformanceLabelEnum_UNKNOWN AssetPerformanceLabelEnum_AssetPerformanceLabel = 1
	// This asset does not yet have any performance informantion. This may be
	// because it is still under review.
	AssetPerformanceLabelEnum_PENDING AssetPerformanceLabelEnum_AssetPerformanceLabel = 2
	// The asset has started getting impressions but the stats are not
	// statistically significant enough to get an asset performance label.
	AssetPerformanceLabelEnum_LEARNING AssetPerformanceLabelEnum_AssetPerformanceLabel = 3
	// Worst performing assets.
	AssetPerformanceLabelEnum_LOW AssetPerformanceLabelEnum_AssetPerformanceLabel = 4
	// Good performing assets.
	AssetPerformanceLabelEnum_GOOD AssetPerformanceLabelEnum_AssetPerformanceLabel = 5
	// Best performing assets.
	AssetPerformanceLabelEnum_BEST AssetPerformanceLabelEnum_AssetPerformanceLabel = 6
)

var AssetPerformanceLabelEnum_AssetPerformanceLabel_name = map[int32]string{
	0: "UNSPECIFIED",
	1: "UNKNOWN",
	2: "PENDING",
	3: "LEARNING",
	4: "LOW",
	5: "GOOD",
	6: "BEST",
}

var AssetPerformanceLabelEnum_AssetPerformanceLabel_value = map[string]int32{
	"UNSPECIFIED": 0,
	"UNKNOWN":     1,
	"PENDING":     2,
	"LEARNING":    3,
	"LOW":         4,
	"GOOD":        5,
	"BEST":        6,
}

func (x AssetPerformanceLabelEnum_AssetPerformanceLabel) String() string {
	return proto.EnumName(AssetPerformanceLabelEnum_AssetPerformanceLabel_name, int32(x))
}

func (AssetPerformanceLabelEnum_AssetPerformanceLabel) EnumDescriptor() ([]byte, []int) {
	return fileDescriptor_49c836d9760c0969, []int{0, 0}
}

// Container for enum describing the performance label of an asset.
type AssetPerformanceLabelEnum struct {
	XXX_NoUnkeyedLiteral struct{} `json:"-"`
	XXX_unrecognized     []byte   `json:"-"`
	XXX_sizecache        int32    `json:"-"`
}

func (m *AssetPerformanceLabelEnum) Reset()         { *m = AssetPerformanceLabelEnum{} }
func (m *AssetPerformanceLabelEnum) String() string { return proto.CompactTextString(m) }
func (*AssetPerformanceLabelEnum) ProtoMessage()    {}
func (*AssetPerformanceLabelEnum) Descriptor() ([]byte, []int) {
	return fileDescriptor_49c836d9760c0969, []int{0}
}

func (m *AssetPerformanceLabelEnum) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_AssetPerformanceLabelEnum.Unmarshal(m, b)
}
func (m *AssetPerformanceLabelEnum) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_AssetPerformanceLabelEnum.Marshal(b, m, deterministic)
}
func (m *AssetPerformanceLabelEnum) XXX_Merge(src proto.Message) {
	xxx_messageInfo_AssetPerformanceLabelEnum.Merge(m, src)
}
func (m *AssetPerformanceLabelEnum) XXX_Size() int {
	return xxx_messageInfo_AssetPerformanceLabelEnum.Size(m)
}
func (m *AssetPerformanceLabelEnum) XXX_DiscardUnknown() {
	xxx_messageInfo_AssetPerformanceLabelEnum.DiscardUnknown(m)
}

var xxx_messageInfo_AssetPerformanceLabelEnum proto.InternalMessageInfo

func init() {
	proto.RegisterEnum("google.ads.googleads.v2.enums.AssetPerformanceLabelEnum_AssetPerformanceLabel", AssetPerformanceLabelEnum_AssetPerformanceLabel_name, AssetPerformanceLabelEnum_AssetPerformanceLabel_value)
	proto.RegisterType((*AssetPerformanceLabelEnum)(nil), "google.ads.googleads.v2.enums.AssetPerformanceLabelEnum")
}

func init() {
	proto.RegisterFile("google/ads/googleads/v2/enums/asset_performance_label.proto", fileDescriptor_49c836d9760c0969)
}

var fileDescriptor_49c836d9760c0969 = []byte{
	// 334 bytes of a gzipped FileDescriptorProto
	0x1f, 0x8b, 0x08, 0x00, 0x00, 0x00, 0x00, 0x00, 0x02, 0xff, 0x7c, 0x50, 0xd1, 0x4e, 0xc2, 0x30,
	0x14, 0x75, 0x03, 0x81, 0x14, 0x13, 0x97, 0x25, 0x3e, 0x48, 0xe4, 0x01, 0x3e, 0xa0, 0x4b, 0xe6,
	0x5b, 0x79, 0xea, 0x64, 0x2e, 0x44, 0xd2, 0x2d, 0x22, 0x90, 0x98, 0x25, 0xa4, 0xb0, 0xba, 0x90,
	0x6c, 0xed, 0xb2, 0x0e, 0x3e, 0xc2, 0xcf, 0xf0, 0xd1, 0x4f, 0xf1, 0x53, 0x7c, 0xf1, 0x17, 0x4c,
	0x57, 0xc1, 0x17, 0xf4, 0xa5, 0x39, 0xb7, 0xe7, 0x9e, 0x93, 0x7b, 0x0e, 0x18, 0xa5, 0x42, 0xa4,
	0x19, 0x73, 0x68, 0x22, 0x1d, 0x0d, 0x15, 0xda, 0xbb, 0x0e, 0xe3, 0xbb, 0x5c, 0x3a, 0x54, 0x4a,
	0x56, 0xad, 0x0a, 0x56, 0xbe, 0x88, 0x32, 0xa7, 0x7c, 0xc3, 0x56, 0x19, 0x5d, 0xb3, 0x0c, 0x16,
	0xa5, 0xa8, 0x84, 0xdd, 0xd7, 0x0a, 0x48, 0x13, 0x09, 0x8f, 0x62, 0xb8, 0x77, 0x61, 0x2d, 0xee,
	0xdd, 0x1c, 0xbc, 0x8b, 0xad, 0x43, 0x39, 0x17, 0x15, 0xad, 0xb6, 0x82, 0x4b, 0x2d, 0x1e, 0xbe,
	0x1a, 0xe0, 0x1a, 0x2b, 0xfb, 0xe8, 0xd7, 0x7d, 0xaa, 0xcc, 0x7d, 0xbe, 0xcb, 0x87, 0x39, 0xb8,
	0x3a, 0x49, 0xda, 0x97, 0xa0, 0x3b, 0x27, 0xb3, 0xc8, 0xbf, 0x9b, 0xdc, 0x4f, 0xfc, 0xb1, 0x75,
	0x66, 0x77, 0x41, 0x7b, 0x4e, 0x1e, 0x48, 0xb8, 0x24, 0x96, 0xa1, 0x86, 0xc8, 0x27, 0xe3, 0x09,
	0x09, 0x2c, 0xd3, 0xbe, 0x00, 0x9d, 0xa9, 0x8f, 0x1f, 0x89, 0x9a, 0x1a, 0x76, 0x1b, 0x34, 0xa6,
	0xe1, 0xd2, 0x6a, 0xda, 0x1d, 0xd0, 0x0c, 0xc2, 0x70, 0x6c, 0x9d, 0x2b, 0xe4, 0xf9, 0xb3, 0x27,
	0xab, 0xe5, 0x7d, 0x19, 0x60, 0xb0, 0x11, 0x39, 0xfc, 0x37, 0x90, 0xd7, 0x3b, 0x79, 0x52, 0xa4,
	0xe2, 0x44, 0xc6, 0xb3, 0xf7, 0x23, 0x4e, 0x45, 0x46, 0x79, 0x0a, 0x45, 0x99, 0x3a, 0x29, 0xe3,
	0x75, 0xd8, 0x43, 0xb5, 0xc5, 0x56, 0xfe, 0xd1, 0xf4, 0xa8, 0x7e, 0xdf, 0xcc, 0x46, 0x80, 0xf1,
	0xbb, 0xd9, 0x0f, 0xb4, 0x15, 0x4e, 0x24, 0xd4, 0x50, 0xa1, 0x85, 0x0b, 0x55, 0x37, 0xf2, 0xe3,
	0xc0, 0xc7, 0x38, 0x91, 0xf1, 0x91, 0x8f, 0x17, 0x6e, 0x5c, 0xf3, 0x9f, 0xe6, 0x40, 0x7f, 0x22,
	0x84, 0x13, 0x89, 0xd0, 0x71, 0x03, 0xa1, 0x85, 0x8b, 0x50, 0xbd, 0xb3, 0x6e, 0xd5, 0x87, 0xdd,
	0x7e, 0x07, 0x00, 0x00, 0xff, 0xff, 0xd9, 0x17, 0x21, 0x42, 0x01, 0x02, 0x00, 0x00,
}
