// Code generated by protoc-gen-go. DO NOT EDIT.
// source: google/ads/googleads/v2/enums/spending_limit_type.proto

package enums

import (
	fmt "fmt"
	math "math"

	proto "github.com/golang/protobuf/proto"
	_ "google.golang.org/genproto/googleapis/api/annotations"
)

// Reference imports to suppress errors if they are not otherwise used.
var _ = proto.Marshal
var _ = fmt.Errorf
var _ = math.Inf

// This is a compile-time assertion to ensure that this generated file
// is compatible with the proto package it is being compiled against.
// A compilation error at this line likely means your copy of the
// proto package needs to be updated.
const _ = proto.ProtoPackageIsVersion3 // please upgrade the proto package

// The possible spending limit types used by certain resources as an
// alternative to absolute money values in micros.
type SpendingLimitTypeEnum_SpendingLimitType int32

const (
	// Not specified.
	SpendingLimitTypeEnum_UNSPECIFIED SpendingLimitTypeEnum_SpendingLimitType = 0
	// Used for return value only. Represents value unknown in this version.
	SpendingLimitTypeEnum_UNKNOWN SpendingLimitTypeEnum_SpendingLimitType = 1
	// Infinite, indicates unlimited spending power.
	SpendingLimitTypeEnum_INFINITE SpendingLimitTypeEnum_SpendingLimitType = 2
)

var SpendingLimitTypeEnum_SpendingLimitType_name = map[int32]string{
	0: "UNSPECIFIED",
	1: "UNKNOWN",
	2: "INFINITE",
}

var SpendingLimitTypeEnum_SpendingLimitType_value = map[string]int32{
	"UNSPECIFIED": 0,
	"UNKNOWN":     1,
	"INFINITE":    2,
}

func (x SpendingLimitTypeEnum_SpendingLimitType) String() string {
	return proto.EnumName(SpendingLimitTypeEnum_SpendingLimitType_name, int32(x))
}

func (SpendingLimitTypeEnum_SpendingLimitType) EnumDescriptor() ([]byte, []int) {
	return fileDescriptor_f79ec95f0807aa85, []int{0, 0}
}

// Message describing spending limit types.
type SpendingLimitTypeEnum struct {
	XXX_NoUnkeyedLiteral struct{} `json:"-"`
	XXX_unrecognized     []byte   `json:"-"`
	XXX_sizecache        int32    `json:"-"`
}

func (m *SpendingLimitTypeEnum) Reset()         { *m = SpendingLimitTypeEnum{} }
func (m *SpendingLimitTypeEnum) String() string { return proto.CompactTextString(m) }
func (*SpendingLimitTypeEnum) ProtoMessage()    {}
func (*SpendingLimitTypeEnum) Descriptor() ([]byte, []int) {
	return fileDescriptor_f79ec95f0807aa85, []int{0}
}

func (m *SpendingLimitTypeEnum) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_SpendingLimitTypeEnum.Unmarshal(m, b)
}
func (m *SpendingLimitTypeEnum) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_SpendingLimitTypeEnum.Marshal(b, m, deterministic)
}
func (m *SpendingLimitTypeEnum) XXX_Merge(src proto.Message) {
	xxx_messageInfo_SpendingLimitTypeEnum.Merge(m, src)
}
func (m *SpendingLimitTypeEnum) XXX_Size() int {
	return xxx_messageInfo_SpendingLimitTypeEnum.Size(m)
}
func (m *SpendingLimitTypeEnum) XXX_DiscardUnknown() {
	xxx_messageInfo_SpendingLimitTypeEnum.DiscardUnknown(m)
}

var xxx_messageInfo_SpendingLimitTypeEnum proto.InternalMessageInfo

func init() {
	proto.RegisterEnum("google.ads.googleads.v2.enums.SpendingLimitTypeEnum_SpendingLimitType", SpendingLimitTypeEnum_SpendingLimitType_name, SpendingLimitTypeEnum_SpendingLimitType_value)
	proto.RegisterType((*SpendingLimitTypeEnum)(nil), "google.ads.googleads.v2.enums.SpendingLimitTypeEnum")
}

func init() {
	proto.RegisterFile("google/ads/googleads/v2/enums/spending_limit_type.proto", fileDescriptor_f79ec95f0807aa85)
}

var fileDescriptor_f79ec95f0807aa85 = []byte{
	// 298 bytes of a gzipped FileDescriptorProto
	0x1f, 0x8b, 0x08, 0x00, 0x00, 0x00, 0x00, 0x00, 0x02, 0xff, 0x7c, 0x50, 0xcd, 0x4a, 0xc3, 0x30,
	0x00, 0x76, 0x15, 0x54, 0x32, 0xc1, 0x59, 0xd0, 0x83, 0xb8, 0xc3, 0xf6, 0x00, 0x09, 0xd4, 0x83,
	0x10, 0x0f, 0xd2, 0x69, 0x37, 0x8a, 0x12, 0x0b, 0xdb, 0xaa, 0x48, 0x61, 0x54, 0x13, 0x42, 0xa0,
	0x4d, 0xc2, 0xd2, 0x0d, 0xf6, 0x3a, 0x1e, 0x7d, 0x14, 0x1f, 0x45, 0x5f, 0x42, 0x9a, 0xac, 0xbd,
	0x0c, 0xbd, 0x84, 0x8f, 0x7c, 0x3f, 0xf9, 0xf2, 0x81, 0x6b, 0xae, 0x14, 0x2f, 0x18, 0xca, 0xa9,
	0x41, 0x0e, 0xd6, 0x68, 0x1d, 0x20, 0x26, 0x57, 0xa5, 0x41, 0x46, 0x33, 0x49, 0x85, 0xe4, 0x8b,
	0x42, 0x94, 0xa2, 0x5a, 0x54, 0x1b, 0xcd, 0xa0, 0x5e, 0xaa, 0x4a, 0xf9, 0x7d, 0xa7, 0x86, 0x39,
	0x35, 0xb0, 0x35, 0xc2, 0x75, 0x00, 0xad, 0xf1, 0xe2, 0xb2, 0xc9, 0xd5, 0x02, 0xe5, 0x52, 0xaa,
	0x2a, 0xaf, 0x84, 0x92, 0xc6, 0x99, 0x87, 0x2f, 0xe0, 0x6c, 0xba, 0x4d, 0x7e, 0xac, 0x83, 0x67,
	0x1b, 0xcd, 0x22, 0xb9, 0x2a, 0x87, 0xb7, 0xe0, 0x74, 0x87, 0xf0, 0x4f, 0x40, 0x77, 0x4e, 0xa6,
	0x49, 0x74, 0x17, 0x8f, 0xe3, 0xe8, 0xbe, 0xb7, 0xe7, 0x77, 0xc1, 0xe1, 0x9c, 0x3c, 0x90, 0xa7,
	0x67, 0xd2, 0xeb, 0xf8, 0xc7, 0xe0, 0x28, 0x26, 0xe3, 0x98, 0xc4, 0xb3, 0xa8, 0xe7, 0x8d, 0x7e,
	0x3a, 0x60, 0xf0, 0xae, 0x4a, 0xf8, 0x6f, 0xbb, 0xd1, 0xf9, 0xce, 0x23, 0x49, 0xdd, 0x2b, 0xe9,
	0xbc, 0x8e, 0xb6, 0x46, 0xae, 0x8a, 0x5c, 0x72, 0xa8, 0x96, 0x1c, 0x71, 0x26, 0x6d, 0xeb, 0x66,
	0x1f, 0x2d, 0xcc, 0x1f, 0x73, 0xdd, 0xd8, 0xf3, 0xc3, 0xdb, 0x9f, 0x84, 0xe1, 0xa7, 0xd7, 0x9f,
	0xb8, 0xa8, 0x90, 0x1a, 0xe8, 0x60, 0x8d, 0xd2, 0x00, 0xd6, 0x3f, 0x35, 0x5f, 0x0d, 0x9f, 0x85,
	0xd4, 0x64, 0x2d, 0x9f, 0xa5, 0x41, 0x66, 0xf9, 0x6f, 0x6f, 0xe0, 0x2e, 0x31, 0x0e, 0xa9, 0xc1,
	0xb8, 0x55, 0x60, 0x9c, 0x06, 0x18, 0x5b, 0xcd, 0xdb, 0x81, 0x2d, 0x76, 0xf5, 0x1b, 0x00, 0x00,
	0xff, 0xff, 0x8e, 0xc8, 0x93, 0xbf, 0xc6, 0x01, 0x00, 0x00,
}
