// Code generated by protoc-gen-go. DO NOT EDIT.
// source: google/ads/googleads/v2/enums/feed_mapping_status.proto

package enums

import (
	fmt "fmt"
	math "math"

	proto "github.com/golang/protobuf/proto"
	_ "google.golang.org/genproto/googleapis/api/annotations"
)

// Reference imports to suppress errors if they are not otherwise used.
var _ = proto.Marshal
var _ = fmt.Errorf
var _ = math.Inf

// This is a compile-time assertion to ensure that this generated file
// is compatible with the proto package it is being compiled against.
// A compilation error at this line likely means your copy of the
// proto package needs to be updated.
const _ = proto.ProtoPackageIsVersion3 // please upgrade the proto package

// Possible statuses of a feed mapping.
type FeedMappingStatusEnum_FeedMappingStatus int32

const (
	// Not specified.
	FeedMappingStatusEnum_UNSPECIFIED FeedMappingStatusEnum_FeedMappingStatus = 0
	// Used for return value only. Represents value unknown in this version.
	FeedMappingStatusEnum_UNKNOWN FeedMappingStatusEnum_FeedMappingStatus = 1
	// Feed mapping is enabled.
	FeedMappingStatusEnum_ENABLED FeedMappingStatusEnum_FeedMappingStatus = 2
	// Feed mapping has been removed.
	FeedMappingStatusEnum_REMOVED FeedMappingStatusEnum_FeedMappingStatus = 3
)

var FeedMappingStatusEnum_FeedMappingStatus_name = map[int32]string{
	0: "UNSPECIFIED",
	1: "UNKNOWN",
	2: "ENABLED",
	3: "REMOVED",
}

var FeedMappingStatusEnum_FeedMappingStatus_value = map[string]int32{
	"UNSPECIFIED": 0,
	"UNKNOWN":     1,
	"ENABLED":     2,
	"REMOVED":     3,
}

func (x FeedMappingStatusEnum_FeedMappingStatus) String() string {
	return proto.EnumName(FeedMappingStatusEnum_FeedMappingStatus_name, int32(x))
}

func (FeedMappingStatusEnum_FeedMappingStatus) EnumDescriptor() ([]byte, []int) {
	return fileDescriptor_3287d4a64cd77129, []int{0, 0}
}

// Container for enum describing possible statuses of a feed mapping.
type FeedMappingStatusEnum struct {
	XXX_NoUnkeyedLiteral struct{} `json:"-"`
	XXX_unrecognized     []byte   `json:"-"`
	XXX_sizecache        int32    `json:"-"`
}

func (m *FeedMappingStatusEnum) Reset()         { *m = FeedMappingStatusEnum{} }
func (m *FeedMappingStatusEnum) String() string { return proto.CompactTextString(m) }
func (*FeedMappingStatusEnum) ProtoMessage()    {}
func (*FeedMappingStatusEnum) Descriptor() ([]byte, []int) {
	return fileDescriptor_3287d4a64cd77129, []int{0}
}

func (m *FeedMappingStatusEnum) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_FeedMappingStatusEnum.Unmarshal(m, b)
}
func (m *FeedMappingStatusEnum) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_FeedMappingStatusEnum.Marshal(b, m, deterministic)
}
func (m *FeedMappingStatusEnum) XXX_Merge(src proto.Message) {
	xxx_messageInfo_FeedMappingStatusEnum.Merge(m, src)
}
func (m *FeedMappingStatusEnum) XXX_Size() int {
	return xxx_messageInfo_FeedMappingStatusEnum.Size(m)
}
func (m *FeedMappingStatusEnum) XXX_DiscardUnknown() {
	xxx_messageInfo_FeedMappingStatusEnum.DiscardUnknown(m)
}

var xxx_messageInfo_FeedMappingStatusEnum proto.InternalMessageInfo

func init() {
	proto.RegisterEnum("google.ads.googleads.v2.enums.FeedMappingStatusEnum_FeedMappingStatus", FeedMappingStatusEnum_FeedMappingStatus_name, FeedMappingStatusEnum_FeedMappingStatus_value)
	proto.RegisterType((*FeedMappingStatusEnum)(nil), "google.ads.googleads.v2.enums.FeedMappingStatusEnum")
}

func init() {
	proto.RegisterFile("google/ads/googleads/v2/enums/feed_mapping_status.proto", fileDescriptor_3287d4a64cd77129)
}

var fileDescriptor_3287d4a64cd77129 = []byte{
	// 303 bytes of a gzipped FileDescriptorProto
	0x1f, 0x8b, 0x08, 0x00, 0x00, 0x00, 0x00, 0x00, 0x02, 0xff, 0x7c, 0x50, 0xcf, 0x4a, 0xc3, 0x30,
	0x18, 0x77, 0x1d, 0x28, 0x64, 0x07, 0xeb, 0x40, 0x0f, 0xe2, 0x0e, 0xdb, 0x03, 0x24, 0x50, 0x0f,
	0x42, 0x3c, 0xa5, 0x2e, 0x1b, 0x63, 0xae, 0x1b, 0x8e, 0x55, 0x90, 0xc2, 0x88, 0x26, 0x86, 0xc2,
	0x9a, 0x94, 0xa5, 0xdb, 0x03, 0x79, 0xf4, 0x51, 0x7c, 0x14, 0x7d, 0x09, 0x49, 0xb2, 0xf6, 0x32,
	0xf4, 0x52, 0x7e, 0x5f, 0x7f, 0x7f, 0xf2, 0xfb, 0x3e, 0x70, 0x27, 0xb5, 0x96, 0x1b, 0x81, 0x18,
	0x37, 0xc8, 0x43, 0x8b, 0xf6, 0x11, 0x12, 0x6a, 0x57, 0x18, 0xf4, 0x2e, 0x04, 0x5f, 0x17, 0xac,
	0x2c, 0x73, 0x25, 0xd7, 0xa6, 0x62, 0xd5, 0xce, 0xc0, 0x72, 0xab, 0x2b, 0xdd, 0xed, 0x79, 0x35,
	0x64, 0xdc, 0xc0, 0xc6, 0x08, 0xf7, 0x11, 0x74, 0xc6, 0xeb, 0x9b, 0x3a, 0xb7, 0xcc, 0x11, 0x53,
	0x4a, 0x57, 0xac, 0xca, 0xb5, 0x3a, 0x98, 0x07, 0x1c, 0x5c, 0x8e, 0x84, 0xe0, 0x33, 0x1f, 0xbc,
	0x74, 0xb9, 0x54, 0xed, 0x8a, 0xc1, 0x14, 0x5c, 0x1c, 0x11, 0xdd, 0x73, 0xd0, 0x59, 0x25, 0xcb,
	0x05, 0x7d, 0x98, 0x8c, 0x26, 0x74, 0x18, 0x9e, 0x74, 0x3b, 0xe0, 0x6c, 0x95, 0x4c, 0x93, 0xf9,
	0x73, 0x12, 0xb6, 0xec, 0x40, 0x13, 0x12, 0x3f, 0xd2, 0x61, 0x18, 0xd8, 0xe1, 0x89, 0xce, 0xe6,
	0x29, 0x1d, 0x86, 0xed, 0xf8, 0xa7, 0x05, 0xfa, 0x6f, 0xba, 0x80, 0xff, 0x36, 0x8d, 0xaf, 0x8e,
	0x1e, 0x5c, 0xd8, 0x8e, 0x8b, 0xd6, 0x4b, 0x7c, 0x30, 0x4a, 0xbd, 0x61, 0x4a, 0x42, 0xbd, 0x95,
	0x48, 0x0a, 0xe5, 0x36, 0xa8, 0x6f, 0x55, 0xe6, 0xe6, 0x8f, 0xd3, 0xdd, 0xbb, 0xef, 0x47, 0xd0,
	0x1e, 0x13, 0xf2, 0x19, 0xf4, 0xc6, 0x3e, 0x8a, 0x70, 0x03, 0x3d, 0xb4, 0x28, 0x8d, 0xa0, 0xdd,
	0xda, 0x7c, 0xd5, 0x7c, 0x46, 0xb8, 0xc9, 0x1a, 0x3e, 0x4b, 0xa3, 0xcc, 0xf1, 0xdf, 0x41, 0xdf,
	0xff, 0xc4, 0x98, 0x70, 0x83, 0x71, 0xa3, 0xc0, 0x38, 0x8d, 0x30, 0x76, 0x9a, 0xd7, 0x53, 0x57,
	0xec, 0xf6, 0x37, 0x00, 0x00, 0xff, 0xff, 0xee, 0x90, 0xd8, 0x73, 0xd2, 0x01, 0x00, 0x00,
}
