// Code generated by protoc-gen-go. DO NOT EDIT.
// source: google/ads/googleads/v1/enums/price_extension_type.proto

package enums

import (
	fmt "fmt"
	math "math"

	proto "github.com/golang/protobuf/proto"
	_ "google.golang.org/genproto/googleapis/api/annotations"
)

// Reference imports to suppress errors if they are not otherwise used.
var _ = proto.Marshal
var _ = fmt.Errorf
var _ = math.Inf

// This is a compile-time assertion to ensure that this generated file
// is compatible with the proto package it is being compiled against.
// A compilation error at this line likely means your copy of the
// proto package needs to be updated.
const _ = proto.ProtoPackageIsVersion3 // please upgrade the proto package

// Price extension type.
type PriceExtensionTypeEnum_PriceExtensionType int32

const (
	// Not specified.
	PriceExtensionTypeEnum_UNSPECIFIED PriceExtensionTypeEnum_PriceExtensionType = 0
	// Used for return value only. Represents value unknown in this version.
	PriceExtensionTypeEnum_UNKNOWN PriceExtensionTypeEnum_PriceExtensionType = 1
	// The type for showing a list of brands.
	PriceExtensionTypeEnum_BRANDS PriceExtensionTypeEnum_PriceExtensionType = 2
	// The type for showing a list of events.
	PriceExtensionTypeEnum_EVENTS PriceExtensionTypeEnum_PriceExtensionType = 3
	// The type for showing locations relevant to your business.
	PriceExtensionTypeEnum_LOCATIONS PriceExtensionTypeEnum_PriceExtensionType = 4
	// The type for showing sub-regions or districts within a city or region.
	PriceExtensionTypeEnum_NEIGHBORHOODS PriceExtensionTypeEnum_PriceExtensionType = 5
	// The type for showing a collection of product categories.
	PriceExtensionTypeEnum_PRODUCT_CATEGORIES PriceExtensionTypeEnum_PriceExtensionType = 6
	// The type for showing a collection of related product tiers.
	PriceExtensionTypeEnum_PRODUCT_TIERS PriceExtensionTypeEnum_PriceExtensionType = 7
	// The type for showing a collection of services offered by your business.
	PriceExtensionTypeEnum_SERVICES PriceExtensionTypeEnum_PriceExtensionType = 8
	// The type for showing a collection of service categories.
	PriceExtensionTypeEnum_SERVICE_CATEGORIES PriceExtensionTypeEnum_PriceExtensionType = 9
	// The type for showing a collection of related service tiers.
	PriceExtensionTypeEnum_SERVICE_TIERS PriceExtensionTypeEnum_PriceExtensionType = 10
)

var PriceExtensionTypeEnum_PriceExtensionType_name = map[int32]string{
	0:  "UNSPECIFIED",
	1:  "UNKNOWN",
	2:  "BRANDS",
	3:  "EVENTS",
	4:  "LOCATIONS",
	5:  "NEIGHBORHOODS",
	6:  "PRODUCT_CATEGORIES",
	7:  "PRODUCT_TIERS",
	8:  "SERVICES",
	9:  "SERVICE_CATEGORIES",
	10: "SERVICE_TIERS",
}

var PriceExtensionTypeEnum_PriceExtensionType_value = map[string]int32{
	"UNSPECIFIED":        0,
	"UNKNOWN":            1,
	"BRANDS":             2,
	"EVENTS":             3,
	"LOCATIONS":          4,
	"NEIGHBORHOODS":      5,
	"PRODUCT_CATEGORIES": 6,
	"PRODUCT_TIERS":      7,
	"SERVICES":           8,
	"SERVICE_CATEGORIES": 9,
	"SERVICE_TIERS":      10,
}

func (x PriceExtensionTypeEnum_PriceExtensionType) String() string {
	return proto.EnumName(PriceExtensionTypeEnum_PriceExtensionType_name, int32(x))
}

func (PriceExtensionTypeEnum_PriceExtensionType) EnumDescriptor() ([]byte, []int) {
	return fileDescriptor_68854bbfc816b83c, []int{0, 0}
}

// Container for enum describing types for a price extension.
type PriceExtensionTypeEnum struct {
	XXX_NoUnkeyedLiteral struct{} `json:"-"`
	XXX_unrecognized     []byte   `json:"-"`
	XXX_sizecache        int32    `json:"-"`
}

func (m *PriceExtensionTypeEnum) Reset()         { *m = PriceExtensionTypeEnum{} }
func (m *PriceExtensionTypeEnum) String() string { return proto.CompactTextString(m) }
func (*PriceExtensionTypeEnum) ProtoMessage()    {}
func (*PriceExtensionTypeEnum) Descriptor() ([]byte, []int) {
	return fileDescriptor_68854bbfc816b83c, []int{0}
}

func (m *PriceExtensionTypeEnum) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_PriceExtensionTypeEnum.Unmarshal(m, b)
}
func (m *PriceExtensionTypeEnum) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_PriceExtensionTypeEnum.Marshal(b, m, deterministic)
}
func (m *PriceExtensionTypeEnum) XXX_Merge(src proto.Message) {
	xxx_messageInfo_PriceExtensionTypeEnum.Merge(m, src)
}
func (m *PriceExtensionTypeEnum) XXX_Size() int {
	return xxx_messageInfo_PriceExtensionTypeEnum.Size(m)
}
func (m *PriceExtensionTypeEnum) XXX_DiscardUnknown() {
	xxx_messageInfo_PriceExtensionTypeEnum.DiscardUnknown(m)
}

var xxx_messageInfo_PriceExtensionTypeEnum proto.InternalMessageInfo

func init() {
	proto.RegisterEnum("google.ads.googleads.v1.enums.PriceExtensionTypeEnum_PriceExtensionType", PriceExtensionTypeEnum_PriceExtensionType_name, PriceExtensionTypeEnum_PriceExtensionType_value)
	proto.RegisterType((*PriceExtensionTypeEnum)(nil), "google.ads.googleads.v1.enums.PriceExtensionTypeEnum")
}

func init() {
	proto.RegisterFile("google/ads/googleads/v1/enums/price_extension_type.proto", fileDescriptor_68854bbfc816b83c)
}

var fileDescriptor_68854bbfc816b83c = []byte{
	// 394 bytes of a gzipped FileDescriptorProto
	0x1f, 0x8b, 0x08, 0x00, 0x00, 0x00, 0x00, 0x00, 0x02, 0xff, 0x7c, 0x91, 0xd1, 0x6a, 0xd4, 0x40,
	0x18, 0x85, 0xcd, 0x56, 0xb7, 0xed, 0xd4, 0xe2, 0x38, 0x17, 0x15, 0xc4, 0x5e, 0xb4, 0x0f, 0x30,
	0x21, 0x78, 0x23, 0xe3, 0xd5, 0x24, 0x19, 0xd3, 0xa0, 0xcc, 0x84, 0x4c, 0x36, 0x82, 0x04, 0x96,
	0xd8, 0x0c, 0x21, 0xd0, 0x9d, 0x09, 0x3b, 0x69, 0xb1, 0xaf, 0xe3, 0xa5, 0x8f, 0xe2, 0x95, 0xcf,
	0xa1, 0x3e, 0x84, 0x4c, 0xd2, 0x2c, 0xc2, 0xa2, 0x37, 0xe1, 0xe4, 0xff, 0xcf, 0x77, 0x48, 0xce,
	0x0f, 0xde, 0xb4, 0xc6, 0xb4, 0x37, 0xca, 0xaf, 0x1b, 0xeb, 0x4f, 0xd2, 0xa9, 0xbb, 0xc0, 0x57,
	0xfa, 0x76, 0x63, 0xfd, 0x7e, 0xdb, 0x5d, 0xab, 0xb5, 0xfa, 0x32, 0x28, 0x6d, 0x3b, 0xa3, 0xd7,
	0xc3, 0x7d, 0xaf, 0x70, 0xbf, 0x35, 0x83, 0x41, 0xe7, 0x93, 0x1d, 0xd7, 0x8d, 0xc5, 0x3b, 0x12,
	0xdf, 0x05, 0x78, 0x24, 0x5f, 0xbe, 0x9a, 0x83, 0xfb, 0xce, 0xaf, 0xb5, 0x36, 0x43, 0x3d, 0x74,
	0x46, 0xdb, 0x09, 0xbe, 0xfc, 0xe5, 0x81, 0xb3, 0xcc, 0x65, 0xb3, 0x39, 0xba, 0xb8, 0xef, 0x15,
	0xd3, 0xb7, 0x9b, 0xcb, 0x1f, 0x1e, 0x40, 0xfb, 0x2b, 0xf4, 0x0c, 0x9c, 0xac, 0xb8, 0xcc, 0x58,
	0x94, 0xbe, 0x4b, 0x59, 0x0c, 0x1f, 0xa1, 0x13, 0x70, 0xb8, 0xe2, 0xef, 0xb9, 0xf8, 0xc8, 0xa1,
	0x87, 0x00, 0x58, 0x86, 0x39, 0xe5, 0xb1, 0x84, 0x0b, 0xa7, 0x59, 0xc9, 0x78, 0x21, 0xe1, 0x01,
	0x3a, 0x05, 0xc7, 0x1f, 0x44, 0x44, 0x8b, 0x54, 0x70, 0x09, 0x1f, 0xa3, 0xe7, 0xe0, 0x94, 0xb3,
	0x34, 0xb9, 0x0a, 0x45, 0x7e, 0x25, 0x44, 0x2c, 0xe1, 0x13, 0x74, 0x06, 0x50, 0x96, 0x8b, 0x78,
	0x15, 0x15, 0xeb, 0x88, 0x16, 0x2c, 0x11, 0x79, 0xca, 0x24, 0x5c, 0x3a, 0xeb, 0x3c, 0x2f, 0x52,
	0x96, 0x4b, 0x78, 0x88, 0x9e, 0x82, 0x23, 0xc9, 0xf2, 0x32, 0x8d, 0x98, 0x84, 0x47, 0x0e, 0x7c,
	0x78, 0xfb, 0x1b, 0x3c, 0x76, 0xe0, 0x3c, 0x9f, 0x40, 0x10, 0xfe, 0xf6, 0xc0, 0xc5, 0xb5, 0xd9,
	0xe0, 0xff, 0x36, 0x16, 0xbe, 0xd8, 0xff, 0xeb, 0xcc, 0x95, 0x95, 0x79, 0x9f, 0xc2, 0x07, 0xb2,
	0x35, 0x37, 0xb5, 0x6e, 0xb1, 0xd9, 0xb6, 0x7e, 0xab, 0xf4, 0x58, 0xe5, 0x7c, 0xb5, 0xbe, 0xb3,
	0xff, 0x38, 0xe2, 0xdb, 0xf1, 0xf9, 0x75, 0x71, 0x90, 0x50, 0xfa, 0x6d, 0x71, 0x9e, 0x4c, 0x51,
	0xb4, 0xb1, 0x78, 0x92, 0x4e, 0x95, 0x01, 0x76, 0xe5, 0xdb, 0xef, 0xf3, 0xbe, 0xa2, 0x8d, 0xad,
	0x76, 0xfb, 0xaa, 0x0c, 0xaa, 0x71, 0xff, 0x73, 0x71, 0x31, 0x0d, 0x09, 0xa1, 0x8d, 0x25, 0x64,
	0xe7, 0x20, 0xa4, 0x0c, 0x08, 0x19, 0x3d, 0x9f, 0x97, 0xe3, 0x87, 0xbd, 0xfe, 0x13, 0x00, 0x00,
	0xff, 0xff, 0x6b, 0x1c, 0x5f, 0xce, 0x5c, 0x02, 0x00, 0x00,
}
