// Code generated by protoc-gen-go. DO NOT EDIT.
// source: google/cloud/automl/v1beta1/regression.proto

package automl

import (
	fmt "fmt"
	math "math"

	proto "github.com/golang/protobuf/proto"
	_ "google.golang.org/genproto/googleapis/api/annotations"
)

// Reference imports to suppress errors if they are not otherwise used.
var _ = proto.Marshal
var _ = fmt.Errorf
var _ = math.Inf

// This is a compile-time assertion to ensure that this generated file
// is compatible with the proto package it is being compiled against.
// A compilation error at this line likely means your copy of the
// proto package needs to be updated.
const _ = proto.ProtoPackageIsVersion3 // please upgrade the proto package

// Metrics for regression problems.
type RegressionEvaluationMetrics struct {
	// Output only. Root Mean Squared Error (RMSE).
	RootMeanSquaredError float32 `protobuf:"fixed32,1,opt,name=root_mean_squared_error,json=rootMeanSquaredError,proto3" json:"root_mean_squared_error,omitempty"`
	// Output only. Mean Absolute Error (MAE).
	MeanAbsoluteError float32 `protobuf:"fixed32,2,opt,name=mean_absolute_error,json=meanAbsoluteError,proto3" json:"mean_absolute_error,omitempty"`
	// Output only. Mean absolute percentage error. Only set if all ground truth
	// values are are positive.
	MeanAbsolutePercentageError float32 `protobuf:"fixed32,3,opt,name=mean_absolute_percentage_error,json=meanAbsolutePercentageError,proto3" json:"mean_absolute_percentage_error,omitempty"`
	// Output only. R squared.
	RSquared float32 `protobuf:"fixed32,4,opt,name=r_squared,json=rSquared,proto3" json:"r_squared,omitempty"`
	// Output only. Root mean squared log error.
	RootMeanSquaredLogError float32  `protobuf:"fixed32,5,opt,name=root_mean_squared_log_error,json=rootMeanSquaredLogError,proto3" json:"root_mean_squared_log_error,omitempty"`
	XXX_NoUnkeyedLiteral    struct{} `json:"-"`
	XXX_unrecognized        []byte   `json:"-"`
	XXX_sizecache           int32    `json:"-"`
}

func (m *RegressionEvaluationMetrics) Reset()         { *m = RegressionEvaluationMetrics{} }
func (m *RegressionEvaluationMetrics) String() string { return proto.CompactTextString(m) }
func (*RegressionEvaluationMetrics) ProtoMessage()    {}
func (*RegressionEvaluationMetrics) Descriptor() ([]byte, []int) {
	return fileDescriptor_b0fa6250b0d4b440, []int{0}
}

func (m *RegressionEvaluationMetrics) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_RegressionEvaluationMetrics.Unmarshal(m, b)
}
func (m *RegressionEvaluationMetrics) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_RegressionEvaluationMetrics.Marshal(b, m, deterministic)
}
func (m *RegressionEvaluationMetrics) XXX_Merge(src proto.Message) {
	xxx_messageInfo_RegressionEvaluationMetrics.Merge(m, src)
}
func (m *RegressionEvaluationMetrics) XXX_Size() int {
	return xxx_messageInfo_RegressionEvaluationMetrics.Size(m)
}
func (m *RegressionEvaluationMetrics) XXX_DiscardUnknown() {
	xxx_messageInfo_RegressionEvaluationMetrics.DiscardUnknown(m)
}

var xxx_messageInfo_RegressionEvaluationMetrics proto.InternalMessageInfo

func (m *RegressionEvaluationMetrics) GetRootMeanSquaredError() float32 {
	if m != nil {
		return m.RootMeanSquaredError
	}
	return 0
}

func (m *RegressionEvaluationMetrics) GetMeanAbsoluteError() float32 {
	if m != nil {
		return m.MeanAbsoluteError
	}
	return 0
}

func (m *RegressionEvaluationMetrics) GetMeanAbsolutePercentageError() float32 {
	if m != nil {
		return m.MeanAbsolutePercentageError
	}
	return 0
}

func (m *RegressionEvaluationMetrics) GetRSquared() float32 {
	if m != nil {
		return m.RSquared
	}
	return 0
}

func (m *RegressionEvaluationMetrics) GetRootMeanSquaredLogError() float32 {
	if m != nil {
		return m.RootMeanSquaredLogError
	}
	return 0
}

func init() {
	proto.RegisterType((*RegressionEvaluationMetrics)(nil), "google.cloud.automl.v1beta1.RegressionEvaluationMetrics")
}

func init() {
	proto.RegisterFile("google/cloud/automl/v1beta1/regression.proto", fileDescriptor_b0fa6250b0d4b440)
}

var fileDescriptor_b0fa6250b0d4b440 = []byte{
	// 337 bytes of a gzipped FileDescriptorProto
	0x1f, 0x8b, 0x08, 0x00, 0x00, 0x00, 0x00, 0x00, 0x02, 0xff, 0x7c, 0x91, 0xcd, 0x4a, 0x03, 0x31,
	0x14, 0x85, 0xe9, 0xf8, 0x83, 0x66, 0x23, 0x8e, 0x42, 0x8b, 0x23, 0x55, 0x5c, 0xb9, 0x90, 0x09,
	0x45, 0xdc, 0x8c, 0x6e, 0xda, 0x52, 0xdc, 0xb4, 0x50, 0x2a, 0xb8, 0x90, 0x42, 0x49, 0xa7, 0x21,
	0x0c, 0xa4, 0xb9, 0xe3, 0x4d, 0xa6, 0x4f, 0xe4, 0x23, 0xf8, 0x14, 0x3e, 0x8a, 0x4f, 0x21, 0x73,
	0x93, 0xd6, 0x5f, 0x5c, 0x0e, 0xdf, 0x77, 0xce, 0x24, 0x27, 0xec, 0x4a, 0x01, 0x28, 0x2d, 0x79,
	0xae, 0xa1, 0x5a, 0x70, 0x51, 0x39, 0x58, 0x6a, 0xbe, 0xea, 0xcc, 0xa5, 0x13, 0x1d, 0x8e, 0x52,
	0xa1, 0xb4, 0xb6, 0x00, 0x93, 0x96, 0x08, 0x0e, 0xe2, 0xc4, 0xdb, 0x29, 0xd9, 0xa9, 0xb7, 0xd3,
	0x60, 0x9f, 0x9c, 0x86, 0x2a, 0x51, 0x16, 0x5c, 0x18, 0x03, 0x4e, 0xb8, 0x02, 0x8c, 0xf5, 0xd1,
	0x8b, 0x97, 0x88, 0x25, 0x93, 0x4d, 0xdf, 0x60, 0x25, 0x74, 0x45, 0x7c, 0x24, 0x1d, 0x16, 0xb9,
	0x8d, 0x6f, 0x58, 0x13, 0x01, 0xdc, 0x6c, 0x29, 0x85, 0x99, 0xd9, 0xe7, 0x4a, 0xa0, 0x5c, 0xcc,
	0x24, 0x22, 0x60, 0xab, 0x71, 0xde, 0xb8, 0x8c, 0x26, 0xc7, 0x35, 0x1e, 0x49, 0x61, 0x1e, 0x3c,
	0x1c, 0xd4, 0x2c, 0x4e, 0xd9, 0x11, 0x25, 0xc4, 0xdc, 0x82, 0xae, 0x9c, 0x0c, 0x91, 0x88, 0x22,
	0x87, 0x35, 0xea, 0x06, 0xe2, 0xfd, 0x3e, 0x6b, 0x7f, 0xf7, 0x4b, 0x89, 0xb9, 0x34, 0x4e, 0xa8,
	0x75, 0x74, 0x8b, 0xa2, 0xc9, 0xd7, 0xe8, 0x78, 0xe3, 0xf8, 0x92, 0x84, 0xed, 0xe3, 0xfa, 0x8c,
	0xad, 0x6d, 0xf2, 0xf7, 0x30, 0x1c, 0x2b, 0xbe, 0x63, 0xc9, 0xef, 0x8b, 0x68, 0x50, 0xa1, 0x7e,
	0x87, 0xf4, 0xe6, 0x8f, 0xcb, 0x0c, 0x41, 0x51, 0x75, 0xef, 0xb5, 0xc1, 0xce, 0x72, 0x58, 0xa6,
	0xff, 0x0c, 0xdd, 0x3b, 0xf8, 0xdc, 0x71, 0x5c, 0x6f, 0xfb, 0xd4, 0x0d, 0xb6, 0x02, 0x2d, 0x8c,
	0x4a, 0x01, 0x15, 0x57, 0xd2, 0xd0, 0xee, 0xdc, 0x23, 0x51, 0x16, 0xf6, 0xcf, 0x37, 0xbe, 0xf5,
	0x9f, 0x6f, 0x51, 0x72, 0x4f, 0xe2, 0xb4, 0x5f, 0x4b, 0xd3, 0x6e, 0xe5, 0x60, 0xa4, 0xa7, 0x8f,
	0x5e, 0x7a, 0x8f, 0xda, 0x9e, 0x66, 0x19, 0xe1, 0x2c, 0x23, 0x3e, 0xcc, 0xb2, 0x20, 0xcc, 0x77,
	0xe9, 0x67, 0xd7, 0x1f, 0x01, 0x00, 0x00, 0xff, 0xff, 0x55, 0x43, 0xc7, 0x17, 0x4f, 0x02, 0x00,
	0x00,
}
