// Code generated by protoc-gen-go. DO NOT EDIT.
// source: google/ads/googleads/v2/common/extensions.proto

package common

import (
	fmt "fmt"
	math "math"

	proto "github.com/golang/protobuf/proto"
	wrappers "github.com/golang/protobuf/ptypes/wrappers"
	enums "google.golang.org/genproto/googleapis/ads/googleads/v2/enums"
	_ "google.golang.org/genproto/googleapis/api/annotations"
)

// Reference imports to suppress errors if they are not otherwise used.
var _ = proto.Marshal
var _ = fmt.Errorf
var _ = math.Inf

// This is a compile-time assertion to ensure that this generated file
// is compatible with the proto package it is being compiled against.
// A compilation error at this line likely means your copy of the
// proto package needs to be updated.
const _ = proto.ProtoPackageIsVersion3 // please upgrade the proto package

// Represents an App extension.
type AppFeedItem struct {
	// The visible text displayed when the link is rendered in an ad.
	// This string must not be empty, and the length of this string should
	// be between 1 and 25, inclusive.
	LinkText *wrappers.StringValue `protobuf:"bytes,1,opt,name=link_text,json=linkText,proto3" json:"link_text,omitempty"`
	// The store-specific ID for the target application.
	// This string must not be empty.
	AppId *wrappers.StringValue `protobuf:"bytes,2,opt,name=app_id,json=appId,proto3" json:"app_id,omitempty"`
	// The application store that the target application belongs to.
	// This field is required.
	AppStore enums.AppStoreEnum_AppStore `protobuf:"varint,3,opt,name=app_store,json=appStore,proto3,enum=google.ads.googleads.v2.enums.AppStoreEnum_AppStore" json:"app_store,omitempty"`
	// A list of possible final URLs after all cross domain redirects.
	// This list must not be empty.
	FinalUrls []*wrappers.StringValue `protobuf:"bytes,4,rep,name=final_urls,json=finalUrls,proto3" json:"final_urls,omitempty"`
	// A list of possible final mobile URLs after all cross domain redirects.
	FinalMobileUrls []*wrappers.StringValue `protobuf:"bytes,5,rep,name=final_mobile_urls,json=finalMobileUrls,proto3" json:"final_mobile_urls,omitempty"`
	// URL template for constructing a tracking URL. Default value is "{lpurl}".
	TrackingUrlTemplate *wrappers.StringValue `protobuf:"bytes,6,opt,name=tracking_url_template,json=trackingUrlTemplate,proto3" json:"tracking_url_template,omitempty"`
	// A list of mappings to be used for substituting URL custom parameter tags in
	// the tracking_url_template, final_urls, and/or final_mobile_urls.
	UrlCustomParameters []*CustomParameter `protobuf:"bytes,7,rep,name=url_custom_parameters,json=urlCustomParameters,proto3" json:"url_custom_parameters,omitempty"`
	// URL template for appending params to landing page URLs served with parallel
	// tracking.
	FinalUrlSuffix       *wrappers.StringValue `protobuf:"bytes,8,opt,name=final_url_suffix,json=finalUrlSuffix,proto3" json:"final_url_suffix,omitempty"`
	XXX_NoUnkeyedLiteral struct{}              `json:"-"`
	XXX_unrecognized     []byte                `json:"-"`
	XXX_sizecache        int32                 `json:"-"`
}

func (m *AppFeedItem) Reset()         { *m = AppFeedItem{} }
func (m *AppFeedItem) String() string { return proto.CompactTextString(m) }
func (*AppFeedItem) ProtoMessage()    {}
func (*AppFeedItem) Descriptor() ([]byte, []int) {
	return fileDescriptor_1279b497763ecdff, []int{0}
}

func (m *AppFeedItem) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_AppFeedItem.Unmarshal(m, b)
}
func (m *AppFeedItem) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_AppFeedItem.Marshal(b, m, deterministic)
}
func (m *AppFeedItem) XXX_Merge(src proto.Message) {
	xxx_messageInfo_AppFeedItem.Merge(m, src)
}
func (m *AppFeedItem) XXX_Size() int {
	return xxx_messageInfo_AppFeedItem.Size(m)
}
func (m *AppFeedItem) XXX_DiscardUnknown() {
	xxx_messageInfo_AppFeedItem.DiscardUnknown(m)
}

var xxx_messageInfo_AppFeedItem proto.InternalMessageInfo

func (m *AppFeedItem) GetLinkText() *wrappers.StringValue {
	if m != nil {
		return m.LinkText
	}
	return nil
}

func (m *AppFeedItem) GetAppId() *wrappers.StringValue {
	if m != nil {
		return m.AppId
	}
	return nil
}

func (m *AppFeedItem) GetAppStore() enums.AppStoreEnum_AppStore {
	if m != nil {
		return m.AppStore
	}
	return enums.AppStoreEnum_UNSPECIFIED
}

func (m *AppFeedItem) GetFinalUrls() []*wrappers.StringValue {
	if m != nil {
		return m.FinalUrls
	}
	return nil
}

func (m *AppFeedItem) GetFinalMobileUrls() []*wrappers.StringValue {
	if m != nil {
		return m.FinalMobileUrls
	}
	return nil
}

func (m *AppFeedItem) GetTrackingUrlTemplate() *wrappers.StringValue {
	if m != nil {
		return m.TrackingUrlTemplate
	}
	return nil
}

func (m *AppFeedItem) GetUrlCustomParameters() []*CustomParameter {
	if m != nil {
		return m.UrlCustomParameters
	}
	return nil
}

func (m *AppFeedItem) GetFinalUrlSuffix() *wrappers.StringValue {
	if m != nil {
		return m.FinalUrlSuffix
	}
	return nil
}

// Represents a Call extension.
type CallFeedItem struct {
	// The advertiser's phone number to append to the ad.
	// This string must not be empty.
	PhoneNumber *wrappers.StringValue `protobuf:"bytes,1,opt,name=phone_number,json=phoneNumber,proto3" json:"phone_number,omitempty"`
	// Uppercase two-letter country code of the advertiser's phone number.
	// This string must not be empty.
	CountryCode *wrappers.StringValue `protobuf:"bytes,2,opt,name=country_code,json=countryCode,proto3" json:"country_code,omitempty"`
	// Indicates whether call tracking is enabled. By default, call tracking is
	// not enabled.
	CallTrackingEnabled *wrappers.BoolValue `protobuf:"bytes,3,opt,name=call_tracking_enabled,json=callTrackingEnabled,proto3" json:"call_tracking_enabled,omitempty"`
	// The conversion action to attribute a call conversion to. If not set a
	// default conversion action is used. This field only has effect if
	// call_tracking_enabled is set to true. Otherwise this field is ignored.
	CallConversionAction *wrappers.StringValue `protobuf:"bytes,4,opt,name=call_conversion_action,json=callConversionAction,proto3" json:"call_conversion_action,omitempty"`
	// If true, disable call conversion tracking. call_conversion_action should
	// not be set if this is true. Optional.
	CallConversionTrackingDisabled *wrappers.BoolValue `protobuf:"bytes,5,opt,name=call_conversion_tracking_disabled,json=callConversionTrackingDisabled,proto3" json:"call_conversion_tracking_disabled,omitempty"`
	// Enum value that indicates whether this call extension uses its own call
	// conversion setting (or just have call conversion disabled), or following
	// the account level setting.
	CallConversionReportingState enums.CallConversionReportingStateEnum_CallConversionReportingState `protobuf:"varint,6,opt,name=call_conversion_reporting_state,json=callConversionReportingState,proto3,enum=google.ads.googleads.v2.enums.CallConversionReportingStateEnum_CallConversionReportingState" json:"call_conversion_reporting_state,omitempty"`
	XXX_NoUnkeyedLiteral         struct{}                                                            `json:"-"`
	XXX_unrecognized             []byte                                                              `json:"-"`
	XXX_sizecache                int32                                                               `json:"-"`
}

func (m *CallFeedItem) Reset()         { *m = CallFeedItem{} }
func (m *CallFeedItem) String() string { return proto.CompactTextString(m) }
func (*CallFeedItem) ProtoMessage()    {}
func (*CallFeedItem) Descriptor() ([]byte, []int) {
	return fileDescriptor_1279b497763ecdff, []int{1}
}

func (m *CallFeedItem) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_CallFeedItem.Unmarshal(m, b)
}
func (m *CallFeedItem) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_CallFeedItem.Marshal(b, m, deterministic)
}
func (m *CallFeedItem) XXX_Merge(src proto.Message) {
	xxx_messageInfo_CallFeedItem.Merge(m, src)
}
func (m *CallFeedItem) XXX_Size() int {
	return xxx_messageInfo_CallFeedItem.Size(m)
}
func (m *CallFeedItem) XXX_DiscardUnknown() {
	xxx_messageInfo_CallFeedItem.DiscardUnknown(m)
}

var xxx_messageInfo_CallFeedItem proto.InternalMessageInfo

func (m *CallFeedItem) GetPhoneNumber() *wrappers.StringValue {
	if m != nil {
		return m.PhoneNumber
	}
	return nil
}

func (m *CallFeedItem) GetCountryCode() *wrappers.StringValue {
	if m != nil {
		return m.CountryCode
	}
	return nil
}

func (m *CallFeedItem) GetCallTrackingEnabled() *wrappers.BoolValue {
	if m != nil {
		return m.CallTrackingEnabled
	}
	return nil
}

func (m *CallFeedItem) GetCallConversionAction() *wrappers.StringValue {
	if m != nil {
		return m.CallConversionAction
	}
	return nil
}

func (m *CallFeedItem) GetCallConversionTrackingDisabled() *wrappers.BoolValue {
	if m != nil {
		return m.CallConversionTrackingDisabled
	}
	return nil
}

func (m *CallFeedItem) GetCallConversionReportingState() enums.CallConversionReportingStateEnum_CallConversionReportingState {
	if m != nil {
		return m.CallConversionReportingState
	}
	return enums.CallConversionReportingStateEnum_UNSPECIFIED
}

// Represents a callout extension.
type CalloutFeedItem struct {
	// The callout text.
	// The length of this string should be between 1 and 25, inclusive.
	CalloutText          *wrappers.StringValue `protobuf:"bytes,1,opt,name=callout_text,json=calloutText,proto3" json:"callout_text,omitempty"`
	XXX_NoUnkeyedLiteral struct{}              `json:"-"`
	XXX_unrecognized     []byte                `json:"-"`
	XXX_sizecache        int32                 `json:"-"`
}

func (m *CalloutFeedItem) Reset()         { *m = CalloutFeedItem{} }
func (m *CalloutFeedItem) String() string { return proto.CompactTextString(m) }
func (*CalloutFeedItem) ProtoMessage()    {}
func (*CalloutFeedItem) Descriptor() ([]byte, []int) {
	return fileDescriptor_1279b497763ecdff, []int{2}
}

func (m *CalloutFeedItem) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_CalloutFeedItem.Unmarshal(m, b)
}
func (m *CalloutFeedItem) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_CalloutFeedItem.Marshal(b, m, deterministic)
}
func (m *CalloutFeedItem) XXX_Merge(src proto.Message) {
	xxx_messageInfo_CalloutFeedItem.Merge(m, src)
}
func (m *CalloutFeedItem) XXX_Size() int {
	return xxx_messageInfo_CalloutFeedItem.Size(m)
}
func (m *CalloutFeedItem) XXX_DiscardUnknown() {
	xxx_messageInfo_CalloutFeedItem.DiscardUnknown(m)
}

var xxx_messageInfo_CalloutFeedItem proto.InternalMessageInfo

func (m *CalloutFeedItem) GetCalloutText() *wrappers.StringValue {
	if m != nil {
		return m.CalloutText
	}
	return nil
}

// Represents a location extension.
type LocationFeedItem struct {
	// The name of the business.
	BusinessName *wrappers.StringValue `protobuf:"bytes,1,opt,name=business_name,json=businessName,proto3" json:"business_name,omitempty"`
	// Line 1 of the business address.
	AddressLine_1 *wrappers.StringValue `protobuf:"bytes,2,opt,name=address_line_1,json=addressLine1,proto3" json:"address_line_1,omitempty"`
	// Line 2 of the business address.
	AddressLine_2 *wrappers.StringValue `protobuf:"bytes,3,opt,name=address_line_2,json=addressLine2,proto3" json:"address_line_2,omitempty"`
	// City of the business address.
	City *wrappers.StringValue `protobuf:"bytes,4,opt,name=city,proto3" json:"city,omitempty"`
	// Province of the business address.
	Province *wrappers.StringValue `protobuf:"bytes,5,opt,name=province,proto3" json:"province,omitempty"`
	// Postal code of the business address.
	PostalCode *wrappers.StringValue `protobuf:"bytes,6,opt,name=postal_code,json=postalCode,proto3" json:"postal_code,omitempty"`
	// Country code of the business address.
	CountryCode *wrappers.StringValue `protobuf:"bytes,7,opt,name=country_code,json=countryCode,proto3" json:"country_code,omitempty"`
	// Phone number of the business.
	PhoneNumber          *wrappers.StringValue `protobuf:"bytes,8,opt,name=phone_number,json=phoneNumber,proto3" json:"phone_number,omitempty"`
	XXX_NoUnkeyedLiteral struct{}              `json:"-"`
	XXX_unrecognized     []byte                `json:"-"`
	XXX_sizecache        int32                 `json:"-"`
}

func (m *LocationFeedItem) Reset()         { *m = LocationFeedItem{} }
func (m *LocationFeedItem) String() string { return proto.CompactTextString(m) }
func (*LocationFeedItem) ProtoMessage()    {}
func (*LocationFeedItem) Descriptor() ([]byte, []int) {
	return fileDescriptor_1279b497763ecdff, []int{3}
}

func (m *LocationFeedItem) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_LocationFeedItem.Unmarshal(m, b)
}
func (m *LocationFeedItem) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_LocationFeedItem.Marshal(b, m, deterministic)
}
func (m *LocationFeedItem) XXX_Merge(src proto.Message) {
	xxx_messageInfo_LocationFeedItem.Merge(m, src)
}
func (m *LocationFeedItem) XXX_Size() int {
	return xxx_messageInfo_LocationFeedItem.Size(m)
}
func (m *LocationFeedItem) XXX_DiscardUnknown() {
	xxx_messageInfo_LocationFeedItem.DiscardUnknown(m)
}

var xxx_messageInfo_LocationFeedItem proto.InternalMessageInfo

func (m *LocationFeedItem) GetBusinessName() *wrappers.StringValue {
	if m != nil {
		return m.BusinessName
	}
	return nil
}

func (m *LocationFeedItem) GetAddressLine_1() *wrappers.StringValue {
	if m != nil {
		return m.AddressLine_1
	}
	return nil
}

func (m *LocationFeedItem) GetAddressLine_2() *wrappers.StringValue {
	if m != nil {
		return m.AddressLine_2
	}
	return nil
}

func (m *LocationFeedItem) GetCity() *wrappers.StringValue {
	if m != nil {
		return m.City
	}
	return nil
}

func (m *LocationFeedItem) GetProvince() *wrappers.StringValue {
	if m != nil {
		return m.Province
	}
	return nil
}

func (m *LocationFeedItem) GetPostalCode() *wrappers.StringValue {
	if m != nil {
		return m.PostalCode
	}
	return nil
}

func (m *LocationFeedItem) GetCountryCode() *wrappers.StringValue {
	if m != nil {
		return m.CountryCode
	}
	return nil
}

func (m *LocationFeedItem) GetPhoneNumber() *wrappers.StringValue {
	if m != nil {
		return m.PhoneNumber
	}
	return nil
}

// Represents an affiliate location extension.
type AffiliateLocationFeedItem struct {
	// The name of the business.
	BusinessName *wrappers.StringValue `protobuf:"bytes,1,opt,name=business_name,json=businessName,proto3" json:"business_name,omitempty"`
	// Line 1 of the business address.
	AddressLine_1 *wrappers.StringValue `protobuf:"bytes,2,opt,name=address_line_1,json=addressLine1,proto3" json:"address_line_1,omitempty"`
	// Line 2 of the business address.
	AddressLine_2 *wrappers.StringValue `protobuf:"bytes,3,opt,name=address_line_2,json=addressLine2,proto3" json:"address_line_2,omitempty"`
	// City of the business address.
	City *wrappers.StringValue `protobuf:"bytes,4,opt,name=city,proto3" json:"city,omitempty"`
	// Province of the business address.
	Province *wrappers.StringValue `protobuf:"bytes,5,opt,name=province,proto3" json:"province,omitempty"`
	// Postal code of the business address.
	PostalCode *wrappers.StringValue `protobuf:"bytes,6,opt,name=postal_code,json=postalCode,proto3" json:"postal_code,omitempty"`
	// Country code of the business address.
	CountryCode *wrappers.StringValue `protobuf:"bytes,7,opt,name=country_code,json=countryCode,proto3" json:"country_code,omitempty"`
	// Phone number of the business.
	PhoneNumber *wrappers.StringValue `protobuf:"bytes,8,opt,name=phone_number,json=phoneNumber,proto3" json:"phone_number,omitempty"`
	// Id of the retail chain that is advertised as a seller of your product.
	ChainId *wrappers.Int64Value `protobuf:"bytes,9,opt,name=chain_id,json=chainId,proto3" json:"chain_id,omitempty"`
	// Name of chain.
	ChainName            *wrappers.StringValue `protobuf:"bytes,10,opt,name=chain_name,json=chainName,proto3" json:"chain_name,omitempty"`
	XXX_NoUnkeyedLiteral struct{}              `json:"-"`
	XXX_unrecognized     []byte                `json:"-"`
	XXX_sizecache        int32                 `json:"-"`
}

func (m *AffiliateLocationFeedItem) Reset()         { *m = AffiliateLocationFeedItem{} }
func (m *AffiliateLocationFeedItem) String() string { return proto.CompactTextString(m) }
func (*AffiliateLocationFeedItem) ProtoMessage()    {}
func (*AffiliateLocationFeedItem) Descriptor() ([]byte, []int) {
	return fileDescriptor_1279b497763ecdff, []int{4}
}

func (m *AffiliateLocationFeedItem) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_AffiliateLocationFeedItem.Unmarshal(m, b)
}
func (m *AffiliateLocationFeedItem) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_AffiliateLocationFeedItem.Marshal(b, m, deterministic)
}
func (m *AffiliateLocationFeedItem) XXX_Merge(src proto.Message) {
	xxx_messageInfo_AffiliateLocationFeedItem.Merge(m, src)
}
func (m *AffiliateLocationFeedItem) XXX_Size() int {
	return xxx_messageInfo_AffiliateLocationFeedItem.Size(m)
}
func (m *AffiliateLocationFeedItem) XXX_DiscardUnknown() {
	xxx_messageInfo_AffiliateLocationFeedItem.DiscardUnknown(m)
}

var xxx_messageInfo_AffiliateLocationFeedItem proto.InternalMessageInfo

func (m *AffiliateLocationFeedItem) GetBusinessName() *wrappers.StringValue {
	if m != nil {
		return m.BusinessName
	}
	return nil
}

func (m *AffiliateLocationFeedItem) GetAddressLine_1() *wrappers.StringValue {
	if m != nil {
		return m.AddressLine_1
	}
	return nil
}

func (m *AffiliateLocationFeedItem) GetAddressLine_2() *wrappers.StringValue {
	if m != nil {
		return m.AddressLine_2
	}
	return nil
}

func (m *AffiliateLocationFeedItem) GetCity() *wrappers.StringValue {
	if m != nil {
		return m.City
	}
	return nil
}

func (m *AffiliateLocationFeedItem) GetProvince() *wrappers.StringValue {
	if m != nil {
		return m.Province
	}
	return nil
}

func (m *AffiliateLocationFeedItem) GetPostalCode() *wrappers.StringValue {
	if m != nil {
		return m.PostalCode
	}
	return nil
}

func (m *AffiliateLocationFeedItem) GetCountryCode() *wrappers.StringValue {
	if m != nil {
		return m.CountryCode
	}
	return nil
}

func (m *AffiliateLocationFeedItem) GetPhoneNumber() *wrappers.StringValue {
	if m != nil {
		return m.PhoneNumber
	}
	return nil
}

func (m *AffiliateLocationFeedItem) GetChainId() *wrappers.Int64Value {
	if m != nil {
		return m.ChainId
	}
	return nil
}

func (m *AffiliateLocationFeedItem) GetChainName() *wrappers.StringValue {
	if m != nil {
		return m.ChainName
	}
	return nil
}

// An extension that users can click on to send a text message to the
// advertiser.
type TextMessageFeedItem struct {
	// The business name to prepend to the message text.
	// This field is required.
	BusinessName *wrappers.StringValue `protobuf:"bytes,1,opt,name=business_name,json=businessName,proto3" json:"business_name,omitempty"`
	// Uppercase two-letter country code of the advertiser's phone number.
	// This field is required.
	CountryCode *wrappers.StringValue `protobuf:"bytes,2,opt,name=country_code,json=countryCode,proto3" json:"country_code,omitempty"`
	// The advertiser's phone number the message will be sent to. Required.
	PhoneNumber *wrappers.StringValue `protobuf:"bytes,3,opt,name=phone_number,json=phoneNumber,proto3" json:"phone_number,omitempty"`
	// The text to show in the ad.
	// This field is required.
	Text *wrappers.StringValue `protobuf:"bytes,4,opt,name=text,proto3" json:"text,omitempty"`
	// The message text populated in the messaging app.
	ExtensionText        *wrappers.StringValue `protobuf:"bytes,5,opt,name=extension_text,json=extensionText,proto3" json:"extension_text,omitempty"`
	XXX_NoUnkeyedLiteral struct{}              `json:"-"`
	XXX_unrecognized     []byte                `json:"-"`
	XXX_sizecache        int32                 `json:"-"`
}

func (m *TextMessageFeedItem) Reset()         { *m = TextMessageFeedItem{} }
func (m *TextMessageFeedItem) String() string { return proto.CompactTextString(m) }
func (*TextMessageFeedItem) ProtoMessage()    {}
func (*TextMessageFeedItem) Descriptor() ([]byte, []int) {
	return fileDescriptor_1279b497763ecdff, []int{5}
}

func (m *TextMessageFeedItem) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_TextMessageFeedItem.Unmarshal(m, b)
}
func (m *TextMessageFeedItem) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_TextMessageFeedItem.Marshal(b, m, deterministic)
}
func (m *TextMessageFeedItem) XXX_Merge(src proto.Message) {
	xxx_messageInfo_TextMessageFeedItem.Merge(m, src)
}
func (m *TextMessageFeedItem) XXX_Size() int {
	return xxx_messageInfo_TextMessageFeedItem.Size(m)
}
func (m *TextMessageFeedItem) XXX_DiscardUnknown() {
	xxx_messageInfo_TextMessageFeedItem.DiscardUnknown(m)
}

var xxx_messageInfo_TextMessageFeedItem proto.InternalMessageInfo

func (m *TextMessageFeedItem) GetBusinessName() *wrappers.StringValue {
	if m != nil {
		return m.BusinessName
	}
	return nil
}

func (m *TextMessageFeedItem) GetCountryCode() *wrappers.StringValue {
	if m != nil {
		return m.CountryCode
	}
	return nil
}

func (m *TextMessageFeedItem) GetPhoneNumber() *wrappers.StringValue {
	if m != nil {
		return m.PhoneNumber
	}
	return nil
}

func (m *TextMessageFeedItem) GetText() *wrappers.StringValue {
	if m != nil {
		return m.Text
	}
	return nil
}

func (m *TextMessageFeedItem) GetExtensionText() *wrappers.StringValue {
	if m != nil {
		return m.ExtensionText
	}
	return nil
}

// Represents a Price extension.
type PriceFeedItem struct {
	// Price extension type of this extension.
	Type enums.PriceExtensionTypeEnum_PriceExtensionType `protobuf:"varint,1,opt,name=type,proto3,enum=google.ads.googleads.v2.enums.PriceExtensionTypeEnum_PriceExtensionType" json:"type,omitempty"`
	// Price qualifier for all offers of this price extension.
	PriceQualifier enums.PriceExtensionPriceQualifierEnum_PriceExtensionPriceQualifier `protobuf:"varint,2,opt,name=price_qualifier,json=priceQualifier,proto3,enum=google.ads.googleads.v2.enums.PriceExtensionPriceQualifierEnum_PriceExtensionPriceQualifier" json:"price_qualifier,omitempty"`
	// Tracking URL template for all offers of this price extension.
	TrackingUrlTemplate *wrappers.StringValue `protobuf:"bytes,3,opt,name=tracking_url_template,json=trackingUrlTemplate,proto3" json:"tracking_url_template,omitempty"`
	// The code of the language used for this price extension.
	LanguageCode *wrappers.StringValue `protobuf:"bytes,4,opt,name=language_code,json=languageCode,proto3" json:"language_code,omitempty"`
	// The price offerings in this price extension.
	PriceOfferings []*PriceOffer `protobuf:"bytes,5,rep,name=price_offerings,json=priceOfferings,proto3" json:"price_offerings,omitempty"`
	// URL template for appending params to landing page URLs served with parallel
	// tracking.
	FinalUrlSuffix       *wrappers.StringValue `protobuf:"bytes,6,opt,name=final_url_suffix,json=finalUrlSuffix,proto3" json:"final_url_suffix,omitempty"`
	XXX_NoUnkeyedLiteral struct{}              `json:"-"`
	XXX_unrecognized     []byte                `json:"-"`
	XXX_sizecache        int32                 `json:"-"`
}

func (m *PriceFeedItem) Reset()         { *m = PriceFeedItem{} }
func (m *PriceFeedItem) String() string { return proto.CompactTextString(m) }
func (*PriceFeedItem) ProtoMessage()    {}
func (*PriceFeedItem) Descriptor() ([]byte, []int) {
	return fileDescriptor_1279b497763ecdff, []int{6}
}

func (m *PriceFeedItem) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_PriceFeedItem.Unmarshal(m, b)
}
func (m *PriceFeedItem) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_PriceFeedItem.Marshal(b, m, deterministic)
}
func (m *PriceFeedItem) XXX_Merge(src proto.Message) {
	xxx_messageInfo_PriceFeedItem.Merge(m, src)
}
func (m *PriceFeedItem) XXX_Size() int {
	return xxx_messageInfo_PriceFeedItem.Size(m)
}
func (m *PriceFeedItem) XXX_DiscardUnknown() {
	xxx_messageInfo_PriceFeedItem.DiscardUnknown(m)
}

var xxx_messageInfo_PriceFeedItem proto.InternalMessageInfo

func (m *PriceFeedItem) GetType() enums.PriceExtensionTypeEnum_PriceExtensionType {
	if m != nil {
		return m.Type
	}
	return enums.PriceExtensionTypeEnum_UNSPECIFIED
}

func (m *PriceFeedItem) GetPriceQualifier() enums.PriceExtensionPriceQualifierEnum_PriceExtensionPriceQualifier {
	if m != nil {
		return m.PriceQualifier
	}
	return enums.PriceExtensionPriceQualifierEnum_UNSPECIFIED
}

func (m *PriceFeedItem) GetTrackingUrlTemplate() *wrappers.StringValue {
	if m != nil {
		return m.TrackingUrlTemplate
	}
	return nil
}

func (m *PriceFeedItem) GetLanguageCode() *wrappers.StringValue {
	if m != nil {
		return m.LanguageCode
	}
	return nil
}

func (m *PriceFeedItem) GetPriceOfferings() []*PriceOffer {
	if m != nil {
		return m.PriceOfferings
	}
	return nil
}

func (m *PriceFeedItem) GetFinalUrlSuffix() *wrappers.StringValue {
	if m != nil {
		return m.FinalUrlSuffix
	}
	return nil
}

// Represents one price offer in a price extension.
type PriceOffer struct {
	// Header text of this offer.
	Header *wrappers.StringValue `protobuf:"bytes,1,opt,name=header,proto3" json:"header,omitempty"`
	// Description text of this offer.
	Description *wrappers.StringValue `protobuf:"bytes,2,opt,name=description,proto3" json:"description,omitempty"`
	// Price value of this offer.
	Price *Money `protobuf:"bytes,3,opt,name=price,proto3" json:"price,omitempty"`
	// Price unit for this offer.
	Unit enums.PriceExtensionPriceUnitEnum_PriceExtensionPriceUnit `protobuf:"varint,4,opt,name=unit,proto3,enum=google.ads.googleads.v2.enums.PriceExtensionPriceUnitEnum_PriceExtensionPriceUnit" json:"unit,omitempty"`
	// A list of possible final URLs after all cross domain redirects.
	FinalUrls []*wrappers.StringValue `protobuf:"bytes,5,rep,name=final_urls,json=finalUrls,proto3" json:"final_urls,omitempty"`
	// A list of possible final mobile URLs after all cross domain redirects.
	FinalMobileUrls      []*wrappers.StringValue `protobuf:"bytes,6,rep,name=final_mobile_urls,json=finalMobileUrls,proto3" json:"final_mobile_urls,omitempty"`
	XXX_NoUnkeyedLiteral struct{}                `json:"-"`
	XXX_unrecognized     []byte                  `json:"-"`
	XXX_sizecache        int32                   `json:"-"`
}

func (m *PriceOffer) Reset()         { *m = PriceOffer{} }
func (m *PriceOffer) String() string { return proto.CompactTextString(m) }
func (*PriceOffer) ProtoMessage()    {}
func (*PriceOffer) Descriptor() ([]byte, []int) {
	return fileDescriptor_1279b497763ecdff, []int{7}
}

func (m *PriceOffer) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_PriceOffer.Unmarshal(m, b)
}
func (m *PriceOffer) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_PriceOffer.Marshal(b, m, deterministic)
}
func (m *PriceOffer) XXX_Merge(src proto.Message) {
	xxx_messageInfo_PriceOffer.Merge(m, src)
}
func (m *PriceOffer) XXX_Size() int {
	return xxx_messageInfo_PriceOffer.Size(m)
}
func (m *PriceOffer) XXX_DiscardUnknown() {
	xxx_messageInfo_PriceOffer.DiscardUnknown(m)
}

var xxx_messageInfo_PriceOffer proto.InternalMessageInfo

func (m *PriceOffer) GetHeader() *wrappers.StringValue {
	if m != nil {
		return m.Header
	}
	return nil
}

func (m *PriceOffer) GetDescription() *wrappers.StringValue {
	if m != nil {
		return m.Description
	}
	return nil
}

func (m *PriceOffer) GetPrice() *Money {
	if m != nil {
		return m.Price
	}
	return nil
}

func (m *PriceOffer) GetUnit() enums.PriceExtensionPriceUnitEnum_PriceExtensionPriceUnit {
	if m != nil {
		return m.Unit
	}
	return enums.PriceExtensionPriceUnitEnum_UNSPECIFIED
}

func (m *PriceOffer) GetFinalUrls() []*wrappers.StringValue {
	if m != nil {
		return m.FinalUrls
	}
	return nil
}

func (m *PriceOffer) GetFinalMobileUrls() []*wrappers.StringValue {
	if m != nil {
		return m.FinalMobileUrls
	}
	return nil
}

// Represents a Promotion extension.
type PromotionFeedItem struct {
	// A freeform description of what the promotion is targeting.
	// This field is required.
	PromotionTarget *wrappers.StringValue `protobuf:"bytes,1,opt,name=promotion_target,json=promotionTarget,proto3" json:"promotion_target,omitempty"`
	// Enum that modifies the qualification of the discount.
	DiscountModifier enums.PromotionExtensionDiscountModifierEnum_PromotionExtensionDiscountModifier `protobuf:"varint,2,opt,name=discount_modifier,json=discountModifier,proto3,enum=google.ads.googleads.v2.enums.PromotionExtensionDiscountModifierEnum_PromotionExtensionDiscountModifier" json:"discount_modifier,omitempty"`
	// Start date of when the promotion is eligible to be redeemed.
	PromotionStartDate *wrappers.StringValue `protobuf:"bytes,7,opt,name=promotion_start_date,json=promotionStartDate,proto3" json:"promotion_start_date,omitempty"`
	// End date of when the promotion is eligible to be redeemed.
	PromotionEndDate *wrappers.StringValue `protobuf:"bytes,8,opt,name=promotion_end_date,json=promotionEndDate,proto3" json:"promotion_end_date,omitempty"`
	// The occasion the promotion was intended for.
	// If an occasion is set, the redemption window will need to fall within
	// the date range associated with the occasion.
	Occasion enums.PromotionExtensionOccasionEnum_PromotionExtensionOccasion `protobuf:"varint,9,opt,name=occasion,proto3,enum=google.ads.googleads.v2.enums.PromotionExtensionOccasionEnum_PromotionExtensionOccasion" json:"occasion,omitempty"`
	// A list of possible final URLs after all cross domain redirects.
	// This field is required.
	FinalUrls []*wrappers.StringValue `protobuf:"bytes,10,rep,name=final_urls,json=finalUrls,proto3" json:"final_urls,omitempty"`
	// A list of possible final mobile URLs after all cross domain redirects.
	FinalMobileUrls []*wrappers.StringValue `protobuf:"bytes,11,rep,name=final_mobile_urls,json=finalMobileUrls,proto3" json:"final_mobile_urls,omitempty"`
	// URL template for constructing a tracking URL.
	TrackingUrlTemplate *wrappers.StringValue `protobuf:"bytes,12,opt,name=tracking_url_template,json=trackingUrlTemplate,proto3" json:"tracking_url_template,omitempty"`
	// A list of mappings to be used for substituting URL custom parameter tags in
	// the tracking_url_template, final_urls, and/or final_mobile_urls.
	UrlCustomParameters []*CustomParameter `protobuf:"bytes,13,rep,name=url_custom_parameters,json=urlCustomParameters,proto3" json:"url_custom_parameters,omitempty"`
	// URL template for appending params to landing page URLs served with parallel
	// tracking.
	FinalUrlSuffix *wrappers.StringValue `protobuf:"bytes,14,opt,name=final_url_suffix,json=finalUrlSuffix,proto3" json:"final_url_suffix,omitempty"`
	// The language of the promotion.
	// Represented as BCP 47 language tag.
	LanguageCode *wrappers.StringValue `protobuf:"bytes,15,opt,name=language_code,json=languageCode,proto3" json:"language_code,omitempty"`
	// Discount type, can be percentage off or amount off.
	//
	// Types that are valid to be assigned to DiscountType:
	//	*PromotionFeedItem_PercentOff
	//	*PromotionFeedItem_MoneyAmountOff
	DiscountType isPromotionFeedItem_DiscountType `protobuf_oneof:"discount_type"`
	// Promotion trigger. Can be by promotion code or promo by eligible order
	// amount.
	//
	// Types that are valid to be assigned to PromotionTrigger:
	//	*PromotionFeedItem_PromotionCode
	//	*PromotionFeedItem_OrdersOverAmount
	PromotionTrigger     isPromotionFeedItem_PromotionTrigger `protobuf_oneof:"promotion_trigger"`
	XXX_NoUnkeyedLiteral struct{}                             `json:"-"`
	XXX_unrecognized     []byte                               `json:"-"`
	XXX_sizecache        int32                                `json:"-"`
}

func (m *PromotionFeedItem) Reset()         { *m = PromotionFeedItem{} }
func (m *PromotionFeedItem) String() string { return proto.CompactTextString(m) }
func (*PromotionFeedItem) ProtoMessage()    {}
func (*PromotionFeedItem) Descriptor() ([]byte, []int) {
	return fileDescriptor_1279b497763ecdff, []int{8}
}

func (m *PromotionFeedItem) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_PromotionFeedItem.Unmarshal(m, b)
}
func (m *PromotionFeedItem) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_PromotionFeedItem.Marshal(b, m, deterministic)
}
func (m *PromotionFeedItem) XXX_Merge(src proto.Message) {
	xxx_messageInfo_PromotionFeedItem.Merge(m, src)
}
func (m *PromotionFeedItem) XXX_Size() int {
	return xxx_messageInfo_PromotionFeedItem.Size(m)
}
func (m *PromotionFeedItem) XXX_DiscardUnknown() {
	xxx_messageInfo_PromotionFeedItem.DiscardUnknown(m)
}

var xxx_messageInfo_PromotionFeedItem proto.InternalMessageInfo

func (m *PromotionFeedItem) GetPromotionTarget() *wrappers.StringValue {
	if m != nil {
		return m.PromotionTarget
	}
	return nil
}

func (m *PromotionFeedItem) GetDiscountModifier() enums.PromotionExtensionDiscountModifierEnum_PromotionExtensionDiscountModifier {
	if m != nil {
		return m.DiscountModifier
	}
	return enums.PromotionExtensionDiscountModifierEnum_UNSPECIFIED
}

func (m *PromotionFeedItem) GetPromotionStartDate() *wrappers.StringValue {
	if m != nil {
		return m.PromotionStartDate
	}
	return nil
}

func (m *PromotionFeedItem) GetPromotionEndDate() *wrappers.StringValue {
	if m != nil {
		return m.PromotionEndDate
	}
	return nil
}

func (m *PromotionFeedItem) GetOccasion() enums.PromotionExtensionOccasionEnum_PromotionExtensionOccasion {
	if m != nil {
		return m.Occasion
	}
	return enums.PromotionExtensionOccasionEnum_UNSPECIFIED
}

func (m *PromotionFeedItem) GetFinalUrls() []*wrappers.StringValue {
	if m != nil {
		return m.FinalUrls
	}
	return nil
}

func (m *PromotionFeedItem) GetFinalMobileUrls() []*wrappers.StringValue {
	if m != nil {
		return m.FinalMobileUrls
	}
	return nil
}

func (m *PromotionFeedItem) GetTrackingUrlTemplate() *wrappers.StringValue {
	if m != nil {
		return m.TrackingUrlTemplate
	}
	return nil
}

func (m *PromotionFeedItem) GetUrlCustomParameters() []*CustomParameter {
	if m != nil {
		return m.UrlCustomParameters
	}
	return nil
}

func (m *PromotionFeedItem) GetFinalUrlSuffix() *wrappers.StringValue {
	if m != nil {
		return m.FinalUrlSuffix
	}
	return nil
}

func (m *PromotionFeedItem) GetLanguageCode() *wrappers.StringValue {
	if m != nil {
		return m.LanguageCode
	}
	return nil
}

type isPromotionFeedItem_DiscountType interface {
	isPromotionFeedItem_DiscountType()
}

type PromotionFeedItem_PercentOff struct {
	PercentOff *wrappers.Int64Value `protobuf:"bytes,3,opt,name=percent_off,json=percentOff,proto3,oneof"`
}

type PromotionFeedItem_MoneyAmountOff struct {
	MoneyAmountOff *Money `protobuf:"bytes,4,opt,name=money_amount_off,json=moneyAmountOff,proto3,oneof"`
}

func (*PromotionFeedItem_PercentOff) isPromotionFeedItem_DiscountType() {}

func (*PromotionFeedItem_MoneyAmountOff) isPromotionFeedItem_DiscountType() {}

func (m *PromotionFeedItem) GetDiscountType() isPromotionFeedItem_DiscountType {
	if m != nil {
		return m.DiscountType
	}
	return nil
}

func (m *PromotionFeedItem) GetPercentOff() *wrappers.Int64Value {
	if x, ok := m.GetDiscountType().(*PromotionFeedItem_PercentOff); ok {
		return x.PercentOff
	}
	return nil
}

func (m *PromotionFeedItem) GetMoneyAmountOff() *Money {
	if x, ok := m.GetDiscountType().(*PromotionFeedItem_MoneyAmountOff); ok {
		return x.MoneyAmountOff
	}
	return nil
}

type isPromotionFeedItem_PromotionTrigger interface {
	isPromotionFeedItem_PromotionTrigger()
}

type PromotionFeedItem_PromotionCode struct {
	PromotionCode *wrappers.StringValue `protobuf:"bytes,5,opt,name=promotion_code,json=promotionCode,proto3,oneof"`
}

type PromotionFeedItem_OrdersOverAmount struct {
	OrdersOverAmount *Money `protobuf:"bytes,6,opt,name=orders_over_amount,json=ordersOverAmount,proto3,oneof"`
}

func (*PromotionFeedItem_PromotionCode) isPromotionFeedItem_PromotionTrigger() {}

func (*PromotionFeedItem_OrdersOverAmount) isPromotionFeedItem_PromotionTrigger() {}

func (m *PromotionFeedItem) GetPromotionTrigger() isPromotionFeedItem_PromotionTrigger {
	if m != nil {
		return m.PromotionTrigger
	}
	return nil
}

func (m *PromotionFeedItem) GetPromotionCode() *wrappers.StringValue {
	if x, ok := m.GetPromotionTrigger().(*PromotionFeedItem_PromotionCode); ok {
		return x.PromotionCode
	}
	return nil
}

func (m *PromotionFeedItem) GetOrdersOverAmount() *Money {
	if x, ok := m.GetPromotionTrigger().(*PromotionFeedItem_OrdersOverAmount); ok {
		return x.OrdersOverAmount
	}
	return nil
}

// XXX_OneofWrappers is for the internal use of the proto package.
func (*PromotionFeedItem) XXX_OneofWrappers() []interface{} {
	return []interface{}{
		(*PromotionFeedItem_PercentOff)(nil),
		(*PromotionFeedItem_MoneyAmountOff)(nil),
		(*PromotionFeedItem_PromotionCode)(nil),
		(*PromotionFeedItem_OrdersOverAmount)(nil),
	}
}

// Represents a structured snippet extension.
type StructuredSnippetFeedItem struct {
	// The header of the snippet.
	// This string must not be empty.
	Header *wrappers.StringValue `protobuf:"bytes,1,opt,name=header,proto3" json:"header,omitempty"`
	// The values in the snippet.
	// The maximum size of this collection is 10.
	Values               []*wrappers.StringValue `protobuf:"bytes,2,rep,name=values,proto3" json:"values,omitempty"`
	XXX_NoUnkeyedLiteral struct{}                `json:"-"`
	XXX_unrecognized     []byte                  `json:"-"`
	XXX_sizecache        int32                   `json:"-"`
}

func (m *StructuredSnippetFeedItem) Reset()         { *m = StructuredSnippetFeedItem{} }
func (m *StructuredSnippetFeedItem) String() string { return proto.CompactTextString(m) }
func (*StructuredSnippetFeedItem) ProtoMessage()    {}
func (*StructuredSnippetFeedItem) Descriptor() ([]byte, []int) {
	return fileDescriptor_1279b497763ecdff, []int{9}
}

func (m *StructuredSnippetFeedItem) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_StructuredSnippetFeedItem.Unmarshal(m, b)
}
func (m *StructuredSnippetFeedItem) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_StructuredSnippetFeedItem.Marshal(b, m, deterministic)
}
func (m *StructuredSnippetFeedItem) XXX_Merge(src proto.Message) {
	xxx_messageInfo_StructuredSnippetFeedItem.Merge(m, src)
}
func (m *StructuredSnippetFeedItem) XXX_Size() int {
	return xxx_messageInfo_StructuredSnippetFeedItem.Size(m)
}
func (m *StructuredSnippetFeedItem) XXX_DiscardUnknown() {
	xxx_messageInfo_StructuredSnippetFeedItem.DiscardUnknown(m)
}

var xxx_messageInfo_StructuredSnippetFeedItem proto.InternalMessageInfo

func (m *StructuredSnippetFeedItem) GetHeader() *wrappers.StringValue {
	if m != nil {
		return m.Header
	}
	return nil
}

func (m *StructuredSnippetFeedItem) GetValues() []*wrappers.StringValue {
	if m != nil {
		return m.Values
	}
	return nil
}

// Represents a sitelink extension.
type SitelinkFeedItem struct {
	// URL display text for the sitelink.
	// The length of this string should be between 1 and 25, inclusive.
	LinkText *wrappers.StringValue `protobuf:"bytes,1,opt,name=link_text,json=linkText,proto3" json:"link_text,omitempty"`
	// First line of the description for the sitelink.
	// If this value is set, line2 must also be set.
	// The length of this string should be between 0 and 35, inclusive.
	Line1 *wrappers.StringValue `protobuf:"bytes,2,opt,name=line1,proto3" json:"line1,omitempty"`
	// Second line of the description for the sitelink.
	// If this value is set, line1 must also be set.
	// The length of this string should be between 0 and 35, inclusive.
	Line2 *wrappers.StringValue `protobuf:"bytes,3,opt,name=line2,proto3" json:"line2,omitempty"`
	// A list of possible final URLs after all cross domain redirects.
	FinalUrls []*wrappers.StringValue `protobuf:"bytes,4,rep,name=final_urls,json=finalUrls,proto3" json:"final_urls,omitempty"`
	// A list of possible final mobile URLs after all cross domain redirects.
	FinalMobileUrls []*wrappers.StringValue `protobuf:"bytes,5,rep,name=final_mobile_urls,json=finalMobileUrls,proto3" json:"final_mobile_urls,omitempty"`
	// URL template for constructing a tracking URL.
	TrackingUrlTemplate *wrappers.StringValue `protobuf:"bytes,6,opt,name=tracking_url_template,json=trackingUrlTemplate,proto3" json:"tracking_url_template,omitempty"`
	// A list of mappings to be used for substituting URL custom parameter tags in
	// the tracking_url_template, final_urls, and/or final_mobile_urls.
	UrlCustomParameters []*CustomParameter `protobuf:"bytes,7,rep,name=url_custom_parameters,json=urlCustomParameters,proto3" json:"url_custom_parameters,omitempty"`
	// Final URL suffix to be appended to landing page URLs served with
	// parallel tracking.
	FinalUrlSuffix       *wrappers.StringValue `protobuf:"bytes,8,opt,name=final_url_suffix,json=finalUrlSuffix,proto3" json:"final_url_suffix,omitempty"`
	XXX_NoUnkeyedLiteral struct{}              `json:"-"`
	XXX_unrecognized     []byte                `json:"-"`
	XXX_sizecache        int32                 `json:"-"`
}

func (m *SitelinkFeedItem) Reset()         { *m = SitelinkFeedItem{} }
func (m *SitelinkFeedItem) String() string { return proto.CompactTextString(m) }
func (*SitelinkFeedItem) ProtoMessage()    {}
func (*SitelinkFeedItem) Descriptor() ([]byte, []int) {
	return fileDescriptor_1279b497763ecdff, []int{10}
}

func (m *SitelinkFeedItem) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_SitelinkFeedItem.Unmarshal(m, b)
}
func (m *SitelinkFeedItem) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_SitelinkFeedItem.Marshal(b, m, deterministic)
}
func (m *SitelinkFeedItem) XXX_Merge(src proto.Message) {
	xxx_messageInfo_SitelinkFeedItem.Merge(m, src)
}
func (m *SitelinkFeedItem) XXX_Size() int {
	return xxx_messageInfo_SitelinkFeedItem.Size(m)
}
func (m *SitelinkFeedItem) XXX_DiscardUnknown() {
	xxx_messageInfo_SitelinkFeedItem.DiscardUnknown(m)
}

var xxx_messageInfo_SitelinkFeedItem proto.InternalMessageInfo

func (m *SitelinkFeedItem) GetLinkText() *wrappers.StringValue {
	if m != nil {
		return m.LinkText
	}
	return nil
}

func (m *SitelinkFeedItem) GetLine1() *wrappers.StringValue {
	if m != nil {
		return m.Line1
	}
	return nil
}

func (m *SitelinkFeedItem) GetLine2() *wrappers.StringValue {
	if m != nil {
		return m.Line2
	}
	return nil
}

func (m *SitelinkFeedItem) GetFinalUrls() []*wrappers.StringValue {
	if m != nil {
		return m.FinalUrls
	}
	return nil
}

func (m *SitelinkFeedItem) GetFinalMobileUrls() []*wrappers.StringValue {
	if m != nil {
		return m.FinalMobileUrls
	}
	return nil
}

func (m *SitelinkFeedItem) GetTrackingUrlTemplate() *wrappers.StringValue {
	if m != nil {
		return m.TrackingUrlTemplate
	}
	return nil
}

func (m *SitelinkFeedItem) GetUrlCustomParameters() []*CustomParameter {
	if m != nil {
		return m.UrlCustomParameters
	}
	return nil
}

func (m *SitelinkFeedItem) GetFinalUrlSuffix() *wrappers.StringValue {
	if m != nil {
		return m.FinalUrlSuffix
	}
	return nil
}

func init() {
	proto.RegisterType((*AppFeedItem)(nil), "google.ads.googleads.v2.common.AppFeedItem")
	proto.RegisterType((*CallFeedItem)(nil), "google.ads.googleads.v2.common.CallFeedItem")
	proto.RegisterType((*CalloutFeedItem)(nil), "google.ads.googleads.v2.common.CalloutFeedItem")
	proto.RegisterType((*LocationFeedItem)(nil), "google.ads.googleads.v2.common.LocationFeedItem")
	proto.RegisterType((*AffiliateLocationFeedItem)(nil), "google.ads.googleads.v2.common.AffiliateLocationFeedItem")
	proto.RegisterType((*TextMessageFeedItem)(nil), "google.ads.googleads.v2.common.TextMessageFeedItem")
	proto.RegisterType((*PriceFeedItem)(nil), "google.ads.googleads.v2.common.PriceFeedItem")
	proto.RegisterType((*PriceOffer)(nil), "google.ads.googleads.v2.common.PriceOffer")
	proto.RegisterType((*PromotionFeedItem)(nil), "google.ads.googleads.v2.common.PromotionFeedItem")
	proto.RegisterType((*StructuredSnippetFeedItem)(nil), "google.ads.googleads.v2.common.StructuredSnippetFeedItem")
	proto.RegisterType((*SitelinkFeedItem)(nil), "google.ads.googleads.v2.common.SitelinkFeedItem")
}

func init() {
	proto.RegisterFile("google/ads/googleads/v2/common/extensions.proto", fileDescriptor_1279b497763ecdff)
}

var fileDescriptor_1279b497763ecdff = []byte{
	// 1573 bytes of a gzipped FileDescriptorProto
	0x1f, 0x8b, 0x08, 0x00, 0x00, 0x00, 0x00, 0x00, 0x02, 0xff, 0xec, 0x59, 0xdf, 0x4e, 0x1b, 0xc7,
	0x17, 0x8e, 0xc1, 0x10, 0x38, 0x06, 0x03, 0x4b, 0xf2, 0x93, 0xc3, 0x2f, 0x4a, 0x53, 0x4b, 0x95,
	0xa2, 0x4a, 0xb5, 0x13, 0x87, 0x46, 0xa9, 0xa3, 0xa6, 0x35, 0x86, 0x04, 0xaa, 0xf0, 0x27, 0x6b,
	0x40, 0x55, 0x85, 0xb4, 0x1a, 0x76, 0xc7, 0x66, 0x94, 0xdd, 0x99, 0xed, 0xcc, 0x2c, 0x85, 0x07,
	0xa8, 0x5a, 0xf5, 0xbe, 0x2f, 0xd0, 0x4a, 0xad, 0xd4, 0x8b, 0xbe, 0x40, 0xaf, 0x7a, 0xdb, 0xbb,
	0xde, 0xf4, 0x21, 0xf2, 0x14, 0xd5, 0xcc, 0xce, 0xae, 0xc1, 0x04, 0x76, 0x4d, 0xa9, 0xd4, 0x8b,
	0x5c, 0xb1, 0xbb, 0x3e, 0xdf, 0x37, 0x33, 0x67, 0xbf, 0xf3, 0x6f, 0x81, 0x7a, 0x8f, 0xb1, 0x9e,
	0x8f, 0xeb, 0xc8, 0x13, 0xe6, 0x52, 0x5d, 0x1d, 0x36, 0xea, 0x2e, 0x0b, 0x02, 0x46, 0xeb, 0xf8,
	0x48, 0x62, 0x2a, 0x08, 0xa3, 0xa2, 0x16, 0x72, 0x26, 0x99, 0x75, 0x27, 0xb6, 0xaa, 0x21, 0x4f,
	0xd4, 0x52, 0x40, 0xed, 0xb0, 0x51, 0x8b, 0x01, 0x0b, 0x1f, 0x66, 0x10, 0xba, 0x91, 0x90, 0x2c,
	0x70, 0x42, 0xc4, 0x51, 0x80, 0x25, 0xe6, 0x31, 0xed, 0xc2, 0xfd, 0x0c, 0x58, 0x17, 0x63, 0xcf,
	0x89, 0xaf, 0x0d, 0xe2, 0x83, 0xf3, 0x10, 0x98, 0x46, 0x81, 0xa8, 0xa3, 0x30, 0x74, 0x84, 0x64,
	0x1c, 0x1b, 0xf3, 0xf6, 0xc5, 0xe6, 0x2e, 0xf2, 0x7d, 0xc7, 0x65, 0xf4, 0x10, 0x73, 0x75, 0x5a,
	0x87, 0xe3, 0x90, 0x71, 0x49, 0x68, 0xcf, 0x11, 0x12, 0xc9, 0x9c, 0x24, 0x21, 0x27, 0x2e, 0x76,
	0x52, 0x97, 0x39, 0xf1, 0xfd, 0x97, 0x11, 0xf2, 0x49, 0x97, 0xa4, 0x47, 0x7d, 0x7a, 0x19, 0x92,
	0x88, 0x12, 0x69, 0xf0, 0x8f, 0x87, 0xc3, 0xcb, 0xe3, 0x30, 0xd9, 0xfe, 0x5a, 0x16, 0x92, 0x05,
	0x4c, 0x2a, 0x4c, 0x1f, 0xed, 0x11, 0xe1, 0xb2, 0x88, 0x4a, 0x27, 0x60, 0xde, 0xc9, 0x43, 0x7c,
	0x3a, 0x3c, 0x15, 0x73, 0x5d, 0xa4, 0x2e, 0x0c, 0x83, 0x11, 0x52, 0x5d, 0xdf, 0xed, 0x47, 0xdd,
	0xfa, 0x57, 0x1c, 0x85, 0x21, 0xe6, 0x46, 0x68, 0x0b, 0xb7, 0x93, 0x15, 0x42, 0x52, 0x47, 0x94,
	0x32, 0x89, 0x64, 0x5f, 0x86, 0xd5, 0xbf, 0x8a, 0x50, 0x6a, 0x85, 0xe1, 0x33, 0x8c, 0xbd, 0x35,
	0x89, 0x03, 0xeb, 0x23, 0x98, 0xf4, 0x09, 0x7d, 0xe5, 0x48, 0x7c, 0x24, 0x2b, 0x85, 0xbb, 0x85,
	0x7b, 0xa5, 0xc6, 0x6d, 0xa3, 0xcf, 0x5a, 0xb2, 0x42, 0xad, 0x23, 0x39, 0xa1, 0xbd, 0x5d, 0xe4,
	0x47, 0xd8, 0x9e, 0x50, 0xe6, 0xdb, 0xf8, 0x48, 0x5a, 0x0f, 0x61, 0x5c, 0x89, 0x85, 0x78, 0x95,
	0x91, 0x1c, 0xb8, 0x31, 0x14, 0x86, 0x6b, 0x9e, 0xf5, 0x12, 0x26, 0x53, 0x85, 0x55, 0x46, 0xef,
	0x16, 0xee, 0x95, 0x1b, 0x8b, 0xb5, 0xf3, 0x42, 0x43, 0xfb, 0xa4, 0xd6, 0x0a, 0xc3, 0x8e, 0x32,
	0x5f, 0xa1, 0x51, 0x90, 0xde, 0xd8, 0x13, 0xc8, 0x5c, 0x59, 0x4f, 0x00, 0xba, 0x84, 0x22, 0xdf,
	0x89, 0xb8, 0x2f, 0x2a, 0xc5, 0xbb, 0xa3, 0x99, 0x7b, 0x99, 0xd4, 0xf6, 0x3b, 0xdc, 0x17, 0xd6,
	0x2a, 0xcc, 0xc5, 0xe0, 0x80, 0xed, 0x13, 0x1f, 0xc7, 0x1c, 0x63, 0x39, 0x38, 0x66, 0x34, 0x6c,
	0x5d, 0xa3, 0x34, 0xd3, 0x16, 0xdc, 0x94, 0x1c, 0xb9, 0xaf, 0x94, 0xf6, 0x23, 0xee, 0x3b, 0x12,
	0x07, 0xa1, 0x8f, 0x24, 0xae, 0x8c, 0xe7, 0xf0, 0xce, 0x7c, 0x02, 0xdd, 0xe1, 0xfe, 0xb6, 0x01,
	0x5a, 0x2e, 0xdc, 0x54, 0x44, 0x83, 0x91, 0x2f, 0x2a, 0xd7, 0xf5, 0xfe, 0xea, 0xb5, 0x8b, 0x53,
	0x4a, 0xad, 0xad, 0x81, 0x5b, 0x09, 0xce, 0x9e, 0x8f, 0xb8, 0x3f, 0xf0, 0x4c, 0x58, 0xcf, 0x60,
	0x36, 0xf5, 0x9e, 0x23, 0xa2, 0x6e, 0x97, 0x1c, 0x55, 0x26, 0x72, 0xec, 0xb8, 0x9c, 0xf8, 0xb0,
	0xa3, 0x31, 0xd5, 0xdf, 0x8b, 0x30, 0xd5, 0x46, 0xbe, 0x9f, 0x2a, 0xeb, 0x13, 0x98, 0x0a, 0x0f,
	0x18, 0xc5, 0x0e, 0x8d, 0x82, 0x7d, 0xcc, 0x73, 0x89, 0xab, 0xa4, 0x11, 0x1b, 0x1a, 0xa0, 0x08,
	0x74, 0x08, 0xf1, 0x63, 0xc7, 0x65, 0x1e, 0xce, 0xa5, 0xb2, 0x92, 0x41, 0xb4, 0x99, 0x87, 0xad,
	0x0d, 0xb8, 0xa9, 0xd3, 0x53, 0xfa, 0x5a, 0x30, 0x45, 0xfb, 0x3e, 0xf6, 0xb4, 0xee, 0x4a, 0x8d,
	0x85, 0x33, 0x4c, 0x4b, 0x8c, 0xf9, 0xe6, 0x7d, 0x28, 0xe0, 0xb6, 0xc1, 0xad, 0xc4, 0x30, 0xcb,
	0x86, 0xff, 0x0d, 0xa6, 0x3b, 0xe4, 0xaa, 0xe0, 0xaa, 0x14, 0x73, 0x6c, 0xed, 0x86, 0xc2, 0xb6,
	0x53, 0x68, 0x4b, 0x23, 0x2d, 0x0c, 0xef, 0x0e, 0x72, 0xa6, 0xdb, 0xf5, 0x88, 0x88, 0xf7, 0x3b,
	0x96, 0xb9, 0xdf, 0x3b, 0xa7, 0xc9, 0x93, 0x9d, 0x2f, 0x1b, 0x06, 0xeb, 0xc7, 0x02, 0xbc, 0x93,
	0x91, 0xaa, 0xb5, 0x4e, 0xcb, 0x8d, 0xbd, 0x8c, 0x68, 0x6c, 0x9f, 0x5a, 0xc8, 0x4e, 0x38, 0x3a,
	0x8a, 0x42, 0x47, 0xe8, 0x45, 0x06, 0xf6, 0x6d, 0xf7, 0x82, 0x5f, 0xab, 0x36, 0xcc, 0x28, 0x34,
	0x8b, 0xe4, 0x49, 0x15, 0xb9, 0xf1, 0xa3, 0xfc, 0x29, 0xaa, 0x64, 0x10, 0x2a, 0x4b, 0x55, 0xbf,
	0x2b, 0xc2, 0xec, 0x0b, 0xe6, 0xea, 0x24, 0x98, 0xb2, 0xb6, 0x60, 0x7a, 0x3f, 0x12, 0x84, 0x62,
	0x21, 0x1c, 0x8a, 0x02, 0x9c, 0x8b, 0x76, 0x2a, 0x81, 0x6c, 0xa0, 0x00, 0x5b, 0x4b, 0x50, 0x46,
	0x9e, 0xc7, 0x15, 0x83, 0x4f, 0x28, 0x76, 0x1e, 0xe4, 0xd2, 0xe7, 0x94, 0xc1, 0xbc, 0x20, 0x14,
	0x3f, 0x38, 0xc3, 0xd1, 0x30, 0xca, 0xcc, 0xcf, 0xd1, 0xb0, 0xee, 0x43, 0xd1, 0x25, 0xf2, 0x38,
	0x97, 0x04, 0xb5, 0xa5, 0xf5, 0x18, 0x26, 0x42, 0xce, 0x0e, 0x09, 0x75, 0xb1, 0x51, 0x56, 0x46,
	0xc6, 0x4f, 0xac, 0xad, 0x8f, 0xa1, 0x14, 0x32, 0x21, 0x91, 0x1f, 0x07, 0x64, 0x9e, 0xc4, 0x06,
	0x31, 0x40, 0xc7, 0xe3, 0x60, 0x40, 0x5f, 0x1f, 0x36, 0xa0, 0x07, 0x53, 0xca, 0xc4, 0x90, 0x29,
	0xa5, 0xfa, 0xed, 0x18, 0xdc, 0x6a, 0x75, 0xbb, 0xc4, 0x27, 0x48, 0xe2, 0xb7, 0xaa, 0x78, 0xab,
	0x0a, 0x5d, 0x68, 0x1e, 0xc1, 0x84, 0x7b, 0x80, 0x08, 0x55, 0xad, 0xcc, 0xa4, 0x06, 0xff, 0xff,
	0x0c, 0x78, 0x8d, 0xca, 0x47, 0x8b, 0x31, 0xf6, 0xba, 0x36, 0x5e, 0xf3, 0x54, 0xe3, 0x11, 0xe3,
	0xb4, 0x58, 0x20, 0xc7, 0xb2, 0x93, 0xda, 0x5e, 0x29, 0xa5, 0xfa, 0xe7, 0x08, 0xcc, 0xab, 0x04,
	0xb5, 0x8e, 0x85, 0x40, 0x3d, 0x7c, 0x95, 0x22, 0xfc, 0xc7, 0x85, 0x73, 0xd0, 0xa3, 0xa3, 0xc3,
	0x7a, 0xf4, 0x3e, 0x14, 0x75, 0xb6, 0xce, 0x25, 0x3f, 0x65, 0x69, 0xb5, 0xa1, 0x7c, 0xa2, 0xf5,
	0x56, 0xd8, 0x3c, 0x22, 0x9c, 0x4e, 0x31, 0x3a, 0xd7, 0xff, 0x5c, 0x84, 0xe9, 0x2d, 0xd5, 0xc6,
	0xa7, 0xde, 0xdc, 0x83, 0xa2, 0xea, 0xe3, 0xb5, 0x13, 0xcb, 0x8d, 0xd5, 0x8c, 0xda, 0xa6, 0xb1,
	0x2b, 0x29, 0xe5, 0x71, 0x18, 0x57, 0xb4, 0xb3, 0x8f, 0x6d, 0xcd, 0x6a, 0x7d, 0x5d, 0x80, 0x99,
	0x81, 0x59, 0x45, 0x3b, 0x3b, 0xbb, 0x8a, 0x9e, 0xa6, 0xd4, 0x77, 0x2f, 0x13, 0x8a, 0x37, 0xac,
	0x79, 0xda, 0xc0, 0x2e, 0x87, 0xa7, 0xee, 0xcf, 0x6f, 0x3d, 0x47, 0x2f, 0xdb, 0x7a, 0xb6, 0x60,
	0xda, 0x47, 0xb4, 0x17, 0xa1, 0x1e, 0x8e, 0x35, 0x94, 0xe7, 0x4d, 0x4e, 0x25, 0x10, 0x2d, 0xa2,
	0x4e, 0xe2, 0x1b, 0xd6, 0xed, 0x62, 0x65, 0x94, 0xf4, 0xd5, 0xef, 0x67, 0xf5, 0xad, 0xfa, 0xb4,
	0x9b, 0x0a, 0x65, 0x4e, 0xba, 0x99, 0x30, 0xbc, 0xb1, 0x5b, 0x1d, 0xbf, 0x44, 0xb7, 0xfa, 0xeb,
	0x28, 0x40, 0x7f, 0x19, 0x6b, 0x11, 0xc6, 0x0f, 0x30, 0xf2, 0x72, 0x76, 0xa9, 0xc6, 0xd6, 0x7a,
	0x0a, 0x25, 0x0f, 0x0b, 0x97, 0x93, 0x50, 0x37, 0x81, 0xb9, 0xc2, 0xec, 0x04, 0xc0, 0x7a, 0x02,
	0x63, 0xfa, 0x78, 0xe6, 0x35, 0xbd, 0x97, 0xe5, 0x97, 0x75, 0x46, 0xf1, 0xb1, 0x1d, 0x63, 0xac,
	0x2e, 0x14, 0xd5, 0x6c, 0xab, 0x5f, 0x4c, 0xb9, 0x61, 0x0f, 0xaf, 0xb7, 0x1d, 0x4a, 0xe4, 0x79,
	0x52, 0x53, 0xbf, 0xd9, 0x9a, 0x7f, 0x60, 0xba, 0x1a, 0xbb, 0x82, 0xe9, 0x6a, 0xfc, 0x12, 0xd3,
	0x55, 0xf5, 0x27, 0x80, 0xb9, 0xad, 0x64, 0x38, 0x4e, 0xc3, 0xfb, 0x39, 0xcc, 0xf6, 0x27, 0x66,
	0x89, 0x78, 0x0f, 0xe7, 0xeb, 0x10, 0x67, 0x52, 0xd4, 0xb6, 0x06, 0x59, 0xdf, 0x17, 0x60, 0xee,
	0xcc, 0xc8, 0x6e, 0x62, 0xf9, 0x20, 0xd3, 0xb7, 0x86, 0x2b, 0xf5, 0xe1, 0xb2, 0x61, 0x5a, 0x37,
	0x44, 0xc6, 0xcd, 0x59, 0x66, 0xf6, 0xac, 0x37, 0xf0, 0xc4, 0xda, 0x80, 0x1b, 0xfd, 0x03, 0x0a,
	0x89, 0xb8, 0x74, 0x3c, 0x15, 0xd8, 0x79, 0x8a, 0xa4, 0x95, 0x22, 0x3b, 0x0a, 0xb8, 0xac, 0xe2,
	0xfa, 0x33, 0xb0, 0x4e, 0x7c, 0x62, 0xa0, 0x5e, 0xcc, 0x96, 0xa7, 0x62, 0xf6, 0x1d, 0xbd, 0x42,
	0x3d, 0xcd, 0x25, 0x61, 0x22, 0xf9, 0x34, 0xa1, 0xcb, 0x66, 0xb9, 0xf1, 0xf9, 0xd0, 0x9e, 0xda,
	0x34, 0x04, 0xe7, 0x78, 0x28, 0xf9, 0xd9, 0x4e, 0x57, 0x1a, 0xd0, 0x23, 0x5c, 0x81, 0x1e, 0x4b,
	0x57, 0x3a, 0xed, 0x4f, 0x5d, 0xf9, 0xb4, 0x3f, 0xfd, 0x2f, 0x4f, 0xfb, 0xe5, 0xe1, 0xf3, 0xe7,
	0xd9, 0xfa, 0x30, 0x33, 0x74, 0x7d, 0x78, 0x0a, 0xa5, 0x10, 0x73, 0x17, 0x53, 0xa9, 0x2a, 0x84,
	0xc9, 0x81, 0x17, 0x35, 0x5e, 0xab, 0xd7, 0x6c, 0x30, 0x88, 0xcd, 0x6e, 0xd7, 0x7a, 0x09, 0xb3,
	0x81, 0x4a, 0x88, 0x0e, 0x0a, 0x74, 0xd4, 0x2a, 0x92, 0xe2, 0x10, 0x89, 0x74, 0xf5, 0x9a, 0x5d,
	0xd6, 0x04, 0x2d, 0x8d, 0x57, 0x94, 0x2b, 0x50, 0xee, 0x47, 0x87, 0x3e, 0x56, 0x8e, 0x26, 0x64,
	0xb5, 0x60, 0x4f, 0xa7, 0x28, 0x7d, 0xb2, 0x1d, 0xb0, 0x18, 0xf7, 0x30, 0x17, 0x0e, 0x3b, 0xc4,
	0xdc, 0xec, 0xcf, 0x94, 0xa9, 0x9c, 0x7b, 0x2b, 0xd8, 0xb3, 0x31, 0xc5, 0xe6, 0x21, 0xe6, 0xf1,
	0x06, 0x97, 0x66, 0x60, 0x3a, 0x4d, 0x51, 0xaa, 0xfd, 0x58, 0x9a, 0x87, 0xb9, 0x13, 0xd9, 0x8f,
	0x93, 0x5e, 0x0f, 0xf3, 0xea, 0x37, 0x05, 0xb8, 0xd5, 0x91, 0x3c, 0x72, 0x65, 0xc4, 0xb1, 0xd7,
	0xa1, 0x24, 0x0c, 0x71, 0x7f, 0x9c, 0xbe, 0x5c, 0xa1, 0x5b, 0x84, 0xf1, 0x43, 0xf5, 0x40, 0x54,
	0x46, 0x72, 0xc4, 0x8a, 0xb1, 0xad, 0xfe, 0x56, 0x84, 0xd9, 0x0e, 0x91, 0xd8, 0x27, 0xf4, 0xd5,
	0x55, 0x7c, 0x6f, 0x6c, 0xc0, 0x98, 0x9a, 0x87, 0xf2, 0x8d, 0x54, 0xb1, 0x69, 0x82, 0xc9, 0x37,
	0x42, 0xc5, 0xa6, 0x6f, 0xbf, 0x27, 0xfe, 0x17, 0xbe, 0x27, 0x2e, 0xbd, 0x2e, 0x40, 0xd5, 0x65,
	0x41, 0xc6, 0x9e, 0x96, 0x66, 0xd2, 0x5a, 0x21, 0xb6, 0x14, 0xed, 0x56, 0xe1, 0x8b, 0x65, 0x03,
	0xe9, 0x31, 0x95, 0x6f, 0x6a, 0x8c, 0xf7, 0xea, 0x3d, 0x4c, 0xf5, 0xa2, 0xc9, 0x27, 0xf7, 0x90,
	0x88, 0xf3, 0xfe, 0x63, 0xf2, 0x24, 0xfe, 0xf3, 0xc3, 0xc8, 0xe8, 0xf3, 0x56, 0xeb, 0x97, 0x91,
	0x3b, 0xcf, 0x63, 0xb2, 0x96, 0x27, 0x6a, 0xf1, 0xa5, 0xba, 0xda, 0x6d, 0xd4, 0xda, 0xda, 0xec,
	0x8f, 0xc4, 0x60, 0xaf, 0xe5, 0x89, 0xbd, 0xd4, 0x60, 0x6f, 0xb7, 0xb1, 0x17, 0x1b, 0xbc, 0x1e,
	0xa9, 0xc6, 0x4f, 0x9b, 0xcd, 0x96, 0x27, 0x9a, 0xcd, 0xd4, 0xa4, 0xd9, 0xdc, 0x6d, 0x34, 0x9b,
	0xb1, 0xd1, 0xfe, 0xb8, 0xde, 0xdd, 0xc3, 0xbf, 0x03, 0x00, 0x00, 0xff, 0xff, 0x42, 0xfd, 0x15,
	0xfb, 0x56, 0x1a, 0x00, 0x00,
}
