// Code generated by protoc-gen-go. DO NOT EDIT.
// source: google/ads/googleads/v1/enums/custom_interest_member_type.proto

package enums

import (
	fmt "fmt"
	math "math"

	proto "github.com/golang/protobuf/proto"
	_ "google.golang.org/genproto/googleapis/api/annotations"
)

// Reference imports to suppress errors if they are not otherwise used.
var _ = proto.Marshal
var _ = fmt.Errorf
var _ = math.Inf

// This is a compile-time assertion to ensure that this generated file
// is compatible with the proto package it is being compiled against.
// A compilation error at this line likely means your copy of the
// proto package needs to be updated.
const _ = proto.ProtoPackageIsVersion3 // please upgrade the proto package

// Enum containing possible custom interest member types.
type CustomInterestMemberTypeEnum_CustomInterestMemberType int32

const (
	// Not specified.
	CustomInterestMemberTypeEnum_UNSPECIFIED CustomInterestMemberTypeEnum_CustomInterestMemberType = 0
	// Used for return value only. Represents value unknown in this version.
	CustomInterestMemberTypeEnum_UNKNOWN CustomInterestMemberTypeEnum_CustomInterestMemberType = 1
	// Custom interest member type KEYWORD.
	CustomInterestMemberTypeEnum_KEYWORD CustomInterestMemberTypeEnum_CustomInterestMemberType = 2
	// Custom interest member type URL.
	CustomInterestMemberTypeEnum_URL CustomInterestMemberTypeEnum_CustomInterestMemberType = 3
)

var CustomInterestMemberTypeEnum_CustomInterestMemberType_name = map[int32]string{
	0: "UNSPECIFIED",
	1: "UNKNOWN",
	2: "KEYWORD",
	3: "URL",
}

var CustomInterestMemberTypeEnum_CustomInterestMemberType_value = map[string]int32{
	"UNSPECIFIED": 0,
	"UNKNOWN":     1,
	"KEYWORD":     2,
	"URL":         3,
}

func (x CustomInterestMemberTypeEnum_CustomInterestMemberType) String() string {
	return proto.EnumName(CustomInterestMemberTypeEnum_CustomInterestMemberType_name, int32(x))
}

func (CustomInterestMemberTypeEnum_CustomInterestMemberType) EnumDescriptor() ([]byte, []int) {
	return fileDescriptor_55e3da660044a7a0, []int{0, 0}
}

// The types of custom interest member, either KEYWORD or URL.
type CustomInterestMemberTypeEnum struct {
	XXX_NoUnkeyedLiteral struct{} `json:"-"`
	XXX_unrecognized     []byte   `json:"-"`
	XXX_sizecache        int32    `json:"-"`
}

func (m *CustomInterestMemberTypeEnum) Reset()         { *m = CustomInterestMemberTypeEnum{} }
func (m *CustomInterestMemberTypeEnum) String() string { return proto.CompactTextString(m) }
func (*CustomInterestMemberTypeEnum) ProtoMessage()    {}
func (*CustomInterestMemberTypeEnum) Descriptor() ([]byte, []int) {
	return fileDescriptor_55e3da660044a7a0, []int{0}
}

func (m *CustomInterestMemberTypeEnum) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_CustomInterestMemberTypeEnum.Unmarshal(m, b)
}
func (m *CustomInterestMemberTypeEnum) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_CustomInterestMemberTypeEnum.Marshal(b, m, deterministic)
}
func (m *CustomInterestMemberTypeEnum) XXX_Merge(src proto.Message) {
	xxx_messageInfo_CustomInterestMemberTypeEnum.Merge(m, src)
}
func (m *CustomInterestMemberTypeEnum) XXX_Size() int {
	return xxx_messageInfo_CustomInterestMemberTypeEnum.Size(m)
}
func (m *CustomInterestMemberTypeEnum) XXX_DiscardUnknown() {
	xxx_messageInfo_CustomInterestMemberTypeEnum.DiscardUnknown(m)
}

var xxx_messageInfo_CustomInterestMemberTypeEnum proto.InternalMessageInfo

func init() {
	proto.RegisterEnum("google.ads.googleads.v1.enums.CustomInterestMemberTypeEnum_CustomInterestMemberType", CustomInterestMemberTypeEnum_CustomInterestMemberType_name, CustomInterestMemberTypeEnum_CustomInterestMemberType_value)
	proto.RegisterType((*CustomInterestMemberTypeEnum)(nil), "google.ads.googleads.v1.enums.CustomInterestMemberTypeEnum")
}

func init() {
	proto.RegisterFile("google/ads/googleads/v1/enums/custom_interest_member_type.proto", fileDescriptor_55e3da660044a7a0)
}

var fileDescriptor_55e3da660044a7a0 = []byte{
	// 313 bytes of a gzipped FileDescriptorProto
	0x1f, 0x8b, 0x08, 0x00, 0x00, 0x00, 0x00, 0x00, 0x02, 0xff, 0x7c, 0x50, 0xcf, 0x6a, 0xc2, 0x30,
	0x18, 0x9f, 0x15, 0x26, 0xc4, 0xc3, 0x4a, 0x4f, 0x63, 0xe8, 0x41, 0x1f, 0x20, 0xa1, 0xec, 0x96,
	0x1d, 0x46, 0xd5, 0x4e, 0xc4, 0xad, 0x8a, 0x9b, 0x95, 0x8d, 0x42, 0xa9, 0x36, 0x84, 0x82, 0x49,
	0x4a, 0x93, 0x0a, 0xbe, 0xce, 0x8e, 0x7b, 0x94, 0x3d, 0xca, 0x8e, 0x7b, 0x82, 0xd1, 0xc4, 0xf6,
	0xd6, 0x5d, 0xca, 0xaf, 0xf9, 0x7d, 0xbf, 0x3f, 0xdf, 0x07, 0x1e, 0xa9, 0x10, 0xf4, 0x48, 0x50,
	0x92, 0x4a, 0x64, 0x60, 0x85, 0x4e, 0x2e, 0x22, 0xbc, 0x64, 0x12, 0x1d, 0x4a, 0xa9, 0x04, 0x8b,
	0x33, 0xae, 0x48, 0x41, 0xa4, 0x8a, 0x19, 0x61, 0x7b, 0x52, 0xc4, 0xea, 0x9c, 0x13, 0x98, 0x17,
	0x42, 0x09, 0x67, 0x68, 0x54, 0x30, 0x49, 0x25, 0x6c, 0x0c, 0xe0, 0xc9, 0x85, 0xda, 0xe0, 0x6e,
	0x50, 0xfb, 0xe7, 0x19, 0x4a, 0x38, 0x17, 0x2a, 0x51, 0x99, 0xe0, 0xd2, 0x88, 0xc7, 0x1c, 0x0c,
	0xa6, 0x3a, 0x61, 0x71, 0x09, 0x78, 0xd1, 0xfe, 0x6f, 0xe7, 0x9c, 0xf8, 0xbc, 0x64, 0xe3, 0x00,
	0xdc, 0xb6, 0xf1, 0xce, 0x0d, 0xe8, 0x6f, 0x83, 0xd7, 0xb5, 0x3f, 0x5d, 0x3c, 0x2d, 0xfc, 0x99,
	0x7d, 0xe5, 0xf4, 0x41, 0x6f, 0x1b, 0x2c, 0x83, 0xd5, 0x2e, 0xb0, 0x3b, 0xd5, 0xcf, 0xd2, 0x7f,
	0xdf, 0xad, 0x36, 0x33, 0xdb, 0x72, 0x7a, 0xa0, 0xbb, 0xdd, 0x3c, 0xdb, 0xdd, 0xc9, 0x6f, 0x07,
	0x8c, 0x0e, 0x82, 0xc1, 0x7f, 0x3b, 0x4f, 0x86, 0x6d, 0x99, 0xeb, 0xaa, 0xf4, 0xba, 0xf3, 0x31,
	0xb9, 0xe8, 0xa9, 0x38, 0x26, 0x9c, 0x42, 0x51, 0x50, 0x44, 0x09, 0xd7, 0x2b, 0xd5, 0x47, 0xcc,
	0x33, 0xd9, 0x72, 0xd3, 0x07, 0xfd, 0xfd, 0xb4, 0xba, 0x73, 0xcf, 0xfb, 0xb2, 0x86, 0x73, 0x63,
	0xe5, 0xa5, 0x12, 0x1a, 0x58, 0xa1, 0xd0, 0x85, 0xd5, 0xfe, 0xf2, 0xbb, 0xe6, 0x23, 0x2f, 0x95,
	0x51, 0xc3, 0x47, 0xa1, 0x1b, 0x69, 0xfe, 0xc7, 0x1a, 0x99, 0x47, 0x8c, 0xbd, 0x54, 0x62, 0xdc,
	0x4c, 0x60, 0x1c, 0xba, 0x18, 0xeb, 0x99, 0xfd, 0xb5, 0x2e, 0x76, 0xff, 0x17, 0x00, 0x00, 0xff,
	0xff, 0x7b, 0xc1, 0x91, 0x36, 0xeb, 0x01, 0x00, 0x00,
}
