// Code generated by protoc-gen-go. DO NOT EDIT.
// source: google/ads/googleads/v1/errors/function_error.proto

package errors

import (
	fmt "fmt"
	math "math"

	proto "github.com/golang/protobuf/proto"
	_ "google.golang.org/genproto/googleapis/api/annotations"
)

// Reference imports to suppress errors if they are not otherwise used.
var _ = proto.Marshal
var _ = fmt.Errorf
var _ = math.Inf

// This is a compile-time assertion to ensure that this generated file
// is compatible with the proto package it is being compiled against.
// A compilation error at this line likely means your copy of the
// proto package needs to be updated.
const _ = proto.ProtoPackageIsVersion3 // please upgrade the proto package

// Enum describing possible function errors.
type FunctionErrorEnum_FunctionError int32

const (
	// Enum unspecified.
	FunctionErrorEnum_UNSPECIFIED FunctionErrorEnum_FunctionError = 0
	// The received error code is not known in this version.
	FunctionErrorEnum_UNKNOWN FunctionErrorEnum_FunctionError = 1
	// The format of the function is not recognized as a supported function
	// format.
	FunctionErrorEnum_INVALID_FUNCTION_FORMAT FunctionErrorEnum_FunctionError = 2
	// Operand data types do not match.
	FunctionErrorEnum_DATA_TYPE_MISMATCH FunctionErrorEnum_FunctionError = 3
	// The operands cannot be used together in a conjunction.
	FunctionErrorEnum_INVALID_CONJUNCTION_OPERANDS FunctionErrorEnum_FunctionError = 4
	// Invalid numer of Operands.
	FunctionErrorEnum_INVALID_NUMBER_OF_OPERANDS FunctionErrorEnum_FunctionError = 5
	// Operand Type not supported.
	FunctionErrorEnum_INVALID_OPERAND_TYPE FunctionErrorEnum_FunctionError = 6
	// Operator not supported.
	FunctionErrorEnum_INVALID_OPERATOR FunctionErrorEnum_FunctionError = 7
	// Request context type not supported.
	FunctionErrorEnum_INVALID_REQUEST_CONTEXT_TYPE FunctionErrorEnum_FunctionError = 8
	// The matching function is not allowed for call placeholders
	FunctionErrorEnum_INVALID_FUNCTION_FOR_CALL_PLACEHOLDER FunctionErrorEnum_FunctionError = 9
	// The matching function is not allowed for the specified placeholder
	FunctionErrorEnum_INVALID_FUNCTION_FOR_PLACEHOLDER FunctionErrorEnum_FunctionError = 10
	// Invalid operand.
	FunctionErrorEnum_INVALID_OPERAND FunctionErrorEnum_FunctionError = 11
	// Missing value for the constant operand.
	FunctionErrorEnum_MISSING_CONSTANT_OPERAND_VALUE FunctionErrorEnum_FunctionError = 12
	// The value of the constant operand is invalid.
	FunctionErrorEnum_INVALID_CONSTANT_OPERAND_VALUE FunctionErrorEnum_FunctionError = 13
	// Invalid function nesting.
	FunctionErrorEnum_INVALID_NESTING FunctionErrorEnum_FunctionError = 14
	// The Feed ID was different from another Feed ID in the same function.
	FunctionErrorEnum_MULTIPLE_FEED_IDS_NOT_SUPPORTED FunctionErrorEnum_FunctionError = 15
	// The matching function is invalid for use with a feed with a fixed schema.
	FunctionErrorEnum_INVALID_FUNCTION_FOR_FEED_WITH_FIXED_SCHEMA FunctionErrorEnum_FunctionError = 16
	// Invalid attribute name.
	FunctionErrorEnum_INVALID_ATTRIBUTE_NAME FunctionErrorEnum_FunctionError = 17
)

var FunctionErrorEnum_FunctionError_name = map[int32]string{
	0:  "UNSPECIFIED",
	1:  "UNKNOWN",
	2:  "INVALID_FUNCTION_FORMAT",
	3:  "DATA_TYPE_MISMATCH",
	4:  "INVALID_CONJUNCTION_OPERANDS",
	5:  "INVALID_NUMBER_OF_OPERANDS",
	6:  "INVALID_OPERAND_TYPE",
	7:  "INVALID_OPERATOR",
	8:  "INVALID_REQUEST_CONTEXT_TYPE",
	9:  "INVALID_FUNCTION_FOR_CALL_PLACEHOLDER",
	10: "INVALID_FUNCTION_FOR_PLACEHOLDER",
	11: "INVALID_OPERAND",
	12: "MISSING_CONSTANT_OPERAND_VALUE",
	13: "INVALID_CONSTANT_OPERAND_VALUE",
	14: "INVALID_NESTING",
	15: "MULTIPLE_FEED_IDS_NOT_SUPPORTED",
	16: "INVALID_FUNCTION_FOR_FEED_WITH_FIXED_SCHEMA",
	17: "INVALID_ATTRIBUTE_NAME",
}

var FunctionErrorEnum_FunctionError_value = map[string]int32{
	"UNSPECIFIED":                                 0,
	"UNKNOWN":                                     1,
	"INVALID_FUNCTION_FORMAT":                     2,
	"DATA_TYPE_MISMATCH":                          3,
	"INVALID_CONJUNCTION_OPERANDS":                4,
	"INVALID_NUMBER_OF_OPERANDS":                  5,
	"INVALID_OPERAND_TYPE":                        6,
	"INVALID_OPERATOR":                            7,
	"INVALID_REQUEST_CONTEXT_TYPE":                8,
	"INVALID_FUNCTION_FOR_CALL_PLACEHOLDER":       9,
	"INVALID_FUNCTION_FOR_PLACEHOLDER":            10,
	"INVALID_OPERAND":                             11,
	"MISSING_CONSTANT_OPERAND_VALUE":              12,
	"INVALID_CONSTANT_OPERAND_VALUE":              13,
	"INVALID_NESTING":                             14,
	"MULTIPLE_FEED_IDS_NOT_SUPPORTED":             15,
	"INVALID_FUNCTION_FOR_FEED_WITH_FIXED_SCHEMA": 16,
	"INVALID_ATTRIBUTE_NAME":                      17,
}

func (x FunctionErrorEnum_FunctionError) String() string {
	return proto.EnumName(FunctionErrorEnum_FunctionError_name, int32(x))
}

func (FunctionErrorEnum_FunctionError) EnumDescriptor() ([]byte, []int) {
	return fileDescriptor_26e86f97fb83f8f1, []int{0, 0}
}

// Container for enum describing possible function errors.
type FunctionErrorEnum struct {
	XXX_NoUnkeyedLiteral struct{} `json:"-"`
	XXX_unrecognized     []byte   `json:"-"`
	XXX_sizecache        int32    `json:"-"`
}

func (m *FunctionErrorEnum) Reset()         { *m = FunctionErrorEnum{} }
func (m *FunctionErrorEnum) String() string { return proto.CompactTextString(m) }
func (*FunctionErrorEnum) ProtoMessage()    {}
func (*FunctionErrorEnum) Descriptor() ([]byte, []int) {
	return fileDescriptor_26e86f97fb83f8f1, []int{0}
}

func (m *FunctionErrorEnum) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_FunctionErrorEnum.Unmarshal(m, b)
}
func (m *FunctionErrorEnum) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_FunctionErrorEnum.Marshal(b, m, deterministic)
}
func (m *FunctionErrorEnum) XXX_Merge(src proto.Message) {
	xxx_messageInfo_FunctionErrorEnum.Merge(m, src)
}
func (m *FunctionErrorEnum) XXX_Size() int {
	return xxx_messageInfo_FunctionErrorEnum.Size(m)
}
func (m *FunctionErrorEnum) XXX_DiscardUnknown() {
	xxx_messageInfo_FunctionErrorEnum.DiscardUnknown(m)
}

var xxx_messageInfo_FunctionErrorEnum proto.InternalMessageInfo

func init() {
	proto.RegisterEnum("google.ads.googleads.v1.errors.FunctionErrorEnum_FunctionError", FunctionErrorEnum_FunctionError_name, FunctionErrorEnum_FunctionError_value)
	proto.RegisterType((*FunctionErrorEnum)(nil), "google.ads.googleads.v1.errors.FunctionErrorEnum")
}

func init() {
	proto.RegisterFile("google/ads/googleads/v1/errors/function_error.proto", fileDescriptor_26e86f97fb83f8f1)
}

var fileDescriptor_26e86f97fb83f8f1 = []byte{
	// 541 bytes of a gzipped FileDescriptorProto
	0x1f, 0x8b, 0x08, 0x00, 0x00, 0x00, 0x00, 0x00, 0x02, 0xff, 0x7c, 0x93, 0x51, 0x6f, 0xd3, 0x30,
	0x10, 0xc7, 0x59, 0x37, 0x36, 0xf0, 0x18, 0xf5, 0xcc, 0x34, 0x50, 0x99, 0xca, 0x54, 0xe0, 0x01,
	0x21, 0x25, 0xaa, 0xf6, 0x16, 0x9e, 0xdc, 0xe4, 0xd2, 0x1a, 0x12, 0x27, 0xc4, 0x4e, 0x37, 0x50,
	0x25, 0xab, 0xac, 0x25, 0xaa, 0xb4, 0x25, 0x55, 0xd3, 0xed, 0x03, 0xf1, 0x08, 0x9f, 0x82, 0x57,
	0x3e, 0x0a, 0x12, 0xdf, 0x01, 0x25, 0x6e, 0x4a, 0x8b, 0x0a, 0x4f, 0xb9, 0xdc, 0xfd, 0xfe, 0xf7,
	0x3f, 0x5b, 0x67, 0x74, 0x96, 0x64, 0x59, 0x72, 0x35, 0x36, 0x87, 0xa3, 0xdc, 0xd4, 0x61, 0x11,
	0xdd, 0xb6, 0xcd, 0xf1, 0x6c, 0x96, 0xcd, 0x72, 0xf3, 0xf3, 0x4d, 0x7a, 0x39, 0x9f, 0x64, 0xa9,
	0x2a, 0xff, 0x8d, 0xe9, 0x2c, 0x9b, 0x67, 0xa4, 0xa9, 0x49, 0x63, 0x38, 0xca, 0x8d, 0xa5, 0xc8,
	0xb8, 0x6d, 0x1b, 0x5a, 0xd4, 0x38, 0xa9, 0x9a, 0x4e, 0x27, 0xe6, 0x30, 0x4d, 0xb3, 0xf9, 0xb0,
	0x68, 0x91, 0x6b, 0x75, 0xeb, 0xfb, 0x0e, 0x3a, 0x74, 0x17, 0x6d, 0xa1, 0x10, 0x40, 0x7a, 0x73,
	0xdd, 0xfa, 0xb6, 0x83, 0x0e, 0xd6, 0xb2, 0xa4, 0x8e, 0xf6, 0x63, 0x2e, 0x42, 0xb0, 0x99, 0xcb,
	0xc0, 0xc1, 0x77, 0xc8, 0x3e, 0xda, 0x8b, 0xf9, 0x3b, 0x1e, 0x9c, 0x73, 0xbc, 0x45, 0x9e, 0xa2,
	0xc7, 0x8c, 0xf7, 0xa9, 0xc7, 0x1c, 0xe5, 0xc6, 0xdc, 0x96, 0x2c, 0xe0, 0xca, 0x0d, 0x22, 0x9f,
	0x4a, 0x5c, 0x23, 0xc7, 0x88, 0x38, 0x54, 0x52, 0x25, 0x3f, 0x84, 0xa0, 0x7c, 0x26, 0x7c, 0x2a,
	0xed, 0x1e, 0xde, 0x26, 0xa7, 0xe8, 0xa4, 0x12, 0xd9, 0x01, 0x7f, 0x5b, 0xe9, 0x82, 0x10, 0x22,
	0xca, 0x1d, 0x81, 0x77, 0x48, 0x13, 0x35, 0x2a, 0x82, 0xc7, 0x7e, 0x07, 0x22, 0x15, 0xb8, 0x7f,
	0xea, 0x77, 0xc9, 0x13, 0x74, 0x54, 0xd5, 0x17, 0xd9, 0xd2, 0x04, 0xef, 0x92, 0x23, 0x84, 0xd7,
	0x2a, 0x32, 0x88, 0xf0, 0xde, 0xaa, 0x63, 0x04, 0xef, 0x63, 0x10, 0xb2, 0x70, 0x96, 0x70, 0x21,
	0xb5, 0xee, 0x1e, 0x79, 0x85, 0x5e, 0x6e, 0x3a, 0x88, 0xb2, 0xa9, 0xe7, 0xa9, 0xd0, 0xa3, 0x36,
	0xf4, 0x02, 0xcf, 0x81, 0x08, 0xdf, 0x27, 0x2f, 0xd0, 0xe9, 0x46, 0x74, 0x95, 0x42, 0xe4, 0x11,
	0xaa, 0xff, 0x35, 0x22, 0xde, 0x27, 0x2d, 0xd4, 0xf4, 0x99, 0x10, 0x8c, 0x77, 0x0b, 0x7f, 0x21,
	0x29, 0x97, 0xcb, 0x03, 0xf4, 0xa9, 0x17, 0x03, 0x7e, 0x50, 0x30, 0x2b, 0xb7, 0xb3, 0x89, 0x39,
	0x58, 0x6d, 0xce, 0x41, 0x48, 0xc6, 0xbb, 0xf8, 0x21, 0x79, 0x8e, 0x9e, 0xf9, 0xb1, 0x27, 0x59,
	0xe8, 0x81, 0x72, 0x01, 0x1c, 0xc5, 0x1c, 0xa1, 0x78, 0x20, 0x95, 0x88, 0xc3, 0x30, 0x88, 0x24,
	0x38, 0xb8, 0x4e, 0x4c, 0xf4, 0x7a, 0xe3, 0xf0, 0xa5, 0xe0, 0x9c, 0xc9, 0x9e, 0x72, 0xd9, 0x05,
	0x38, 0x4a, 0xd8, 0x3d, 0xf0, 0x29, 0xc6, 0xa4, 0x81, 0x8e, 0x2b, 0x01, 0x95, 0x32, 0x62, 0x9d,
	0x58, 0x82, 0xe2, 0xd4, 0x07, 0x7c, 0xd8, 0xf9, 0xb5, 0x85, 0x5a, 0x97, 0xd9, 0xb5, 0xf1, 0xff,
	0x45, 0xec, 0x90, 0xb5, 0x8d, 0x0a, 0x8b, 0xf5, 0x0b, 0xb7, 0x3e, 0x3a, 0x0b, 0x55, 0x92, 0x5d,
	0x0d, 0xd3, 0xc4, 0xc8, 0x66, 0x89, 0x99, 0x8c, 0xd3, 0x72, 0x39, 0xab, 0x37, 0x30, 0x9d, 0xe4,
	0xff, 0x7a, 0x12, 0x6f, 0xf4, 0xe7, 0x4b, 0x6d, 0xbb, 0x4b, 0xe9, 0xd7, 0x5a, 0xb3, 0xab, 0x9b,
	0xd1, 0x51, 0x6e, 0xe8, 0xb0, 0x88, 0xfa, 0x6d, 0xa3, 0xb4, 0xcc, 0x7f, 0x54, 0xc0, 0x80, 0x8e,
	0xf2, 0xc1, 0x12, 0x18, 0xf4, 0xdb, 0x03, 0x0d, 0xfc, 0xac, 0xb5, 0x74, 0xd6, 0xb2, 0xe8, 0x28,
	0xb7, 0xac, 0x25, 0x62, 0x59, 0xfd, 0xb6, 0x65, 0x69, 0xe8, 0xd3, 0x6e, 0x39, 0xdd, 0xd9, 0xef,
	0x00, 0x00, 0x00, 0xff, 0xff, 0x03, 0xc2, 0xf5, 0x98, 0xaf, 0x03, 0x00, 0x00,
}
