// Code generated by protoc-gen-go. DO NOT EDIT.
// source: google/iam/credentials/v1/common.proto

package credentials

import (
	fmt "fmt"
	math "math"

	proto "github.com/golang/protobuf/proto"
	duration "github.com/golang/protobuf/ptypes/duration"
	timestamp "github.com/golang/protobuf/ptypes/timestamp"
)

// Reference imports to suppress errors if they are not otherwise used.
var _ = proto.Marshal
var _ = fmt.Errorf
var _ = math.Inf

// This is a compile-time assertion to ensure that this generated file
// is compatible with the proto package it is being compiled against.
// A compilation error at this line likely means your copy of the
// proto package needs to be updated.
const _ = proto.ProtoPackageIsVersion3 // please upgrade the proto package

type GenerateAccessTokenRequest struct {
	// The resource name of the service account for which the credentials
	// are requested, in the following format:
	// `projects/-/serviceAccounts/{ACCOUNT_EMAIL_OR_UNIQUEID}`.
	Name string `protobuf:"bytes,1,opt,name=name,proto3" json:"name,omitempty"`
	// The sequence of service accounts in a delegation chain. Each service
	// account must be granted the `roles/iam.serviceAccountTokenCreator` role
	// on its next service account in the chain. The last service account in the
	// chain must be granted the `roles/iam.serviceAccountTokenCreator` role
	// on the service account that is specified in the `name` field of the
	// request.
	//
	// The delegates must have the following format:
	// `projects/-/serviceAccounts/{ACCOUNT_EMAIL_OR_UNIQUEID}`
	Delegates []string `protobuf:"bytes,2,rep,name=delegates,proto3" json:"delegates,omitempty"`
	// Code to identify the scopes to be included in the OAuth 2.0 access token.
	// See https://developers.google.com/identity/protocols/googlescopes for more
	// information.
	// At least one value required.
	Scope []string `protobuf:"bytes,4,rep,name=scope,proto3" json:"scope,omitempty"`
	// The desired lifetime duration of the access token in seconds.
	// Must be set to a value less than or equal to 3600 (1 hour). If a value is
	// not specified, the token's lifetime will be set to a default value of one
	// hour.
	Lifetime             *duration.Duration `protobuf:"bytes,7,opt,name=lifetime,proto3" json:"lifetime,omitempty"`
	XXX_NoUnkeyedLiteral struct{}           `json:"-"`
	XXX_unrecognized     []byte             `json:"-"`
	XXX_sizecache        int32              `json:"-"`
}

func (m *GenerateAccessTokenRequest) Reset()         { *m = GenerateAccessTokenRequest{} }
func (m *GenerateAccessTokenRequest) String() string { return proto.CompactTextString(m) }
func (*GenerateAccessTokenRequest) ProtoMessage()    {}
func (*GenerateAccessTokenRequest) Descriptor() ([]byte, []int) {
	return fileDescriptor_e91212214ea1422e, []int{0}
}

func (m *GenerateAccessTokenRequest) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_GenerateAccessTokenRequest.Unmarshal(m, b)
}
func (m *GenerateAccessTokenRequest) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_GenerateAccessTokenRequest.Marshal(b, m, deterministic)
}
func (m *GenerateAccessTokenRequest) XXX_Merge(src proto.Message) {
	xxx_messageInfo_GenerateAccessTokenRequest.Merge(m, src)
}
func (m *GenerateAccessTokenRequest) XXX_Size() int {
	return xxx_messageInfo_GenerateAccessTokenRequest.Size(m)
}
func (m *GenerateAccessTokenRequest) XXX_DiscardUnknown() {
	xxx_messageInfo_GenerateAccessTokenRequest.DiscardUnknown(m)
}

var xxx_messageInfo_GenerateAccessTokenRequest proto.InternalMessageInfo

func (m *GenerateAccessTokenRequest) GetName() string {
	if m != nil {
		return m.Name
	}
	return ""
}

func (m *GenerateAccessTokenRequest) GetDelegates() []string {
	if m != nil {
		return m.Delegates
	}
	return nil
}

func (m *GenerateAccessTokenRequest) GetScope() []string {
	if m != nil {
		return m.Scope
	}
	return nil
}

func (m *GenerateAccessTokenRequest) GetLifetime() *duration.Duration {
	if m != nil {
		return m.Lifetime
	}
	return nil
}

type GenerateAccessTokenResponse struct {
	// The OAuth 2.0 access token.
	AccessToken string `protobuf:"bytes,1,opt,name=access_token,json=accessToken,proto3" json:"access_token,omitempty"`
	// Token expiration time.
	// The expiration time is always set.
	ExpireTime           *timestamp.Timestamp `protobuf:"bytes,3,opt,name=expire_time,json=expireTime,proto3" json:"expire_time,omitempty"`
	XXX_NoUnkeyedLiteral struct{}             `json:"-"`
	XXX_unrecognized     []byte               `json:"-"`
	XXX_sizecache        int32                `json:"-"`
}

func (m *GenerateAccessTokenResponse) Reset()         { *m = GenerateAccessTokenResponse{} }
func (m *GenerateAccessTokenResponse) String() string { return proto.CompactTextString(m) }
func (*GenerateAccessTokenResponse) ProtoMessage()    {}
func (*GenerateAccessTokenResponse) Descriptor() ([]byte, []int) {
	return fileDescriptor_e91212214ea1422e, []int{1}
}

func (m *GenerateAccessTokenResponse) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_GenerateAccessTokenResponse.Unmarshal(m, b)
}
func (m *GenerateAccessTokenResponse) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_GenerateAccessTokenResponse.Marshal(b, m, deterministic)
}
func (m *GenerateAccessTokenResponse) XXX_Merge(src proto.Message) {
	xxx_messageInfo_GenerateAccessTokenResponse.Merge(m, src)
}
func (m *GenerateAccessTokenResponse) XXX_Size() int {
	return xxx_messageInfo_GenerateAccessTokenResponse.Size(m)
}
func (m *GenerateAccessTokenResponse) XXX_DiscardUnknown() {
	xxx_messageInfo_GenerateAccessTokenResponse.DiscardUnknown(m)
}

var xxx_messageInfo_GenerateAccessTokenResponse proto.InternalMessageInfo

func (m *GenerateAccessTokenResponse) GetAccessToken() string {
	if m != nil {
		return m.AccessToken
	}
	return ""
}

func (m *GenerateAccessTokenResponse) GetExpireTime() *timestamp.Timestamp {
	if m != nil {
		return m.ExpireTime
	}
	return nil
}

type SignBlobRequest struct {
	// The resource name of the service account for which the credentials
	// are requested, in the following format:
	// `projects/-/serviceAccounts/{ACCOUNT_EMAIL_OR_UNIQUEID}`.
	Name string `protobuf:"bytes,1,opt,name=name,proto3" json:"name,omitempty"`
	// The sequence of service accounts in a delegation chain. Each service
	// account must be granted the `roles/iam.serviceAccountTokenCreator` role
	// on its next service account in the chain. The last service account in the
	// chain must be granted the `roles/iam.serviceAccountTokenCreator` role
	// on the service account that is specified in the `name` field of the
	// request.
	//
	// The delegates must have the following format:
	// `projects/-/serviceAccounts/{ACCOUNT_EMAIL_OR_UNIQUEID}`
	Delegates []string `protobuf:"bytes,3,rep,name=delegates,proto3" json:"delegates,omitempty"`
	// The bytes to sign.
	Payload              []byte   `protobuf:"bytes,5,opt,name=payload,proto3" json:"payload,omitempty"`
	XXX_NoUnkeyedLiteral struct{} `json:"-"`
	XXX_unrecognized     []byte   `json:"-"`
	XXX_sizecache        int32    `json:"-"`
}

func (m *SignBlobRequest) Reset()         { *m = SignBlobRequest{} }
func (m *SignBlobRequest) String() string { return proto.CompactTextString(m) }
func (*SignBlobRequest) ProtoMessage()    {}
func (*SignBlobRequest) Descriptor() ([]byte, []int) {
	return fileDescriptor_e91212214ea1422e, []int{2}
}

func (m *SignBlobRequest) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_SignBlobRequest.Unmarshal(m, b)
}
func (m *SignBlobRequest) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_SignBlobRequest.Marshal(b, m, deterministic)
}
func (m *SignBlobRequest) XXX_Merge(src proto.Message) {
	xxx_messageInfo_SignBlobRequest.Merge(m, src)
}
func (m *SignBlobRequest) XXX_Size() int {
	return xxx_messageInfo_SignBlobRequest.Size(m)
}
func (m *SignBlobRequest) XXX_DiscardUnknown() {
	xxx_messageInfo_SignBlobRequest.DiscardUnknown(m)
}

var xxx_messageInfo_SignBlobRequest proto.InternalMessageInfo

func (m *SignBlobRequest) GetName() string {
	if m != nil {
		return m.Name
	}
	return ""
}

func (m *SignBlobRequest) GetDelegates() []string {
	if m != nil {
		return m.Delegates
	}
	return nil
}

func (m *SignBlobRequest) GetPayload() []byte {
	if m != nil {
		return m.Payload
	}
	return nil
}

type SignBlobResponse struct {
	// The ID of the key used to sign the blob.
	KeyId string `protobuf:"bytes,1,opt,name=key_id,json=keyId,proto3" json:"key_id,omitempty"`
	// The signed blob.
	SignedBlob           []byte   `protobuf:"bytes,4,opt,name=signed_blob,json=signedBlob,proto3" json:"signed_blob,omitempty"`
	XXX_NoUnkeyedLiteral struct{} `json:"-"`
	XXX_unrecognized     []byte   `json:"-"`
	XXX_sizecache        int32    `json:"-"`
}

func (m *SignBlobResponse) Reset()         { *m = SignBlobResponse{} }
func (m *SignBlobResponse) String() string { return proto.CompactTextString(m) }
func (*SignBlobResponse) ProtoMessage()    {}
func (*SignBlobResponse) Descriptor() ([]byte, []int) {
	return fileDescriptor_e91212214ea1422e, []int{3}
}

func (m *SignBlobResponse) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_SignBlobResponse.Unmarshal(m, b)
}
func (m *SignBlobResponse) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_SignBlobResponse.Marshal(b, m, deterministic)
}
func (m *SignBlobResponse) XXX_Merge(src proto.Message) {
	xxx_messageInfo_SignBlobResponse.Merge(m, src)
}
func (m *SignBlobResponse) XXX_Size() int {
	return xxx_messageInfo_SignBlobResponse.Size(m)
}
func (m *SignBlobResponse) XXX_DiscardUnknown() {
	xxx_messageInfo_SignBlobResponse.DiscardUnknown(m)
}

var xxx_messageInfo_SignBlobResponse proto.InternalMessageInfo

func (m *SignBlobResponse) GetKeyId() string {
	if m != nil {
		return m.KeyId
	}
	return ""
}

func (m *SignBlobResponse) GetSignedBlob() []byte {
	if m != nil {
		return m.SignedBlob
	}
	return nil
}

type SignJwtRequest struct {
	// The resource name of the service account for which the credentials
	// are requested, in the following format:
	// `projects/-/serviceAccounts/{ACCOUNT_EMAIL_OR_UNIQUEID}`.
	Name string `protobuf:"bytes,1,opt,name=name,proto3" json:"name,omitempty"`
	// The sequence of service accounts in a delegation chain. Each service
	// account must be granted the `roles/iam.serviceAccountTokenCreator` role
	// on its next service account in the chain. The last service account in the
	// chain must be granted the `roles/iam.serviceAccountTokenCreator` role
	// on the service account that is specified in the `name` field of the
	// request.
	//
	// The delegates must have the following format:
	// `projects/-/serviceAccounts/{ACCOUNT_EMAIL_OR_UNIQUEID}`
	Delegates []string `protobuf:"bytes,3,rep,name=delegates,proto3" json:"delegates,omitempty"`
	// The JWT payload to sign: a JSON object that contains a JWT Claims Set.
	Payload              string   `protobuf:"bytes,5,opt,name=payload,proto3" json:"payload,omitempty"`
	XXX_NoUnkeyedLiteral struct{} `json:"-"`
	XXX_unrecognized     []byte   `json:"-"`
	XXX_sizecache        int32    `json:"-"`
}

func (m *SignJwtRequest) Reset()         { *m = SignJwtRequest{} }
func (m *SignJwtRequest) String() string { return proto.CompactTextString(m) }
func (*SignJwtRequest) ProtoMessage()    {}
func (*SignJwtRequest) Descriptor() ([]byte, []int) {
	return fileDescriptor_e91212214ea1422e, []int{4}
}

func (m *SignJwtRequest) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_SignJwtRequest.Unmarshal(m, b)
}
func (m *SignJwtRequest) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_SignJwtRequest.Marshal(b, m, deterministic)
}
func (m *SignJwtRequest) XXX_Merge(src proto.Message) {
	xxx_messageInfo_SignJwtRequest.Merge(m, src)
}
func (m *SignJwtRequest) XXX_Size() int {
	return xxx_messageInfo_SignJwtRequest.Size(m)
}
func (m *SignJwtRequest) XXX_DiscardUnknown() {
	xxx_messageInfo_SignJwtRequest.DiscardUnknown(m)
}

var xxx_messageInfo_SignJwtRequest proto.InternalMessageInfo

func (m *SignJwtRequest) GetName() string {
	if m != nil {
		return m.Name
	}
	return ""
}

func (m *SignJwtRequest) GetDelegates() []string {
	if m != nil {
		return m.Delegates
	}
	return nil
}

func (m *SignJwtRequest) GetPayload() string {
	if m != nil {
		return m.Payload
	}
	return ""
}

type SignJwtResponse struct {
	// The ID of the key used to sign the JWT.
	KeyId string `protobuf:"bytes,1,opt,name=key_id,json=keyId,proto3" json:"key_id,omitempty"`
	// The signed JWT.
	SignedJwt            string   `protobuf:"bytes,2,opt,name=signed_jwt,json=signedJwt,proto3" json:"signed_jwt,omitempty"`
	XXX_NoUnkeyedLiteral struct{} `json:"-"`
	XXX_unrecognized     []byte   `json:"-"`
	XXX_sizecache        int32    `json:"-"`
}

func (m *SignJwtResponse) Reset()         { *m = SignJwtResponse{} }
func (m *SignJwtResponse) String() string { return proto.CompactTextString(m) }
func (*SignJwtResponse) ProtoMessage()    {}
func (*SignJwtResponse) Descriptor() ([]byte, []int) {
	return fileDescriptor_e91212214ea1422e, []int{5}
}

func (m *SignJwtResponse) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_SignJwtResponse.Unmarshal(m, b)
}
func (m *SignJwtResponse) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_SignJwtResponse.Marshal(b, m, deterministic)
}
func (m *SignJwtResponse) XXX_Merge(src proto.Message) {
	xxx_messageInfo_SignJwtResponse.Merge(m, src)
}
func (m *SignJwtResponse) XXX_Size() int {
	return xxx_messageInfo_SignJwtResponse.Size(m)
}
func (m *SignJwtResponse) XXX_DiscardUnknown() {
	xxx_messageInfo_SignJwtResponse.DiscardUnknown(m)
}

var xxx_messageInfo_SignJwtResponse proto.InternalMessageInfo

func (m *SignJwtResponse) GetKeyId() string {
	if m != nil {
		return m.KeyId
	}
	return ""
}

func (m *SignJwtResponse) GetSignedJwt() string {
	if m != nil {
		return m.SignedJwt
	}
	return ""
}

type GenerateIdTokenRequest struct {
	// The resource name of the service account for which the credentials
	// are requested, in the following format:
	// `projects/-/serviceAccounts/{ACCOUNT_EMAIL_OR_UNIQUEID}`.
	Name string `protobuf:"bytes,1,opt,name=name,proto3" json:"name,omitempty"`
	// The sequence of service accounts in a delegation chain. Each service
	// account must be granted the `roles/iam.serviceAccountTokenCreator` role
	// on its next service account in the chain. The last service account in the
	// chain must be granted the `roles/iam.serviceAccountTokenCreator` role
	// on the service account that is specified in the `name` field of the
	// request.
	//
	// The delegates must have the following format:
	// `projects/-/serviceAccounts/{ACCOUNT_EMAIL_OR_UNIQUEID}`
	Delegates []string `protobuf:"bytes,2,rep,name=delegates,proto3" json:"delegates,omitempty"`
	// The audience for the token, such as the API or account that this token
	// grants access to.
	Audience string `protobuf:"bytes,3,opt,name=audience,proto3" json:"audience,omitempty"`
	// Include the service account email in the token. If set to `true`, the
	// token will contain `email` and `email_verified` claims.
	IncludeEmail         bool     `protobuf:"varint,4,opt,name=include_email,json=includeEmail,proto3" json:"include_email,omitempty"`
	XXX_NoUnkeyedLiteral struct{} `json:"-"`
	XXX_unrecognized     []byte   `json:"-"`
	XXX_sizecache        int32    `json:"-"`
}

func (m *GenerateIdTokenRequest) Reset()         { *m = GenerateIdTokenRequest{} }
func (m *GenerateIdTokenRequest) String() string { return proto.CompactTextString(m) }
func (*GenerateIdTokenRequest) ProtoMessage()    {}
func (*GenerateIdTokenRequest) Descriptor() ([]byte, []int) {
	return fileDescriptor_e91212214ea1422e, []int{6}
}

func (m *GenerateIdTokenRequest) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_GenerateIdTokenRequest.Unmarshal(m, b)
}
func (m *GenerateIdTokenRequest) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_GenerateIdTokenRequest.Marshal(b, m, deterministic)
}
func (m *GenerateIdTokenRequest) XXX_Merge(src proto.Message) {
	xxx_messageInfo_GenerateIdTokenRequest.Merge(m, src)
}
func (m *GenerateIdTokenRequest) XXX_Size() int {
	return xxx_messageInfo_GenerateIdTokenRequest.Size(m)
}
func (m *GenerateIdTokenRequest) XXX_DiscardUnknown() {
	xxx_messageInfo_GenerateIdTokenRequest.DiscardUnknown(m)
}

var xxx_messageInfo_GenerateIdTokenRequest proto.InternalMessageInfo

func (m *GenerateIdTokenRequest) GetName() string {
	if m != nil {
		return m.Name
	}
	return ""
}

func (m *GenerateIdTokenRequest) GetDelegates() []string {
	if m != nil {
		return m.Delegates
	}
	return nil
}

func (m *GenerateIdTokenRequest) GetAudience() string {
	if m != nil {
		return m.Audience
	}
	return ""
}

func (m *GenerateIdTokenRequest) GetIncludeEmail() bool {
	if m != nil {
		return m.IncludeEmail
	}
	return false
}

type GenerateIdTokenResponse struct {
	// The OpenId Connect ID token.
	Token                string   `protobuf:"bytes,1,opt,name=token,proto3" json:"token,omitempty"`
	XXX_NoUnkeyedLiteral struct{} `json:"-"`
	XXX_unrecognized     []byte   `json:"-"`
	XXX_sizecache        int32    `json:"-"`
}

func (m *GenerateIdTokenResponse) Reset()         { *m = GenerateIdTokenResponse{} }
func (m *GenerateIdTokenResponse) String() string { return proto.CompactTextString(m) }
func (*GenerateIdTokenResponse) ProtoMessage()    {}
func (*GenerateIdTokenResponse) Descriptor() ([]byte, []int) {
	return fileDescriptor_e91212214ea1422e, []int{7}
}

func (m *GenerateIdTokenResponse) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_GenerateIdTokenResponse.Unmarshal(m, b)
}
func (m *GenerateIdTokenResponse) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_GenerateIdTokenResponse.Marshal(b, m, deterministic)
}
func (m *GenerateIdTokenResponse) XXX_Merge(src proto.Message) {
	xxx_messageInfo_GenerateIdTokenResponse.Merge(m, src)
}
func (m *GenerateIdTokenResponse) XXX_Size() int {
	return xxx_messageInfo_GenerateIdTokenResponse.Size(m)
}
func (m *GenerateIdTokenResponse) XXX_DiscardUnknown() {
	xxx_messageInfo_GenerateIdTokenResponse.DiscardUnknown(m)
}

var xxx_messageInfo_GenerateIdTokenResponse proto.InternalMessageInfo

func (m *GenerateIdTokenResponse) GetToken() string {
	if m != nil {
		return m.Token
	}
	return ""
}

func init() {
	proto.RegisterType((*GenerateAccessTokenRequest)(nil), "google.iam.credentials.v1.GenerateAccessTokenRequest")
	proto.RegisterType((*GenerateAccessTokenResponse)(nil), "google.iam.credentials.v1.GenerateAccessTokenResponse")
	proto.RegisterType((*SignBlobRequest)(nil), "google.iam.credentials.v1.SignBlobRequest")
	proto.RegisterType((*SignBlobResponse)(nil), "google.iam.credentials.v1.SignBlobResponse")
	proto.RegisterType((*SignJwtRequest)(nil), "google.iam.credentials.v1.SignJwtRequest")
	proto.RegisterType((*SignJwtResponse)(nil), "google.iam.credentials.v1.SignJwtResponse")
	proto.RegisterType((*GenerateIdTokenRequest)(nil), "google.iam.credentials.v1.GenerateIdTokenRequest")
	proto.RegisterType((*GenerateIdTokenResponse)(nil), "google.iam.credentials.v1.GenerateIdTokenResponse")
}

func init() {
	proto.RegisterFile("google/iam/credentials/v1/common.proto", fileDescriptor_e91212214ea1422e)
}

var fileDescriptor_e91212214ea1422e = []byte{
	// 520 bytes of a gzipped FileDescriptorProto
	0x1f, 0x8b, 0x08, 0x00, 0x00, 0x00, 0x00, 0x00, 0x02, 0xff, 0xac, 0x54, 0x4f, 0x6f, 0xd3, 0x4e,
	0x10, 0x95, 0x9b, 0xa4, 0x8d, 0x27, 0xf9, 0xfd, 0x40, 0x56, 0x01, 0x27, 0xfc, 0x69, 0x70, 0x25,
	0x94, 0x93, 0xad, 0x82, 0x38, 0xf5, 0xd4, 0xb4, 0xa8, 0x4a, 0x24, 0xa4, 0xca, 0xf4, 0x84, 0x40,
	0xd6, 0xc6, 0x3b, 0xb5, 0x96, 0xac, 0x77, 0x8d, 0x77, 0xdd, 0x90, 0x03, 0x9f, 0xa0, 0x1f, 0x81,
	0x2f, 0xca, 0x11, 0x79, 0x6d, 0x37, 0x51, 0x1b, 0x21, 0x24, 0xb8, 0x79, 0xde, 0xbc, 0x99, 0x79,
	0x3b, 0xfb, 0xd6, 0xf0, 0x2a, 0x91, 0x32, 0xe1, 0x18, 0x30, 0x92, 0x06, 0x71, 0x8e, 0x14, 0x85,
	0x66, 0x84, 0xab, 0xe0, 0xfa, 0x28, 0x88, 0x65, 0x9a, 0x4a, 0xe1, 0x67, 0xb9, 0xd4, 0xd2, 0x19,
	0x54, 0x3c, 0x9f, 0x91, 0xd4, 0xdf, 0xe0, 0xf9, 0xd7, 0x47, 0xc3, 0x17, 0x75, 0x0b, 0x43, 0x9c,
	0x17, 0x57, 0x01, 0x2d, 0x72, 0xa2, 0x59, 0x53, 0x3a, 0x3c, 0xb8, 0x9b, 0xd7, 0x2c, 0x45, 0xa5,
	0x49, 0x9a, 0x55, 0x04, 0xef, 0x87, 0x05, 0xc3, 0x73, 0x14, 0x98, 0x13, 0x8d, 0x27, 0x71, 0x8c,
	0x4a, 0x5d, 0xca, 0x05, 0x8a, 0x10, 0xbf, 0x16, 0xa8, 0xb4, 0xe3, 0x40, 0x5b, 0x90, 0x14, 0x5d,
	0x6b, 0x64, 0x8d, 0xed, 0xd0, 0x7c, 0x3b, 0xcf, 0xc0, 0xa6, 0xc8, 0x31, 0x21, 0x1a, 0x95, 0xbb,
	0x33, 0x6a, 0x8d, 0xed, 0x70, 0x0d, 0x38, 0xfb, 0xd0, 0x51, 0xb1, 0xcc, 0xd0, 0x6d, 0x9b, 0x4c,
	0x15, 0x38, 0x6f, 0xa1, 0xcb, 0xd9, 0x15, 0x96, 0xd3, 0xdd, 0xbd, 0x91, 0x35, 0xee, 0xbd, 0x1e,
	0xf8, 0xf5, 0xa9, 0x1a, 0x69, 0xfe, 0x59, 0x2d, 0x3d, 0xbc, 0xa5, 0x7a, 0xdf, 0xe1, 0xe9, 0x56,
	0x71, 0x2a, 0x93, 0x42, 0xa1, 0xf3, 0x12, 0xfa, 0xc4, 0xc0, 0x91, 0x2e, 0xf1, 0x5a, 0x65, 0x8f,
	0xac, 0xa9, 0xce, 0x31, 0xf4, 0xf0, 0x5b, 0xc6, 0x72, 0x8c, 0xcc, 0xec, 0x96, 0x99, 0x3d, 0xbc,
	0x37, 0xfb, 0xb2, 0x59, 0x4b, 0x08, 0x15, 0xbd, 0x04, 0xbc, 0xcf, 0xf0, 0xe0, 0x03, 0x4b, 0xc4,
	0x84, 0xcb, 0xf9, 0x1f, 0x2f, 0xa4, 0x75, 0x77, 0x21, 0x2e, 0xec, 0x65, 0x64, 0xc5, 0x25, 0xa1,
	0x6e, 0x67, 0x64, 0x8d, 0xfb, 0x61, 0x13, 0x7a, 0x33, 0x78, 0xb8, 0x6e, 0x5f, 0x1f, 0xe9, 0x11,
	0xec, 0x2e, 0x70, 0x15, 0x31, 0x5a, 0x4f, 0xe8, 0x2c, 0x70, 0x35, 0xa5, 0xce, 0x01, 0xf4, 0x14,
	0x4b, 0x04, 0xd2, 0x68, 0xce, 0xe5, 0xdc, 0x6d, 0x9b, 0x46, 0x50, 0x41, 0x65, 0xbd, 0xf7, 0x09,
	0xfe, 0x2f, 0x7b, 0xcd, 0x96, 0xfa, 0x9f, 0x29, 0xb5, 0xd7, 0x4a, 0xcf, 0xab, 0x45, 0x98, 0xee,
	0xbf, 0x17, 0xfa, 0x1c, 0x6a, 0x55, 0xd1, 0x97, 0xa5, 0x76, 0x77, 0x4c, 0xca, 0xae, 0x90, 0xd9,
	0x52, 0x7b, 0x37, 0x16, 0x3c, 0x6e, 0x6e, 0x74, 0x4a, 0xff, 0xd2, 0x6a, 0x43, 0xe8, 0x92, 0x82,
	0x32, 0x14, 0x71, 0x75, 0xb1, 0x76, 0x78, 0x1b, 0x3b, 0x87, 0xf0, 0x1f, 0x13, 0x31, 0x2f, 0x28,
	0x46, 0x98, 0x12, 0xc6, 0xcd, 0xca, 0xba, 0x61, 0xbf, 0x06, 0xdf, 0x95, 0x98, 0x17, 0xc0, 0x93,
	0x7b, 0x62, 0xea, 0xe3, 0xed, 0x43, 0x67, 0xd3, 0x53, 0x55, 0x30, 0xb9, 0xb1, 0xe0, 0x30, 0x96,
	0x69, 0x63, 0x9f, 0x98, 0xcb, 0x82, 0x6e, 0x79, 0x96, 0x93, 0xc1, 0xf4, 0xe4, 0xfd, 0xe9, 0x1a,
	0x3a, 0x35, 0xaf, 0xf9, 0xa2, 0x34, 0xdb, 0x85, 0xf5, 0xf1, 0xac, 0xae, 0x4e, 0x24, 0x27, 0x22,
	0xf1, 0x65, 0x9e, 0x04, 0x09, 0x0a, 0x63, 0xc5, 0xa0, 0x4a, 0x91, 0x8c, 0xa9, 0x2d, 0x7f, 0x85,
	0xe3, 0x8d, 0xf0, 0xa7, 0x65, 0xcd, 0x77, 0x4d, 0xcd, 0x9b, 0x5f, 0x01, 0x00, 0x00, 0xff, 0xff,
	0xba, 0x34, 0x84, 0xed, 0x48, 0x04, 0x00, 0x00,
}
