// Code generated by protoc-gen-go. DO NOT EDIT.
// source: google/ads/googleads/v1/resources/video.proto

package resources

import (
	fmt "fmt"
	math "math"

	proto "github.com/golang/protobuf/proto"
	wrappers "github.com/golang/protobuf/ptypes/wrappers"
	_ "google.golang.org/genproto/googleapis/api/annotations"
)

// Reference imports to suppress errors if they are not otherwise used.
var _ = proto.Marshal
var _ = fmt.Errorf
var _ = math.Inf

// This is a compile-time assertion to ensure that this generated file
// is compatible with the proto package it is being compiled against.
// A compilation error at this line likely means your copy of the
// proto package needs to be updated.
const _ = proto.ProtoPackageIsVersion3 // please upgrade the proto package

// A video.
type Video struct {
	// The resource name of the video.
	// Video resource names have the form:
	//
	// `customers/{customer_id}/videos/{video_id}`
	ResourceName string `protobuf:"bytes,1,opt,name=resource_name,json=resourceName,proto3" json:"resource_name,omitempty"`
	// The ID of the video.
	Id *wrappers.StringValue `protobuf:"bytes,2,opt,name=id,proto3" json:"id,omitempty"`
	// The owner channel id of the video.
	ChannelId *wrappers.StringValue `protobuf:"bytes,3,opt,name=channel_id,json=channelId,proto3" json:"channel_id,omitempty"`
	// The duration of the video in milliseconds.
	DurationMillis *wrappers.Int64Value `protobuf:"bytes,4,opt,name=duration_millis,json=durationMillis,proto3" json:"duration_millis,omitempty"`
	// The title of the video.
	Title                *wrappers.StringValue `protobuf:"bytes,5,opt,name=title,proto3" json:"title,omitempty"`
	XXX_NoUnkeyedLiteral struct{}              `json:"-"`
	XXX_unrecognized     []byte                `json:"-"`
	XXX_sizecache        int32                 `json:"-"`
}

func (m *Video) Reset()         { *m = Video{} }
func (m *Video) String() string { return proto.CompactTextString(m) }
func (*Video) ProtoMessage()    {}
func (*Video) Descriptor() ([]byte, []int) {
	return fileDescriptor_a029458d5852873f, []int{0}
}

func (m *Video) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_Video.Unmarshal(m, b)
}
func (m *Video) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_Video.Marshal(b, m, deterministic)
}
func (m *Video) XXX_Merge(src proto.Message) {
	xxx_messageInfo_Video.Merge(m, src)
}
func (m *Video) XXX_Size() int {
	return xxx_messageInfo_Video.Size(m)
}
func (m *Video) XXX_DiscardUnknown() {
	xxx_messageInfo_Video.DiscardUnknown(m)
}

var xxx_messageInfo_Video proto.InternalMessageInfo

func (m *Video) GetResourceName() string {
	if m != nil {
		return m.ResourceName
	}
	return ""
}

func (m *Video) GetId() *wrappers.StringValue {
	if m != nil {
		return m.Id
	}
	return nil
}

func (m *Video) GetChannelId() *wrappers.StringValue {
	if m != nil {
		return m.ChannelId
	}
	return nil
}

func (m *Video) GetDurationMillis() *wrappers.Int64Value {
	if m != nil {
		return m.DurationMillis
	}
	return nil
}

func (m *Video) GetTitle() *wrappers.StringValue {
	if m != nil {
		return m.Title
	}
	return nil
}

func init() {
	proto.RegisterType((*Video)(nil), "google.ads.googleads.v1.resources.Video")
}

func init() {
	proto.RegisterFile("google/ads/googleads/v1/resources/video.proto", fileDescriptor_a029458d5852873f)
}

var fileDescriptor_a029458d5852873f = []byte{
	// 371 bytes of a gzipped FileDescriptorProto
	0x1f, 0x8b, 0x08, 0x00, 0x00, 0x00, 0x00, 0x00, 0x02, 0xff, 0x8c, 0x91, 0x4f, 0x4b, 0xfb, 0x30,
	0x18, 0xc7, 0x69, 0xf7, 0xdb, 0x0f, 0x16, 0xff, 0x41, 0x4f, 0x65, 0x0e, 0xd9, 0x94, 0xc1, 0x0e,
	0x9a, 0xd2, 0x29, 0x1e, 0xb2, 0x53, 0x87, 0x30, 0x26, 0x28, 0x63, 0x42, 0x0f, 0x52, 0x18, 0xd9,
	0x12, 0x6b, 0xa0, 0x4d, 0x4a, 0xd2, 0xce, 0xd7, 0xe1, 0x5b, 0xf0, 0xe8, 0x4b, 0xf1, 0xa5, 0xf8,
	0x06, 0xbc, 0x4a, 0x9b, 0xa6, 0x17, 0x41, 0x77, 0xfb, 0xb6, 0xcf, 0xe7, 0xf9, 0x3c, 0x49, 0x1e,
	0x70, 0x11, 0x0b, 0x11, 0x27, 0xd4, 0xc3, 0x44, 0x79, 0x3a, 0x96, 0x69, 0xeb, 0x7b, 0x92, 0x2a,
	0x51, 0xc8, 0x0d, 0x55, 0xde, 0x96, 0x11, 0x2a, 0x60, 0x26, 0x45, 0x2e, 0x9c, 0x81, 0x66, 0x20,
	0x26, 0x0a, 0x36, 0x38, 0xdc, 0xfa, 0xb0, 0xc1, 0xbb, 0x3d, 0x63, 0xcc, 0x98, 0x87, 0x39, 0x17,
	0x39, 0xce, 0x99, 0xe0, 0x4a, 0x0b, 0xba, 0x27, 0x75, 0xb5, 0xfa, 0x5a, 0x17, 0x4f, 0xde, 0x8b,
	0xc4, 0x59, 0x46, 0x65, 0x5d, 0x3f, 0x7d, 0xb5, 0x41, 0x3b, 0x2c, 0x07, 0x3a, 0x67, 0xe0, 0xc0,
	0x48, 0x57, 0x1c, 0xa7, 0xd4, 0xb5, 0xfa, 0xd6, 0xa8, 0xb3, 0xdc, 0x37, 0x3f, 0xef, 0x71, 0x4a,
	0x9d, 0x73, 0x60, 0x33, 0xe2, 0xda, 0x7d, 0x6b, 0xb4, 0x37, 0xee, 0xd5, 0x27, 0x82, 0xc6, 0x0d,
	0x1f, 0x72, 0xc9, 0x78, 0x1c, 0xe2, 0xa4, 0xa0, 0x4b, 0x9b, 0x11, 0x67, 0x02, 0xc0, 0xe6, 0x19,
	0x73, 0x4e, 0x93, 0x15, 0x23, 0x6e, 0x6b, 0x87, 0xae, 0x4e, 0xcd, 0xcf, 0x89, 0x73, 0x03, 0x8e,
	0x48, 0x21, 0xab, 0xcb, 0xac, 0x52, 0x96, 0x24, 0x4c, 0xb9, 0xff, 0x2a, 0xc3, 0xf1, 0x0f, 0xc3,
	0x9c, 0xe7, 0xd7, 0x57, 0x5a, 0x70, 0x68, 0x7a, 0xee, 0xaa, 0x16, 0x67, 0x0c, 0xda, 0x39, 0xcb,
	0x13, 0xea, 0xb6, 0x77, 0x98, 0xae, 0xd1, 0xe9, 0x97, 0x05, 0x86, 0x1b, 0x91, 0xc2, 0x3f, 0xdf,
	0x7e, 0x0a, 0xaa, 0xa7, 0x5b, 0x94, 0xae, 0x85, 0xf5, 0x78, 0x5b, 0x37, 0xc4, 0x22, 0xc1, 0x3c,
	0x86, 0x42, 0xc6, 0x5e, 0x4c, 0x79, 0x35, 0xc9, 0xec, 0x3a, 0x63, 0xea, 0x97, 0xd5, 0x4f, 0x9a,
	0xf4, 0x66, 0xb7, 0x66, 0x41, 0xf0, 0x6e, 0x0f, 0x66, 0x5a, 0x19, 0x10, 0x05, 0x75, 0x2c, 0x53,
	0xe8, 0xc3, 0xa5, 0x21, 0x3f, 0x0c, 0x13, 0x05, 0x44, 0x45, 0x0d, 0x13, 0x85, 0x7e, 0xd4, 0x30,
	0x9f, 0xf6, 0x50, 0x17, 0x10, 0x0a, 0x88, 0x42, 0xa8, 0xa1, 0x10, 0x0a, 0x7d, 0x84, 0x1a, 0x6e,
	0xfd, 0xbf, 0x3a, 0xec, 0xe5, 0x77, 0x00, 0x00, 0x00, 0xff, 0xff, 0x2d, 0xbe, 0x56, 0x02, 0xa6,
	0x02, 0x00, 0x00,
}
