// Code generated by protoc-gen-go. DO NOT EDIT.
// source: google/ads/googleads/v1/enums/google_ads_field_data_type.proto

package enums

import (
	fmt "fmt"
	math "math"

	proto "github.com/golang/protobuf/proto"
	_ "google.golang.org/genproto/googleapis/api/annotations"
)

// Reference imports to suppress errors if they are not otherwise used.
var _ = proto.Marshal
var _ = fmt.Errorf
var _ = math.Inf

// This is a compile-time assertion to ensure that this generated file
// is compatible with the proto package it is being compiled against.
// A compilation error at this line likely means your copy of the
// proto package needs to be updated.
const _ = proto.ProtoPackageIsVersion3 // please upgrade the proto package

// These are the various types a GoogleAdsService artifact may take on.
type GoogleAdsFieldDataTypeEnum_GoogleAdsFieldDataType int32

const (
	// Unspecified
	GoogleAdsFieldDataTypeEnum_UNSPECIFIED GoogleAdsFieldDataTypeEnum_GoogleAdsFieldDataType = 0
	// Unknown
	GoogleAdsFieldDataTypeEnum_UNKNOWN GoogleAdsFieldDataTypeEnum_GoogleAdsFieldDataType = 1
	// Maps to google.protobuf.BoolValue
	//
	// Applicable operators:  =, !=
	GoogleAdsFieldDataTypeEnum_BOOLEAN GoogleAdsFieldDataTypeEnum_GoogleAdsFieldDataType = 2
	// Maps to google.protobuf.StringValue. It can be compared using the set of
	// operators specific to dates however.
	//
	// Applicable operators:  =, <, >, <=, >=, BETWEEN, DURING, and IN
	GoogleAdsFieldDataTypeEnum_DATE GoogleAdsFieldDataTypeEnum_GoogleAdsFieldDataType = 3
	// Maps to google.protobuf.DoubleValue
	//
	// Applicable operators:  =, !=, <, >, IN, NOT IN
	GoogleAdsFieldDataTypeEnum_DOUBLE GoogleAdsFieldDataTypeEnum_GoogleAdsFieldDataType = 4
	// Maps to an enum. It's specific definition can be found at type_url.
	//
	// Applicable operators:  =, !=, IN, NOT IN
	GoogleAdsFieldDataTypeEnum_ENUM GoogleAdsFieldDataTypeEnum_GoogleAdsFieldDataType = 5
	// Maps to google.protobuf.FloatValue
	//
	// Applicable operators:  =, !=, <, >, IN, NOT IN
	GoogleAdsFieldDataTypeEnum_FLOAT GoogleAdsFieldDataTypeEnum_GoogleAdsFieldDataType = 6
	// Maps to google.protobuf.Int32Value
	//
	// Applicable operators:  =, !=, <, >, <=, >=, BETWEEN, IN, NOT IN
	GoogleAdsFieldDataTypeEnum_INT32 GoogleAdsFieldDataTypeEnum_GoogleAdsFieldDataType = 7
	// Maps to google.protobuf.Int64Value
	//
	// Applicable operators:  =, !=, <, >, <=, >=, BETWEEN, IN, NOT IN
	GoogleAdsFieldDataTypeEnum_INT64 GoogleAdsFieldDataTypeEnum_GoogleAdsFieldDataType = 8
	// Maps to a protocol buffer message type. The data type's details can be
	// found in type_url.
	//
	// No operators work with MESSAGE fields.
	GoogleAdsFieldDataTypeEnum_MESSAGE GoogleAdsFieldDataTypeEnum_GoogleAdsFieldDataType = 9
	// Maps to google.protobuf.StringValue. Represents the resource name
	// (unique id) of a resource or one of its foreign keys.
	//
	// No operators work with RESOURCE_NAME fields.
	GoogleAdsFieldDataTypeEnum_RESOURCE_NAME GoogleAdsFieldDataTypeEnum_GoogleAdsFieldDataType = 10
	// Maps to google.protobuf.StringValue.
	//
	// Applicable operators:  =, !=, LIKE, NOT LIKE, IN, NOT IN
	GoogleAdsFieldDataTypeEnum_STRING GoogleAdsFieldDataTypeEnum_GoogleAdsFieldDataType = 11
	// Maps to google.protobuf.UInt64Value
	//
	// Applicable operators:  =, !=, <, >, <=, >=, BETWEEN, IN, NOT IN
	GoogleAdsFieldDataTypeEnum_UINT64 GoogleAdsFieldDataTypeEnum_GoogleAdsFieldDataType = 12
)

var GoogleAdsFieldDataTypeEnum_GoogleAdsFieldDataType_name = map[int32]string{
	0:  "UNSPECIFIED",
	1:  "UNKNOWN",
	2:  "BOOLEAN",
	3:  "DATE",
	4:  "DOUBLE",
	5:  "ENUM",
	6:  "FLOAT",
	7:  "INT32",
	8:  "INT64",
	9:  "MESSAGE",
	10: "RESOURCE_NAME",
	11: "STRING",
	12: "UINT64",
}

var GoogleAdsFieldDataTypeEnum_GoogleAdsFieldDataType_value = map[string]int32{
	"UNSPECIFIED":   0,
	"UNKNOWN":       1,
	"BOOLEAN":       2,
	"DATE":          3,
	"DOUBLE":        4,
	"ENUM":          5,
	"FLOAT":         6,
	"INT32":         7,
	"INT64":         8,
	"MESSAGE":       9,
	"RESOURCE_NAME": 10,
	"STRING":        11,
	"UINT64":        12,
}

func (x GoogleAdsFieldDataTypeEnum_GoogleAdsFieldDataType) String() string {
	return proto.EnumName(GoogleAdsFieldDataTypeEnum_GoogleAdsFieldDataType_name, int32(x))
}

func (GoogleAdsFieldDataTypeEnum_GoogleAdsFieldDataType) EnumDescriptor() ([]byte, []int) {
	return fileDescriptor_d86b5d9b002287f6, []int{0, 0}
}

// Container holding the various data types.
type GoogleAdsFieldDataTypeEnum struct {
	XXX_NoUnkeyedLiteral struct{} `json:"-"`
	XXX_unrecognized     []byte   `json:"-"`
	XXX_sizecache        int32    `json:"-"`
}

func (m *GoogleAdsFieldDataTypeEnum) Reset()         { *m = GoogleAdsFieldDataTypeEnum{} }
func (m *GoogleAdsFieldDataTypeEnum) String() string { return proto.CompactTextString(m) }
func (*GoogleAdsFieldDataTypeEnum) ProtoMessage()    {}
func (*GoogleAdsFieldDataTypeEnum) Descriptor() ([]byte, []int) {
	return fileDescriptor_d86b5d9b002287f6, []int{0}
}

func (m *GoogleAdsFieldDataTypeEnum) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_GoogleAdsFieldDataTypeEnum.Unmarshal(m, b)
}
func (m *GoogleAdsFieldDataTypeEnum) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_GoogleAdsFieldDataTypeEnum.Marshal(b, m, deterministic)
}
func (m *GoogleAdsFieldDataTypeEnum) XXX_Merge(src proto.Message) {
	xxx_messageInfo_GoogleAdsFieldDataTypeEnum.Merge(m, src)
}
func (m *GoogleAdsFieldDataTypeEnum) XXX_Size() int {
	return xxx_messageInfo_GoogleAdsFieldDataTypeEnum.Size(m)
}
func (m *GoogleAdsFieldDataTypeEnum) XXX_DiscardUnknown() {
	xxx_messageInfo_GoogleAdsFieldDataTypeEnum.DiscardUnknown(m)
}

var xxx_messageInfo_GoogleAdsFieldDataTypeEnum proto.InternalMessageInfo

func init() {
	proto.RegisterEnum("google.ads.googleads.v1.enums.GoogleAdsFieldDataTypeEnum_GoogleAdsFieldDataType", GoogleAdsFieldDataTypeEnum_GoogleAdsFieldDataType_name, GoogleAdsFieldDataTypeEnum_GoogleAdsFieldDataType_value)
	proto.RegisterType((*GoogleAdsFieldDataTypeEnum)(nil), "google.ads.googleads.v1.enums.GoogleAdsFieldDataTypeEnum")
}

func init() {
	proto.RegisterFile("google/ads/googleads/v1/enums/google_ads_field_data_type.proto", fileDescriptor_d86b5d9b002287f6)
}

var fileDescriptor_d86b5d9b002287f6 = []byte{
	// 398 bytes of a gzipped FileDescriptorProto
	0x1f, 0x8b, 0x08, 0x00, 0x00, 0x00, 0x00, 0x00, 0x02, 0xff, 0x7c, 0x51, 0xcf, 0x8e, 0x93, 0x40,
	0x18, 0x17, 0x76, 0xb7, 0xbb, 0x3b, 0xd5, 0x38, 0x72, 0xf0, 0xb0, 0xba, 0x87, 0xdd, 0x07, 0x18,
	0x82, 0x6b, 0x3c, 0x8c, 0x89, 0xc9, 0x50, 0xa6, 0x84, 0xd8, 0x0e, 0x4d, 0x81, 0x9a, 0x18, 0x12,
	0x32, 0x3a, 0x48, 0x48, 0x5a, 0x86, 0x74, 0x68, 0x93, 0xbe, 0x8e, 0x47, 0x9f, 0xc1, 0x27, 0xf0,
	0x15, 0x7c, 0x03, 0x4f, 0x3e, 0x82, 0x19, 0x28, 0x9c, 0xea, 0x5e, 0xc8, 0x8f, 0xef, 0xf7, 0xe7,
	0x83, 0xdf, 0x07, 0x3e, 0x14, 0x52, 0x16, 0xeb, 0xdc, 0xe6, 0x42, 0xd9, 0x1d, 0xd4, 0x68, 0xef,
	0xd8, 0x79, 0xb5, 0xdb, 0xf4, 0xa3, 0x8c, 0x0b, 0x95, 0x7d, 0x2b, 0xf3, 0xb5, 0xc8, 0x04, 0x6f,
	0x78, 0xd6, 0x1c, 0xea, 0x1c, 0xd5, 0x5b, 0xd9, 0x48, 0xeb, 0xb6, 0x53, 0x20, 0x2e, 0x14, 0x1a,
	0xfc, 0x68, 0xef, 0xa0, 0xd6, 0x7f, 0xf3, 0xba, 0x8f, 0xaf, 0x4b, 0x9b, 0x57, 0x95, 0x6c, 0x78,
	0x53, 0xca, 0x4a, 0x75, 0xe6, 0xfb, 0xdf, 0x06, 0xb8, 0xf1, 0x5b, 0x01, 0x11, 0x6a, 0xaa, 0xf3,
	0x3d, 0xde, 0xf0, 0xf8, 0x50, 0xe7, 0xb4, 0xda, 0x6d, 0xee, 0x7f, 0x1a, 0xe0, 0xe5, 0x69, 0xda,
	0x7a, 0x0e, 0xc6, 0x09, 0x8b, 0x16, 0x74, 0x12, 0x4c, 0x03, 0xea, 0xc1, 0x27, 0xd6, 0x18, 0x5c,
	0x26, 0xec, 0x23, 0x0b, 0x3f, 0x31, 0x68, 0xe8, 0x17, 0x37, 0x0c, 0x67, 0x94, 0x30, 0x68, 0x5a,
	0x57, 0xe0, 0xdc, 0x23, 0x31, 0x85, 0x67, 0x16, 0x00, 0x23, 0x2f, 0x4c, 0xdc, 0x19, 0x85, 0xe7,
	0x7a, 0x4a, 0x59, 0x32, 0x87, 0x17, 0xd6, 0x35, 0xb8, 0x98, 0xce, 0x42, 0x12, 0xc3, 0x91, 0x86,
	0x01, 0x8b, 0x1f, 0xde, 0xc0, 0xcb, 0x23, 0x7c, 0xf7, 0x16, 0x5e, 0xe9, 0xb4, 0x39, 0x8d, 0x22,
	0xe2, 0x53, 0x78, 0x6d, 0xbd, 0x00, 0xcf, 0x96, 0x34, 0x0a, 0x93, 0xe5, 0x84, 0x66, 0x8c, 0xcc,
	0x29, 0x04, 0x3a, 0x36, 0x8a, 0x97, 0x01, 0xf3, 0xe1, 0x58, 0xe3, 0xa4, 0xf3, 0x3d, 0x75, 0xff,
	0x1a, 0xe0, 0xee, 0xab, 0xdc, 0xa0, 0x47, 0x1b, 0x72, 0x5f, 0x9d, 0xfe, 0xc3, 0x85, 0x2e, 0x68,
	0x61, 0x7c, 0x76, 0x8f, 0xee, 0x42, 0xae, 0x79, 0x55, 0x20, 0xb9, 0x2d, 0xec, 0x22, 0xaf, 0xda,
	0xfa, 0xfa, 0x7b, 0xd5, 0xa5, 0xfa, 0xcf, 0xf9, 0xde, 0xb7, 0xcf, 0xef, 0xe6, 0x99, 0x4f, 0xc8,
	0x0f, 0xf3, 0xb6, 0xdb, 0x84, 0x88, 0x50, 0x68, 0x58, 0x8a, 0x56, 0x0e, 0xd2, 0x65, 0xab, 0x5f,
	0x3d, 0x9f, 0x12, 0xa1, 0xd2, 0x81, 0x4f, 0x57, 0x4e, 0xda, 0xf2, 0x7f, 0xcc, 0xbb, 0x6e, 0x88,
	0x31, 0x11, 0x0a, 0xe3, 0x41, 0x81, 0xf1, 0xca, 0xc1, 0xb8, 0xd5, 0x7c, 0x19, 0xb5, 0x1f, 0xf6,
	0xf0, 0x2f, 0x00, 0x00, 0xff, 0xff, 0x92, 0x3a, 0x3d, 0x17, 0x56, 0x02, 0x00, 0x00,
}
