// Code generated by protoc-gen-go. DO NOT EDIT.
// source: google/ads/googleads/v2/enums/campaign_experiment_traffic_split_type.proto

package enums

import (
	fmt "fmt"
	math "math"

	proto "github.com/golang/protobuf/proto"
	_ "google.golang.org/genproto/googleapis/api/annotations"
)

// Reference imports to suppress errors if they are not otherwise used.
var _ = proto.Marshal
var _ = fmt.Errorf
var _ = math.Inf

// This is a compile-time assertion to ensure that this generated file
// is compatible with the proto package it is being compiled against.
// A compilation error at this line likely means your copy of the
// proto package needs to be updated.
const _ = proto.ProtoPackageIsVersion3 // please upgrade the proto package

// Enum of strategies for splitting traffic between base and experiment
// campaigns in campaign experiment.
type CampaignExperimentTrafficSplitTypeEnum_CampaignExperimentTrafficSplitType int32

const (
	// Not specified.
	CampaignExperimentTrafficSplitTypeEnum_UNSPECIFIED CampaignExperimentTrafficSplitTypeEnum_CampaignExperimentTrafficSplitType = 0
	// Used for return value only. Represents value unknown in this version.
	CampaignExperimentTrafficSplitTypeEnum_UNKNOWN CampaignExperimentTrafficSplitTypeEnum_CampaignExperimentTrafficSplitType = 1
	// Traffic is randomly assigned to the base or experiment arm for each
	// query, independent of previous assignments for the same user.
	CampaignExperimentTrafficSplitTypeEnum_RANDOM_QUERY CampaignExperimentTrafficSplitTypeEnum_CampaignExperimentTrafficSplitType = 2
	// Traffic is split using cookies to keep users in the same arm (base or
	// experiment) of the experiment.
	CampaignExperimentTrafficSplitTypeEnum_COOKIE CampaignExperimentTrafficSplitTypeEnum_CampaignExperimentTrafficSplitType = 3
)

var CampaignExperimentTrafficSplitTypeEnum_CampaignExperimentTrafficSplitType_name = map[int32]string{
	0: "UNSPECIFIED",
	1: "UNKNOWN",
	2: "RANDOM_QUERY",
	3: "COOKIE",
}

var CampaignExperimentTrafficSplitTypeEnum_CampaignExperimentTrafficSplitType_value = map[string]int32{
	"UNSPECIFIED":  0,
	"UNKNOWN":      1,
	"RANDOM_QUERY": 2,
	"COOKIE":       3,
}

func (x CampaignExperimentTrafficSplitTypeEnum_CampaignExperimentTrafficSplitType) String() string {
	return proto.EnumName(CampaignExperimentTrafficSplitTypeEnum_CampaignExperimentTrafficSplitType_name, int32(x))
}

func (CampaignExperimentTrafficSplitTypeEnum_CampaignExperimentTrafficSplitType) EnumDescriptor() ([]byte, []int) {
	return fileDescriptor_b4d6dfa929344a7d, []int{0, 0}
}

// Container for enum describing campaign experiment traffic split type.
type CampaignExperimentTrafficSplitTypeEnum struct {
	XXX_NoUnkeyedLiteral struct{} `json:"-"`
	XXX_unrecognized     []byte   `json:"-"`
	XXX_sizecache        int32    `json:"-"`
}

func (m *CampaignExperimentTrafficSplitTypeEnum) Reset() {
	*m = CampaignExperimentTrafficSplitTypeEnum{}
}
func (m *CampaignExperimentTrafficSplitTypeEnum) String() string { return proto.CompactTextString(m) }
func (*CampaignExperimentTrafficSplitTypeEnum) ProtoMessage()    {}
func (*CampaignExperimentTrafficSplitTypeEnum) Descriptor() ([]byte, []int) {
	return fileDescriptor_b4d6dfa929344a7d, []int{0}
}

func (m *CampaignExperimentTrafficSplitTypeEnum) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_CampaignExperimentTrafficSplitTypeEnum.Unmarshal(m, b)
}
func (m *CampaignExperimentTrafficSplitTypeEnum) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_CampaignExperimentTrafficSplitTypeEnum.Marshal(b, m, deterministic)
}
func (m *CampaignExperimentTrafficSplitTypeEnum) XXX_Merge(src proto.Message) {
	xxx_messageInfo_CampaignExperimentTrafficSplitTypeEnum.Merge(m, src)
}
func (m *CampaignExperimentTrafficSplitTypeEnum) XXX_Size() int {
	return xxx_messageInfo_CampaignExperimentTrafficSplitTypeEnum.Size(m)
}
func (m *CampaignExperimentTrafficSplitTypeEnum) XXX_DiscardUnknown() {
	xxx_messageInfo_CampaignExperimentTrafficSplitTypeEnum.DiscardUnknown(m)
}

var xxx_messageInfo_CampaignExperimentTrafficSplitTypeEnum proto.InternalMessageInfo

func init() {
	proto.RegisterEnum("google.ads.googleads.v2.enums.CampaignExperimentTrafficSplitTypeEnum_CampaignExperimentTrafficSplitType", CampaignExperimentTrafficSplitTypeEnum_CampaignExperimentTrafficSplitType_name, CampaignExperimentTrafficSplitTypeEnum_CampaignExperimentTrafficSplitType_value)
	proto.RegisterType((*CampaignExperimentTrafficSplitTypeEnum)(nil), "google.ads.googleads.v2.enums.CampaignExperimentTrafficSplitTypeEnum")
}

func init() {
	proto.RegisterFile("google/ads/googleads/v2/enums/campaign_experiment_traffic_split_type.proto", fileDescriptor_b4d6dfa929344a7d)
}

var fileDescriptor_b4d6dfa929344a7d = []byte{
	// 341 bytes of a gzipped FileDescriptorProto
	0x1f, 0x8b, 0x08, 0x00, 0x00, 0x00, 0x00, 0x00, 0x02, 0xff, 0x84, 0x51, 0xcd, 0x6a, 0xe3, 0x30,
	0x18, 0x5c, 0x3b, 0x90, 0x05, 0x65, 0x61, 0x8d, 0x8f, 0xcb, 0xe6, 0x90, 0x1c, 0xda, 0x9b, 0x0c,
	0xee, 0x4d, 0x3d, 0x39, 0x89, 0x1b, 0xd2, 0x50, 0x3b, 0xcd, 0x5f, 0x69, 0x31, 0xb8, 0x6a, 0xac,
	0x08, 0x41, 0x2c, 0x09, 0x4b, 0x09, 0xcd, 0x2b, 0xf4, 0x31, 0x7a, 0xec, 0xa3, 0xf4, 0x51, 0xfa,
	0x0c, 0x3d, 0x14, 0x5b, 0x89, 0x6f, 0x6d, 0x2e, 0x62, 0xd0, 0x8c, 0x66, 0xbe, 0xf9, 0x04, 0xae,
	0xa9, 0x10, 0x74, 0x43, 0x3c, 0x9c, 0x29, 0xcf, 0xc0, 0x12, 0xed, 0x7c, 0x8f, 0xf0, 0x6d, 0xae,
	0xbc, 0x15, 0xce, 0x25, 0x66, 0x94, 0xa7, 0xe4, 0x59, 0x92, 0x82, 0xe5, 0x84, 0xeb, 0x54, 0x17,
	0x78, 0xbd, 0x66, 0xab, 0x54, 0xc9, 0x0d, 0xd3, 0xa9, 0xde, 0x4b, 0x02, 0x65, 0x21, 0xb4, 0x70,
	0xdb, 0xc6, 0x00, 0xe2, 0x4c, 0xc1, 0xda, 0x0b, 0xee, 0x7c, 0x58, 0x79, 0xfd, 0xfb, 0x7f, 0x8c,
	0x92, 0xcc, 0xc3, 0x9c, 0x0b, 0x8d, 0x35, 0x13, 0x5c, 0x99, 0xc7, 0xdd, 0x17, 0x0b, 0x9c, 0xf5,
	0x0f, 0x69, 0x61, 0x1d, 0x36, 0x37, 0x59, 0xb3, 0x32, 0x6a, 0xbe, 0x97, 0x24, 0xe4, 0xdb, 0xbc,
	0xfb, 0x08, 0xba, 0xa7, 0x95, 0xee, 0x5f, 0xd0, 0x5a, 0x44, 0xb3, 0x49, 0xd8, 0x1f, 0x5d, 0x8d,
	0xc2, 0x81, 0xf3, 0xcb, 0x6d, 0x81, 0xdf, 0x8b, 0x68, 0x1c, 0xc5, 0x77, 0x91, 0x63, 0xb9, 0x0e,
	0xf8, 0x33, 0x0d, 0xa2, 0x41, 0x7c, 0x93, 0xde, 0x2e, 0xc2, 0xe9, 0xbd, 0x63, 0xbb, 0x00, 0x34,
	0xfb, 0x71, 0x3c, 0x1e, 0x85, 0x4e, 0xa3, 0xf7, 0x69, 0x81, 0xce, 0x4a, 0xe4, 0xf0, 0xc7, 0x42,
	0xbd, 0xf3, 0xd3, 0x53, 0x4c, 0xca, 0x6e, 0x13, 0xeb, 0xa1, 0x77, 0x70, 0xa2, 0x62, 0x83, 0x39,
	0x85, 0xa2, 0xa0, 0x1e, 0x25, 0xbc, 0x6a, 0x7e, 0x5c, 0xbb, 0x64, 0xea, 0x9b, 0x5f, 0xb8, 0xac,
	0xce, 0x57, 0xbb, 0x31, 0x0c, 0x82, 0x37, 0xbb, 0x3d, 0x34, 0x56, 0x41, 0xa6, 0xa0, 0x81, 0x25,
	0x5a, 0xfa, 0xb0, 0xdc, 0x8d, 0x7a, 0x3f, 0xf2, 0x49, 0x90, 0xa9, 0xa4, 0xe6, 0x93, 0xa5, 0x9f,
	0x54, 0xfc, 0x87, 0xdd, 0x31, 0x97, 0x08, 0x05, 0x99, 0x42, 0xa8, 0x56, 0x20, 0xb4, 0xf4, 0x11,
	0xaa, 0x34, 0x4f, 0xcd, 0x6a, 0xb0, 0x8b, 0xaf, 0x00, 0x00, 0x00, 0xff, 0xff, 0x45, 0x8c, 0xca,
	0x9b, 0x1d, 0x02, 0x00, 0x00,
}
