// Code generated by protoc-gen-go. DO NOT EDIT.
// source: google/ads/googleads/v2/resources/customer_extension_setting.proto

package resources

import (
	fmt "fmt"
	math "math"

	proto "github.com/golang/protobuf/proto"
	wrappers "github.com/golang/protobuf/ptypes/wrappers"
	enums "google.golang.org/genproto/googleapis/ads/googleads/v2/enums"
	_ "google.golang.org/genproto/googleapis/api/annotations"
)

// Reference imports to suppress errors if they are not otherwise used.
var _ = proto.Marshal
var _ = fmt.Errorf
var _ = math.Inf

// This is a compile-time assertion to ensure that this generated file
// is compatible with the proto package it is being compiled against.
// A compilation error at this line likely means your copy of the
// proto package needs to be updated.
const _ = proto.ProtoPackageIsVersion3 // please upgrade the proto package

// A customer extension setting.
type CustomerExtensionSetting struct {
	// The resource name of the customer extension setting.
	// CustomerExtensionSetting resource names have the form:
	//
	// `customers/{customer_id}/customerExtensionSettings/{extension_type}`
	ResourceName string `protobuf:"bytes,1,opt,name=resource_name,json=resourceName,proto3" json:"resource_name,omitempty"`
	// The extension type of the customer extension setting.
	ExtensionType enums.ExtensionTypeEnum_ExtensionType `protobuf:"varint,2,opt,name=extension_type,json=extensionType,proto3,enum=google.ads.googleads.v2.enums.ExtensionTypeEnum_ExtensionType" json:"extension_type,omitempty"`
	// The resource names of the extension feed items to serve under the customer.
	// ExtensionFeedItem resource names have the form:
	//
	// `customers/{customer_id}/extensionFeedItems/{feed_item_id}`
	ExtensionFeedItems []*wrappers.StringValue `protobuf:"bytes,3,rep,name=extension_feed_items,json=extensionFeedItems,proto3" json:"extension_feed_items,omitempty"`
	// The device for which the extensions will serve. Optional.
	Device               enums.ExtensionSettingDeviceEnum_ExtensionSettingDevice `protobuf:"varint,4,opt,name=device,proto3,enum=google.ads.googleads.v2.enums.ExtensionSettingDeviceEnum_ExtensionSettingDevice" json:"device,omitempty"`
	XXX_NoUnkeyedLiteral struct{}                                                `json:"-"`
	XXX_unrecognized     []byte                                                  `json:"-"`
	XXX_sizecache        int32                                                   `json:"-"`
}

func (m *CustomerExtensionSetting) Reset()         { *m = CustomerExtensionSetting{} }
func (m *CustomerExtensionSetting) String() string { return proto.CompactTextString(m) }
func (*CustomerExtensionSetting) ProtoMessage()    {}
func (*CustomerExtensionSetting) Descriptor() ([]byte, []int) {
	return fileDescriptor_cd04e47360d4a207, []int{0}
}

func (m *CustomerExtensionSetting) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_CustomerExtensionSetting.Unmarshal(m, b)
}
func (m *CustomerExtensionSetting) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_CustomerExtensionSetting.Marshal(b, m, deterministic)
}
func (m *CustomerExtensionSetting) XXX_Merge(src proto.Message) {
	xxx_messageInfo_CustomerExtensionSetting.Merge(m, src)
}
func (m *CustomerExtensionSetting) XXX_Size() int {
	return xxx_messageInfo_CustomerExtensionSetting.Size(m)
}
func (m *CustomerExtensionSetting) XXX_DiscardUnknown() {
	xxx_messageInfo_CustomerExtensionSetting.DiscardUnknown(m)
}

var xxx_messageInfo_CustomerExtensionSetting proto.InternalMessageInfo

func (m *CustomerExtensionSetting) GetResourceName() string {
	if m != nil {
		return m.ResourceName
	}
	return ""
}

func (m *CustomerExtensionSetting) GetExtensionType() enums.ExtensionTypeEnum_ExtensionType {
	if m != nil {
		return m.ExtensionType
	}
	return enums.ExtensionTypeEnum_UNSPECIFIED
}

func (m *CustomerExtensionSetting) GetExtensionFeedItems() []*wrappers.StringValue {
	if m != nil {
		return m.ExtensionFeedItems
	}
	return nil
}

func (m *CustomerExtensionSetting) GetDevice() enums.ExtensionSettingDeviceEnum_ExtensionSettingDevice {
	if m != nil {
		return m.Device
	}
	return enums.ExtensionSettingDeviceEnum_UNSPECIFIED
}

func init() {
	proto.RegisterType((*CustomerExtensionSetting)(nil), "google.ads.googleads.v2.resources.CustomerExtensionSetting")
}

func init() {
	proto.RegisterFile("google/ads/googleads/v2/resources/customer_extension_setting.proto", fileDescriptor_cd04e47360d4a207)
}

var fileDescriptor_cd04e47360d4a207 = []byte{
	// 430 bytes of a gzipped FileDescriptorProto
	0x1f, 0x8b, 0x08, 0x00, 0x00, 0x00, 0x00, 0x00, 0x02, 0xff, 0x8c, 0x52, 0xd1, 0x6a, 0x14, 0x31,
	0x14, 0x65, 0x67, 0xa5, 0xe0, 0x68, 0xfb, 0x30, 0xf8, 0x30, 0x94, 0x2a, 0x5b, 0xa5, 0xb0, 0x4f,
	0x09, 0xc4, 0xb7, 0x28, 0xc2, 0xac, 0xd6, 0xa2, 0x0f, 0x65, 0x99, 0xca, 0x3e, 0xc8, 0xc2, 0x90,
	0x6e, 0x6e, 0x63, 0x60, 0x27, 0x19, 0x92, 0xcc, 0x6a, 0x7f, 0xc1, 0xcf, 0xf0, 0xd1, 0x4f, 0xf1,
	0x2b, 0x7c, 0xf6, 0x2b, 0x64, 0x27, 0x93, 0xe8, 0x20, 0x6b, 0xf7, 0xed, 0x4e, 0xee, 0x39, 0xe7,
	0x9e, 0x73, 0xe7, 0xa6, 0x33, 0xa1, 0xb5, 0x58, 0x03, 0x66, 0xdc, 0x62, 0x5f, 0x6e, 0xab, 0x0d,
	0xc1, 0x06, 0xac, 0x6e, 0xcd, 0x0a, 0x2c, 0x5e, 0xb5, 0xd6, 0xe9, 0x1a, 0x4c, 0x05, 0x5f, 0x1c,
	0x28, 0x2b, 0xb5, 0xaa, 0x2c, 0x38, 0x27, 0x95, 0x40, 0x8d, 0xd1, 0x4e, 0x67, 0xa7, 0x9e, 0x88,
	0x18, 0xb7, 0x28, 0x6a, 0xa0, 0x0d, 0x41, 0x51, 0xe3, 0xf8, 0xe5, 0xae, 0x31, 0xa0, 0xda, 0xda,
	0xe2, 0x7f, 0x94, 0x2b, 0x0e, 0x1b, 0xb9, 0x02, 0x3f, 0xe0, 0x98, 0xec, 0xcb, 0x76, 0xb7, 0x4d,
	0xe0, 0x3c, 0xe9, 0x39, 0xdd, 0xd7, 0x75, 0x7b, 0x83, 0x3f, 0x1b, 0xd6, 0x34, 0x60, 0x6c, 0xdf,
	0x3f, 0x09, 0x9a, 0x8d, 0xc4, 0x4c, 0x29, 0xed, 0x98, 0x93, 0x5a, 0xf5, 0xdd, 0xa7, 0x3f, 0x93,
	0x34, 0x7f, 0xdd, 0xe7, 0x3e, 0x0f, 0xf2, 0x57, 0xde, 0x5b, 0xf6, 0x2c, 0x3d, 0x0c, 0xc9, 0x2a,
	0xc5, 0x6a, 0xc8, 0x47, 0x93, 0xd1, 0xf4, 0x7e, 0xf9, 0x30, 0x3c, 0x5e, 0xb2, 0x1a, 0x32, 0x48,
	0x8f, 0x86, 0xbe, 0xf2, 0x64, 0x32, 0x9a, 0x1e, 0x91, 0x57, 0x68, 0xd7, 0xb6, 0xba, 0x30, 0x28,
	0x4e, 0xfb, 0x70, 0xdb, 0xc0, 0xb9, 0x6a, 0xeb, 0xe1, 0x4b, 0x79, 0x08, 0x7f, 0x7f, 0x66, 0x97,
	0xe9, 0xa3, 0x3f, 0x63, 0x6e, 0x00, 0x78, 0x25, 0x1d, 0xd4, 0x36, 0x1f, 0x4f, 0xc6, 0xd3, 0x07,
	0xe4, 0x24, 0x0c, 0x0b, 0x5b, 0x40, 0x57, 0xce, 0x48, 0x25, 0x16, 0x6c, 0xdd, 0x42, 0x99, 0x45,
	0xe6, 0x5b, 0x00, 0xfe, 0x6e, 0xcb, 0xcb, 0x3e, 0xa5, 0x07, 0x7e, 0xf5, 0xf9, 0xbd, 0xce, 0xee,
	0x7c, 0x5f, 0xbb, 0xfd, 0x72, 0xde, 0x74, 0xe4, 0xa1, 0xef, 0x41, 0xab, 0xec, 0xf5, 0x67, 0x5f,
	0x93, 0xf4, 0x6c, 0xa5, 0x6b, 0x74, 0xe7, 0xf1, 0xcc, 0x1e, 0xef, 0xfa, 0x13, 0xf3, 0x6d, 0xaa,
	0xf9, 0xe8, 0xe3, 0xfb, 0x5e, 0x43, 0xe8, 0x35, 0x53, 0x02, 0x69, 0x23, 0xb0, 0x00, 0xd5, 0x65,
	0x0e, 0xf7, 0xd2, 0x48, 0xfb, 0x9f, 0x1b, 0x7f, 0x11, 0xab, 0x6f, 0xc9, 0xf8, 0xa2, 0x28, 0xbe,
	0x27, 0xa7, 0x17, 0x5e, 0xb2, 0xe0, 0x16, 0xf9, 0x72, 0x5b, 0x2d, 0x08, 0x2a, 0x03, 0xf2, 0x47,
	0xc0, 0x2c, 0x0b, 0x6e, 0x97, 0x11, 0xb3, 0x5c, 0x90, 0x65, 0xc4, 0xfc, 0x4a, 0xce, 0x7c, 0x83,
	0xd2, 0x82, 0x5b, 0x4a, 0x23, 0x8a, 0xd2, 0x05, 0xa1, 0x34, 0xe2, 0xae, 0x0f, 0x3a, 0xb3, 0xcf,
	0x7f, 0x07, 0x00, 0x00, 0xff, 0xff, 0xb7, 0xa7, 0x0b, 0xac, 0x8f, 0x03, 0x00, 0x00,
}
