// Code generated by protoc-gen-go. DO NOT EDIT.
// source: google/ads/googleads/v2/resources/ad_group_criterion.proto

package resources

import (
	fmt "fmt"
	math "math"

	proto "github.com/golang/protobuf/proto"
	wrappers "github.com/golang/protobuf/ptypes/wrappers"
	common "google.golang.org/genproto/googleapis/ads/googleads/v2/common"
	enums "google.golang.org/genproto/googleapis/ads/googleads/v2/enums"
	_ "google.golang.org/genproto/googleapis/api/annotations"
)

// Reference imports to suppress errors if they are not otherwise used.
var _ = proto.Marshal
var _ = fmt.Errorf
var _ = math.Inf

// This is a compile-time assertion to ensure that this generated file
// is compatible with the proto package it is being compiled against.
// A compilation error at this line likely means your copy of the
// proto package needs to be updated.
const _ = proto.ProtoPackageIsVersion3 // please upgrade the proto package

// An ad group criterion.
type AdGroupCriterion struct {
	// The resource name of the ad group criterion.
	// Ad group criterion resource names have the form:
	//
	// `customers/{customer_id}/adGroupCriteria/{ad_group_id}~{criterion_id}`
	ResourceName string `protobuf:"bytes,1,opt,name=resource_name,json=resourceName,proto3" json:"resource_name,omitempty"`
	// The ID of the criterion.
	//
	// This field is ignored for mutates.
	CriterionId *wrappers.Int64Value `protobuf:"bytes,26,opt,name=criterion_id,json=criterionId,proto3" json:"criterion_id,omitempty"`
	// The status of the criterion.
	Status enums.AdGroupCriterionStatusEnum_AdGroupCriterionStatus `protobuf:"varint,3,opt,name=status,proto3,enum=google.ads.googleads.v2.enums.AdGroupCriterionStatusEnum_AdGroupCriterionStatus" json:"status,omitempty"`
	// Information regarding the quality of the criterion.
	QualityInfo *AdGroupCriterion_QualityInfo `protobuf:"bytes,4,opt,name=quality_info,json=qualityInfo,proto3" json:"quality_info,omitempty"`
	// The ad group to which the criterion belongs.
	AdGroup *wrappers.StringValue `protobuf:"bytes,5,opt,name=ad_group,json=adGroup,proto3" json:"ad_group,omitempty"`
	// The type of the criterion.
	Type enums.CriterionTypeEnum_CriterionType `protobuf:"varint,25,opt,name=type,proto3,enum=google.ads.googleads.v2.enums.CriterionTypeEnum_CriterionType" json:"type,omitempty"`
	// Whether to target (`false`) or exclude (`true`) the criterion.
	//
	// This field is immutable. To switch a criterion from positive to negative,
	// remove then re-add it.
	Negative *wrappers.BoolValue `protobuf:"bytes,31,opt,name=negative,proto3" json:"negative,omitempty"`
	// Serving status of the criterion.
	SystemServingStatus enums.CriterionSystemServingStatusEnum_CriterionSystemServingStatus `protobuf:"varint,52,opt,name=system_serving_status,json=systemServingStatus,proto3,enum=google.ads.googleads.v2.enums.CriterionSystemServingStatusEnum_CriterionSystemServingStatus" json:"system_serving_status,omitempty"`
	// Approval status of the criterion.
	ApprovalStatus enums.AdGroupCriterionApprovalStatusEnum_AdGroupCriterionApprovalStatus `protobuf:"varint,53,opt,name=approval_status,json=approvalStatus,proto3,enum=google.ads.googleads.v2.enums.AdGroupCriterionApprovalStatusEnum_AdGroupCriterionApprovalStatus" json:"approval_status,omitempty"`
	// The modifier for the bid when the criterion matches. The modifier must be
	// in the range: 0.1 - 10.0. Most targetable criteria types support modifiers.
	BidModifier *wrappers.DoubleValue `protobuf:"bytes,44,opt,name=bid_modifier,json=bidModifier,proto3" json:"bid_modifier,omitempty"`
	// The CPC (cost-per-click) bid.
	CpcBidMicros *wrappers.Int64Value `protobuf:"bytes,16,opt,name=cpc_bid_micros,json=cpcBidMicros,proto3" json:"cpc_bid_micros,omitempty"`
	// The CPM (cost-per-thousand viewable impressions) bid.
	CpmBidMicros *wrappers.Int64Value `protobuf:"bytes,17,opt,name=cpm_bid_micros,json=cpmBidMicros,proto3" json:"cpm_bid_micros,omitempty"`
	// The CPV (cost-per-view) bid.
	CpvBidMicros *wrappers.Int64Value `protobuf:"bytes,24,opt,name=cpv_bid_micros,json=cpvBidMicros,proto3" json:"cpv_bid_micros,omitempty"`
	// The CPC bid amount, expressed as a fraction of the advertised price
	// for some good or service. The valid range for the fraction is [0,1) and the
	// value stored here is 1,000,000 * [fraction].
	PercentCpcBidMicros *wrappers.Int64Value `protobuf:"bytes,33,opt,name=percent_cpc_bid_micros,json=percentCpcBidMicros,proto3" json:"percent_cpc_bid_micros,omitempty"`
	// The effective CPC (cost-per-click) bid.
	EffectiveCpcBidMicros *wrappers.Int64Value `protobuf:"bytes,18,opt,name=effective_cpc_bid_micros,json=effectiveCpcBidMicros,proto3" json:"effective_cpc_bid_micros,omitempty"`
	// The effective CPM (cost-per-thousand viewable impressions) bid.
	EffectiveCpmBidMicros *wrappers.Int64Value `protobuf:"bytes,19,opt,name=effective_cpm_bid_micros,json=effectiveCpmBidMicros,proto3" json:"effective_cpm_bid_micros,omitempty"`
	// The effective CPV (cost-per-view) bid.
	EffectiveCpvBidMicros *wrappers.Int64Value `protobuf:"bytes,20,opt,name=effective_cpv_bid_micros,json=effectiveCpvBidMicros,proto3" json:"effective_cpv_bid_micros,omitempty"`
	// The effective Percent CPC bid amount.
	EffectivePercentCpcBidMicros *wrappers.Int64Value `protobuf:"bytes,34,opt,name=effective_percent_cpc_bid_micros,json=effectivePercentCpcBidMicros,proto3" json:"effective_percent_cpc_bid_micros,omitempty"`
	// Source of the effective CPC bid.
	EffectiveCpcBidSource enums.BiddingSourceEnum_BiddingSource `protobuf:"varint,21,opt,name=effective_cpc_bid_source,json=effectiveCpcBidSource,proto3,enum=google.ads.googleads.v2.enums.BiddingSourceEnum_BiddingSource" json:"effective_cpc_bid_source,omitempty"`
	// Source of the effective CPM bid.
	EffectiveCpmBidSource enums.BiddingSourceEnum_BiddingSource `protobuf:"varint,22,opt,name=effective_cpm_bid_source,json=effectiveCpmBidSource,proto3,enum=google.ads.googleads.v2.enums.BiddingSourceEnum_BiddingSource" json:"effective_cpm_bid_source,omitempty"`
	// Source of the effective CPV bid.
	EffectiveCpvBidSource enums.BiddingSourceEnum_BiddingSource `protobuf:"varint,23,opt,name=effective_cpv_bid_source,json=effectiveCpvBidSource,proto3,enum=google.ads.googleads.v2.enums.BiddingSourceEnum_BiddingSource" json:"effective_cpv_bid_source,omitempty"`
	// Source of the effective Percent CPC bid.
	EffectivePercentCpcBidSource enums.BiddingSourceEnum_BiddingSource `protobuf:"varint,35,opt,name=effective_percent_cpc_bid_source,json=effectivePercentCpcBidSource,proto3,enum=google.ads.googleads.v2.enums.BiddingSourceEnum_BiddingSource" json:"effective_percent_cpc_bid_source,omitempty"`
	// Estimates for criterion bids at various positions.
	PositionEstimates *AdGroupCriterion_PositionEstimates `protobuf:"bytes,10,opt,name=position_estimates,json=positionEstimates,proto3" json:"position_estimates,omitempty"`
	// The list of possible final URLs after all cross-domain redirects for the
	// ad.
	FinalUrls []*wrappers.StringValue `protobuf:"bytes,11,rep,name=final_urls,json=finalUrls,proto3" json:"final_urls,omitempty"`
	// The list of possible final mobile URLs after all cross-domain redirects.
	FinalMobileUrls []*wrappers.StringValue `protobuf:"bytes,51,rep,name=final_mobile_urls,json=finalMobileUrls,proto3" json:"final_mobile_urls,omitempty"`
	// URL template for appending params to final URL.
	FinalUrlSuffix *wrappers.StringValue `protobuf:"bytes,50,opt,name=final_url_suffix,json=finalUrlSuffix,proto3" json:"final_url_suffix,omitempty"`
	// The URL template for constructing a tracking URL.
	TrackingUrlTemplate *wrappers.StringValue `protobuf:"bytes,13,opt,name=tracking_url_template,json=trackingUrlTemplate,proto3" json:"tracking_url_template,omitempty"`
	// The list of mappings used to substitute custom parameter tags in a
	// `tracking_url_template`, `final_urls`, or `mobile_final_urls`.
	UrlCustomParameters []*common.CustomParameter `protobuf:"bytes,14,rep,name=url_custom_parameters,json=urlCustomParameters,proto3" json:"url_custom_parameters,omitempty"`
	// The ad group criterion.
	//
	// Exactly one must be set.
	//
	// Types that are valid to be assigned to Criterion:
	//	*AdGroupCriterion_Keyword
	//	*AdGroupCriterion_Placement
	//	*AdGroupCriterion_MobileAppCategory
	//	*AdGroupCriterion_MobileApplication
	//	*AdGroupCriterion_ListingGroup
	//	*AdGroupCriterion_AgeRange
	//	*AdGroupCriterion_Gender
	//	*AdGroupCriterion_IncomeRange
	//	*AdGroupCriterion_ParentalStatus
	//	*AdGroupCriterion_UserList
	//	*AdGroupCriterion_YoutubeVideo
	//	*AdGroupCriterion_YoutubeChannel
	//	*AdGroupCriterion_Topic
	//	*AdGroupCriterion_UserInterest
	//	*AdGroupCriterion_Webpage
	//	*AdGroupCriterion_AppPaymentModel
	//	*AdGroupCriterion_CustomAffinity
	//	*AdGroupCriterion_CustomIntent
	Criterion            isAdGroupCriterion_Criterion `protobuf_oneof:"criterion"`
	XXX_NoUnkeyedLiteral struct{}                     `json:"-"`
	XXX_unrecognized     []byte                       `json:"-"`
	XXX_sizecache        int32                        `json:"-"`
}

func (m *AdGroupCriterion) Reset()         { *m = AdGroupCriterion{} }
func (m *AdGroupCriterion) String() string { return proto.CompactTextString(m) }
func (*AdGroupCriterion) ProtoMessage()    {}
func (*AdGroupCriterion) Descriptor() ([]byte, []int) {
	return fileDescriptor_9b297e97332d2125, []int{0}
}

func (m *AdGroupCriterion) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_AdGroupCriterion.Unmarshal(m, b)
}
func (m *AdGroupCriterion) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_AdGroupCriterion.Marshal(b, m, deterministic)
}
func (m *AdGroupCriterion) XXX_Merge(src proto.Message) {
	xxx_messageInfo_AdGroupCriterion.Merge(m, src)
}
func (m *AdGroupCriterion) XXX_Size() int {
	return xxx_messageInfo_AdGroupCriterion.Size(m)
}
func (m *AdGroupCriterion) XXX_DiscardUnknown() {
	xxx_messageInfo_AdGroupCriterion.DiscardUnknown(m)
}

var xxx_messageInfo_AdGroupCriterion proto.InternalMessageInfo

func (m *AdGroupCriterion) GetResourceName() string {
	if m != nil {
		return m.ResourceName
	}
	return ""
}

func (m *AdGroupCriterion) GetCriterionId() *wrappers.Int64Value {
	if m != nil {
		return m.CriterionId
	}
	return nil
}

func (m *AdGroupCriterion) GetStatus() enums.AdGroupCriterionStatusEnum_AdGroupCriterionStatus {
	if m != nil {
		return m.Status
	}
	return enums.AdGroupCriterionStatusEnum_UNSPECIFIED
}

func (m *AdGroupCriterion) GetQualityInfo() *AdGroupCriterion_QualityInfo {
	if m != nil {
		return m.QualityInfo
	}
	return nil
}

func (m *AdGroupCriterion) GetAdGroup() *wrappers.StringValue {
	if m != nil {
		return m.AdGroup
	}
	return nil
}

func (m *AdGroupCriterion) GetType() enums.CriterionTypeEnum_CriterionType {
	if m != nil {
		return m.Type
	}
	return enums.CriterionTypeEnum_UNSPECIFIED
}

func (m *AdGroupCriterion) GetNegative() *wrappers.BoolValue {
	if m != nil {
		return m.Negative
	}
	return nil
}

func (m *AdGroupCriterion) GetSystemServingStatus() enums.CriterionSystemServingStatusEnum_CriterionSystemServingStatus {
	if m != nil {
		return m.SystemServingStatus
	}
	return enums.CriterionSystemServingStatusEnum_UNSPECIFIED
}

func (m *AdGroupCriterion) GetApprovalStatus() enums.AdGroupCriterionApprovalStatusEnum_AdGroupCriterionApprovalStatus {
	if m != nil {
		return m.ApprovalStatus
	}
	return enums.AdGroupCriterionApprovalStatusEnum_UNSPECIFIED
}

func (m *AdGroupCriterion) GetBidModifier() *wrappers.DoubleValue {
	if m != nil {
		return m.BidModifier
	}
	return nil
}

func (m *AdGroupCriterion) GetCpcBidMicros() *wrappers.Int64Value {
	if m != nil {
		return m.CpcBidMicros
	}
	return nil
}

func (m *AdGroupCriterion) GetCpmBidMicros() *wrappers.Int64Value {
	if m != nil {
		return m.CpmBidMicros
	}
	return nil
}

func (m *AdGroupCriterion) GetCpvBidMicros() *wrappers.Int64Value {
	if m != nil {
		return m.CpvBidMicros
	}
	return nil
}

func (m *AdGroupCriterion) GetPercentCpcBidMicros() *wrappers.Int64Value {
	if m != nil {
		return m.PercentCpcBidMicros
	}
	return nil
}

func (m *AdGroupCriterion) GetEffectiveCpcBidMicros() *wrappers.Int64Value {
	if m != nil {
		return m.EffectiveCpcBidMicros
	}
	return nil
}

func (m *AdGroupCriterion) GetEffectiveCpmBidMicros() *wrappers.Int64Value {
	if m != nil {
		return m.EffectiveCpmBidMicros
	}
	return nil
}

func (m *AdGroupCriterion) GetEffectiveCpvBidMicros() *wrappers.Int64Value {
	if m != nil {
		return m.EffectiveCpvBidMicros
	}
	return nil
}

func (m *AdGroupCriterion) GetEffectivePercentCpcBidMicros() *wrappers.Int64Value {
	if m != nil {
		return m.EffectivePercentCpcBidMicros
	}
	return nil
}

func (m *AdGroupCriterion) GetEffectiveCpcBidSource() enums.BiddingSourceEnum_BiddingSource {
	if m != nil {
		return m.EffectiveCpcBidSource
	}
	return enums.BiddingSourceEnum_UNSPECIFIED
}

func (m *AdGroupCriterion) GetEffectiveCpmBidSource() enums.BiddingSourceEnum_BiddingSource {
	if m != nil {
		return m.EffectiveCpmBidSource
	}
	return enums.BiddingSourceEnum_UNSPECIFIED
}

func (m *AdGroupCriterion) GetEffectiveCpvBidSource() enums.BiddingSourceEnum_BiddingSource {
	if m != nil {
		return m.EffectiveCpvBidSource
	}
	return enums.BiddingSourceEnum_UNSPECIFIED
}

func (m *AdGroupCriterion) GetEffectivePercentCpcBidSource() enums.BiddingSourceEnum_BiddingSource {
	if m != nil {
		return m.EffectivePercentCpcBidSource
	}
	return enums.BiddingSourceEnum_UNSPECIFIED
}

func (m *AdGroupCriterion) GetPositionEstimates() *AdGroupCriterion_PositionEstimates {
	if m != nil {
		return m.PositionEstimates
	}
	return nil
}

func (m *AdGroupCriterion) GetFinalUrls() []*wrappers.StringValue {
	if m != nil {
		return m.FinalUrls
	}
	return nil
}

func (m *AdGroupCriterion) GetFinalMobileUrls() []*wrappers.StringValue {
	if m != nil {
		return m.FinalMobileUrls
	}
	return nil
}

func (m *AdGroupCriterion) GetFinalUrlSuffix() *wrappers.StringValue {
	if m != nil {
		return m.FinalUrlSuffix
	}
	return nil
}

func (m *AdGroupCriterion) GetTrackingUrlTemplate() *wrappers.StringValue {
	if m != nil {
		return m.TrackingUrlTemplate
	}
	return nil
}

func (m *AdGroupCriterion) GetUrlCustomParameters() []*common.CustomParameter {
	if m != nil {
		return m.UrlCustomParameters
	}
	return nil
}

type isAdGroupCriterion_Criterion interface {
	isAdGroupCriterion_Criterion()
}

type AdGroupCriterion_Keyword struct {
	Keyword *common.KeywordInfo `protobuf:"bytes,27,opt,name=keyword,proto3,oneof"`
}

type AdGroupCriterion_Placement struct {
	Placement *common.PlacementInfo `protobuf:"bytes,28,opt,name=placement,proto3,oneof"`
}

type AdGroupCriterion_MobileAppCategory struct {
	MobileAppCategory *common.MobileAppCategoryInfo `protobuf:"bytes,29,opt,name=mobile_app_category,json=mobileAppCategory,proto3,oneof"`
}

type AdGroupCriterion_MobileApplication struct {
	MobileApplication *common.MobileApplicationInfo `protobuf:"bytes,30,opt,name=mobile_application,json=mobileApplication,proto3,oneof"`
}

type AdGroupCriterion_ListingGroup struct {
	ListingGroup *common.ListingGroupInfo `protobuf:"bytes,32,opt,name=listing_group,json=listingGroup,proto3,oneof"`
}

type AdGroupCriterion_AgeRange struct {
	AgeRange *common.AgeRangeInfo `protobuf:"bytes,36,opt,name=age_range,json=ageRange,proto3,oneof"`
}

type AdGroupCriterion_Gender struct {
	Gender *common.GenderInfo `protobuf:"bytes,37,opt,name=gender,proto3,oneof"`
}

type AdGroupCriterion_IncomeRange struct {
	IncomeRange *common.IncomeRangeInfo `protobuf:"bytes,38,opt,name=income_range,json=incomeRange,proto3,oneof"`
}

type AdGroupCriterion_ParentalStatus struct {
	ParentalStatus *common.ParentalStatusInfo `protobuf:"bytes,39,opt,name=parental_status,json=parentalStatus,proto3,oneof"`
}

type AdGroupCriterion_UserList struct {
	UserList *common.UserListInfo `protobuf:"bytes,42,opt,name=user_list,json=userList,proto3,oneof"`
}

type AdGroupCriterion_YoutubeVideo struct {
	YoutubeVideo *common.YouTubeVideoInfo `protobuf:"bytes,40,opt,name=youtube_video,json=youtubeVideo,proto3,oneof"`
}

type AdGroupCriterion_YoutubeChannel struct {
	YoutubeChannel *common.YouTubeChannelInfo `protobuf:"bytes,41,opt,name=youtube_channel,json=youtubeChannel,proto3,oneof"`
}

type AdGroupCriterion_Topic struct {
	Topic *common.TopicInfo `protobuf:"bytes,43,opt,name=topic,proto3,oneof"`
}

type AdGroupCriterion_UserInterest struct {
	UserInterest *common.UserInterestInfo `protobuf:"bytes,45,opt,name=user_interest,json=userInterest,proto3,oneof"`
}

type AdGroupCriterion_Webpage struct {
	Webpage *common.WebpageInfo `protobuf:"bytes,46,opt,name=webpage,proto3,oneof"`
}

type AdGroupCriterion_AppPaymentModel struct {
	AppPaymentModel *common.AppPaymentModelInfo `protobuf:"bytes,47,opt,name=app_payment_model,json=appPaymentModel,proto3,oneof"`
}

type AdGroupCriterion_CustomAffinity struct {
	CustomAffinity *common.CustomAffinityInfo `protobuf:"bytes,48,opt,name=custom_affinity,json=customAffinity,proto3,oneof"`
}

type AdGroupCriterion_CustomIntent struct {
	CustomIntent *common.CustomIntentInfo `protobuf:"bytes,49,opt,name=custom_intent,json=customIntent,proto3,oneof"`
}

func (*AdGroupCriterion_Keyword) isAdGroupCriterion_Criterion() {}

func (*AdGroupCriterion_Placement) isAdGroupCriterion_Criterion() {}

func (*AdGroupCriterion_MobileAppCategory) isAdGroupCriterion_Criterion() {}

func (*AdGroupCriterion_MobileApplication) isAdGroupCriterion_Criterion() {}

func (*AdGroupCriterion_ListingGroup) isAdGroupCriterion_Criterion() {}

func (*AdGroupCriterion_AgeRange) isAdGroupCriterion_Criterion() {}

func (*AdGroupCriterion_Gender) isAdGroupCriterion_Criterion() {}

func (*AdGroupCriterion_IncomeRange) isAdGroupCriterion_Criterion() {}

func (*AdGroupCriterion_ParentalStatus) isAdGroupCriterion_Criterion() {}

func (*AdGroupCriterion_UserList) isAdGroupCriterion_Criterion() {}

func (*AdGroupCriterion_YoutubeVideo) isAdGroupCriterion_Criterion() {}

func (*AdGroupCriterion_YoutubeChannel) isAdGroupCriterion_Criterion() {}

func (*AdGroupCriterion_Topic) isAdGroupCriterion_Criterion() {}

func (*AdGroupCriterion_UserInterest) isAdGroupCriterion_Criterion() {}

func (*AdGroupCriterion_Webpage) isAdGroupCriterion_Criterion() {}

func (*AdGroupCriterion_AppPaymentModel) isAdGroupCriterion_Criterion() {}

func (*AdGroupCriterion_CustomAffinity) isAdGroupCriterion_Criterion() {}

func (*AdGroupCriterion_CustomIntent) isAdGroupCriterion_Criterion() {}

func (m *AdGroupCriterion) GetCriterion() isAdGroupCriterion_Criterion {
	if m != nil {
		return m.Criterion
	}
	return nil
}

func (m *AdGroupCriterion) GetKeyword() *common.KeywordInfo {
	if x, ok := m.GetCriterion().(*AdGroupCriterion_Keyword); ok {
		return x.Keyword
	}
	return nil
}

func (m *AdGroupCriterion) GetPlacement() *common.PlacementInfo {
	if x, ok := m.GetCriterion().(*AdGroupCriterion_Placement); ok {
		return x.Placement
	}
	return nil
}

func (m *AdGroupCriterion) GetMobileAppCategory() *common.MobileAppCategoryInfo {
	if x, ok := m.GetCriterion().(*AdGroupCriterion_MobileAppCategory); ok {
		return x.MobileAppCategory
	}
	return nil
}

func (m *AdGroupCriterion) GetMobileApplication() *common.MobileApplicationInfo {
	if x, ok := m.GetCriterion().(*AdGroupCriterion_MobileApplication); ok {
		return x.MobileApplication
	}
	return nil
}

func (m *AdGroupCriterion) GetListingGroup() *common.ListingGroupInfo {
	if x, ok := m.GetCriterion().(*AdGroupCriterion_ListingGroup); ok {
		return x.ListingGroup
	}
	return nil
}

func (m *AdGroupCriterion) GetAgeRange() *common.AgeRangeInfo {
	if x, ok := m.GetCriterion().(*AdGroupCriterion_AgeRange); ok {
		return x.AgeRange
	}
	return nil
}

func (m *AdGroupCriterion) GetGender() *common.GenderInfo {
	if x, ok := m.GetCriterion().(*AdGroupCriterion_Gender); ok {
		return x.Gender
	}
	return nil
}

func (m *AdGroupCriterion) GetIncomeRange() *common.IncomeRangeInfo {
	if x, ok := m.GetCriterion().(*AdGroupCriterion_IncomeRange); ok {
		return x.IncomeRange
	}
	return nil
}

func (m *AdGroupCriterion) GetParentalStatus() *common.ParentalStatusInfo {
	if x, ok := m.GetCriterion().(*AdGroupCriterion_ParentalStatus); ok {
		return x.ParentalStatus
	}
	return nil
}

func (m *AdGroupCriterion) GetUserList() *common.UserListInfo {
	if x, ok := m.GetCriterion().(*AdGroupCriterion_UserList); ok {
		return x.UserList
	}
	return nil
}

func (m *AdGroupCriterion) GetYoutubeVideo() *common.YouTubeVideoInfo {
	if x, ok := m.GetCriterion().(*AdGroupCriterion_YoutubeVideo); ok {
		return x.YoutubeVideo
	}
	return nil
}

func (m *AdGroupCriterion) GetYoutubeChannel() *common.YouTubeChannelInfo {
	if x, ok := m.GetCriterion().(*AdGroupCriterion_YoutubeChannel); ok {
		return x.YoutubeChannel
	}
	return nil
}

func (m *AdGroupCriterion) GetTopic() *common.TopicInfo {
	if x, ok := m.GetCriterion().(*AdGroupCriterion_Topic); ok {
		return x.Topic
	}
	return nil
}

func (m *AdGroupCriterion) GetUserInterest() *common.UserInterestInfo {
	if x, ok := m.GetCriterion().(*AdGroupCriterion_UserInterest); ok {
		return x.UserInterest
	}
	return nil
}

func (m *AdGroupCriterion) GetWebpage() *common.WebpageInfo {
	if x, ok := m.GetCriterion().(*AdGroupCriterion_Webpage); ok {
		return x.Webpage
	}
	return nil
}

func (m *AdGroupCriterion) GetAppPaymentModel() *common.AppPaymentModelInfo {
	if x, ok := m.GetCriterion().(*AdGroupCriterion_AppPaymentModel); ok {
		return x.AppPaymentModel
	}
	return nil
}

func (m *AdGroupCriterion) GetCustomAffinity() *common.CustomAffinityInfo {
	if x, ok := m.GetCriterion().(*AdGroupCriterion_CustomAffinity); ok {
		return x.CustomAffinity
	}
	return nil
}

func (m *AdGroupCriterion) GetCustomIntent() *common.CustomIntentInfo {
	if x, ok := m.GetCriterion().(*AdGroupCriterion_CustomIntent); ok {
		return x.CustomIntent
	}
	return nil
}

// XXX_OneofWrappers is for the internal use of the proto package.
func (*AdGroupCriterion) XXX_OneofWrappers() []interface{} {
	return []interface{}{
		(*AdGroupCriterion_Keyword)(nil),
		(*AdGroupCriterion_Placement)(nil),
		(*AdGroupCriterion_MobileAppCategory)(nil),
		(*AdGroupCriterion_MobileApplication)(nil),
		(*AdGroupCriterion_ListingGroup)(nil),
		(*AdGroupCriterion_AgeRange)(nil),
		(*AdGroupCriterion_Gender)(nil),
		(*AdGroupCriterion_IncomeRange)(nil),
		(*AdGroupCriterion_ParentalStatus)(nil),
		(*AdGroupCriterion_UserList)(nil),
		(*AdGroupCriterion_YoutubeVideo)(nil),
		(*AdGroupCriterion_YoutubeChannel)(nil),
		(*AdGroupCriterion_Topic)(nil),
		(*AdGroupCriterion_UserInterest)(nil),
		(*AdGroupCriterion_Webpage)(nil),
		(*AdGroupCriterion_AppPaymentModel)(nil),
		(*AdGroupCriterion_CustomAffinity)(nil),
		(*AdGroupCriterion_CustomIntent)(nil),
	}
}

// A container for ad group criterion quality information.
type AdGroupCriterion_QualityInfo struct {
	// The quality score.
	//
	// This field may not be populated if Google does not have enough
	// information to determine a value.
	QualityScore *wrappers.Int32Value `protobuf:"bytes,1,opt,name=quality_score,json=qualityScore,proto3" json:"quality_score,omitempty"`
	// The performance of the ad compared to other advertisers.
	CreativeQualityScore enums.QualityScoreBucketEnum_QualityScoreBucket `protobuf:"varint,2,opt,name=creative_quality_score,json=creativeQualityScore,proto3,enum=google.ads.googleads.v2.enums.QualityScoreBucketEnum_QualityScoreBucket" json:"creative_quality_score,omitempty"`
	// The quality score of the landing page.
	PostClickQualityScore enums.QualityScoreBucketEnum_QualityScoreBucket `protobuf:"varint,3,opt,name=post_click_quality_score,json=postClickQualityScore,proto3,enum=google.ads.googleads.v2.enums.QualityScoreBucketEnum_QualityScoreBucket" json:"post_click_quality_score,omitempty"`
	// The click-through rate compared to that of other advertisers.
	SearchPredictedCtr   enums.QualityScoreBucketEnum_QualityScoreBucket `protobuf:"varint,4,opt,name=search_predicted_ctr,json=searchPredictedCtr,proto3,enum=google.ads.googleads.v2.enums.QualityScoreBucketEnum_QualityScoreBucket" json:"search_predicted_ctr,omitempty"`
	XXX_NoUnkeyedLiteral struct{}                                        `json:"-"`
	XXX_unrecognized     []byte                                          `json:"-"`
	XXX_sizecache        int32                                           `json:"-"`
}

func (m *AdGroupCriterion_QualityInfo) Reset()         { *m = AdGroupCriterion_QualityInfo{} }
func (m *AdGroupCriterion_QualityInfo) String() string { return proto.CompactTextString(m) }
func (*AdGroupCriterion_QualityInfo) ProtoMessage()    {}
func (*AdGroupCriterion_QualityInfo) Descriptor() ([]byte, []int) {
	return fileDescriptor_9b297e97332d2125, []int{0, 0}
}

func (m *AdGroupCriterion_QualityInfo) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_AdGroupCriterion_QualityInfo.Unmarshal(m, b)
}
func (m *AdGroupCriterion_QualityInfo) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_AdGroupCriterion_QualityInfo.Marshal(b, m, deterministic)
}
func (m *AdGroupCriterion_QualityInfo) XXX_Merge(src proto.Message) {
	xxx_messageInfo_AdGroupCriterion_QualityInfo.Merge(m, src)
}
func (m *AdGroupCriterion_QualityInfo) XXX_Size() int {
	return xxx_messageInfo_AdGroupCriterion_QualityInfo.Size(m)
}
func (m *AdGroupCriterion_QualityInfo) XXX_DiscardUnknown() {
	xxx_messageInfo_AdGroupCriterion_QualityInfo.DiscardUnknown(m)
}

var xxx_messageInfo_AdGroupCriterion_QualityInfo proto.InternalMessageInfo

func (m *AdGroupCriterion_QualityInfo) GetQualityScore() *wrappers.Int32Value {
	if m != nil {
		return m.QualityScore
	}
	return nil
}

func (m *AdGroupCriterion_QualityInfo) GetCreativeQualityScore() enums.QualityScoreBucketEnum_QualityScoreBucket {
	if m != nil {
		return m.CreativeQualityScore
	}
	return enums.QualityScoreBucketEnum_UNSPECIFIED
}

func (m *AdGroupCriterion_QualityInfo) GetPostClickQualityScore() enums.QualityScoreBucketEnum_QualityScoreBucket {
	if m != nil {
		return m.PostClickQualityScore
	}
	return enums.QualityScoreBucketEnum_UNSPECIFIED
}

func (m *AdGroupCriterion_QualityInfo) GetSearchPredictedCtr() enums.QualityScoreBucketEnum_QualityScoreBucket {
	if m != nil {
		return m.SearchPredictedCtr
	}
	return enums.QualityScoreBucketEnum_UNSPECIFIED
}

// Estimates for criterion bids at various positions.
type AdGroupCriterion_PositionEstimates struct {
	// The estimate of the CPC bid required for ad to be shown on first
	// page of search results.
	FirstPageCpcMicros *wrappers.Int64Value `protobuf:"bytes,1,opt,name=first_page_cpc_micros,json=firstPageCpcMicros,proto3" json:"first_page_cpc_micros,omitempty"`
	// The estimate of the CPC bid required for ad to be displayed in first
	// position, at the top of the first page of search results.
	FirstPositionCpcMicros *wrappers.Int64Value `protobuf:"bytes,2,opt,name=first_position_cpc_micros,json=firstPositionCpcMicros,proto3" json:"first_position_cpc_micros,omitempty"`
	// The estimate of the CPC bid required for ad to be displayed at the top
	// of the first page of search results.
	TopOfPageCpcMicros *wrappers.Int64Value `protobuf:"bytes,3,opt,name=top_of_page_cpc_micros,json=topOfPageCpcMicros,proto3" json:"top_of_page_cpc_micros,omitempty"`
	// Estimate of how many clicks per week you might get by changing your
	// keyword bid to the value in first_position_cpc_micros.
	EstimatedAddClicksAtFirstPositionCpc *wrappers.Int64Value `protobuf:"bytes,4,opt,name=estimated_add_clicks_at_first_position_cpc,json=estimatedAddClicksAtFirstPositionCpc,proto3" json:"estimated_add_clicks_at_first_position_cpc,omitempty"`
	// Estimate of how your cost per week might change when changing your
	// keyword bid to the value in first_position_cpc_micros.
	EstimatedAddCostAtFirstPositionCpc *wrappers.Int64Value `protobuf:"bytes,5,opt,name=estimated_add_cost_at_first_position_cpc,json=estimatedAddCostAtFirstPositionCpc,proto3" json:"estimated_add_cost_at_first_position_cpc,omitempty"`
	XXX_NoUnkeyedLiteral               struct{}             `json:"-"`
	XXX_unrecognized                   []byte               `json:"-"`
	XXX_sizecache                      int32                `json:"-"`
}

func (m *AdGroupCriterion_PositionEstimates) Reset()         { *m = AdGroupCriterion_PositionEstimates{} }
func (m *AdGroupCriterion_PositionEstimates) String() string { return proto.CompactTextString(m) }
func (*AdGroupCriterion_PositionEstimates) ProtoMessage()    {}
func (*AdGroupCriterion_PositionEstimates) Descriptor() ([]byte, []int) {
	return fileDescriptor_9b297e97332d2125, []int{0, 1}
}

func (m *AdGroupCriterion_PositionEstimates) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_AdGroupCriterion_PositionEstimates.Unmarshal(m, b)
}
func (m *AdGroupCriterion_PositionEstimates) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_AdGroupCriterion_PositionEstimates.Marshal(b, m, deterministic)
}
func (m *AdGroupCriterion_PositionEstimates) XXX_Merge(src proto.Message) {
	xxx_messageInfo_AdGroupCriterion_PositionEstimates.Merge(m, src)
}
func (m *AdGroupCriterion_PositionEstimates) XXX_Size() int {
	return xxx_messageInfo_AdGroupCriterion_PositionEstimates.Size(m)
}
func (m *AdGroupCriterion_PositionEstimates) XXX_DiscardUnknown() {
	xxx_messageInfo_AdGroupCriterion_PositionEstimates.DiscardUnknown(m)
}

var xxx_messageInfo_AdGroupCriterion_PositionEstimates proto.InternalMessageInfo

func (m *AdGroupCriterion_PositionEstimates) GetFirstPageCpcMicros() *wrappers.Int64Value {
	if m != nil {
		return m.FirstPageCpcMicros
	}
	return nil
}

func (m *AdGroupCriterion_PositionEstimates) GetFirstPositionCpcMicros() *wrappers.Int64Value {
	if m != nil {
		return m.FirstPositionCpcMicros
	}
	return nil
}

func (m *AdGroupCriterion_PositionEstimates) GetTopOfPageCpcMicros() *wrappers.Int64Value {
	if m != nil {
		return m.TopOfPageCpcMicros
	}
	return nil
}

func (m *AdGroupCriterion_PositionEstimates) GetEstimatedAddClicksAtFirstPositionCpc() *wrappers.Int64Value {
	if m != nil {
		return m.EstimatedAddClicksAtFirstPositionCpc
	}
	return nil
}

func (m *AdGroupCriterion_PositionEstimates) GetEstimatedAddCostAtFirstPositionCpc() *wrappers.Int64Value {
	if m != nil {
		return m.EstimatedAddCostAtFirstPositionCpc
	}
	return nil
}

func init() {
	proto.RegisterType((*AdGroupCriterion)(nil), "google.ads.googleads.v2.resources.AdGroupCriterion")
	proto.RegisterType((*AdGroupCriterion_QualityInfo)(nil), "google.ads.googleads.v2.resources.AdGroupCriterion.QualityInfo")
	proto.RegisterType((*AdGroupCriterion_PositionEstimates)(nil), "google.ads.googleads.v2.resources.AdGroupCriterion.PositionEstimates")
}

func init() {
	proto.RegisterFile("google/ads/googleads/v2/resources/ad_group_criterion.proto", fileDescriptor_9b297e97332d2125)
}

var fileDescriptor_9b297e97332d2125 = []byte{
	// 1705 bytes of a gzipped FileDescriptorProto
	0x1f, 0x8b, 0x08, 0x00, 0x00, 0x00, 0x00, 0x00, 0x02, 0xff, 0xac, 0x98, 0xdd, 0x72, 0x1b, 0xb7,
	0x15, 0xc7, 0x4b, 0x29, 0x76, 0x2c, 0x48, 0x96, 0x2d, 0xc8, 0x52, 0x11, 0xc5, 0x4d, 0x65, 0x27,
	0x6e, 0x14, 0x27, 0x26, 0x53, 0x3a, 0x4e, 0x3b, 0xcc, 0x34, 0x29, 0xc5, 0xd8, 0xb2, 0x9a, 0x2a,
	0x61, 0x28, 0x59, 0x99, 0x76, 0xd4, 0xd9, 0x82, 0xbb, 0xe0, 0x1a, 0xe3, 0xdd, 0x05, 0x0c, 0x60,
	0xa9, 0xb2, 0x17, 0x9d, 0x69, 0x2f, 0x3a, 0xd3, 0xbb, 0x3e, 0x43, 0x2f, 0xfb, 0x1a, 0xbd, 0xeb,
	0x4d, 0xdf, 0xa3, 0x0f, 0xd0, 0xeb, 0x0e, 0xbe, 0xc8, 0x25, 0x29, 0x72, 0xa9, 0x8c, 0xee, 0x76,
	0xcf, 0xe2, 0xff, 0x3b, 0x07, 0x07, 0x67, 0xb1, 0x07, 0x0b, 0x1a, 0x31, 0x63, 0x71, 0x42, 0x6a,
	0x38, 0x92, 0x35, 0x7b, 0xa9, 0xaf, 0xfa, 0xf5, 0x9a, 0x20, 0x92, 0xe5, 0x22, 0x24, 0xb2, 0x86,
	0xa3, 0x20, 0x16, 0x2c, 0xe7, 0x41, 0x28, 0xa8, 0x22, 0x82, 0xb2, 0xac, 0xca, 0x05, 0x53, 0x0c,
	0xde, 0xb3, 0x82, 0x2a, 0x8e, 0x64, 0x75, 0xa8, 0xad, 0xf6, 0xeb, 0xd5, 0xa1, 0x76, 0xe7, 0xd1,
	0x2c, 0x7c, 0xc8, 0xd2, 0x94, 0x65, 0x35, 0x87, 0xc4, 0x96, 0xb8, 0xf3, 0xa4, 0x6c, 0x78, 0x2e,
	0x15, 0x4b, 0x03, 0x8e, 0x05, 0x4e, 0x89, 0x22, 0xc2, 0xc9, 0x9e, 0xcd, 0x92, 0x91, 0x2c, 0x4f,
	0x2f, 0x9a, 0x40, 0x80, 0x39, 0x17, 0xac, 0x8f, 0x93, 0x40, 0x2a, 0xac, 0x72, 0xe9, 0x38, 0xbf,
	0xb8, 0x34, 0x67, 0x4c, 0x5e, 0x9f, 0x2f, 0xef, 0xd2, 0x28, 0xa2, 0x59, 0x1c, 0xd8, 0xdc, 0x38,
	0x4d, 0x6b, 0xbe, 0xa6, 0xe0, 0x69, 0x20, 0x15, 0x49, 0x03, 0x49, 0x44, 0xdf, 0x40, 0x2e, 0xe1,
	0x78, 0x04, 0x51, 0x03, 0xee, 0x1d, 0xff, 0x7c, 0xbe, 0xe6, 0x75, 0x8e, 0x13, 0xaa, 0x06, 0x81,
	0x0c, 0x99, 0x20, 0x41, 0x37, 0x0f, 0x5f, 0x11, 0xe5, 0x94, 0xef, 0x38, 0xa5, 0xb9, 0xeb, 0xe6,
	0xbd, 0xda, 0xb9, 0xc0, 0x9c, 0x13, 0xe1, 0xa3, 0xb9, 0xeb, 0xc9, 0x9c, 0xd6, 0x70, 0x96, 0x31,
	0x85, 0x15, 0x65, 0x99, 0x7b, 0x7a, 0xff, 0x5f, 0xef, 0x83, 0xdb, 0xcd, 0xe8, 0x40, 0xe7, 0xb1,
	0xe5, 0xe3, 0x82, 0xef, 0x82, 0x9b, 0xbe, 0x66, 0x82, 0x0c, 0xa7, 0x04, 0x55, 0x76, 0x2b, 0x7b,
	0x2b, 0x9d, 0x35, 0x6f, 0xfc, 0x1a, 0xa7, 0x04, 0x7e, 0x0e, 0xd6, 0x46, 0x33, 0xa1, 0x11, 0xda,
	0xd9, 0xad, 0xec, 0xad, 0xd6, 0xdf, 0x76, 0xa5, 0x57, 0xf5, 0xe1, 0x54, 0x0f, 0x33, 0xf5, 0xe9,
	0x27, 0xa7, 0x38, 0xc9, 0x49, 0x67, 0x75, 0x28, 0x38, 0x8c, 0xe0, 0x4b, 0x70, 0xdd, 0x66, 0x0d,
	0x2d, 0xef, 0x56, 0xf6, 0xd6, 0xeb, 0xed, 0xea, 0xac, 0xfa, 0x35, 0x29, 0xa8, 0x4e, 0x46, 0x79,
	0x6c, 0xc4, 0x4f, 0xb3, 0x3c, 0x9d, 0xf1, 0xa8, 0xe3, 0xf8, 0xb0, 0x0b, 0xd6, 0x7c, 0xfe, 0x68,
	0xd6, 0x63, 0xe8, 0x0d, 0x13, 0xe9, 0x17, 0xd5, 0xd2, 0xf7, 0x65, 0x0a, 0x5c, 0xfd, 0xd6, 0x72,
	0x0e, 0xb3, 0x1e, 0xeb, 0xac, 0xbe, 0x1e, 0xdd, 0xc0, 0x9f, 0x81, 0x1b, 0xbe, 0x1e, 0xd1, 0x35,
	0xc3, 0xbf, 0x3b, 0x95, 0x89, 0x63, 0x25, 0x68, 0x16, 0xdb, 0x54, 0xbc, 0x89, 0x2d, 0x1a, 0x76,
	0xc0, 0x1b, 0xba, 0x0c, 0xd0, 0x5b, 0x26, 0x09, 0x9f, 0x97, 0x24, 0x61, 0x18, 0xc9, 0xc9, 0x80,
	0x13, 0x33, 0xf7, 0x31, 0x4b, 0xc7, 0xb0, 0xe0, 0xa7, 0xe0, 0x46, 0x46, 0x62, 0xac, 0x68, 0x9f,
	0xa0, 0x1f, 0x9b, 0x60, 0x76, 0xa6, 0x82, 0xd9, 0x67, 0x2c, 0xb1, 0xa1, 0x0c, 0xc7, 0xc2, 0xbf,
	0x57, 0xc0, 0xd6, 0x85, 0x85, 0x8d, 0x3e, 0x31, 0xd1, 0x9d, 0x2d, 0x1a, 0xdd, 0xb1, 0x81, 0x1c,
	0x5b, 0x46, 0x61, 0xa1, 0xe6, 0x0d, 0xe8, 0x6c, 0xca, 0x69, 0x23, 0xfc, 0x5b, 0x05, 0xdc, 0x9a,
	0xd8, 0x1d, 0xd0, 0x13, 0x13, 0xcc, 0xef, 0x2f, 0x59, 0x2f, 0x4d, 0x47, 0x99, 0x53, 0x37, 0xe3,
	0x43, 0x3a, 0xeb, 0x78, 0xec, 0x1e, 0x7e, 0x01, 0xd6, 0xba, 0x34, 0x0a, 0x52, 0x16, 0xd1, 0x1e,
	0x25, 0x02, 0x7d, 0x34, 0x63, 0x9d, 0xbf, 0x64, 0x79, 0x37, 0x21, 0xae, 0xe4, 0xbb, 0x34, 0x3a,
	0x72, 0x02, 0xd8, 0x04, 0xeb, 0x21, 0x0f, 0x03, 0x03, 0xa1, 0xa1, 0x60, 0x12, 0xdd, 0x2e, 0x7f,
	0x69, 0xd6, 0x42, 0x1e, 0xee, 0xd3, 0xe8, 0xc8, 0x08, 0x2c, 0x22, 0x2d, 0x22, 0x36, 0x16, 0x42,
	0xa4, 0x13, 0x88, 0x7e, 0x11, 0x81, 0x16, 0x42, 0xf4, 0x47, 0x88, 0x36, 0xd8, 0xe6, 0x44, 0x84,
	0x24, 0x53, 0xc1, 0xc4, 0x84, 0xee, 0x95, 0xa3, 0x36, 0x9d, 0xb4, 0x55, 0x9c, 0xd7, 0x09, 0x40,
	0xa4, 0xd7, 0x23, 0xa1, 0xae, 0xc3, 0x49, 0x26, 0x2c, 0x67, 0x6e, 0x0d, 0xc5, 0xf3, 0xa8, 0x63,
	0x79, 0xdb, 0xbc, 0x1c, 0x35, 0x9d, 0x49, 0x1d, 0x4b, 0xe5, 0x9d, 0xcb, 0x51, 0x0b, 0x39, 0x0d,
	0xc1, 0xee, 0x88, 0x3a, 0x23, 0xbb, 0xf7, 0xcb, 0xe9, 0x77, 0x87, 0x90, 0xf6, 0x05, 0x69, 0x3e,
	0xbf, 0x28, 0xcd, 0x76, 0xb7, 0x43, 0x5b, 0x0b, 0xed, 0x40, 0xfb, 0xf6, 0xb3, 0x79, 0x6c, 0x34,
	0xe6, 0x2d, 0x1a, 0xb3, 0x4c, 0xad, 0x84, 0x35, 0x4f, 0x3a, 0x4e, 0x8b, 0x8e, 0xb7, 0xaf, 0xdc,
	0x71, 0x3a, 0xd3, 0x71, 0xbf, 0xe8, 0xf8, 0x87, 0x57, 0xee, 0xb8, 0x3f, 0x72, 0xfc, 0xd7, 0xca,
	0xbc, 0x05, 0x75, 0x11, 0xbc, 0x7b, 0x25, 0x11, 0xcc, 0x58, 0x73, 0x17, 0x88, 0x02, 0x90, 0x33,
	0x49, 0xf5, 0x57, 0x3f, 0x20, 0x52, 0xd1, 0x14, 0x2b, 0x22, 0x11, 0x30, 0xa5, 0xf4, 0xf4, 0xfb,
	0x7c, 0x04, 0xdb, 0x8e, 0xf6, 0xd4, 0xc3, 0x3a, 0x1b, 0x7c, 0xd2, 0x04, 0x3f, 0x03, 0xa0, 0x47,
	0x33, 0x9c, 0x04, 0xb9, 0x48, 0x24, 0x5a, 0xdd, 0x5d, 0x2e, 0xfd, 0x24, 0xae, 0x98, 0xf1, 0x2f,
	0x44, 0x22, 0xe1, 0x73, 0xb0, 0x61, 0xc5, 0x29, 0xeb, 0xd2, 0x84, 0x58, 0xc6, 0xe3, 0x05, 0x18,
	0xb7, 0x8c, 0xec, 0xc8, 0xa8, 0x0c, 0xe9, 0x19, 0xb8, 0x3d, 0x0c, 0x23, 0x90, 0x79, 0xaf, 0x47,
	0xff, 0x80, 0xea, 0x0b, 0x7c, 0x9f, 0xd7, 0x7d, 0x30, 0xc7, 0x46, 0x03, 0xdb, 0x60, 0x4b, 0x09,
	0x1c, 0xbe, 0xd2, 0xdf, 0x44, 0x8d, 0x52, 0x24, 0xe5, 0x09, 0x56, 0x04, 0xdd, 0x5c, 0x00, 0xb6,
	0xe9, 0xa5, 0x2f, 0x44, 0x72, 0xe2, 0x84, 0x30, 0x04, 0x5b, 0x1a, 0x34, 0xd9, 0x43, 0x4b, 0xb4,
	0x6e, 0xe6, 0x59, 0x9b, 0xb9, 0x32, 0xb6, 0xf9, 0xae, 0xb6, 0x8c, 0xb0, 0xed, 0x75, 0x9d, 0xcd,
	0x5c, 0x24, 0x13, 0x36, 0x09, 0x0f, 0xc0, 0x9b, 0xaf, 0xc8, 0xe0, 0x9c, 0x89, 0x08, 0xbd, 0x6d,
	0x02, 0xfd, 0xb0, 0x0c, 0xfb, 0x95, 0x1d, 0xae, 0x9b, 0x9a, 0xe7, 0x3f, 0xe8, 0x78, 0x35, 0x3c,
	0x02, 0x2b, 0x3c, 0xc1, 0x21, 0x49, 0x49, 0xa6, 0xd0, 0x5d, 0x83, 0x7a, 0x54, 0x86, 0x6a, 0x7b,
	0x81, 0x83, 0x8d, 0x08, 0x30, 0x06, 0x9b, 0x6e, 0x69, 0x31, 0xe7, 0x41, 0x88, 0x15, 0x89, 0x99,
	0x18, 0xa0, 0x1f, 0x19, 0xf0, 0x93, 0x32, 0xb0, 0x5d, 0xdf, 0x26, 0xe7, 0x2d, 0x27, 0x74, 0x0e,
	0x36, 0xd2, 0xc9, 0x07, 0xb0, 0x07, 0xe0, 0xc8, 0x51, 0x42, 0x43, 0xd3, 0xfc, 0xa2, 0x77, 0x2e,
	0xe9, 0xc7, 0x0b, 0xa7, 0xfc, 0xf8, 0x07, 0xf0, 0x3b, 0x70, 0x33, 0xa1, 0x52, 0xe9, 0xf2, 0xb0,
	0x4d, 0xe0, 0xae, 0x71, 0xf1, 0x71, 0x99, 0x8b, 0x5f, 0x5b, 0x91, 0x79, 0xc3, 0x1c, 0x7d, 0x2d,
	0x29, 0xd8, 0xe0, 0x57, 0x60, 0x05, 0xc7, 0x24, 0x10, 0x38, 0x8b, 0x09, 0x7a, 0xcf, 0x40, 0x3f,
	0x2a, 0x83, 0x36, 0x63, 0xd2, 0xd1, 0xe3, 0x1d, 0xf0, 0x06, 0x76, 0xf7, 0xf0, 0x4b, 0x70, 0x3d,
	0x26, 0x59, 0x44, 0x04, 0x7a, 0x60, 0x48, 0x0f, 0xcb, 0x48, 0x07, 0x66, 0xb4, 0xe3, 0x38, 0x2d,
	0x3c, 0x01, 0x6b, 0x34, 0x0b, 0x59, 0xea, 0xa3, 0xfa, 0x89, 0x61, 0x95, 0x16, 0xec, 0xa1, 0xd1,
	0x14, 0x03, 0x5b, 0xa5, 0x23, 0x13, 0xfc, 0x1d, 0xb8, 0xc5, 0xb1, 0x20, 0x99, 0x1a, 0x35, 0x7a,
	0xef, 0x1b, 0x70, 0xbd, 0xb4, 0xce, 0x9c, 0xcc, 0xb6, 0x69, 0x8e, 0xbd, 0xce, 0xc7, 0xac, 0x3a,
	0x8f, 0xb9, 0x24, 0x22, 0xd0, 0xc9, 0x45, 0x0f, 0x17, 0xcb, 0xe3, 0x0b, 0x49, 0x84, 0x5e, 0x20,
	0x9f, 0xc7, 0xdc, 0xdd, 0xeb, 0xd5, 0x1e, 0xb0, 0x5c, 0xe5, 0x5d, 0x12, 0xf4, 0x69, 0x44, 0x18,
	0xda, 0x5b, 0x6c, 0xb5, 0x7f, 0xc3, 0xf2, 0x93, 0xbc, 0x4b, 0x4e, 0xb5, 0xc6, 0xaf, 0xb6, 0x03,
	0x19, 0x9b, 0x4e, 0x82, 0x07, 0x87, 0x2f, 0x71, 0x96, 0x91, 0x04, 0x7d, 0xb0, 0x58, 0x12, 0x1c,
	0xba, 0x65, 0x55, 0x3e, 0x09, 0x0e, 0xe6, 0xac, 0xb0, 0x09, 0xae, 0x29, 0xc6, 0x69, 0x88, 0x3e,
	0x34, 0xd0, 0x0f, 0xca, 0xa0, 0x27, 0x7a, 0xb0, 0x63, 0x59, 0xa5, 0x9e, 0xba, 0xc9, 0x23, 0xcd,
	0x14, 0x11, 0x44, 0x2a, 0xf4, 0x68, 0xb1, 0xa9, 0xeb, 0x5c, 0x1e, 0x3a, 0x8d, 0x9f, 0x7a, 0x5e,
	0xb0, 0xe9, 0xad, 0xea, 0x9c, 0x74, 0x39, 0x8e, 0x09, 0xaa, 0x2e, 0xb6, 0x55, 0x7d, 0x67, 0x87,
	0xfb, 0xad, 0xca, 0xa9, 0x21, 0x06, 0x1b, 0x7a, 0x53, 0xe1, 0x78, 0xa0, 0xb7, 0x1a, 0xdd, 0xae,
	0x93, 0x04, 0xd5, 0x0c, 0xf2, 0x71, 0xe9, 0x9b, 0xc3, 0x79, 0xdb, 0xea, 0x8e, 0xb4, 0xcc, 0xa1,
	0xf5, 0x09, 0xa4, 0x68, 0xd6, 0xcb, 0xe4, 0xf6, 0x6d, 0xdc, 0xeb, 0xd1, 0x8c, 0xaa, 0x01, 0xfa,
	0x78, 0xb1, 0x65, 0xb2, 0x3b, 0x74, 0xd3, 0xa9, 0xfc, 0x32, 0x85, 0x63, 0x56, 0x9d, 0x63, 0x87,
	0xd7, 0x59, 0xce, 0x14, 0xfa, 0xe9, 0x62, 0x39, 0xb6, 0xf0, 0x43, 0xa3, 0xf1, 0x39, 0x0e, 0x0b,
	0xb6, 0x9d, 0xff, 0x2c, 0x83, 0xd5, 0xc2, 0x11, 0x16, 0xfe, 0x12, 0xdc, 0x1c, 0xfb, 0xb3, 0x60,
	0x0e, 0xfa, 0x33, 0x1a, 0xcc, 0xc7, 0x75, 0x77, 0x12, 0x70, 0x8a, 0x63, 0x2d, 0x80, 0x7f, 0x02,
	0xdb, 0xa1, 0x20, 0xe6, 0xf8, 0x18, 0x8c, 0xa3, 0x96, 0x4c, 0x6b, 0xf3, 0xbc, 0xa4, 0xb5, 0xf9,
	0xb6, 0x00, 0xdb, 0x37, 0xbf, 0x35, 0x4c, 0x7f, 0x33, 0x6d, 0xee, 0xdc, 0xf1, 0x7e, 0x8a, 0xcf,
	0xe0, 0x9f, 0x2b, 0x00, 0x71, 0x26, 0x55, 0x10, 0x26, 0x34, 0x7c, 0x35, 0x11, 0xc2, 0xf2, 0x15,
	0x87, 0xb0, 0xa5, 0x3d, 0xb5, 0xb4, 0xa3, 0xb1, 0x18, 0xfe, 0x08, 0xee, 0x48, 0x82, 0x45, 0xf8,
	0x32, 0xe0, 0x82, 0x44, 0x34, 0x54, 0x24, 0x0a, 0x42, 0x25, 0xcc, 0x7f, 0x86, 0xab, 0x74, 0x0f,
	0xad, 0x97, 0xb6, 0x77, 0xd2, 0x52, 0x62, 0xe7, 0x7f, 0xcb, 0x60, 0x63, 0xaa, 0x1f, 0x83, 0x5f,
	0x83, 0xad, 0x1e, 0x15, 0x52, 0x05, 0xfa, 0x85, 0x30, 0x3d, 0xa7, 0x3b, 0x40, 0x54, 0xca, 0x0f,
	0x10, 0xd0, 0x28, 0xdb, 0x38, 0xd6, 0x0d, 0xbc, 0x3b, 0x36, 0x9c, 0x82, 0xb7, 0x1c, 0xcf, 0x37,
	0x92, 0x05, 0xe6, 0x52, 0x39, 0x73, 0xdb, 0x32, 0x9d, 0x78, 0xc4, 0xfd, 0x06, 0x6c, 0x2b, 0xc6,
	0x03, 0xd6, 0x9b, 0x0a, 0x74, 0x79, 0x81, 0x40, 0x15, 0xe3, 0xdf, 0xf4, 0xc6, 0x03, 0xcd, 0xc1,
	0x43, 0xdf, 0xe2, 0x46, 0x01, 0x8e, 0x22, 0x5b, 0x16, 0x32, 0xc0, 0x2a, 0x98, 0x9e, 0x80, 0xfb,
	0x11, 0x34, 0xd7, 0xc9, 0x7b, 0x43, 0x5c, 0x33, 0x8a, 0xcc, 0xd2, 0xcb, 0xa6, 0x7a, 0x36, 0x31,
	0x1b, 0xf8, 0x1a, 0xec, 0x4d, 0xb8, 0xd5, 0x25, 0x79, 0xb1, 0xd3, 0x6b, 0xe5, 0x4e, 0xef, 0x8f,
	0x39, 0x65, 0x52, 0x4d, 0xbb, 0xdc, 0x5f, 0x05, 0x2b, 0xc3, 0xbf, 0x69, 0xfb, 0x7f, 0x59, 0x02,
	0x0f, 0x42, 0x96, 0x96, 0x37, 0xf3, 0xfb, 0x5b, 0x93, 0xdd, 0x7c, 0x5b, 0xfb, 0x6f, 0x57, 0x7e,
	0xfb, 0x2b, 0xa7, 0x8d, 0x59, 0x82, 0xb3, 0xb8, 0xca, 0x44, 0x5c, 0x8b, 0x49, 0x66, 0xa2, 0xf3,
	0x3f, 0x24, 0x39, 0x95, 0x73, 0x7e, 0x4c, 0x7f, 0x36, 0xbc, 0xfa, 0xc7, 0xd2, 0xf2, 0x41, 0xb3,
	0xf9, 0xcf, 0xa5, 0x7b, 0x07, 0x16, 0xd9, 0x8c, 0x64, 0xd5, 0x5e, 0xea, 0xab, 0xd3, 0x7a, 0xb5,
	0xe3, 0x47, 0xfe, 0xdb, 0x8f, 0x39, 0x6b, 0x46, 0xf2, 0x6c, 0x38, 0xe6, 0xec, 0xb4, 0x7e, 0x36,
	0x1c, 0xf3, 0xdf, 0xa5, 0x07, 0xf6, 0x41, 0xa3, 0xd1, 0x8c, 0x64, 0xa3, 0x31, 0x1c, 0xd5, 0x68,
	0x9c, 0xd6, 0x1b, 0x8d, 0xe1, 0xb8, 0xee, 0x75, 0x13, 0xec, 0xe3, 0xff, 0x07, 0x00, 0x00, 0xff,
	0xff, 0x80, 0xb9, 0xd4, 0x02, 0x44, 0x17, 0x00, 0x00,
}
