// Code generated by protoc-gen-go. DO NOT EDIT.
// source: google/ads/googleads/v2/resources/click_view.proto

package resources

import (
	fmt "fmt"
	math "math"

	proto "github.com/golang/protobuf/proto"
	wrappers "github.com/golang/protobuf/ptypes/wrappers"
	common "google.golang.org/genproto/googleapis/ads/googleads/v2/common"
	_ "google.golang.org/genproto/googleapis/api/annotations"
)

// Reference imports to suppress errors if they are not otherwise used.
var _ = proto.Marshal
var _ = fmt.Errorf
var _ = math.Inf

// This is a compile-time assertion to ensure that this generated file
// is compatible with the proto package it is being compiled against.
// A compilation error at this line likely means your copy of the
// proto package needs to be updated.
const _ = proto.ProtoPackageIsVersion3 // please upgrade the proto package

// A click view with metrics aggregated at each click level, including both
// valid and invalid clicks. For non-Search campaigns, metrics.clicks
// represents the number of valid and invalid interactions.
type ClickView struct {
	// The resource name of the click view.
	// Click view resource names have the form:
	//
	// `customers/{customer_id}/clickViews/{date (yyyy-MM-dd)}~{gclid}`
	ResourceName string `protobuf:"bytes,1,opt,name=resource_name,json=resourceName,proto3" json:"resource_name,omitempty"`
	// The Google Click ID.
	Gclid *wrappers.StringValue `protobuf:"bytes,2,opt,name=gclid,proto3" json:"gclid,omitempty"`
	// The location criteria matching the area of interest associated with the
	// impression.
	AreaOfInterest *common.ClickLocation `protobuf:"bytes,3,opt,name=area_of_interest,json=areaOfInterest,proto3" json:"area_of_interest,omitempty"`
	// The location criteria matching the location of presence associated with the
	// impression.
	LocationOfPresence *common.ClickLocation `protobuf:"bytes,4,opt,name=location_of_presence,json=locationOfPresence,proto3" json:"location_of_presence,omitempty"`
	// Page number in search results where the ad was shown.
	PageNumber *wrappers.Int64Value `protobuf:"bytes,5,opt,name=page_number,json=pageNumber,proto3" json:"page_number,omitempty"`
	// The associated ad.
	AdGroupAd            *wrappers.StringValue `protobuf:"bytes,7,opt,name=ad_group_ad,json=adGroupAd,proto3" json:"ad_group_ad,omitempty"`
	XXX_NoUnkeyedLiteral struct{}              `json:"-"`
	XXX_unrecognized     []byte                `json:"-"`
	XXX_sizecache        int32                 `json:"-"`
}

func (m *ClickView) Reset()         { *m = ClickView{} }
func (m *ClickView) String() string { return proto.CompactTextString(m) }
func (*ClickView) ProtoMessage()    {}
func (*ClickView) Descriptor() ([]byte, []int) {
	return fileDescriptor_0b0611b0c8085235, []int{0}
}

func (m *ClickView) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_ClickView.Unmarshal(m, b)
}
func (m *ClickView) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_ClickView.Marshal(b, m, deterministic)
}
func (m *ClickView) XXX_Merge(src proto.Message) {
	xxx_messageInfo_ClickView.Merge(m, src)
}
func (m *ClickView) XXX_Size() int {
	return xxx_messageInfo_ClickView.Size(m)
}
func (m *ClickView) XXX_DiscardUnknown() {
	xxx_messageInfo_ClickView.DiscardUnknown(m)
}

var xxx_messageInfo_ClickView proto.InternalMessageInfo

func (m *ClickView) GetResourceName() string {
	if m != nil {
		return m.ResourceName
	}
	return ""
}

func (m *ClickView) GetGclid() *wrappers.StringValue {
	if m != nil {
		return m.Gclid
	}
	return nil
}

func (m *ClickView) GetAreaOfInterest() *common.ClickLocation {
	if m != nil {
		return m.AreaOfInterest
	}
	return nil
}

func (m *ClickView) GetLocationOfPresence() *common.ClickLocation {
	if m != nil {
		return m.LocationOfPresence
	}
	return nil
}

func (m *ClickView) GetPageNumber() *wrappers.Int64Value {
	if m != nil {
		return m.PageNumber
	}
	return nil
}

func (m *ClickView) GetAdGroupAd() *wrappers.StringValue {
	if m != nil {
		return m.AdGroupAd
	}
	return nil
}

func init() {
	proto.RegisterType((*ClickView)(nil), "google.ads.googleads.v2.resources.ClickView")
}

func init() {
	proto.RegisterFile("google/ads/googleads/v2/resources/click_view.proto", fileDescriptor_0b0611b0c8085235)
}

var fileDescriptor_0b0611b0c8085235 = []byte{
	// 448 bytes of a gzipped FileDescriptorProto
	0x1f, 0x8b, 0x08, 0x00, 0x00, 0x00, 0x00, 0x00, 0x02, 0xff, 0x9c, 0x92, 0x4f, 0x6b, 0xd4, 0x40,
	0x18, 0x87, 0xc9, 0xae, 0x55, 0x76, 0xaa, 0x45, 0x82, 0x87, 0x50, 0x8b, 0xb4, 0x4a, 0xa1, 0x17,
	0x27, 0x90, 0x8a, 0x87, 0xe8, 0x25, 0xf5, 0xb0, 0x54, 0xa4, 0x5d, 0x56, 0x88, 0x20, 0x0b, 0x61,
	0x36, 0xf3, 0xee, 0x30, 0x98, 0xcc, 0x84, 0x99, 0x64, 0xf7, 0xbb, 0x78, 0xf4, 0xe8, 0x47, 0xf1,
	0xa3, 0xf8, 0x15, 0xbc, 0xc8, 0x64, 0xfe, 0x5c, 0x64, 0x55, 0x7a, 0x7b, 0x93, 0x79, 0x7e, 0x4f,
	0xde, 0x77, 0xf2, 0xa2, 0x8c, 0x49, 0xc9, 0x1a, 0x48, 0x09, 0xd5, 0xa9, 0x2d, 0x4d, 0xb5, 0xcd,
	0x52, 0x05, 0x5a, 0x0e, 0xaa, 0x06, 0x9d, 0xd6, 0x0d, 0xaf, 0xbf, 0x54, 0x5b, 0x0e, 0x3b, 0xdc,
	0x29, 0xd9, 0xcb, 0xf8, 0xcc, 0x82, 0x98, 0x50, 0x8d, 0x43, 0x06, 0x6f, 0x33, 0x1c, 0x32, 0xc7,
	0x97, 0xfb, 0xb4, 0xb5, 0x6c, 0x5b, 0x29, 0x9c, 0xb3, 0x91, 0x35, 0xe9, 0xb9, 0x14, 0xd6, 0x7b,
	0xfc, 0xcc, 0x85, 0xc6, 0xa7, 0xf5, 0xb0, 0x49, 0x77, 0x8a, 0x74, 0x1d, 0x28, 0xed, 0xce, 0x4f,
	0xbc, 0xb4, 0xe3, 0x29, 0x11, 0x42, 0xf6, 0x63, 0xd8, 0x9d, 0x3e, 0xff, 0x3a, 0x45, 0xb3, 0x77,
	0x46, 0x5b, 0x72, 0xd8, 0xc5, 0x2f, 0xd0, 0x23, 0xdf, 0x4d, 0x25, 0x48, 0x0b, 0x49, 0x74, 0x1a,
	0x5d, 0xcc, 0x96, 0x0f, 0xfd, 0xcb, 0x1b, 0xd2, 0x42, 0x9c, 0xa1, 0x03, 0x56, 0x37, 0x9c, 0x26,
	0x93, 0xd3, 0xe8, 0xe2, 0x30, 0x3b, 0x71, 0xd3, 0x60, 0xdf, 0x00, 0xfe, 0xd8, 0x2b, 0x2e, 0x58,
	0x49, 0x9a, 0x01, 0x96, 0x16, 0x8d, 0x3f, 0xa1, 0xc7, 0x44, 0x01, 0xa9, 0xe4, 0xa6, 0xe2, 0xa2,
	0x07, 0x05, 0xba, 0x4f, 0xa6, 0x63, 0xfc, 0x25, 0xde, 0x77, 0x2f, 0x76, 0x68, 0x3c, 0x76, 0xf7,
	0xc1, 0xcd, 0xbc, 0x3c, 0x32, 0x9a, 0xdb, 0xcd, 0xb5, 0x93, 0xc4, 0x15, 0x7a, 0xe2, 0xef, 0xc3,
	0xc8, 0x3b, 0x05, 0x1a, 0x44, 0x0d, 0xc9, 0xbd, 0xbb, 0xc8, 0x63, 0xaf, 0xba, 0xdd, 0x2c, 0x9c,
	0x28, 0x7e, 0x8b, 0x0e, 0x3b, 0xc2, 0xa0, 0x12, 0x43, 0xbb, 0x06, 0x95, 0x1c, 0x8c, 0xde, 0xa7,
	0x7f, 0xcc, 0x7c, 0x2d, 0xfa, 0xd7, 0xaf, 0xec, 0xc8, 0xc8, 0xf0, 0x37, 0x23, 0x6e, 0xd2, 0x84,
	0x56, 0x4c, 0xc9, 0xa1, 0xab, 0x08, 0x4d, 0x1e, 0xfc, 0xc7, 0x8d, 0xcd, 0x08, 0x9d, 0x1b, 0xbe,
	0xa0, 0x57, 0xbf, 0x22, 0x74, 0x5e, 0xcb, 0x16, 0xff, 0x73, 0x73, 0xae, 0x8e, 0xc2, 0x3f, 0x5c,
	0x18, 0xe7, 0x22, 0xfa, 0xfc, 0xde, 0x85, 0x98, 0x6c, 0x88, 0x60, 0x58, 0x2a, 0x96, 0x32, 0x10,
	0xe3, 0x17, 0xfd, 0x6e, 0x75, 0x5c, 0xff, 0x65, 0x83, 0xdf, 0x84, 0xea, 0xdb, 0x64, 0x3a, 0x2f,
	0x8a, 0xef, 0x93, 0xb3, 0xb9, 0x55, 0x16, 0x54, 0x63, 0x5b, 0x9a, 0xaa, 0xcc, 0xf0, 0xd2, 0x93,
	0x3f, 0x3c, 0xb3, 0x2a, 0xa8, 0x5e, 0x05, 0x66, 0x55, 0x66, 0xab, 0xc0, 0xfc, 0x9c, 0x9c, 0xdb,
	0x83, 0x3c, 0x2f, 0xa8, 0xce, 0xf3, 0x40, 0xe5, 0x79, 0x99, 0xe5, 0x79, 0xe0, 0xd6, 0xf7, 0xc7,
	0x66, 0x2f, 0x7f, 0x07, 0x00, 0x00, 0xff, 0xff, 0x8d, 0xe7, 0x0a, 0xbf, 0x6d, 0x03, 0x00, 0x00,
}
