// Code generated by protoc-gen-go. DO NOT EDIT.
// source: google/ads/googleads/v2/common/asset_types.proto

package common

import (
	fmt "fmt"
	math "math"

	proto "github.com/golang/protobuf/proto"
	wrappers "github.com/golang/protobuf/ptypes/wrappers"
	enums "google.golang.org/genproto/googleapis/ads/googleads/v2/enums"
	_ "google.golang.org/genproto/googleapis/api/annotations"
)

// Reference imports to suppress errors if they are not otherwise used.
var _ = proto.Marshal
var _ = fmt.Errorf
var _ = math.Inf

// This is a compile-time assertion to ensure that this generated file
// is compatible with the proto package it is being compiled against.
// A compilation error at this line likely means your copy of the
// proto package needs to be updated.
const _ = proto.ProtoPackageIsVersion3 // please upgrade the proto package

// A YouTube asset.
type YoutubeVideoAsset struct {
	// YouTube video id. This is the 11 character string value used in the
	// YouTube video URL.
	YoutubeVideoId       *wrappers.StringValue `protobuf:"bytes,1,opt,name=youtube_video_id,json=youtubeVideoId,proto3" json:"youtube_video_id,omitempty"`
	XXX_NoUnkeyedLiteral struct{}              `json:"-"`
	XXX_unrecognized     []byte                `json:"-"`
	XXX_sizecache        int32                 `json:"-"`
}

func (m *YoutubeVideoAsset) Reset()         { *m = YoutubeVideoAsset{} }
func (m *YoutubeVideoAsset) String() string { return proto.CompactTextString(m) }
func (*YoutubeVideoAsset) ProtoMessage()    {}
func (*YoutubeVideoAsset) Descriptor() ([]byte, []int) {
	return fileDescriptor_9a795a4c39c332df, []int{0}
}

func (m *YoutubeVideoAsset) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_YoutubeVideoAsset.Unmarshal(m, b)
}
func (m *YoutubeVideoAsset) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_YoutubeVideoAsset.Marshal(b, m, deterministic)
}
func (m *YoutubeVideoAsset) XXX_Merge(src proto.Message) {
	xxx_messageInfo_YoutubeVideoAsset.Merge(m, src)
}
func (m *YoutubeVideoAsset) XXX_Size() int {
	return xxx_messageInfo_YoutubeVideoAsset.Size(m)
}
func (m *YoutubeVideoAsset) XXX_DiscardUnknown() {
	xxx_messageInfo_YoutubeVideoAsset.DiscardUnknown(m)
}

var xxx_messageInfo_YoutubeVideoAsset proto.InternalMessageInfo

func (m *YoutubeVideoAsset) GetYoutubeVideoId() *wrappers.StringValue {
	if m != nil {
		return m.YoutubeVideoId
	}
	return nil
}

// A MediaBundle asset.
type MediaBundleAsset struct {
	// Media bundle (ZIP file) asset data. The format of the uploaded ZIP file
	// depends on the ad field where it will be used. For more information on the
	// format, see the documentation of the ad field where you plan on using the
	// MediaBundleAsset. This field is mutate only.
	Data                 *wrappers.BytesValue `protobuf:"bytes,1,opt,name=data,proto3" json:"data,omitempty"`
	XXX_NoUnkeyedLiteral struct{}             `json:"-"`
	XXX_unrecognized     []byte               `json:"-"`
	XXX_sizecache        int32                `json:"-"`
}

func (m *MediaBundleAsset) Reset()         { *m = MediaBundleAsset{} }
func (m *MediaBundleAsset) String() string { return proto.CompactTextString(m) }
func (*MediaBundleAsset) ProtoMessage()    {}
func (*MediaBundleAsset) Descriptor() ([]byte, []int) {
	return fileDescriptor_9a795a4c39c332df, []int{1}
}

func (m *MediaBundleAsset) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_MediaBundleAsset.Unmarshal(m, b)
}
func (m *MediaBundleAsset) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_MediaBundleAsset.Marshal(b, m, deterministic)
}
func (m *MediaBundleAsset) XXX_Merge(src proto.Message) {
	xxx_messageInfo_MediaBundleAsset.Merge(m, src)
}
func (m *MediaBundleAsset) XXX_Size() int {
	return xxx_messageInfo_MediaBundleAsset.Size(m)
}
func (m *MediaBundleAsset) XXX_DiscardUnknown() {
	xxx_messageInfo_MediaBundleAsset.DiscardUnknown(m)
}

var xxx_messageInfo_MediaBundleAsset proto.InternalMessageInfo

func (m *MediaBundleAsset) GetData() *wrappers.BytesValue {
	if m != nil {
		return m.Data
	}
	return nil
}

// An Image asset.
type ImageAsset struct {
	// The raw bytes data of an image. This field is mutate only.
	Data *wrappers.BytesValue `protobuf:"bytes,1,opt,name=data,proto3" json:"data,omitempty"`
	// File size of the image asset in bytes.
	FileSize *wrappers.Int64Value `protobuf:"bytes,2,opt,name=file_size,json=fileSize,proto3" json:"file_size,omitempty"`
	// MIME type of the image asset.
	MimeType enums.MimeTypeEnum_MimeType `protobuf:"varint,3,opt,name=mime_type,json=mimeType,proto3,enum=google.ads.googleads.v2.enums.MimeTypeEnum_MimeType" json:"mime_type,omitempty"`
	// Metadata for this image at its original size.
	FullSize             *ImageDimension `protobuf:"bytes,4,opt,name=full_size,json=fullSize,proto3" json:"full_size,omitempty"`
	XXX_NoUnkeyedLiteral struct{}        `json:"-"`
	XXX_unrecognized     []byte          `json:"-"`
	XXX_sizecache        int32           `json:"-"`
}

func (m *ImageAsset) Reset()         { *m = ImageAsset{} }
func (m *ImageAsset) String() string { return proto.CompactTextString(m) }
func (*ImageAsset) ProtoMessage()    {}
func (*ImageAsset) Descriptor() ([]byte, []int) {
	return fileDescriptor_9a795a4c39c332df, []int{2}
}

func (m *ImageAsset) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_ImageAsset.Unmarshal(m, b)
}
func (m *ImageAsset) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_ImageAsset.Marshal(b, m, deterministic)
}
func (m *ImageAsset) XXX_Merge(src proto.Message) {
	xxx_messageInfo_ImageAsset.Merge(m, src)
}
func (m *ImageAsset) XXX_Size() int {
	return xxx_messageInfo_ImageAsset.Size(m)
}
func (m *ImageAsset) XXX_DiscardUnknown() {
	xxx_messageInfo_ImageAsset.DiscardUnknown(m)
}

var xxx_messageInfo_ImageAsset proto.InternalMessageInfo

func (m *ImageAsset) GetData() *wrappers.BytesValue {
	if m != nil {
		return m.Data
	}
	return nil
}

func (m *ImageAsset) GetFileSize() *wrappers.Int64Value {
	if m != nil {
		return m.FileSize
	}
	return nil
}

func (m *ImageAsset) GetMimeType() enums.MimeTypeEnum_MimeType {
	if m != nil {
		return m.MimeType
	}
	return enums.MimeTypeEnum_UNSPECIFIED
}

func (m *ImageAsset) GetFullSize() *ImageDimension {
	if m != nil {
		return m.FullSize
	}
	return nil
}

// Metadata for an image at a certain size, either original or resized.
type ImageDimension struct {
	// Height of the image.
	HeightPixels *wrappers.Int64Value `protobuf:"bytes,1,opt,name=height_pixels,json=heightPixels,proto3" json:"height_pixels,omitempty"`
	// Width of the image.
	WidthPixels *wrappers.Int64Value `protobuf:"bytes,2,opt,name=width_pixels,json=widthPixels,proto3" json:"width_pixels,omitempty"`
	// A URL that returns the image with this height and width.
	Url                  *wrappers.StringValue `protobuf:"bytes,3,opt,name=url,proto3" json:"url,omitempty"`
	XXX_NoUnkeyedLiteral struct{}              `json:"-"`
	XXX_unrecognized     []byte                `json:"-"`
	XXX_sizecache        int32                 `json:"-"`
}

func (m *ImageDimension) Reset()         { *m = ImageDimension{} }
func (m *ImageDimension) String() string { return proto.CompactTextString(m) }
func (*ImageDimension) ProtoMessage()    {}
func (*ImageDimension) Descriptor() ([]byte, []int) {
	return fileDescriptor_9a795a4c39c332df, []int{3}
}

func (m *ImageDimension) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_ImageDimension.Unmarshal(m, b)
}
func (m *ImageDimension) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_ImageDimension.Marshal(b, m, deterministic)
}
func (m *ImageDimension) XXX_Merge(src proto.Message) {
	xxx_messageInfo_ImageDimension.Merge(m, src)
}
func (m *ImageDimension) XXX_Size() int {
	return xxx_messageInfo_ImageDimension.Size(m)
}
func (m *ImageDimension) XXX_DiscardUnknown() {
	xxx_messageInfo_ImageDimension.DiscardUnknown(m)
}

var xxx_messageInfo_ImageDimension proto.InternalMessageInfo

func (m *ImageDimension) GetHeightPixels() *wrappers.Int64Value {
	if m != nil {
		return m.HeightPixels
	}
	return nil
}

func (m *ImageDimension) GetWidthPixels() *wrappers.Int64Value {
	if m != nil {
		return m.WidthPixels
	}
	return nil
}

func (m *ImageDimension) GetUrl() *wrappers.StringValue {
	if m != nil {
		return m.Url
	}
	return nil
}

// A Text asset.
type TextAsset struct {
	// Text content of the text asset.
	Text                 *wrappers.StringValue `protobuf:"bytes,1,opt,name=text,proto3" json:"text,omitempty"`
	XXX_NoUnkeyedLiteral struct{}              `json:"-"`
	XXX_unrecognized     []byte                `json:"-"`
	XXX_sizecache        int32                 `json:"-"`
}

func (m *TextAsset) Reset()         { *m = TextAsset{} }
func (m *TextAsset) String() string { return proto.CompactTextString(m) }
func (*TextAsset) ProtoMessage()    {}
func (*TextAsset) Descriptor() ([]byte, []int) {
	return fileDescriptor_9a795a4c39c332df, []int{4}
}

func (m *TextAsset) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_TextAsset.Unmarshal(m, b)
}
func (m *TextAsset) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_TextAsset.Marshal(b, m, deterministic)
}
func (m *TextAsset) XXX_Merge(src proto.Message) {
	xxx_messageInfo_TextAsset.Merge(m, src)
}
func (m *TextAsset) XXX_Size() int {
	return xxx_messageInfo_TextAsset.Size(m)
}
func (m *TextAsset) XXX_DiscardUnknown() {
	xxx_messageInfo_TextAsset.DiscardUnknown(m)
}

var xxx_messageInfo_TextAsset proto.InternalMessageInfo

func (m *TextAsset) GetText() *wrappers.StringValue {
	if m != nil {
		return m.Text
	}
	return nil
}

func init() {
	proto.RegisterType((*YoutubeVideoAsset)(nil), "google.ads.googleads.v2.common.YoutubeVideoAsset")
	proto.RegisterType((*MediaBundleAsset)(nil), "google.ads.googleads.v2.common.MediaBundleAsset")
	proto.RegisterType((*ImageAsset)(nil), "google.ads.googleads.v2.common.ImageAsset")
	proto.RegisterType((*ImageDimension)(nil), "google.ads.googleads.v2.common.ImageDimension")
	proto.RegisterType((*TextAsset)(nil), "google.ads.googleads.v2.common.TextAsset")
}

func init() {
	proto.RegisterFile("google/ads/googleads/v2/common/asset_types.proto", fileDescriptor_9a795a4c39c332df)
}

var fileDescriptor_9a795a4c39c332df = []byte{
	// 537 bytes of a gzipped FileDescriptorProto
	0x1f, 0x8b, 0x08, 0x00, 0x00, 0x00, 0x00, 0x00, 0x02, 0xff, 0x9c, 0x93, 0x41, 0x6b, 0xdb, 0x30,
	0x14, 0xc7, 0x71, 0x1a, 0x46, 0xa2, 0x76, 0x59, 0xe7, 0x53, 0xc8, 0x4a, 0x29, 0x3e, 0xf5, 0x32,
	0xb9, 0x78, 0x65, 0x0c, 0x8f, 0x8d, 0x39, 0xed, 0x56, 0xc2, 0x28, 0x64, 0x69, 0x09, 0x6c, 0x0b,
	0x04, 0xa5, 0x7a, 0x71, 0x04, 0x96, 0x64, 0x2c, 0x39, 0x4d, 0xfa, 0x45, 0x76, 0xdf, 0x71, 0x1f,
	0x63, 0xc7, 0x7d, 0x94, 0x7e, 0x8a, 0x21, 0xc9, 0x09, 0x1d, 0x23, 0x6b, 0xd9, 0xc9, 0xcf, 0xd2,
	0xff, 0xff, 0xd3, 0xd3, 0x7b, 0x4f, 0xe8, 0x28, 0x95, 0x32, 0xcd, 0x20, 0x24, 0x54, 0x85, 0x2e,
	0x34, 0xd1, 0x3c, 0x0a, 0xaf, 0x24, 0xe7, 0x52, 0x84, 0x44, 0x29, 0xd0, 0x63, 0xbd, 0xcc, 0x41,
	0xe1, 0xbc, 0x90, 0x5a, 0xfa, 0xfb, 0x4e, 0x86, 0x09, 0x55, 0x78, 0xed, 0xc0, 0xf3, 0x08, 0x3b,
	0x47, 0xe7, 0xf9, 0x26, 0x22, 0x88, 0x92, 0xab, 0x90, 0x33, 0x0e, 0x96, 0xe7, 0x70, 0x9d, 0x0a,
	0x17, 0xda, 0xbf, 0x49, 0x39, 0x0d, 0xaf, 0x0b, 0x92, 0xe7, 0x50, 0x54, 0xc7, 0x75, 0xf6, 0x56,
	0xb8, 0x9c, 0x85, 0x44, 0x08, 0xa9, 0x89, 0x66, 0x52, 0x54, 0xbb, 0xc1, 0x57, 0xf4, 0xf4, 0xb3,
	0x2c, 0x75, 0x39, 0x81, 0x21, 0xa3, 0x20, 0x13, 0x93, 0xad, 0xff, 0x01, 0xed, 0x2e, 0xdd, 0xe2,
	0x78, 0x6e, 0x56, 0xc7, 0x8c, 0xb6, 0xbd, 0x03, 0xef, 0x70, 0x3b, 0xda, 0xab, 0x32, 0xc6, 0xab,
	0xd3, 0xf0, 0x85, 0x2e, 0x98, 0x48, 0x87, 0x24, 0x2b, 0x61, 0xd0, 0x5a, 0xde, 0x41, 0xf5, 0x68,
	0x70, 0x82, 0x76, 0xcf, 0x81, 0x32, 0xd2, 0x2d, 0x05, 0xcd, 0xc0, 0xb1, 0x43, 0x54, 0xa7, 0x44,
	0x93, 0x8a, 0xf7, 0xec, 0x2f, 0x5e, 0x77, 0xa9, 0x41, 0x39, 0x9c, 0x15, 0x06, 0xdf, 0x6a, 0x08,
	0xf5, 0x38, 0x49, 0xff, 0xd3, 0xef, 0xbf, 0x42, 0xcd, 0x29, 0xcb, 0x60, 0xac, 0xd8, 0x0d, 0xb4,
	0x6b, 0x1b, 0x5c, 0x3d, 0xa1, 0x5f, 0x1e, 0x3b, 0x57, 0xc3, 0xa8, 0x2f, 0xd8, 0x0d, 0xf8, 0x9f,
	0x50, 0x73, 0x5d, 0xec, 0xf6, 0xd6, 0x81, 0x77, 0xd8, 0x8a, 0x8e, 0xf1, 0xa6, 0xe6, 0xd9, 0xe6,
	0xe0, 0x73, 0xc6, 0xe1, 0x72, 0x99, 0xc3, 0x7b, 0x51, 0xf2, 0xf5, 0xcf, 0xa0, 0xc1, 0xab, 0xc8,
	0xff, 0x88, 0x9a, 0xd3, 0x32, 0xcb, 0x5c, 0x32, 0x75, 0x9b, 0x0c, 0xc6, 0xff, 0x9e, 0x07, 0x6c,
	0x2f, 0x7f, 0xca, 0x38, 0x08, 0xc5, 0xa4, 0x18, 0x34, 0x0c, 0xc0, 0xe4, 0x17, 0xfc, 0xf4, 0x50,
	0xeb, 0xcf, 0x4d, 0xff, 0x1d, 0x7a, 0x3c, 0x03, 0x96, 0xce, 0xf4, 0x38, 0x67, 0x0b, 0xc8, 0xd4,
	0xc6, 0x32, 0xdd, 0xb9, 0xf0, 0x8e, 0x73, 0xf4, 0xad, 0xc1, 0x7f, 0x8b, 0x76, 0xae, 0x19, 0xd5,
	0xb3, 0x15, 0xe0, 0x01, 0x15, 0xdb, 0xb6, 0x86, 0xca, 0x8f, 0xd1, 0x56, 0x59, 0x64, 0xb6, 0x5c,
	0xf7, 0x8d, 0x8b, 0x11, 0x06, 0x6f, 0x50, 0xf3, 0x12, 0x16, 0xda, 0x35, 0xf7, 0x08, 0xd5, 0x35,
	0x2c, 0xf4, 0x83, 0x86, 0xcd, 0x2a, 0xbb, 0xb7, 0x1e, 0x0a, 0xae, 0x24, 0xbf, 0xa7, 0x86, 0xdd,
	0x27, 0x96, 0x6f, 0x5a, 0xa0, 0xfa, 0x06, 0xd6, 0xf7, 0xbe, 0x9c, 0x56, 0x96, 0x54, 0x66, 0x44,
	0xa4, 0x58, 0x16, 0x69, 0x98, 0x82, 0xb0, 0x47, 0xad, 0x9e, 0x5d, 0xce, 0xd4, 0xa6, 0x77, 0xfd,
	0xda, 0x7d, 0xbe, 0xd7, 0xb6, 0xce, 0x92, 0xe4, 0x47, 0x6d, 0xff, 0xcc, 0xc1, 0x12, 0xaa, 0xb0,
	0x0b, 0x4d, 0x34, 0x8c, 0xf0, 0x89, 0x95, 0xfd, 0x5a, 0x09, 0x46, 0x09, 0x55, 0xa3, 0xb5, 0x60,
	0x34, 0x8c, 0x46, 0x4e, 0x70, 0x5b, 0x0b, 0xdc, 0x6a, 0x1c, 0x27, 0x54, 0xc5, 0xf1, 0x5a, 0x12,
	0xc7, 0xc3, 0x28, 0x8e, 0x9d, 0x68, 0xf2, 0xc8, 0x66, 0xf7, 0xe2, 0x77, 0x00, 0x00, 0x00, 0xff,
	0xff, 0xff, 0xfa, 0x51, 0x11, 0x74, 0x04, 0x00, 0x00,
}
