// Code generated by protoc-gen-go. DO NOT EDIT.
// source: google/ads/googleads/v1/resources/ad_group_criterion_simulation.proto

package resources

import (
	fmt "fmt"
	math "math"

	proto "github.com/golang/protobuf/proto"
	wrappers "github.com/golang/protobuf/ptypes/wrappers"
	common "google.golang.org/genproto/googleapis/ads/googleads/v1/common"
	enums "google.golang.org/genproto/googleapis/ads/googleads/v1/enums"
	_ "google.golang.org/genproto/googleapis/api/annotations"
)

// Reference imports to suppress errors if they are not otherwise used.
var _ = proto.Marshal
var _ = fmt.Errorf
var _ = math.Inf

// This is a compile-time assertion to ensure that this generated file
// is compatible with the proto package it is being compiled against.
// A compilation error at this line likely means your copy of the
// proto package needs to be updated.
const _ = proto.ProtoPackageIsVersion3 // please upgrade the proto package

// An ad group criterion simulation. Supported combinations of advertising
// channel type, criterion type, simulation type, and simulation modification
// method are detailed below respectively.
//
// SEARCH  KEYWORD  CPC_BID  UNIFORM
type AdGroupCriterionSimulation struct {
	// The resource name of the ad group criterion simulation.
	// Ad group criterion simulation resource names have the form:
	//
	//
	// `customers/{customer_id}/adGroupCriterionSimulations/{ad_group_id}~{criterion_id}~{type}~{modification_method}~{start_date}~{end_date}`
	ResourceName string `protobuf:"bytes,1,opt,name=resource_name,json=resourceName,proto3" json:"resource_name,omitempty"`
	// AdGroup ID of the simulation.
	AdGroupId *wrappers.Int64Value `protobuf:"bytes,2,opt,name=ad_group_id,json=adGroupId,proto3" json:"ad_group_id,omitempty"`
	// Criterion ID of the simulation.
	CriterionId *wrappers.Int64Value `protobuf:"bytes,3,opt,name=criterion_id,json=criterionId,proto3" json:"criterion_id,omitempty"`
	// The field that the simulation modifies.
	Type enums.SimulationTypeEnum_SimulationType `protobuf:"varint,4,opt,name=type,proto3,enum=google.ads.googleads.v1.enums.SimulationTypeEnum_SimulationType" json:"type,omitempty"`
	// How the simulation modifies the field.
	ModificationMethod enums.SimulationModificationMethodEnum_SimulationModificationMethod `protobuf:"varint,5,opt,name=modification_method,json=modificationMethod,proto3,enum=google.ads.googleads.v1.enums.SimulationModificationMethodEnum_SimulationModificationMethod" json:"modification_method,omitempty"`
	// First day on which the simulation is based, in YYYY-MM-DD format.
	StartDate *wrappers.StringValue `protobuf:"bytes,6,opt,name=start_date,json=startDate,proto3" json:"start_date,omitempty"`
	// Last day on which the simulation is based, in YYYY-MM-DD format.
	EndDate *wrappers.StringValue `protobuf:"bytes,7,opt,name=end_date,json=endDate,proto3" json:"end_date,omitempty"`
	// List of simulation points.
	//
	// Types that are valid to be assigned to PointList:
	//	*AdGroupCriterionSimulation_CpcBidPointList
	PointList            isAdGroupCriterionSimulation_PointList `protobuf_oneof:"point_list"`
	XXX_NoUnkeyedLiteral struct{}                               `json:"-"`
	XXX_unrecognized     []byte                                 `json:"-"`
	XXX_sizecache        int32                                  `json:"-"`
}

func (m *AdGroupCriterionSimulation) Reset()         { *m = AdGroupCriterionSimulation{} }
func (m *AdGroupCriterionSimulation) String() string { return proto.CompactTextString(m) }
func (*AdGroupCriterionSimulation) ProtoMessage()    {}
func (*AdGroupCriterionSimulation) Descriptor() ([]byte, []int) {
	return fileDescriptor_f859d33f99a752e1, []int{0}
}

func (m *AdGroupCriterionSimulation) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_AdGroupCriterionSimulation.Unmarshal(m, b)
}
func (m *AdGroupCriterionSimulation) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_AdGroupCriterionSimulation.Marshal(b, m, deterministic)
}
func (m *AdGroupCriterionSimulation) XXX_Merge(src proto.Message) {
	xxx_messageInfo_AdGroupCriterionSimulation.Merge(m, src)
}
func (m *AdGroupCriterionSimulation) XXX_Size() int {
	return xxx_messageInfo_AdGroupCriterionSimulation.Size(m)
}
func (m *AdGroupCriterionSimulation) XXX_DiscardUnknown() {
	xxx_messageInfo_AdGroupCriterionSimulation.DiscardUnknown(m)
}

var xxx_messageInfo_AdGroupCriterionSimulation proto.InternalMessageInfo

func (m *AdGroupCriterionSimulation) GetResourceName() string {
	if m != nil {
		return m.ResourceName
	}
	return ""
}

func (m *AdGroupCriterionSimulation) GetAdGroupId() *wrappers.Int64Value {
	if m != nil {
		return m.AdGroupId
	}
	return nil
}

func (m *AdGroupCriterionSimulation) GetCriterionId() *wrappers.Int64Value {
	if m != nil {
		return m.CriterionId
	}
	return nil
}

func (m *AdGroupCriterionSimulation) GetType() enums.SimulationTypeEnum_SimulationType {
	if m != nil {
		return m.Type
	}
	return enums.SimulationTypeEnum_UNSPECIFIED
}

func (m *AdGroupCriterionSimulation) GetModificationMethod() enums.SimulationModificationMethodEnum_SimulationModificationMethod {
	if m != nil {
		return m.ModificationMethod
	}
	return enums.SimulationModificationMethodEnum_UNSPECIFIED
}

func (m *AdGroupCriterionSimulation) GetStartDate() *wrappers.StringValue {
	if m != nil {
		return m.StartDate
	}
	return nil
}

func (m *AdGroupCriterionSimulation) GetEndDate() *wrappers.StringValue {
	if m != nil {
		return m.EndDate
	}
	return nil
}

type isAdGroupCriterionSimulation_PointList interface {
	isAdGroupCriterionSimulation_PointList()
}

type AdGroupCriterionSimulation_CpcBidPointList struct {
	CpcBidPointList *common.CpcBidSimulationPointList `protobuf:"bytes,8,opt,name=cpc_bid_point_list,json=cpcBidPointList,proto3,oneof"`
}

func (*AdGroupCriterionSimulation_CpcBidPointList) isAdGroupCriterionSimulation_PointList() {}

func (m *AdGroupCriterionSimulation) GetPointList() isAdGroupCriterionSimulation_PointList {
	if m != nil {
		return m.PointList
	}
	return nil
}

func (m *AdGroupCriterionSimulation) GetCpcBidPointList() *common.CpcBidSimulationPointList {
	if x, ok := m.GetPointList().(*AdGroupCriterionSimulation_CpcBidPointList); ok {
		return x.CpcBidPointList
	}
	return nil
}

// XXX_OneofWrappers is for the internal use of the proto package.
func (*AdGroupCriterionSimulation) XXX_OneofWrappers() []interface{} {
	return []interface{}{
		(*AdGroupCriterionSimulation_CpcBidPointList)(nil),
	}
}

func init() {
	proto.RegisterType((*AdGroupCriterionSimulation)(nil), "google.ads.googleads.v1.resources.AdGroupCriterionSimulation")
}

func init() {
	proto.RegisterFile("google/ads/googleads/v1/resources/ad_group_criterion_simulation.proto", fileDescriptor_f859d33f99a752e1)
}

var fileDescriptor_f859d33f99a752e1 = []byte{
	// 556 bytes of a gzipped FileDescriptorProto
	0x1f, 0x8b, 0x08, 0x00, 0x00, 0x00, 0x00, 0x00, 0x02, 0xff, 0x8c, 0x54, 0xdd, 0x6e, 0xd3, 0x3e,
	0x14, 0xff, 0xa7, 0xfb, 0xf6, 0xfa, 0x07, 0x29, 0xdc, 0x44, 0x65, 0x82, 0x0e, 0x34, 0xa9, 0x57,
	0x8e, 0xba, 0x21, 0x10, 0xa9, 0x84, 0x48, 0xc7, 0x54, 0x8a, 0x18, 0xaa, 0xb2, 0xa9, 0x17, 0xa8,
	0x52, 0xe4, 0xc6, 0x5e, 0x66, 0xa9, 0xb1, 0x2d, 0xdb, 0x19, 0xda, 0x3b, 0xc0, 0x0d, 0x8f, 0xc0,
	0x25, 0x8f, 0xc2, 0xa3, 0xf0, 0x14, 0x28, 0x4e, 0xe2, 0x4e, 0x2d, 0x65, 0xbd, 0x3b, 0x3e, 0xe7,
	0xf7, 0xd1, 0xf3, 0x73, 0x1d, 0x70, 0x96, 0x72, 0x9e, 0xce, 0x88, 0x8f, 0xb0, 0xf2, 0xcb, 0xb2,
	0xa8, 0x6e, 0xba, 0xbe, 0x24, 0x8a, 0xe7, 0x32, 0x21, 0xca, 0x47, 0x38, 0x4e, 0x25, 0xcf, 0x45,
	0x9c, 0x48, 0xaa, 0x89, 0xa4, 0x9c, 0xc5, 0x8a, 0x66, 0xf9, 0x0c, 0x69, 0xca, 0x19, 0x14, 0x92,
	0x6b, 0xee, 0x1e, 0x96, 0x5c, 0x88, 0xb0, 0x82, 0x56, 0x06, 0xde, 0x74, 0xa1, 0x95, 0x69, 0xf9,
	0xab, 0x9c, 0x12, 0x9e, 0x65, 0x9c, 0xf9, 0x8b, 0x9a, 0xad, 0xfe, 0x2a, 0x02, 0x61, 0x79, 0xa6,
	0xee, 0xe0, 0xe3, 0x8c, 0x63, 0x7a, 0x45, 0x93, 0xea, 0x40, 0xf4, 0x35, 0xc7, 0x95, 0xc6, 0xc9,
	0xda, 0x1a, 0xfa, 0x56, 0x90, 0x8a, 0x74, 0x50, 0x93, 0x04, 0xf5, 0x11, 0x63, 0x5c, 0x1b, 0x84,
	0xaa, 0xa6, 0x4f, 0xaa, 0xa9, 0x39, 0x4d, 0xf3, 0x2b, 0xff, 0x8b, 0x44, 0x42, 0x10, 0x59, 0xcd,
	0x9f, 0x7d, 0xdf, 0x02, 0xad, 0x10, 0x0f, 0x8a, 0xc4, 0x4e, 0xeb, 0xc0, 0x2e, 0xac, 0x8f, 0xfb,
	0x1c, 0xfc, 0x5f, 0x67, 0x12, 0x33, 0x94, 0x11, 0xcf, 0x69, 0x3b, 0x9d, 0xbd, 0xa8, 0x59, 0x37,
	0x3f, 0xa1, 0x8c, 0xb8, 0x3d, 0xb0, 0x6f, 0x53, 0xa7, 0xd8, 0x6b, 0xb4, 0x9d, 0xce, 0xfe, 0xf1,
	0xe3, 0x2a, 0x59, 0x58, 0x3b, 0xc3, 0x21, 0xd3, 0x2f, 0x5f, 0x8c, 0xd1, 0x2c, 0x27, 0xd1, 0x1e,
	0x2a, 0x2d, 0x87, 0xd8, 0x7d, 0x03, 0x9a, 0xf3, 0x9b, 0xa2, 0xd8, 0xdb, 0xb8, 0x9f, 0xbd, 0x6f,
	0x09, 0x43, 0xec, 0x5e, 0x82, 0xcd, 0x22, 0x0c, 0x6f, 0xb3, 0xed, 0x74, 0x1e, 0x1c, 0xbf, 0x85,
	0xab, 0xae, 0xd6, 0x44, 0x08, 0xe7, 0xab, 0x5d, 0xde, 0x0a, 0x72, 0xc6, 0xf2, 0x6c, 0xa1, 0x15,
	0x19, 0x35, 0xf7, 0x9b, 0x03, 0x1e, 0xfd, 0xe5, 0x9e, 0xbc, 0x2d, 0xe3, 0x32, 0x59, 0xdb, 0xe5,
	0xfc, 0x8e, 0xc6, 0xb9, 0x91, 0x58, 0xf0, 0x5c, 0x06, 0x44, 0x6e, 0xb6, 0xd4, 0x73, 0x7b, 0x00,
	0x28, 0x8d, 0xa4, 0x8e, 0x31, 0xd2, 0xc4, 0xdb, 0x36, 0x19, 0x1d, 0x2c, 0x65, 0x74, 0xa1, 0x25,
	0x65, 0x69, 0x15, 0xb1, 0xc1, 0xbf, 0x43, 0x9a, 0xb8, 0xaf, 0xc0, 0x2e, 0x61, 0xb8, 0xa4, 0xee,
	0xac, 0x41, 0xdd, 0x21, 0x0c, 0x1b, 0xe2, 0x35, 0x70, 0x13, 0x91, 0xc4, 0x53, 0x8a, 0x63, 0xc1,
	0x29, 0xd3, 0xf1, 0x8c, 0x2a, 0xed, 0xed, 0x1a, 0x89, 0xd7, 0x2b, 0x33, 0x28, 0x5f, 0x08, 0x3c,
	0x15, 0x49, 0x9f, 0xe2, 0xf9, 0xa6, 0xa3, 0x42, 0xe1, 0x23, 0x55, 0xfa, 0xfd, 0x7f, 0xd1, 0xc3,
	0xc4, 0x0c, 0x6d, 0xab, 0xdf, 0x04, 0x60, 0xee, 0xd0, 0xff, 0xda, 0x00, 0x47, 0x09, 0xcf, 0xe0,
	0xbd, 0xcf, 0xb4, 0xff, 0x74, 0xf5, 0x7f, 0x77, 0x54, 0xac, 0x36, 0x72, 0x3e, 0x7f, 0xa8, 0x54,
	0x52, 0x3e, 0x43, 0x2c, 0x85, 0x5c, 0xa6, 0x7e, 0x4a, 0x98, 0x59, 0xbc, 0x7e, 0x64, 0x82, 0xaa,
	0x7f, 0x7c, 0x52, 0x7a, 0xb6, 0xfa, 0xd1, 0xd8, 0x18, 0x84, 0xe1, 0xcf, 0xc6, 0xe1, 0xa0, 0x94,
	0x0c, 0xb1, 0x82, 0x65, 0x59, 0x54, 0xe3, 0x2e, 0x8c, 0x6a, 0xe4, 0xaf, 0x1a, 0x33, 0x09, 0xb1,
	0x9a, 0x58, 0xcc, 0x64, 0xdc, 0x9d, 0x58, 0xcc, 0xef, 0xc6, 0x51, 0x39, 0x08, 0x82, 0x10, 0xab,
	0x20, 0xb0, 0xa8, 0x20, 0x18, 0x77, 0x83, 0xc0, 0xe2, 0xa6, 0xdb, 0xe6, 0xc7, 0x9e, 0xfc, 0x09,
	0x00, 0x00, 0xff, 0xff, 0xf3, 0xad, 0x6b, 0x0a, 0xfe, 0x04, 0x00, 0x00,
}
