// Code generated by protoc-gen-go. DO NOT EDIT.
// source: google/ads/googleads/v1/enums/advertising_channel_sub_type.proto

package enums

import (
	fmt "fmt"
	math "math"

	proto "github.com/golang/protobuf/proto"
	_ "google.golang.org/genproto/googleapis/api/annotations"
)

// Reference imports to suppress errors if they are not otherwise used.
var _ = proto.Marshal
var _ = fmt.Errorf
var _ = math.Inf

// This is a compile-time assertion to ensure that this generated file
// is compatible with the proto package it is being compiled against.
// A compilation error at this line likely means your copy of the
// proto package needs to be updated.
const _ = proto.ProtoPackageIsVersion3 // please upgrade the proto package

// Enum describing the different channel subtypes.
type AdvertisingChannelSubTypeEnum_AdvertisingChannelSubType int32

const (
	// Not specified.
	AdvertisingChannelSubTypeEnum_UNSPECIFIED AdvertisingChannelSubTypeEnum_AdvertisingChannelSubType = 0
	// Used as a return value only. Represents value unknown in this version.
	AdvertisingChannelSubTypeEnum_UNKNOWN AdvertisingChannelSubTypeEnum_AdvertisingChannelSubType = 1
	// Mobile app campaigns for Search.
	AdvertisingChannelSubTypeEnum_SEARCH_MOBILE_APP AdvertisingChannelSubTypeEnum_AdvertisingChannelSubType = 2
	// Mobile app campaigns for Display.
	AdvertisingChannelSubTypeEnum_DISPLAY_MOBILE_APP AdvertisingChannelSubTypeEnum_AdvertisingChannelSubType = 3
	// AdWords express campaigns for search.
	AdvertisingChannelSubTypeEnum_SEARCH_EXPRESS AdvertisingChannelSubTypeEnum_AdvertisingChannelSubType = 4
	// AdWords Express campaigns for display.
	AdvertisingChannelSubTypeEnum_DISPLAY_EXPRESS AdvertisingChannelSubTypeEnum_AdvertisingChannelSubType = 5
	// Smart Shopping campaigns.
	AdvertisingChannelSubTypeEnum_SHOPPING_SMART_ADS AdvertisingChannelSubTypeEnum_AdvertisingChannelSubType = 6
	// Gmail Ad campaigns.
	AdvertisingChannelSubTypeEnum_DISPLAY_GMAIL_AD AdvertisingChannelSubTypeEnum_AdvertisingChannelSubType = 7
	// Smart display campaigns.
	AdvertisingChannelSubTypeEnum_DISPLAY_SMART_CAMPAIGN AdvertisingChannelSubTypeEnum_AdvertisingChannelSubType = 8
	// Video Outstream campaigns.
	AdvertisingChannelSubTypeEnum_VIDEO_OUTSTREAM AdvertisingChannelSubTypeEnum_AdvertisingChannelSubType = 9
	// Video TrueView for Action campaigns.
	AdvertisingChannelSubTypeEnum_VIDEO_ACTION AdvertisingChannelSubTypeEnum_AdvertisingChannelSubType = 10
	// Video campaigns with non-skippable video ads.
	AdvertisingChannelSubTypeEnum_VIDEO_NON_SKIPPABLE AdvertisingChannelSubTypeEnum_AdvertisingChannelSubType = 11
	// App Campaign that allows you to easily promote your Android or iOS app
	// across Google's top properties including Search, Play, YouTube, and the
	// Google Display Network.
	AdvertisingChannelSubTypeEnum_APP_CAMPAIGN AdvertisingChannelSubTypeEnum_AdvertisingChannelSubType = 12
	// App Campaign for engagement, focused on driving re-engagement with the
	// app across several of Google’s top properties including Search, YouTube,
	// and the Google Display Network.
	AdvertisingChannelSubTypeEnum_APP_CAMPAIGN_FOR_ENGAGEMENT AdvertisingChannelSubTypeEnum_AdvertisingChannelSubType = 13
	// Shopping Comparison Listing campaigns.
	AdvertisingChannelSubTypeEnum_SHOPPING_COMPARISON_LISTING_ADS AdvertisingChannelSubTypeEnum_AdvertisingChannelSubType = 15
)

var AdvertisingChannelSubTypeEnum_AdvertisingChannelSubType_name = map[int32]string{
	0:  "UNSPECIFIED",
	1:  "UNKNOWN",
	2:  "SEARCH_MOBILE_APP",
	3:  "DISPLAY_MOBILE_APP",
	4:  "SEARCH_EXPRESS",
	5:  "DISPLAY_EXPRESS",
	6:  "SHOPPING_SMART_ADS",
	7:  "DISPLAY_GMAIL_AD",
	8:  "DISPLAY_SMART_CAMPAIGN",
	9:  "VIDEO_OUTSTREAM",
	10: "VIDEO_ACTION",
	11: "VIDEO_NON_SKIPPABLE",
	12: "APP_CAMPAIGN",
	13: "APP_CAMPAIGN_FOR_ENGAGEMENT",
	15: "SHOPPING_COMPARISON_LISTING_ADS",
}

var AdvertisingChannelSubTypeEnum_AdvertisingChannelSubType_value = map[string]int32{
	"UNSPECIFIED":                     0,
	"UNKNOWN":                         1,
	"SEARCH_MOBILE_APP":               2,
	"DISPLAY_MOBILE_APP":              3,
	"SEARCH_EXPRESS":                  4,
	"DISPLAY_EXPRESS":                 5,
	"SHOPPING_SMART_ADS":              6,
	"DISPLAY_GMAIL_AD":                7,
	"DISPLAY_SMART_CAMPAIGN":          8,
	"VIDEO_OUTSTREAM":                 9,
	"VIDEO_ACTION":                    10,
	"VIDEO_NON_SKIPPABLE":             11,
	"APP_CAMPAIGN":                    12,
	"APP_CAMPAIGN_FOR_ENGAGEMENT":     13,
	"SHOPPING_COMPARISON_LISTING_ADS": 15,
}

func (x AdvertisingChannelSubTypeEnum_AdvertisingChannelSubType) String() string {
	return proto.EnumName(AdvertisingChannelSubTypeEnum_AdvertisingChannelSubType_name, int32(x))
}

func (AdvertisingChannelSubTypeEnum_AdvertisingChannelSubType) EnumDescriptor() ([]byte, []int) {
	return fileDescriptor_4530783206e05cfb, []int{0, 0}
}

// An immutable specialization of an Advertising Channel.
type AdvertisingChannelSubTypeEnum struct {
	XXX_NoUnkeyedLiteral struct{} `json:"-"`
	XXX_unrecognized     []byte   `json:"-"`
	XXX_sizecache        int32    `json:"-"`
}

func (m *AdvertisingChannelSubTypeEnum) Reset()         { *m = AdvertisingChannelSubTypeEnum{} }
func (m *AdvertisingChannelSubTypeEnum) String() string { return proto.CompactTextString(m) }
func (*AdvertisingChannelSubTypeEnum) ProtoMessage()    {}
func (*AdvertisingChannelSubTypeEnum) Descriptor() ([]byte, []int) {
	return fileDescriptor_4530783206e05cfb, []int{0}
}

func (m *AdvertisingChannelSubTypeEnum) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_AdvertisingChannelSubTypeEnum.Unmarshal(m, b)
}
func (m *AdvertisingChannelSubTypeEnum) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_AdvertisingChannelSubTypeEnum.Marshal(b, m, deterministic)
}
func (m *AdvertisingChannelSubTypeEnum) XXX_Merge(src proto.Message) {
	xxx_messageInfo_AdvertisingChannelSubTypeEnum.Merge(m, src)
}
func (m *AdvertisingChannelSubTypeEnum) XXX_Size() int {
	return xxx_messageInfo_AdvertisingChannelSubTypeEnum.Size(m)
}
func (m *AdvertisingChannelSubTypeEnum) XXX_DiscardUnknown() {
	xxx_messageInfo_AdvertisingChannelSubTypeEnum.DiscardUnknown(m)
}

var xxx_messageInfo_AdvertisingChannelSubTypeEnum proto.InternalMessageInfo

func init() {
	proto.RegisterEnum("google.ads.googleads.v1.enums.AdvertisingChannelSubTypeEnum_AdvertisingChannelSubType", AdvertisingChannelSubTypeEnum_AdvertisingChannelSubType_name, AdvertisingChannelSubTypeEnum_AdvertisingChannelSubType_value)
	proto.RegisterType((*AdvertisingChannelSubTypeEnum)(nil), "google.ads.googleads.v1.enums.AdvertisingChannelSubTypeEnum")
}

func init() {
	proto.RegisterFile("google/ads/googleads/v1/enums/advertising_channel_sub_type.proto", fileDescriptor_4530783206e05cfb)
}

var fileDescriptor_4530783206e05cfb = []byte{
	// 494 bytes of a gzipped FileDescriptorProto
	0x1f, 0x8b, 0x08, 0x00, 0x00, 0x00, 0x00, 0x00, 0x02, 0xff, 0x7c, 0x92, 0xcf, 0x6e, 0xd3, 0x40,
	0x10, 0xc6, 0x49, 0x02, 0x2d, 0x6c, 0x0a, 0x59, 0xb6, 0x50, 0x44, 0x21, 0x54, 0x2d, 0x77, 0x5b,
	0x11, 0x37, 0x73, 0x61, 0xe2, 0x6c, 0xdd, 0x55, 0xe3, 0xf5, 0xca, 0xeb, 0x84, 0x3f, 0x8a, 0xb4,
	0x72, 0x6a, 0xcb, 0x44, 0x4a, 0xec, 0x28, 0xeb, 0x44, 0xea, 0x83, 0xf0, 0x02, 0x1c, 0x79, 0x14,
	0x1e, 0x85, 0x6b, 0x5f, 0x00, 0xd9, 0xae, 0xd3, 0x5e, 0xd2, 0x8b, 0x35, 0xfa, 0xe6, 0xb7, 0xdf,
	0x8c, 0xf5, 0x0d, 0xfa, 0x92, 0x64, 0x59, 0x32, 0x8f, 0xcd, 0x30, 0xd2, 0x66, 0x55, 0x16, 0xd5,
	0xa6, 0x67, 0xc6, 0xe9, 0x7a, 0xa1, 0xcd, 0x30, 0xda, 0xc4, 0xab, 0x7c, 0xa6, 0x67, 0x69, 0xa2,
	0xae, 0x7e, 0x86, 0x69, 0x1a, 0xcf, 0x95, 0x5e, 0x4f, 0x55, 0x7e, 0xbd, 0x8c, 0x8d, 0xe5, 0x2a,
	0xcb, 0x33, 0xd2, 0xad, 0x9e, 0x19, 0x61, 0xa4, 0x8d, 0xad, 0x83, 0xb1, 0xe9, 0x19, 0xa5, 0xc3,
	0xf1, 0xfb, 0x7a, 0xc0, 0x72, 0x66, 0x86, 0x69, 0x9a, 0xe5, 0x61, 0x3e, 0xcb, 0x52, 0x5d, 0x3d,
	0x3e, 0xfb, 0xd5, 0x42, 0x5d, 0xb8, 0x9b, 0x61, 0x57, 0x23, 0xe4, 0x7a, 0x1a, 0x5c, 0x2f, 0x63,
	0x9a, 0xae, 0x17, 0x67, 0x37, 0x4d, 0xf4, 0x76, 0x27, 0x41, 0x3a, 0xa8, 0x3d, 0xe2, 0x52, 0x50,
	0x9b, 0x9d, 0x33, 0x3a, 0xc0, 0x8f, 0x48, 0x1b, 0xed, 0x8f, 0xf8, 0x25, 0xf7, 0xbe, 0x72, 0xdc,
	0x20, 0xaf, 0xd1, 0x4b, 0x49, 0xc1, 0xb7, 0x2f, 0x94, 0xeb, 0xf5, 0xd9, 0x90, 0x2a, 0x10, 0x02,
	0x37, 0xc9, 0x11, 0x22, 0x03, 0x26, 0xc5, 0x10, 0xbe, 0xdf, 0xd7, 0x5b, 0x84, 0xa0, 0x17, 0xb7,
	0x38, 0xfd, 0x26, 0x7c, 0x2a, 0x25, 0x7e, 0x4c, 0x0e, 0x51, 0xa7, 0x66, 0x6b, 0xf1, 0x49, 0x61,
	0x20, 0x2f, 0x3c, 0x21, 0x18, 0x77, 0x94, 0x74, 0xc1, 0x0f, 0x14, 0x0c, 0x24, 0xde, 0x23, 0xaf,
	0x10, 0xae, 0x61, 0xc7, 0x05, 0x36, 0x54, 0x30, 0xc0, 0xfb, 0xe4, 0x18, 0x1d, 0xd5, 0x6a, 0x05,
	0xdb, 0xe0, 0x0a, 0x60, 0x0e, 0xc7, 0x4f, 0x0b, 0xfb, 0x31, 0x1b, 0x50, 0x4f, 0x79, 0xa3, 0x40,
	0x06, 0x3e, 0x05, 0x17, 0x3f, 0x23, 0x18, 0x1d, 0x54, 0x22, 0xd8, 0x01, 0xf3, 0x38, 0x46, 0xe4,
	0x0d, 0x3a, 0xac, 0x14, 0xee, 0x71, 0x25, 0x2f, 0x99, 0x10, 0xd0, 0x1f, 0x52, 0xdc, 0x2e, 0x50,
	0x10, 0xe2, 0xce, 0xf1, 0x80, 0x9c, 0xa0, 0x77, 0xf7, 0x15, 0x75, 0xee, 0xf9, 0x8a, 0x72, 0x07,
	0x1c, 0xea, 0x52, 0x1e, 0xe0, 0xe7, 0xe4, 0x23, 0x3a, 0xd9, 0x2e, 0x6f, 0x7b, 0xae, 0x00, 0x9f,
	0x49, 0x8f, 0xab, 0x21, 0x93, 0x41, 0x21, 0x15, 0x7f, 0xd2, 0xe9, 0xdf, 0x34, 0xd0, 0xe9, 0x55,
	0xb6, 0x30, 0x1e, 0xcc, 0xb6, 0xff, 0x61, 0x67, 0x30, 0xa2, 0x48, 0x57, 0x34, 0x7e, 0xf4, 0x6f,
	0x0d, 0x92, 0x6c, 0x1e, 0xa6, 0x89, 0x91, 0xad, 0x12, 0x33, 0x89, 0xd3, 0x32, 0xfb, 0xfa, 0xdc,
	0x96, 0x33, 0xbd, 0xe3, 0xfa, 0x3e, 0x97, 0xdf, 0xdf, 0xcd, 0x96, 0x03, 0xf0, 0xa7, 0xd9, 0x75,
	0x2a, 0x2b, 0x88, 0xb4, 0x51, 0x95, 0x45, 0x35, 0xee, 0x19, 0xc5, 0x99, 0xe8, 0xbf, 0x75, 0x7f,
	0x02, 0x91, 0x9e, 0x6c, 0xfb, 0x93, 0x71, 0x6f, 0x52, 0xf6, 0xff, 0x35, 0x4f, 0x2b, 0xd1, 0xb2,
	0x20, 0xd2, 0x96, 0xb5, 0x25, 0x2c, 0x6b, 0xdc, 0xb3, 0xac, 0x92, 0x99, 0xee, 0x95, 0x8b, 0x7d,
	0xfa, 0x1f, 0x00, 0x00, 0xff, 0xff, 0x85, 0x86, 0x4a, 0x64, 0x15, 0x03, 0x00, 0x00,
}
