// Code generated by protoc-gen-go. DO NOT EDIT.
// source: google/ads/googleads/v2/errors/id_error.proto

package errors

import (
	fmt "fmt"
	math "math"

	proto "github.com/golang/protobuf/proto"
	_ "google.golang.org/genproto/googleapis/api/annotations"
)

// Reference imports to suppress errors if they are not otherwise used.
var _ = proto.Marshal
var _ = fmt.Errorf
var _ = math.Inf

// This is a compile-time assertion to ensure that this generated file
// is compatible with the proto package it is being compiled against.
// A compilation error at this line likely means your copy of the
// proto package needs to be updated.
const _ = proto.ProtoPackageIsVersion3 // please upgrade the proto package

// Enum describing possible id errors.
type IdErrorEnum_IdError int32

const (
	// Enum unspecified.
	IdErrorEnum_UNSPECIFIED IdErrorEnum_IdError = 0
	// The received error code is not known in this version.
	IdErrorEnum_UNKNOWN IdErrorEnum_IdError = 1
	// Id not found
	IdErrorEnum_NOT_FOUND IdErrorEnum_IdError = 2
)

var IdErrorEnum_IdError_name = map[int32]string{
	0: "UNSPECIFIED",
	1: "UNKNOWN",
	2: "NOT_FOUND",
}

var IdErrorEnum_IdError_value = map[string]int32{
	"UNSPECIFIED": 0,
	"UNKNOWN":     1,
	"NOT_FOUND":   2,
}

func (x IdErrorEnum_IdError) String() string {
	return proto.EnumName(IdErrorEnum_IdError_name, int32(x))
}

func (IdErrorEnum_IdError) EnumDescriptor() ([]byte, []int) {
	return fileDescriptor_23a7bd9531354c26, []int{0, 0}
}

// Container for enum describing possible id errors.
type IdErrorEnum struct {
	XXX_NoUnkeyedLiteral struct{} `json:"-"`
	XXX_unrecognized     []byte   `json:"-"`
	XXX_sizecache        int32    `json:"-"`
}

func (m *IdErrorEnum) Reset()         { *m = IdErrorEnum{} }
func (m *IdErrorEnum) String() string { return proto.CompactTextString(m) }
func (*IdErrorEnum) ProtoMessage()    {}
func (*IdErrorEnum) Descriptor() ([]byte, []int) {
	return fileDescriptor_23a7bd9531354c26, []int{0}
}

func (m *IdErrorEnum) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_IdErrorEnum.Unmarshal(m, b)
}
func (m *IdErrorEnum) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_IdErrorEnum.Marshal(b, m, deterministic)
}
func (m *IdErrorEnum) XXX_Merge(src proto.Message) {
	xxx_messageInfo_IdErrorEnum.Merge(m, src)
}
func (m *IdErrorEnum) XXX_Size() int {
	return xxx_messageInfo_IdErrorEnum.Size(m)
}
func (m *IdErrorEnum) XXX_DiscardUnknown() {
	xxx_messageInfo_IdErrorEnum.DiscardUnknown(m)
}

var xxx_messageInfo_IdErrorEnum proto.InternalMessageInfo

func init() {
	proto.RegisterEnum("google.ads.googleads.v2.errors.IdErrorEnum_IdError", IdErrorEnum_IdError_name, IdErrorEnum_IdError_value)
	proto.RegisterType((*IdErrorEnum)(nil), "google.ads.googleads.v2.errors.IdErrorEnum")
}

func init() {
	proto.RegisterFile("google/ads/googleads/v2/errors/id_error.proto", fileDescriptor_23a7bd9531354c26)
}

var fileDescriptor_23a7bd9531354c26 = []byte{
	// 279 bytes of a gzipped FileDescriptorProto
	0x1f, 0x8b, 0x08, 0x00, 0x00, 0x00, 0x00, 0x00, 0x02, 0xff, 0x7c, 0x90, 0x41, 0x4a, 0xc4, 0x30,
	0x14, 0x86, 0x6d, 0x05, 0x07, 0x53, 0xc5, 0xd2, 0xa5, 0xc8, 0x2c, 0xba, 0x37, 0x81, 0x0a, 0x2e,
	0xe2, 0xaa, 0x63, 0x3b, 0x43, 0x11, 0xd2, 0x82, 0xb6, 0x82, 0x14, 0x86, 0x6a, 0x4a, 0x28, 0xcc,
	0x24, 0x25, 0xa9, 0x73, 0x20, 0x97, 0x1e, 0xc5, 0x8b, 0x08, 0x9e, 0x42, 0xda, 0xd7, 0x76, 0xa7,
	0xab, 0x7c, 0x09, 0x5f, 0xfe, 0xf7, 0x27, 0xe8, 0x5a, 0x28, 0x25, 0x76, 0x35, 0xa9, 0xb8, 0x21,
	0x80, 0x3d, 0x1d, 0x02, 0x52, 0x6b, 0xad, 0xb4, 0x21, 0x0d, 0xdf, 0x0e, 0x84, 0x5b, 0xad, 0x3a,
	0xe5, 0x2d, 0xc1, 0xc1, 0x15, 0x37, 0x78, 0xd6, 0xf1, 0x21, 0xc0, 0xa0, 0x5f, 0x5e, 0x4d, 0x71,
	0x6d, 0x43, 0x2a, 0x29, 0x55, 0x57, 0x75, 0x8d, 0x92, 0x06, 0x6e, 0xfb, 0x31, 0x72, 0x12, 0x1e,
	0xf7, 0x66, 0x2c, 0xdf, 0xf7, 0xfe, 0x2d, 0x5a, 0x8c, 0x5b, 0xef, 0x02, 0x39, 0x39, 0x7b, 0xcc,
	0xe2, 0xfb, 0x64, 0x9d, 0xc4, 0x91, 0x7b, 0xe4, 0x39, 0x68, 0x91, 0xb3, 0x07, 0x96, 0x3e, 0x33,
	0xd7, 0xf2, 0xce, 0xd1, 0x29, 0x4b, 0x9f, 0xb6, 0xeb, 0x34, 0x67, 0x91, 0x6b, 0xaf, 0xbe, 0x2d,
	0xe4, 0xbf, 0xa9, 0x3d, 0xfe, 0xbf, 0xcb, 0xea, 0x6c, 0x0c, 0xcf, 0xfa, 0xd9, 0x99, 0xf5, 0x12,
	0x8d, 0xbe, 0x50, 0xbb, 0x4a, 0x0a, 0xac, 0xb4, 0x20, 0xa2, 0x96, 0x43, 0xb3, 0xe9, 0xe9, 0x6d,
	0x63, 0xfe, 0xfa, 0x89, 0x3b, 0x58, 0x3e, 0xec, 0xe3, 0x4d, 0x18, 0x7e, 0xda, 0xcb, 0x0d, 0x84,
	0x85, 0xdc, 0x60, 0xc0, 0x9e, 0x8a, 0x00, 0x0f, 0x23, 0xcd, 0xd7, 0x24, 0x94, 0x21, 0x37, 0xe5,
	0x2c, 0x94, 0x45, 0x50, 0x82, 0xf0, 0x63, 0xfb, 0x70, 0x4a, 0x69, 0xc8, 0x0d, 0xa5, 0xb3, 0x42,
	0x69, 0x11, 0x50, 0x0a, 0xd2, 0xeb, 0xc9, 0xd0, 0xee, 0xe6, 0x37, 0x00, 0x00, 0xff, 0xff, 0x17,
	0x86, 0x4e, 0xd1, 0xa6, 0x01, 0x00, 0x00,
}
