// Code generated by protoc-gen-go. DO NOT EDIT.
// source: google/ads/googleads/v1/enums/attribution_model.proto

package enums

import (
	fmt "fmt"
	math "math"

	proto "github.com/golang/protobuf/proto"
	_ "google.golang.org/genproto/googleapis/api/annotations"
)

// Reference imports to suppress errors if they are not otherwise used.
var _ = proto.Marshal
var _ = fmt.Errorf
var _ = math.Inf

// This is a compile-time assertion to ensure that this generated file
// is compatible with the proto package it is being compiled against.
// A compilation error at this line likely means your copy of the
// proto package needs to be updated.
const _ = proto.ProtoPackageIsVersion3 // please upgrade the proto package

// The attribution model that describes how to distribute credit for a
// particular conversion across potentially many prior interactions.
type AttributionModelEnum_AttributionModel int32

const (
	// Not specified.
	AttributionModelEnum_UNSPECIFIED AttributionModelEnum_AttributionModel = 0
	// Used for return value only. Represents value unknown in this version.
	AttributionModelEnum_UNKNOWN AttributionModelEnum_AttributionModel = 1
	// Uses external attribution.
	AttributionModelEnum_EXTERNAL AttributionModelEnum_AttributionModel = 100
	// Attributes all credit for a conversion to its last click.
	AttributionModelEnum_GOOGLE_ADS_LAST_CLICK AttributionModelEnum_AttributionModel = 101
	// Attributes all credit for a conversion to its first click using Google
	// Search attribution.
	AttributionModelEnum_GOOGLE_SEARCH_ATTRIBUTION_FIRST_CLICK AttributionModelEnum_AttributionModel = 102
	// Attributes credit for a conversion equally across all of its clicks using
	// Google Search attribution.
	AttributionModelEnum_GOOGLE_SEARCH_ATTRIBUTION_LINEAR AttributionModelEnum_AttributionModel = 103
	// Attributes exponentially more credit for a conversion to its more recent
	// clicks using Google Search attribution (half-life is 1 week).
	AttributionModelEnum_GOOGLE_SEARCH_ATTRIBUTION_TIME_DECAY AttributionModelEnum_AttributionModel = 104
	// Attributes 40% of the credit for a conversion to its first and last
	// clicks. Remaining 20% is evenly distributed across all other clicks. This
	// uses Google Search attribution.
	AttributionModelEnum_GOOGLE_SEARCH_ATTRIBUTION_POSITION_BASED AttributionModelEnum_AttributionModel = 105
	// Flexible model that uses machine learning to determine the appropriate
	// distribution of credit among clicks using Google Search attribution.
	AttributionModelEnum_GOOGLE_SEARCH_ATTRIBUTION_DATA_DRIVEN AttributionModelEnum_AttributionModel = 106
)

var AttributionModelEnum_AttributionModel_name = map[int32]string{
	0:   "UNSPECIFIED",
	1:   "UNKNOWN",
	100: "EXTERNAL",
	101: "GOOGLE_ADS_LAST_CLICK",
	102: "GOOGLE_SEARCH_ATTRIBUTION_FIRST_CLICK",
	103: "GOOGLE_SEARCH_ATTRIBUTION_LINEAR",
	104: "GOOGLE_SEARCH_ATTRIBUTION_TIME_DECAY",
	105: "GOOGLE_SEARCH_ATTRIBUTION_POSITION_BASED",
	106: "GOOGLE_SEARCH_ATTRIBUTION_DATA_DRIVEN",
}

var AttributionModelEnum_AttributionModel_value = map[string]int32{
	"UNSPECIFIED":                              0,
	"UNKNOWN":                                  1,
	"EXTERNAL":                                 100,
	"GOOGLE_ADS_LAST_CLICK":                    101,
	"GOOGLE_SEARCH_ATTRIBUTION_FIRST_CLICK":    102,
	"GOOGLE_SEARCH_ATTRIBUTION_LINEAR":         103,
	"GOOGLE_SEARCH_ATTRIBUTION_TIME_DECAY":     104,
	"GOOGLE_SEARCH_ATTRIBUTION_POSITION_BASED": 105,
	"GOOGLE_SEARCH_ATTRIBUTION_DATA_DRIVEN":    106,
}

func (x AttributionModelEnum_AttributionModel) String() string {
	return proto.EnumName(AttributionModelEnum_AttributionModel_name, int32(x))
}

func (AttributionModelEnum_AttributionModel) EnumDescriptor() ([]byte, []int) {
	return fileDescriptor_544444d91d4f05f0, []int{0, 0}
}

// Container for enum representing the attribution model that describes how to
// distribute credit for a particular conversion across potentially many prior
// interactions.
type AttributionModelEnum struct {
	XXX_NoUnkeyedLiteral struct{} `json:"-"`
	XXX_unrecognized     []byte   `json:"-"`
	XXX_sizecache        int32    `json:"-"`
}

func (m *AttributionModelEnum) Reset()         { *m = AttributionModelEnum{} }
func (m *AttributionModelEnum) String() string { return proto.CompactTextString(m) }
func (*AttributionModelEnum) ProtoMessage()    {}
func (*AttributionModelEnum) Descriptor() ([]byte, []int) {
	return fileDescriptor_544444d91d4f05f0, []int{0}
}

func (m *AttributionModelEnum) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_AttributionModelEnum.Unmarshal(m, b)
}
func (m *AttributionModelEnum) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_AttributionModelEnum.Marshal(b, m, deterministic)
}
func (m *AttributionModelEnum) XXX_Merge(src proto.Message) {
	xxx_messageInfo_AttributionModelEnum.Merge(m, src)
}
func (m *AttributionModelEnum) XXX_Size() int {
	return xxx_messageInfo_AttributionModelEnum.Size(m)
}
func (m *AttributionModelEnum) XXX_DiscardUnknown() {
	xxx_messageInfo_AttributionModelEnum.DiscardUnknown(m)
}

var xxx_messageInfo_AttributionModelEnum proto.InternalMessageInfo

func init() {
	proto.RegisterEnum("google.ads.googleads.v1.enums.AttributionModelEnum_AttributionModel", AttributionModelEnum_AttributionModel_name, AttributionModelEnum_AttributionModel_value)
	proto.RegisterType((*AttributionModelEnum)(nil), "google.ads.googleads.v1.enums.AttributionModelEnum")
}

func init() {
	proto.RegisterFile("google/ads/googleads/v1/enums/attribution_model.proto", fileDescriptor_544444d91d4f05f0)
}

var fileDescriptor_544444d91d4f05f0 = []byte{
	// 407 bytes of a gzipped FileDescriptorProto
	0x1f, 0x8b, 0x08, 0x00, 0x00, 0x00, 0x00, 0x00, 0x02, 0xff, 0x7c, 0x92, 0xdd, 0x6a, 0xd4, 0x40,
	0x1c, 0xc5, 0xdd, 0x08, 0x2a, 0x53, 0xc1, 0x61, 0xb0, 0x17, 0x8a, 0x05, 0x5b, 0x2a, 0x54, 0x90,
	0x09, 0x41, 0xbc, 0x19, 0xaf, 0xfe, 0x49, 0xa6, 0xeb, 0xd0, 0x74, 0xb2, 0x24, 0xd9, 0xf5, 0x83,
	0x85, 0x21, 0x35, 0x31, 0x46, 0x36, 0x99, 0x65, 0x27, 0xdb, 0x07, 0xf2, 0x52, 0xf0, 0x35, 0xbc,
	0xf0, 0x51, 0xfa, 0x14, 0x92, 0xa4, 0x1b, 0xa1, 0x90, 0xbd, 0x09, 0x87, 0x9c, 0xdf, 0x39, 0x0c,
	0x73, 0x06, 0xbd, 0x2b, 0xb4, 0x2e, 0x56, 0xb9, 0x9d, 0x66, 0xc6, 0xee, 0x65, 0xab, 0xae, 0x1d,
	0x3b, 0xaf, 0xb7, 0x95, 0xb1, 0xd3, 0xa6, 0xd9, 0x94, 0x57, 0xdb, 0xa6, 0xd4, 0xb5, 0xaa, 0x74,
	0x96, 0xaf, 0xe8, 0x7a, 0xa3, 0x1b, 0x4d, 0x8e, 0x7a, 0x96, 0xa6, 0x99, 0xa1, 0x43, 0x8c, 0x5e,
	0x3b, 0xb4, 0x8b, 0x3d, 0x7f, 0xb1, 0x6b, 0x5d, 0x97, 0x76, 0x5a, 0xd7, 0xba, 0x49, 0xdb, 0x06,
	0xd3, 0x87, 0x4f, 0xfe, 0x58, 0xe8, 0x29, 0xfc, 0x2f, 0xbe, 0x6c, 0x7b, 0x79, 0xbd, 0xad, 0x4e,
	0x7e, 0x5b, 0x08, 0xdf, 0x35, 0xc8, 0x13, 0x74, 0x30, 0x97, 0xf1, 0x8c, 0x7b, 0xe2, 0x5c, 0x70,
	0x1f, 0xdf, 0x23, 0x07, 0xe8, 0xe1, 0x5c, 0x5e, 0xc8, 0xf0, 0xa3, 0xc4, 0x13, 0xf2, 0x18, 0x3d,
	0xe2, 0x9f, 0x12, 0x1e, 0x49, 0x08, 0x70, 0x46, 0x9e, 0xa1, 0xc3, 0x69, 0x18, 0x4e, 0x03, 0xae,
	0xc0, 0x8f, 0x55, 0x00, 0x71, 0xa2, 0xbc, 0x40, 0x78, 0x17, 0x38, 0x27, 0xaf, 0xd1, 0xab, 0x5b,
	0x2b, 0xe6, 0x10, 0x79, 0x1f, 0x14, 0x24, 0x49, 0x24, 0xdc, 0x79, 0x22, 0x42, 0xa9, 0xce, 0x45,
	0x34, 0xa0, 0xdf, 0xc8, 0x29, 0x7a, 0x39, 0x8e, 0x06, 0x42, 0x72, 0x88, 0x70, 0x41, 0xce, 0xd0,
	0xe9, 0x38, 0x95, 0x88, 0x4b, 0xae, 0x7c, 0xee, 0xc1, 0x67, 0xfc, 0x9d, 0xbc, 0x41, 0x67, 0xe3,
	0xe4, 0x2c, 0x8c, 0x45, 0x27, 0x5c, 0x88, 0xb9, 0x8f, 0xcb, 0xfd, 0x07, 0xf5, 0x21, 0x01, 0xe5,
	0x47, 0x62, 0xc1, 0x25, 0xfe, 0xe1, 0xde, 0x4c, 0xd0, 0xf1, 0x57, 0x5d, 0xd1, 0xbd, 0x63, 0xb8,
	0x87, 0x77, 0xaf, 0x74, 0xd6, 0xae, 0x30, 0x9b, 0x7c, 0x71, 0x6f, 0x73, 0x85, 0x5e, 0xa5, 0x75,
	0x41, 0xf5, 0xa6, 0xb0, 0x8b, 0xbc, 0xee, 0x36, 0xda, 0xbd, 0x85, 0x75, 0x69, 0x46, 0x9e, 0xc6,
	0xfb, 0xee, 0xfb, 0xd3, 0xba, 0x3f, 0x05, 0xf8, 0x65, 0x1d, 0x4d, 0xfb, 0x2a, 0xc8, 0x0c, 0xed,
	0x65, 0xab, 0x16, 0x0e, 0x6d, 0x77, 0x35, 0x7f, 0x77, 0xfe, 0x12, 0x32, 0xb3, 0x1c, 0xfc, 0xe5,
	0xc2, 0x59, 0x76, 0xfe, 0x8d, 0x75, 0xdc, 0xff, 0x64, 0x0c, 0x32, 0xc3, 0xd8, 0x40, 0x30, 0xb6,
	0x70, 0x18, 0xeb, 0x98, 0xab, 0x07, 0xdd, 0xc1, 0xde, 0xfe, 0x0b, 0x00, 0x00, 0xff, 0xff, 0xd9,
	0xf0, 0xcb, 0x05, 0xb2, 0x02, 0x00, 0x00,
}
