// Code generated by protoc-gen-go. DO NOT EDIT.
// source: google/cloud/datacatalog/v1beta1/search.proto

package datacatalog

import (
	fmt "fmt"
	math "math"

	proto "github.com/golang/protobuf/proto"
	_ "github.com/golang/protobuf/ptypes/timestamp"
	_ "google.golang.org/genproto/googleapis/api/annotations"
)

// Reference imports to suppress errors if they are not otherwise used.
var _ = proto.Marshal
var _ = fmt.Errorf
var _ = math.Inf

// This is a compile-time assertion to ensure that this generated file
// is compatible with the proto package it is being compiled against.
// A compilation error at this line likely means your copy of the
// proto package needs to be updated.
const _ = proto.ProtoPackageIsVersion3 // please upgrade the proto package

// The different types of resources that can be returned in search.
type SearchResultType int32

const (
	// Default unknown type.
	SearchResultType_SEARCH_RESULT_TYPE_UNSPECIFIED SearchResultType = 0
	// An [Entry][google.cloud.datacatalog.v1beta1.Entry].
	SearchResultType_ENTRY SearchResultType = 1
	// A [TagTemplate][google.cloud.datacatalog.v1beta1.TagTemplate].
	SearchResultType_TAG_TEMPLATE SearchResultType = 2
	// An [EntryGroup][google.cloud.datacatalog.v1beta1.EntryGroup].
	SearchResultType_ENTRY_GROUP SearchResultType = 3
)

var SearchResultType_name = map[int32]string{
	0: "SEARCH_RESULT_TYPE_UNSPECIFIED",
	1: "ENTRY",
	2: "TAG_TEMPLATE",
	3: "ENTRY_GROUP",
}

var SearchResultType_value = map[string]int32{
	"SEARCH_RESULT_TYPE_UNSPECIFIED": 0,
	"ENTRY":                          1,
	"TAG_TEMPLATE":                   2,
	"ENTRY_GROUP":                    3,
}

func (x SearchResultType) String() string {
	return proto.EnumName(SearchResultType_name, int32(x))
}

func (SearchResultType) EnumDescriptor() ([]byte, []int) {
	return fileDescriptor_075a004a2049c613, []int{0}
}

// A result that appears in the response of a search request. Each result
// captures details of one entry that matches the search.
type SearchCatalogResult struct {
	// Type of the search result. This field can be used to determine which Get
	// method to call to fetch the full resource.
	SearchResultType SearchResultType `protobuf:"varint,1,opt,name=search_result_type,json=searchResultType,proto3,enum=google.cloud.datacatalog.v1beta1.SearchResultType" json:"search_result_type,omitempty"`
	// Sub-type of the search result. This is a dot-delimited description of the
	// resource's full type, and is the same as the value callers would provide in
	// the "type" search facet.  Examples: "entry.table", "entry.dataStream",
	// "tagTemplate"
	SearchResultSubtype string `protobuf:"bytes,2,opt,name=search_result_subtype,json=searchResultSubtype,proto3" json:"search_result_subtype,omitempty"`
	// The relative resource name of the resource in URL format.
	// Examples:
	// "projects/{project_id}/locations/{location_id}/entryGroups/{entry_group_id}/entries/{entry_id}".
	// "projects/{project_id}/tagTemplates/{tag_template_id}".
	RelativeResourceName string `protobuf:"bytes,3,opt,name=relative_resource_name,json=relativeResourceName,proto3" json:"relative_resource_name,omitempty"`
	// The full name of the cloud resource the entry belongs to. See:
	// https://cloud.google.com/apis/design/resource_names#full_resource_name
	// Example:
	// "//bigquery.googleapis.com/projects/projectId/datasets/datasetId/tables/tableId".
	LinkedResource       string   `protobuf:"bytes,4,opt,name=linked_resource,json=linkedResource,proto3" json:"linked_resource,omitempty"`
	XXX_NoUnkeyedLiteral struct{} `json:"-"`
	XXX_unrecognized     []byte   `json:"-"`
	XXX_sizecache        int32    `json:"-"`
}

func (m *SearchCatalogResult) Reset()         { *m = SearchCatalogResult{} }
func (m *SearchCatalogResult) String() string { return proto.CompactTextString(m) }
func (*SearchCatalogResult) ProtoMessage()    {}
func (*SearchCatalogResult) Descriptor() ([]byte, []int) {
	return fileDescriptor_075a004a2049c613, []int{0}
}

func (m *SearchCatalogResult) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_SearchCatalogResult.Unmarshal(m, b)
}
func (m *SearchCatalogResult) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_SearchCatalogResult.Marshal(b, m, deterministic)
}
func (m *SearchCatalogResult) XXX_Merge(src proto.Message) {
	xxx_messageInfo_SearchCatalogResult.Merge(m, src)
}
func (m *SearchCatalogResult) XXX_Size() int {
	return xxx_messageInfo_SearchCatalogResult.Size(m)
}
func (m *SearchCatalogResult) XXX_DiscardUnknown() {
	xxx_messageInfo_SearchCatalogResult.DiscardUnknown(m)
}

var xxx_messageInfo_SearchCatalogResult proto.InternalMessageInfo

func (m *SearchCatalogResult) GetSearchResultType() SearchResultType {
	if m != nil {
		return m.SearchResultType
	}
	return SearchResultType_SEARCH_RESULT_TYPE_UNSPECIFIED
}

func (m *SearchCatalogResult) GetSearchResultSubtype() string {
	if m != nil {
		return m.SearchResultSubtype
	}
	return ""
}

func (m *SearchCatalogResult) GetRelativeResourceName() string {
	if m != nil {
		return m.RelativeResourceName
	}
	return ""
}

func (m *SearchCatalogResult) GetLinkedResource() string {
	if m != nil {
		return m.LinkedResource
	}
	return ""
}

func init() {
	proto.RegisterEnum("google.cloud.datacatalog.v1beta1.SearchResultType", SearchResultType_name, SearchResultType_value)
	proto.RegisterType((*SearchCatalogResult)(nil), "google.cloud.datacatalog.v1beta1.SearchCatalogResult")
}

func init() {
	proto.RegisterFile("google/cloud/datacatalog/v1beta1/search.proto", fileDescriptor_075a004a2049c613)
}

var fileDescriptor_075a004a2049c613 = []byte{
	// 384 bytes of a gzipped FileDescriptorProto
	0x1f, 0x8b, 0x08, 0x00, 0x00, 0x00, 0x00, 0x00, 0x02, 0xff, 0x84, 0x92, 0x41, 0x6f, 0xda, 0x30,
	0x1c, 0xc5, 0x17, 0xd8, 0x26, 0xe1, 0x4d, 0x10, 0x99, 0x6d, 0x42, 0x08, 0x6d, 0x88, 0xcb, 0xd0,
	0xa4, 0xc5, 0x82, 0xed, 0xd6, 0x13, 0xa5, 0x2e, 0x45, 0xa5, 0x34, 0x72, 0xc2, 0x81, 0x5e, 0x5c,
	0x27, 0x71, 0xd3, 0xa8, 0x49, 0x1c, 0x25, 0x0e, 0x12, 0x5f, 0xa1, 0x9f, 0xb8, 0xc7, 0xaa, 0x76,
	0xa8, 0x28, 0x12, 0xea, 0xd1, 0xef, 0xfd, 0xde, 0xfb, 0xff, 0x65, 0x1b, 0xfc, 0x0d, 0x85, 0x08,
	0x63, 0x8e, 0xfc, 0x58, 0x94, 0x01, 0x0a, 0x98, 0x64, 0x3e, 0x93, 0x2c, 0x16, 0x21, 0xda, 0x8c,
	0x3c, 0x2e, 0xd9, 0x08, 0x15, 0x9c, 0xe5, 0xfe, 0xbd, 0x95, 0xe5, 0x42, 0x0a, 0xd8, 0xd7, 0xb8,
	0xa5, 0x70, 0x6b, 0x0f, 0xb7, 0x2a, 0xbc, 0xdb, 0xab, 0x0a, 0x59, 0x16, 0x21, 0x96, 0xa6, 0x42,
	0x32, 0x19, 0x89, 0xb4, 0xd0, 0xf9, 0xee, 0xaf, 0xca, 0x55, 0x27, 0xaf, 0xbc, 0x43, 0x32, 0x4a,
	0x78, 0x21, 0x59, 0x92, 0x69, 0x60, 0xf0, 0x58, 0x03, 0x6d, 0x47, 0x4d, 0x9c, 0xea, 0x62, 0xc2,
	0x8b, 0x32, 0x96, 0xf0, 0x16, 0x40, 0xbd, 0x08, 0xcd, 0x95, 0x40, 0xe5, 0x36, 0xe3, 0x1d, 0xa3,
	0x6f, 0x0c, 0x9b, 0xe3, 0xb1, 0xf5, 0xde, 0x56, 0x96, 0xae, 0xd4, 0x5d, 0xee, 0x36, 0xe3, 0xc4,
	0x2c, 0x0e, 0x14, 0x38, 0x06, 0xdf, 0xdf, 0x4e, 0x28, 0x4a, 0x4f, 0x0d, 0xa9, 0xf5, 0x8d, 0x61,
	0x83, 0xb4, 0xf7, 0x03, 0x8e, 0xb6, 0xe0, 0x7f, 0xf0, 0x23, 0xe7, 0x31, 0x93, 0xd1, 0x86, 0xbf,
	0xa4, 0x44, 0x99, 0xfb, 0x9c, 0xa6, 0x2c, 0xe1, 0x9d, 0xba, 0x0a, 0x7d, 0xdb, 0xb9, 0xa4, 0x32,
	0x97, 0x2c, 0xe1, 0xf0, 0x37, 0x68, 0xc5, 0x51, 0xfa, 0xc0, 0x83, 0xd7, 0x4c, 0xe7, 0xa3, 0xc2,
	0x9b, 0x5a, 0xde, 0xc1, 0x7f, 0x02, 0x60, 0x1e, 0x2e, 0x0e, 0x07, 0xe0, 0xa7, 0x83, 0x27, 0x64,
	0x7a, 0x41, 0x09, 0x76, 0x56, 0x0b, 0x97, 0xba, 0x6b, 0x1b, 0xd3, 0xd5, 0xd2, 0xb1, 0xf1, 0x74,
	0x7e, 0x3e, 0xc7, 0x67, 0xe6, 0x07, 0xd8, 0x00, 0x9f, 0xf0, 0xd2, 0x25, 0x6b, 0xd3, 0x80, 0x26,
	0xf8, 0xea, 0x4e, 0x66, 0xd4, 0xc5, 0x57, 0xf6, 0x62, 0xe2, 0x62, 0xb3, 0x06, 0x5b, 0xe0, 0x8b,
	0x32, 0xe9, 0x8c, 0x5c, 0xaf, 0x6c, 0xb3, 0x7e, 0x9a, 0x81, 0x9e, 0x2f, 0x92, 0xa3, 0x77, 0x68,
	0x1b, 0x37, 0x97, 0x95, 0x17, 0x8a, 0x98, 0xa5, 0xa1, 0x25, 0xf2, 0x10, 0x85, 0x3c, 0x55, 0x0f,
	0x86, 0xb4, 0xc5, 0xb2, 0xa8, 0x38, 0xfe, 0x87, 0x4e, 0xf6, 0xb4, 0x27, 0xc3, 0xf0, 0x3e, 0xab,
	0xe8, 0xbf, 0xe7, 0x00, 0x00, 0x00, 0xff, 0xff, 0xed, 0xf3, 0x86, 0xb3, 0x7d, 0x02, 0x00, 0x00,
}
