// Code generated by protoc-gen-go. DO NOT EDIT.
// source: google/ads/googleads/v2/enums/listing_custom_attribute_index.proto

package enums

import (
	fmt "fmt"
	math "math"

	proto "github.com/golang/protobuf/proto"
	_ "google.golang.org/genproto/googleapis/api/annotations"
)

// Reference imports to suppress errors if they are not otherwise used.
var _ = proto.Marshal
var _ = fmt.Errorf
var _ = math.Inf

// This is a compile-time assertion to ensure that this generated file
// is compatible with the proto package it is being compiled against.
// A compilation error at this line likely means your copy of the
// proto package needs to be updated.
const _ = proto.ProtoPackageIsVersion3 // please upgrade the proto package

// The index of the listing custom attribute.
type ListingCustomAttributeIndexEnum_ListingCustomAttributeIndex int32

const (
	// Not specified.
	ListingCustomAttributeIndexEnum_UNSPECIFIED ListingCustomAttributeIndexEnum_ListingCustomAttributeIndex = 0
	// Used for return value only. Represents value unknown in this version.
	ListingCustomAttributeIndexEnum_UNKNOWN ListingCustomAttributeIndexEnum_ListingCustomAttributeIndex = 1
	// First listing custom attribute.
	ListingCustomAttributeIndexEnum_INDEX0 ListingCustomAttributeIndexEnum_ListingCustomAttributeIndex = 7
	// Second listing custom attribute.
	ListingCustomAttributeIndexEnum_INDEX1 ListingCustomAttributeIndexEnum_ListingCustomAttributeIndex = 8
	// Third listing custom attribute.
	ListingCustomAttributeIndexEnum_INDEX2 ListingCustomAttributeIndexEnum_ListingCustomAttributeIndex = 9
	// Fourth listing custom attribute.
	ListingCustomAttributeIndexEnum_INDEX3 ListingCustomAttributeIndexEnum_ListingCustomAttributeIndex = 10
	// Fifth listing custom attribute.
	ListingCustomAttributeIndexEnum_INDEX4 ListingCustomAttributeIndexEnum_ListingCustomAttributeIndex = 11
)

var ListingCustomAttributeIndexEnum_ListingCustomAttributeIndex_name = map[int32]string{
	0:  "UNSPECIFIED",
	1:  "UNKNOWN",
	7:  "INDEX0",
	8:  "INDEX1",
	9:  "INDEX2",
	10: "INDEX3",
	11: "INDEX4",
}

var ListingCustomAttributeIndexEnum_ListingCustomAttributeIndex_value = map[string]int32{
	"UNSPECIFIED": 0,
	"UNKNOWN":     1,
	"INDEX0":      7,
	"INDEX1":      8,
	"INDEX2":      9,
	"INDEX3":      10,
	"INDEX4":      11,
}

func (x ListingCustomAttributeIndexEnum_ListingCustomAttributeIndex) String() string {
	return proto.EnumName(ListingCustomAttributeIndexEnum_ListingCustomAttributeIndex_name, int32(x))
}

func (ListingCustomAttributeIndexEnum_ListingCustomAttributeIndex) EnumDescriptor() ([]byte, []int) {
	return fileDescriptor_15903c2a443a0f0b, []int{0, 0}
}

// Container for enum describing the index of the listing custom attribute.
type ListingCustomAttributeIndexEnum struct {
	XXX_NoUnkeyedLiteral struct{} `json:"-"`
	XXX_unrecognized     []byte   `json:"-"`
	XXX_sizecache        int32    `json:"-"`
}

func (m *ListingCustomAttributeIndexEnum) Reset()         { *m = ListingCustomAttributeIndexEnum{} }
func (m *ListingCustomAttributeIndexEnum) String() string { return proto.CompactTextString(m) }
func (*ListingCustomAttributeIndexEnum) ProtoMessage()    {}
func (*ListingCustomAttributeIndexEnum) Descriptor() ([]byte, []int) {
	return fileDescriptor_15903c2a443a0f0b, []int{0}
}

func (m *ListingCustomAttributeIndexEnum) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_ListingCustomAttributeIndexEnum.Unmarshal(m, b)
}
func (m *ListingCustomAttributeIndexEnum) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_ListingCustomAttributeIndexEnum.Marshal(b, m, deterministic)
}
func (m *ListingCustomAttributeIndexEnum) XXX_Merge(src proto.Message) {
	xxx_messageInfo_ListingCustomAttributeIndexEnum.Merge(m, src)
}
func (m *ListingCustomAttributeIndexEnum) XXX_Size() int {
	return xxx_messageInfo_ListingCustomAttributeIndexEnum.Size(m)
}
func (m *ListingCustomAttributeIndexEnum) XXX_DiscardUnknown() {
	xxx_messageInfo_ListingCustomAttributeIndexEnum.DiscardUnknown(m)
}

var xxx_messageInfo_ListingCustomAttributeIndexEnum proto.InternalMessageInfo

func init() {
	proto.RegisterEnum("google.ads.googleads.v2.enums.ListingCustomAttributeIndexEnum_ListingCustomAttributeIndex", ListingCustomAttributeIndexEnum_ListingCustomAttributeIndex_name, ListingCustomAttributeIndexEnum_ListingCustomAttributeIndex_value)
	proto.RegisterType((*ListingCustomAttributeIndexEnum)(nil), "google.ads.googleads.v2.enums.ListingCustomAttributeIndexEnum")
}

func init() {
	proto.RegisterFile("google/ads/googleads/v2/enums/listing_custom_attribute_index.proto", fileDescriptor_15903c2a443a0f0b)
}

var fileDescriptor_15903c2a443a0f0b = []byte{
	// 328 bytes of a gzipped FileDescriptorProto
	0x1f, 0x8b, 0x08, 0x00, 0x00, 0x00, 0x00, 0x00, 0x02, 0xff, 0x7c, 0x91, 0xb1, 0x4e, 0xf3, 0x30,
	0x14, 0x85, 0xff, 0xf4, 0x97, 0x5a, 0x70, 0x07, 0xac, 0x8c, 0x40, 0x05, 0xed, 0x03, 0x38, 0x90,
	0x32, 0x99, 0x29, 0x6d, 0x43, 0x15, 0x81, 0x42, 0x25, 0xd4, 0x82, 0x50, 0xa4, 0xca, 0xad, 0x23,
	0xcb, 0x52, 0x63, 0x57, 0xb5, 0x53, 0x78, 0x16, 0x46, 0x46, 0x1e, 0x85, 0x47, 0x61, 0x67, 0x47,
	0xb1, 0x89, 0x37, 0xb2, 0x44, 0x9f, 0x72, 0xef, 0x3d, 0xe7, 0xde, 0x63, 0x30, 0x62, 0x52, 0xb2,
	0x4d, 0x1e, 0x10, 0xaa, 0x02, 0x8b, 0x15, 0xed, 0xc3, 0x20, 0x17, 0x65, 0xa1, 0x82, 0x0d, 0x57,
	0x9a, 0x0b, 0xb6, 0x5c, 0x97, 0x4a, 0xcb, 0x62, 0x49, 0xb4, 0xde, 0xf1, 0x55, 0xa9, 0xf3, 0x25,
	0x17, 0x34, 0x7f, 0x45, 0xdb, 0x9d, 0xd4, 0xd2, 0xef, 0xd9, 0x41, 0x44, 0xa8, 0x42, 0x4e, 0x03,
	0xed, 0x43, 0x64, 0x34, 0x8e, 0x4f, 0x6b, 0x8b, 0x2d, 0x0f, 0x88, 0x10, 0x52, 0x13, 0xcd, 0xa5,
	0x50, 0x76, 0x78, 0xf0, 0xe6, 0x81, 0xb3, 0x3b, 0xeb, 0x32, 0x36, 0x26, 0x51, 0xed, 0x91, 0x54,
	0x16, 0xb1, 0x28, 0x8b, 0xc1, 0x0b, 0x38, 0x69, 0x68, 0xf1, 0x8f, 0x40, 0x77, 0x9e, 0x3e, 0xcc,
	0xe2, 0x71, 0x72, 0x93, 0xc4, 0x13, 0xf8, 0xcf, 0xef, 0x82, 0xce, 0x3c, 0xbd, 0x4d, 0xef, 0x1f,
	0x53, 0xe8, 0xf9, 0x00, 0xb4, 0x93, 0x74, 0x12, 0x3f, 0x5d, 0xc0, 0x8e, 0xe3, 0x4b, 0x78, 0xe0,
	0x38, 0x84, 0x87, 0x8e, 0x87, 0x10, 0x38, 0xbe, 0x82, 0xdd, 0xd1, 0xb7, 0x07, 0xfa, 0x6b, 0x59,
	0xa0, 0xc6, 0x03, 0x47, 0xe7, 0x0d, 0xcb, 0xcd, 0xaa, 0x23, 0x67, 0xde, 0xf3, 0x6f, 0xce, 0x88,
	0xc9, 0x0d, 0x11, 0x0c, 0xc9, 0x1d, 0x0b, 0x58, 0x2e, 0x4c, 0x04, 0x75, 0xee, 0x5b, 0xae, 0xfe,
	0x78, 0x86, 0x6b, 0xf3, 0x7d, 0x6f, 0xfd, 0x9f, 0x46, 0xd1, 0x47, 0xab, 0x37, 0xb5, 0x52, 0x11,
	0x55, 0xc8, 0x62, 0x45, 0x8b, 0x10, 0x55, 0x59, 0xa9, 0xcf, 0xba, 0x9e, 0x45, 0x54, 0x65, 0xae,
	0x9e, 0x2d, 0xc2, 0xcc, 0xd4, 0xbf, 0x5a, 0x7d, 0xfb, 0x13, 0xe3, 0x88, 0x2a, 0x8c, 0x5d, 0x07,
	0xc6, 0x8b, 0x10, 0x63, 0xd3, 0xb3, 0x6a, 0x9b, 0xc5, 0x86, 0x3f, 0x01, 0x00, 0x00, 0xff, 0xff,
	0x60, 0xec, 0x17, 0xb1, 0x1e, 0x02, 0x00, 0x00,
}
