// Code generated by protoc-gen-go. DO NOT EDIT.
// source: google/ads/googleads/v1/enums/custom_placeholder_field.proto

package enums

import (
	fmt "fmt"
	math "math"

	proto "github.com/golang/protobuf/proto"
	_ "google.golang.org/genproto/googleapis/api/annotations"
)

// Reference imports to suppress errors if they are not otherwise used.
var _ = proto.Marshal
var _ = fmt.Errorf
var _ = math.Inf

// This is a compile-time assertion to ensure that this generated file
// is compatible with the proto package it is being compiled against.
// A compilation error at this line likely means your copy of the
// proto package needs to be updated.
const _ = proto.ProtoPackageIsVersion3 // please upgrade the proto package

// Possible values for Custom placeholder fields.
type CustomPlaceholderFieldEnum_CustomPlaceholderField int32

const (
	// Not specified.
	CustomPlaceholderFieldEnum_UNSPECIFIED CustomPlaceholderFieldEnum_CustomPlaceholderField = 0
	// Used for return value only. Represents value unknown in this version.
	CustomPlaceholderFieldEnum_UNKNOWN CustomPlaceholderFieldEnum_CustomPlaceholderField = 1
	// Data Type: STRING. Required. Combination ID and ID2 must be unique per
	// offer.
	CustomPlaceholderFieldEnum_ID CustomPlaceholderFieldEnum_CustomPlaceholderField = 2
	// Data Type: STRING. Combination ID and ID2 must be unique per offer.
	CustomPlaceholderFieldEnum_ID2 CustomPlaceholderFieldEnum_CustomPlaceholderField = 3
	// Data Type: STRING. Required. Main headline with product name to be shown
	// in dynamic ad.
	CustomPlaceholderFieldEnum_ITEM_TITLE CustomPlaceholderFieldEnum_CustomPlaceholderField = 4
	// Data Type: STRING. Optional text to be shown in the image ad.
	CustomPlaceholderFieldEnum_ITEM_SUBTITLE CustomPlaceholderFieldEnum_CustomPlaceholderField = 5
	// Data Type: STRING. Optional description of the product to be shown in the
	// ad.
	CustomPlaceholderFieldEnum_ITEM_DESCRIPTION CustomPlaceholderFieldEnum_CustomPlaceholderField = 6
	// Data Type: STRING. Full address of your offer or service, including
	// postal code. This will be used to identify the closest product to the
	// user when there are multiple offers in the feed that are relevant to the
	// user.
	CustomPlaceholderFieldEnum_ITEM_ADDRESS CustomPlaceholderFieldEnum_CustomPlaceholderField = 7
	// Data Type: STRING. Price to be shown in the ad.
	// Example: "100.00 USD"
	CustomPlaceholderFieldEnum_PRICE CustomPlaceholderFieldEnum_CustomPlaceholderField = 8
	// Data Type: STRING. Formatted price to be shown in the ad.
	// Example: "Starting at $100.00 USD", "$80 - $100"
	CustomPlaceholderFieldEnum_FORMATTED_PRICE CustomPlaceholderFieldEnum_CustomPlaceholderField = 9
	// Data Type: STRING. Sale price to be shown in the ad.
	// Example: "80.00 USD"
	CustomPlaceholderFieldEnum_SALE_PRICE CustomPlaceholderFieldEnum_CustomPlaceholderField = 10
	// Data Type: STRING. Formatted sale price to be shown in the ad.
	// Example: "On sale for $80.00", "$60 - $80"
	CustomPlaceholderFieldEnum_FORMATTED_SALE_PRICE CustomPlaceholderFieldEnum_CustomPlaceholderField = 11
	// Data Type: URL. Image to be displayed in the ad. Highly recommended for
	// image ads.
	CustomPlaceholderFieldEnum_IMAGE_URL CustomPlaceholderFieldEnum_CustomPlaceholderField = 12
	// Data Type: STRING. Used as a recommendation engine signal to serve items
	// in the same category.
	CustomPlaceholderFieldEnum_ITEM_CATEGORY CustomPlaceholderFieldEnum_CustomPlaceholderField = 13
	// Data Type: URL_LIST. Final URLs for the ad when using Upgraded
	// URLs. User will be redirected to these URLs when they click on an ad, or
	// when they click on a specific product for ads that have multiple
	// products.
	CustomPlaceholderFieldEnum_FINAL_URLS CustomPlaceholderFieldEnum_CustomPlaceholderField = 14
	// Data Type: URL_LIST. Final mobile URLs for the ad when using Upgraded
	// URLs.
	CustomPlaceholderFieldEnum_FINAL_MOBILE_URLS CustomPlaceholderFieldEnum_CustomPlaceholderField = 15
	// Data Type: URL. Tracking template for the ad when using Upgraded URLs.
	CustomPlaceholderFieldEnum_TRACKING_URL CustomPlaceholderFieldEnum_CustomPlaceholderField = 16
	// Data Type: STRING_LIST. Keywords used for product retrieval.
	CustomPlaceholderFieldEnum_CONTEXTUAL_KEYWORDS CustomPlaceholderFieldEnum_CustomPlaceholderField = 17
	// Data Type: STRING. Android app link. Must be formatted as:
	// android-app://{package_id}/{scheme}/{host_path}.
	// The components are defined as follows:
	// package_id: app ID as specified in Google Play.
	// scheme: the scheme to pass to the application. Can be HTTP, or a custom
	//   scheme.
	// host_path: identifies the specific content within your application.
	CustomPlaceholderFieldEnum_ANDROID_APP_LINK CustomPlaceholderFieldEnum_CustomPlaceholderField = 18
	// Data Type: STRING_LIST. List of recommended IDs to show together with
	// this item.
	CustomPlaceholderFieldEnum_SIMILAR_IDS CustomPlaceholderFieldEnum_CustomPlaceholderField = 19
	// Data Type: STRING. iOS app link.
	CustomPlaceholderFieldEnum_IOS_APP_LINK CustomPlaceholderFieldEnum_CustomPlaceholderField = 20
	// Data Type: INT64. iOS app store ID.
	CustomPlaceholderFieldEnum_IOS_APP_STORE_ID CustomPlaceholderFieldEnum_CustomPlaceholderField = 21
)

var CustomPlaceholderFieldEnum_CustomPlaceholderField_name = map[int32]string{
	0:  "UNSPECIFIED",
	1:  "UNKNOWN",
	2:  "ID",
	3:  "ID2",
	4:  "ITEM_TITLE",
	5:  "ITEM_SUBTITLE",
	6:  "ITEM_DESCRIPTION",
	7:  "ITEM_ADDRESS",
	8:  "PRICE",
	9:  "FORMATTED_PRICE",
	10: "SALE_PRICE",
	11: "FORMATTED_SALE_PRICE",
	12: "IMAGE_URL",
	13: "ITEM_CATEGORY",
	14: "FINAL_URLS",
	15: "FINAL_MOBILE_URLS",
	16: "TRACKING_URL",
	17: "CONTEXTUAL_KEYWORDS",
	18: "ANDROID_APP_LINK",
	19: "SIMILAR_IDS",
	20: "IOS_APP_LINK",
	21: "IOS_APP_STORE_ID",
}

var CustomPlaceholderFieldEnum_CustomPlaceholderField_value = map[string]int32{
	"UNSPECIFIED":          0,
	"UNKNOWN":              1,
	"ID":                   2,
	"ID2":                  3,
	"ITEM_TITLE":           4,
	"ITEM_SUBTITLE":        5,
	"ITEM_DESCRIPTION":     6,
	"ITEM_ADDRESS":         7,
	"PRICE":                8,
	"FORMATTED_PRICE":      9,
	"SALE_PRICE":           10,
	"FORMATTED_SALE_PRICE": 11,
	"IMAGE_URL":            12,
	"ITEM_CATEGORY":        13,
	"FINAL_URLS":           14,
	"FINAL_MOBILE_URLS":    15,
	"TRACKING_URL":         16,
	"CONTEXTUAL_KEYWORDS":  17,
	"ANDROID_APP_LINK":     18,
	"SIMILAR_IDS":          19,
	"IOS_APP_LINK":         20,
	"IOS_APP_STORE_ID":     21,
}

func (x CustomPlaceholderFieldEnum_CustomPlaceholderField) String() string {
	return proto.EnumName(CustomPlaceholderFieldEnum_CustomPlaceholderField_name, int32(x))
}

func (CustomPlaceholderFieldEnum_CustomPlaceholderField) EnumDescriptor() ([]byte, []int) {
	return fileDescriptor_03e8133214061585, []int{0, 0}
}

// Values for Custom placeholder fields.
// For more information about dynamic remarketing feeds, see
// https://support.google.com/google-ads/answer/6053288.
type CustomPlaceholderFieldEnum struct {
	XXX_NoUnkeyedLiteral struct{} `json:"-"`
	XXX_unrecognized     []byte   `json:"-"`
	XXX_sizecache        int32    `json:"-"`
}

func (m *CustomPlaceholderFieldEnum) Reset()         { *m = CustomPlaceholderFieldEnum{} }
func (m *CustomPlaceholderFieldEnum) String() string { return proto.CompactTextString(m) }
func (*CustomPlaceholderFieldEnum) ProtoMessage()    {}
func (*CustomPlaceholderFieldEnum) Descriptor() ([]byte, []int) {
	return fileDescriptor_03e8133214061585, []int{0}
}

func (m *CustomPlaceholderFieldEnum) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_CustomPlaceholderFieldEnum.Unmarshal(m, b)
}
func (m *CustomPlaceholderFieldEnum) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_CustomPlaceholderFieldEnum.Marshal(b, m, deterministic)
}
func (m *CustomPlaceholderFieldEnum) XXX_Merge(src proto.Message) {
	xxx_messageInfo_CustomPlaceholderFieldEnum.Merge(m, src)
}
func (m *CustomPlaceholderFieldEnum) XXX_Size() int {
	return xxx_messageInfo_CustomPlaceholderFieldEnum.Size(m)
}
func (m *CustomPlaceholderFieldEnum) XXX_DiscardUnknown() {
	xxx_messageInfo_CustomPlaceholderFieldEnum.DiscardUnknown(m)
}

var xxx_messageInfo_CustomPlaceholderFieldEnum proto.InternalMessageInfo

func init() {
	proto.RegisterEnum("google.ads.googleads.v1.enums.CustomPlaceholderFieldEnum_CustomPlaceholderField", CustomPlaceholderFieldEnum_CustomPlaceholderField_name, CustomPlaceholderFieldEnum_CustomPlaceholderField_value)
	proto.RegisterType((*CustomPlaceholderFieldEnum)(nil), "google.ads.googleads.v1.enums.CustomPlaceholderFieldEnum")
}

func init() {
	proto.RegisterFile("google/ads/googleads/v1/enums/custom_placeholder_field.proto", fileDescriptor_03e8133214061585)
}

var fileDescriptor_03e8133214061585 = []byte{
	// 524 bytes of a gzipped FileDescriptorProto
	0x1f, 0x8b, 0x08, 0x00, 0x00, 0x00, 0x00, 0x00, 0x02, 0xff, 0x7c, 0x52, 0xdd, 0x8e, 0xd2, 0x40,
	0x18, 0x15, 0x70, 0x41, 0x86, 0x65, 0x19, 0x06, 0x56, 0xcd, 0xea, 0x5e, 0xec, 0x3e, 0x40, 0x1b,
	0xf4, 0xae, 0x7a, 0x33, 0x74, 0x06, 0x32, 0xa1, 0xb4, 0x4d, 0x67, 0x60, 0x5d, 0x43, 0xd2, 0x54,
	0x5a, 0x2b, 0x09, 0x74, 0x08, 0x85, 0x7d, 0x1d, 0x13, 0x2f, 0x7d, 0x08, 0x1f, 0xc0, 0x47, 0xf1,
	0xca, 0x47, 0x30, 0x33, 0xe5, 0xc7, 0x8b, 0xd5, 0x9b, 0xe6, 0xfb, 0xce, 0x77, 0xce, 0xe9, 0x37,
	0x33, 0x07, 0xbc, 0x4f, 0xa5, 0x4c, 0x97, 0x89, 0x19, 0xc5, 0xb9, 0x59, 0x94, 0xaa, 0x7a, 0xe8,
	0x99, 0x49, 0xb6, 0x5b, 0xe5, 0xe6, 0x7c, 0x97, 0x6f, 0xe5, 0x2a, 0x5c, 0x2f, 0xa3, 0x79, 0xf2,
	0x45, 0x2e, 0xe3, 0x64, 0x13, 0x7e, 0x5e, 0x24, 0xcb, 0xd8, 0x58, 0x6f, 0xe4, 0x56, 0xa2, 0xeb,
	0x42, 0x62, 0x44, 0x71, 0x6e, 0x1c, 0xd5, 0xc6, 0x43, 0xcf, 0xd0, 0xea, 0xab, 0xd7, 0x07, 0xf3,
	0xf5, 0xc2, 0x8c, 0xb2, 0x4c, 0x6e, 0xa3, 0xed, 0x42, 0x66, 0x79, 0x21, 0xbe, 0xfd, 0x51, 0x01,
	0x57, 0xb6, 0xf6, 0xf7, 0x4f, 0xf6, 0x03, 0xe5, 0x4e, 0xb3, 0xdd, 0xea, 0xf6, 0x6b, 0x05, 0x3c,
	0x7f, 0x7c, 0x8c, 0x5a, 0xa0, 0x31, 0x71, 0xb9, 0x4f, 0x6d, 0x36, 0x60, 0x94, 0xc0, 0x27, 0xa8,
	0x01, 0x6a, 0x13, 0x77, 0xe4, 0x7a, 0x77, 0x2e, 0x2c, 0xa1, 0x2a, 0x28, 0x33, 0x02, 0xcb, 0xa8,
	0x06, 0x2a, 0x8c, 0xbc, 0x81, 0x15, 0x74, 0x01, 0x00, 0x13, 0x74, 0x1c, 0x0a, 0x26, 0x1c, 0x0a,
	0x9f, 0xa2, 0x36, 0x68, 0xea, 0x9e, 0x4f, 0xfa, 0x05, 0x74, 0x86, 0xba, 0x00, 0x6a, 0x88, 0x50,
	0x6e, 0x07, 0xcc, 0x17, 0xcc, 0x73, 0x61, 0x15, 0x41, 0x70, 0xae, 0x51, 0x4c, 0x48, 0x40, 0x39,
	0x87, 0x35, 0x54, 0x07, 0x67, 0x7e, 0xc0, 0x6c, 0x0a, 0x9f, 0xa1, 0x0e, 0x68, 0x0d, 0xbc, 0x60,
	0x8c, 0x85, 0xa0, 0x24, 0x2c, 0xc0, 0xba, 0xfa, 0x15, 0xc7, 0x0e, 0xdd, 0xf7, 0x00, 0xbd, 0x04,
	0xdd, 0x13, 0xe9, 0xaf, 0x49, 0x03, 0x35, 0x41, 0x9d, 0x8d, 0xf1, 0x90, 0x86, 0x93, 0xc0, 0x81,
	0xe7, 0xc7, 0x9d, 0x6c, 0x2c, 0xe8, 0xd0, 0x0b, 0xee, 0x61, 0x53, 0x79, 0x0d, 0x98, 0x8b, 0x1d,
	0xc5, 0xe0, 0xf0, 0x02, 0x5d, 0x82, 0x76, 0xd1, 0x8f, 0xbd, 0x3e, 0x73, 0x68, 0x01, 0xb7, 0xd4,
	0x92, 0x22, 0xc0, 0xf6, 0x88, 0xb9, 0x43, 0xed, 0x05, 0xd1, 0x0b, 0xd0, 0xb1, 0x3d, 0x57, 0xd0,
	0x0f, 0x62, 0x82, 0x9d, 0x70, 0x44, 0xef, 0xef, 0xbc, 0x80, 0x70, 0xd8, 0x56, 0xa7, 0xc4, 0x2e,
	0x09, 0x3c, 0x46, 0x42, 0xec, 0xfb, 0xa1, 0xc3, 0xdc, 0x11, 0x44, 0xea, 0x36, 0x39, 0x1b, 0x33,
	0x07, 0x07, 0x21, 0x23, 0x1c, 0x76, 0xf4, 0xb1, 0x3d, 0x7e, 0xa2, 0x74, 0xf5, 0xf5, 0xec, 0x11,
	0x2e, 0xbc, 0x80, 0x86, 0x8c, 0xc0, 0xcb, 0xfe, 0xef, 0x12, 0xb8, 0x99, 0xcb, 0x95, 0xf1, 0xdf,
	0x10, 0xf4, 0x5f, 0x3d, 0xfe, 0x88, 0xbe, 0xca, 0x80, 0x5f, 0xfa, 0xd8, 0xdf, 0xab, 0x53, 0xb9,
	0x8c, 0xb2, 0xd4, 0x90, 0x9b, 0xd4, 0x4c, 0x93, 0x4c, 0x27, 0xe4, 0x10, 0xc8, 0xf5, 0x22, 0xff,
	0x47, 0x3e, 0xdf, 0xe9, 0xef, 0xb7, 0x72, 0x65, 0x88, 0xf1, 0xf7, 0xf2, 0xf5, 0xb0, 0xb0, 0xc2,
	0x71, 0x6e, 0x14, 0xa5, 0xaa, 0xa6, 0x3d, 0x43, 0xe5, 0x29, 0xff, 0x79, 0x98, 0xcf, 0x70, 0x9c,
	0xcf, 0x8e, 0xf3, 0xd9, 0xb4, 0x37, 0xd3, 0xf3, 0x5f, 0xe5, 0x9b, 0x02, 0xb4, 0x2c, 0x1c, 0xe7,
	0x96, 0x75, 0x64, 0x58, 0xd6, 0xb4, 0x67, 0x59, 0x9a, 0xf3, 0xa9, 0xaa, 0x17, 0x7b, 0xfb, 0x27,
	0x00, 0x00, 0xff, 0xff, 0x74, 0x08, 0x91, 0xb6, 0x37, 0x03, 0x00, 0x00,
}
