// Code generated by protoc-gen-go. DO NOT EDIT.
// source: google/ads/googleads/v2/errors/custom_interest_error.proto

package errors

import (
	fmt "fmt"
	math "math"

	proto "github.com/golang/protobuf/proto"
	_ "google.golang.org/genproto/googleapis/api/annotations"
)

// Reference imports to suppress errors if they are not otherwise used.
var _ = proto.Marshal
var _ = fmt.Errorf
var _ = math.Inf

// This is a compile-time assertion to ensure that this generated file
// is compatible with the proto package it is being compiled against.
// A compilation error at this line likely means your copy of the
// proto package needs to be updated.
const _ = proto.ProtoPackageIsVersion3 // please upgrade the proto package

// Enum describing possible custom interest errors.
type CustomInterestErrorEnum_CustomInterestError int32

const (
	// Enum unspecified.
	CustomInterestErrorEnum_UNSPECIFIED CustomInterestErrorEnum_CustomInterestError = 0
	// The received error code is not known in this version.
	CustomInterestErrorEnum_UNKNOWN CustomInterestErrorEnum_CustomInterestError = 1
	// Duplicate custom interest name ignoring case.
	CustomInterestErrorEnum_NAME_ALREADY_USED CustomInterestErrorEnum_CustomInterestError = 2
	// In the remove custom interest member operation, both member ID and
	// pair [type, parameter] are not present.
	CustomInterestErrorEnum_CUSTOM_INTEREST_MEMBER_ID_AND_TYPE_PARAMETER_NOT_PRESENT_IN_REMOVE CustomInterestErrorEnum_CustomInterestError = 3
	// The pair of [type, parameter] does not exist.
	CustomInterestErrorEnum_TYPE_AND_PARAMETER_NOT_FOUND CustomInterestErrorEnum_CustomInterestError = 4
	// The pair of [type, parameter] already exists.
	CustomInterestErrorEnum_TYPE_AND_PARAMETER_ALREADY_EXISTED CustomInterestErrorEnum_CustomInterestError = 5
	// Unsupported custom interest member type.
	CustomInterestErrorEnum_INVALID_CUSTOM_INTEREST_MEMBER_TYPE CustomInterestErrorEnum_CustomInterestError = 6
	// Cannot remove a custom interest while it's still being targeted.
	CustomInterestErrorEnum_CANNOT_REMOVE_WHILE_IN_USE CustomInterestErrorEnum_CustomInterestError = 7
	// Cannot mutate custom interest type.
	CustomInterestErrorEnum_CANNOT_CHANGE_TYPE CustomInterestErrorEnum_CustomInterestError = 8
)

var CustomInterestErrorEnum_CustomInterestError_name = map[int32]string{
	0: "UNSPECIFIED",
	1: "UNKNOWN",
	2: "NAME_ALREADY_USED",
	3: "CUSTOM_INTEREST_MEMBER_ID_AND_TYPE_PARAMETER_NOT_PRESENT_IN_REMOVE",
	4: "TYPE_AND_PARAMETER_NOT_FOUND",
	5: "TYPE_AND_PARAMETER_ALREADY_EXISTED",
	6: "INVALID_CUSTOM_INTEREST_MEMBER_TYPE",
	7: "CANNOT_REMOVE_WHILE_IN_USE",
	8: "CANNOT_CHANGE_TYPE",
}

var CustomInterestErrorEnum_CustomInterestError_value = map[string]int32{
	"UNSPECIFIED":       0,
	"UNKNOWN":           1,
	"NAME_ALREADY_USED": 2,
	"CUSTOM_INTEREST_MEMBER_ID_AND_TYPE_PARAMETER_NOT_PRESENT_IN_REMOVE": 3,
	"TYPE_AND_PARAMETER_NOT_FOUND":                                       4,
	"TYPE_AND_PARAMETER_ALREADY_EXISTED":                                 5,
	"INVALID_CUSTOM_INTEREST_MEMBER_TYPE":                                6,
	"CANNOT_REMOVE_WHILE_IN_USE":                                         7,
	"CANNOT_CHANGE_TYPE":                                                 8,
}

func (x CustomInterestErrorEnum_CustomInterestError) String() string {
	return proto.EnumName(CustomInterestErrorEnum_CustomInterestError_name, int32(x))
}

func (CustomInterestErrorEnum_CustomInterestError) EnumDescriptor() ([]byte, []int) {
	return fileDescriptor_08f77b2aa98e1ebb, []int{0, 0}
}

// Container for enum describing possible custom interest errors.
type CustomInterestErrorEnum struct {
	XXX_NoUnkeyedLiteral struct{} `json:"-"`
	XXX_unrecognized     []byte   `json:"-"`
	XXX_sizecache        int32    `json:"-"`
}

func (m *CustomInterestErrorEnum) Reset()         { *m = CustomInterestErrorEnum{} }
func (m *CustomInterestErrorEnum) String() string { return proto.CompactTextString(m) }
func (*CustomInterestErrorEnum) ProtoMessage()    {}
func (*CustomInterestErrorEnum) Descriptor() ([]byte, []int) {
	return fileDescriptor_08f77b2aa98e1ebb, []int{0}
}

func (m *CustomInterestErrorEnum) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_CustomInterestErrorEnum.Unmarshal(m, b)
}
func (m *CustomInterestErrorEnum) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_CustomInterestErrorEnum.Marshal(b, m, deterministic)
}
func (m *CustomInterestErrorEnum) XXX_Merge(src proto.Message) {
	xxx_messageInfo_CustomInterestErrorEnum.Merge(m, src)
}
func (m *CustomInterestErrorEnum) XXX_Size() int {
	return xxx_messageInfo_CustomInterestErrorEnum.Size(m)
}
func (m *CustomInterestErrorEnum) XXX_DiscardUnknown() {
	xxx_messageInfo_CustomInterestErrorEnum.DiscardUnknown(m)
}

var xxx_messageInfo_CustomInterestErrorEnum proto.InternalMessageInfo

func init() {
	proto.RegisterEnum("google.ads.googleads.v2.errors.CustomInterestErrorEnum_CustomInterestError", CustomInterestErrorEnum_CustomInterestError_name, CustomInterestErrorEnum_CustomInterestError_value)
	proto.RegisterType((*CustomInterestErrorEnum)(nil), "google.ads.googleads.v2.errors.CustomInterestErrorEnum")
}

func init() {
	proto.RegisterFile("google/ads/googleads/v2/errors/custom_interest_error.proto", fileDescriptor_08f77b2aa98e1ebb)
}

var fileDescriptor_08f77b2aa98e1ebb = []byte{
	// 448 bytes of a gzipped FileDescriptorProto
	0x1f, 0x8b, 0x08, 0x00, 0x00, 0x00, 0x00, 0x00, 0x02, 0xff, 0x7c, 0x92, 0xdf, 0x6a, 0xdb, 0x30,
	0x18, 0xc5, 0x17, 0x77, 0x6b, 0x87, 0x7a, 0x31, 0x4f, 0x63, 0x7f, 0x28, 0x25, 0x8c, 0x0c, 0xb6,
	0x3b, 0x1b, 0xbc, 0x3b, 0xed, 0x4a, 0xb1, 0xbe, 0xa4, 0x62, 0xb1, 0x6c, 0xfc, 0xaf, 0xeb, 0x08,
	0x08, 0xaf, 0x36, 0x26, 0xd0, 0x58, 0xc1, 0x72, 0xfb, 0x40, 0xbb, 0xdc, 0x3b, 0xec, 0x05, 0xf6,
	0x06, 0x7b, 0x85, 0xdd, 0xee, 0x05, 0x86, 0xad, 0x24, 0x30, 0x48, 0x7b, 0xe5, 0x83, 0x74, 0x7e,
	0x47, 0x07, 0x7f, 0x1f, 0x22, 0xb5, 0x52, 0xf5, 0x4d, 0xe5, 0x16, 0xa5, 0x76, 0x8d, 0xec, 0xd5,
	0x9d, 0xe7, 0x56, 0x6d, 0xab, 0x5a, 0xed, 0x5e, 0xdf, 0xea, 0x4e, 0xad, 0xe5, 0xaa, 0xe9, 0xaa,
	0xb6, 0xd2, 0x9d, 0x1c, 0x8e, 0x9d, 0x4d, 0xab, 0x3a, 0x85, 0xc7, 0x06, 0x70, 0x8a, 0x52, 0x3b,
	0x7b, 0xd6, 0xb9, 0xf3, 0x1c, 0xc3, 0x9e, 0x9d, 0xef, 0xb2, 0x37, 0x2b, 0xb7, 0x68, 0x1a, 0xd5,
	0x15, 0xdd, 0x4a, 0x35, 0xda, 0xd0, 0x93, 0xdf, 0x16, 0x7a, 0xed, 0x0f, 0xe9, 0x7c, 0x1b, 0x0e,
	0x3d, 0x06, 0xcd, 0xed, 0x7a, 0xf2, 0xd3, 0x42, 0x2f, 0x0e, 0xdc, 0xe1, 0x67, 0xe8, 0x34, 0x13,
	0x49, 0x04, 0x3e, 0x9f, 0x71, 0x60, 0xf6, 0x23, 0x7c, 0x8a, 0x4e, 0x32, 0xf1, 0x59, 0x84, 0x97,
	0xc2, 0x1e, 0xe1, 0x97, 0xe8, 0xb9, 0xa0, 0x01, 0x48, 0xba, 0x88, 0x81, 0xb2, 0x2b, 0x99, 0x25,
	0xc0, 0x6c, 0x0b, 0xcf, 0xd0, 0xd4, 0xcf, 0x92, 0x34, 0x0c, 0x24, 0x17, 0x29, 0xc4, 0x90, 0xa4,
	0x32, 0x80, 0x60, 0x0a, 0xb1, 0xe4, 0x4c, 0x52, 0xc1, 0x64, 0x7a, 0x15, 0x81, 0x8c, 0x68, 0x4c,
	0x03, 0x48, 0x21, 0x96, 0x22, 0x4c, 0x65, 0x14, 0x43, 0x02, 0x22, 0x95, 0x5c, 0xc8, 0x18, 0x82,
	0x30, 0x07, 0xfb, 0x08, 0xbf, 0x45, 0xe7, 0x83, 0xb3, 0x47, 0xfe, 0x77, 0xcf, 0xc2, 0x4c, 0x30,
	0xfb, 0x31, 0x7e, 0x8f, 0x26, 0x07, 0x1c, 0xbb, 0x3a, 0xf0, 0x85, 0x27, 0x29, 0x30, 0xfb, 0x09,
	0xfe, 0x80, 0xde, 0x71, 0x91, 0xd3, 0x05, 0x67, 0xf2, 0x9e, 0x66, 0x7d, 0x8c, 0x7d, 0x8c, 0xc7,
	0xe8, 0xcc, 0xa7, 0xa2, 0x7f, 0xc2, 0xb4, 0x90, 0x97, 0x17, 0x7c, 0x01, 0x7d, 0xab, 0x2c, 0x01,
	0xfb, 0x04, 0xbf, 0x42, 0x78, 0x7b, 0xef, 0x5f, 0x50, 0x31, 0x07, 0xc3, 0x3d, 0x9d, 0xfe, 0x1d,
	0xa1, 0xc9, 0xb5, 0x5a, 0x3b, 0x0f, 0x0f, 0x68, 0xfa, 0xe6, 0xc0, 0x3f, 0x8e, 0xfa, 0xe1, 0x44,
	0xa3, 0xaf, 0x6c, 0xcb, 0xd6, 0xea, 0xa6, 0x68, 0x6a, 0x47, 0xb5, 0xb5, 0x5b, 0x57, 0xcd, 0x30,
	0xba, 0xdd, 0xa2, 0x6c, 0x56, 0xfa, 0xbe, 0xbd, 0xf9, 0x64, 0x3e, 0xdf, 0xad, 0xa3, 0x39, 0xa5,
	0x3f, 0xac, 0xf1, 0xdc, 0x84, 0xd1, 0x52, 0x3b, 0x46, 0xf6, 0x2a, 0xf7, 0x9c, 0xe1, 0x49, 0xfd,
	0x6b, 0x67, 0x58, 0xd2, 0x52, 0x2f, 0xf7, 0x86, 0x65, 0xee, 0x2d, 0x8d, 0xe1, 0x8f, 0x35, 0x31,
	0xa7, 0x84, 0xd0, 0x52, 0x13, 0xb2, 0xb7, 0x10, 0x92, 0x7b, 0x84, 0x18, 0xd3, 0xb7, 0xe3, 0xa1,
	0xdd, 0xc7, 0x7f, 0x01, 0x00, 0x00, 0xff, 0xff, 0x8c, 0x91, 0x24, 0x0d, 0xd4, 0x02, 0x00, 0x00,
}
