// Code generated by protoc-gen-go. DO NOT EDIT.
// source: google/ads/googleads/v1/enums/geo_targeting_type.proto

package enums

import (
	fmt "fmt"
	math "math"

	proto "github.com/golang/protobuf/proto"
	_ "google.golang.org/genproto/googleapis/api/annotations"
)

// Reference imports to suppress errors if they are not otherwise used.
var _ = proto.Marshal
var _ = fmt.Errorf
var _ = math.Inf

// This is a compile-time assertion to ensure that this generated file
// is compatible with the proto package it is being compiled against.
// A compilation error at this line likely means your copy of the
// proto package needs to be updated.
const _ = proto.ProtoPackageIsVersion3 // please upgrade the proto package

// The possible geo targeting types.
type GeoTargetingTypeEnum_GeoTargetingType int32

const (
	// Not specified.
	GeoTargetingTypeEnum_UNSPECIFIED GeoTargetingTypeEnum_GeoTargetingType = 0
	// The value is unknown in this version.
	GeoTargetingTypeEnum_UNKNOWN GeoTargetingTypeEnum_GeoTargetingType = 1
	// Location the user is interested in while making the query.
	GeoTargetingTypeEnum_AREA_OF_INTEREST GeoTargetingTypeEnum_GeoTargetingType = 2
	// Location of the user issuing the query.
	GeoTargetingTypeEnum_LOCATION_OF_PRESENCE GeoTargetingTypeEnum_GeoTargetingType = 3
)

var GeoTargetingTypeEnum_GeoTargetingType_name = map[int32]string{
	0: "UNSPECIFIED",
	1: "UNKNOWN",
	2: "AREA_OF_INTEREST",
	3: "LOCATION_OF_PRESENCE",
}

var GeoTargetingTypeEnum_GeoTargetingType_value = map[string]int32{
	"UNSPECIFIED":          0,
	"UNKNOWN":              1,
	"AREA_OF_INTEREST":     2,
	"LOCATION_OF_PRESENCE": 3,
}

func (x GeoTargetingTypeEnum_GeoTargetingType) String() string {
	return proto.EnumName(GeoTargetingTypeEnum_GeoTargetingType_name, int32(x))
}

func (GeoTargetingTypeEnum_GeoTargetingType) EnumDescriptor() ([]byte, []int) {
	return fileDescriptor_9acbd086c416c55e, []int{0, 0}
}

// Container for enum describing possible geo targeting types.
type GeoTargetingTypeEnum struct {
	XXX_NoUnkeyedLiteral struct{} `json:"-"`
	XXX_unrecognized     []byte   `json:"-"`
	XXX_sizecache        int32    `json:"-"`
}

func (m *GeoTargetingTypeEnum) Reset()         { *m = GeoTargetingTypeEnum{} }
func (m *GeoTargetingTypeEnum) String() string { return proto.CompactTextString(m) }
func (*GeoTargetingTypeEnum) ProtoMessage()    {}
func (*GeoTargetingTypeEnum) Descriptor() ([]byte, []int) {
	return fileDescriptor_9acbd086c416c55e, []int{0}
}

func (m *GeoTargetingTypeEnum) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_GeoTargetingTypeEnum.Unmarshal(m, b)
}
func (m *GeoTargetingTypeEnum) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_GeoTargetingTypeEnum.Marshal(b, m, deterministic)
}
func (m *GeoTargetingTypeEnum) XXX_Merge(src proto.Message) {
	xxx_messageInfo_GeoTargetingTypeEnum.Merge(m, src)
}
func (m *GeoTargetingTypeEnum) XXX_Size() int {
	return xxx_messageInfo_GeoTargetingTypeEnum.Size(m)
}
func (m *GeoTargetingTypeEnum) XXX_DiscardUnknown() {
	xxx_messageInfo_GeoTargetingTypeEnum.DiscardUnknown(m)
}

var xxx_messageInfo_GeoTargetingTypeEnum proto.InternalMessageInfo

func init() {
	proto.RegisterEnum("google.ads.googleads.v1.enums.GeoTargetingTypeEnum_GeoTargetingType", GeoTargetingTypeEnum_GeoTargetingType_name, GeoTargetingTypeEnum_GeoTargetingType_value)
	proto.RegisterType((*GeoTargetingTypeEnum)(nil), "google.ads.googleads.v1.enums.GeoTargetingTypeEnum")
}

func init() {
	proto.RegisterFile("google/ads/googleads/v1/enums/geo_targeting_type.proto", fileDescriptor_9acbd086c416c55e)
}

var fileDescriptor_9acbd086c416c55e = []byte{
	// 323 bytes of a gzipped FileDescriptorProto
	0x1f, 0x8b, 0x08, 0x00, 0x00, 0x00, 0x00, 0x00, 0x02, 0xff, 0x7c, 0x50, 0xdf, 0x4a, 0xf3, 0x30,
	0x1c, 0xfd, 0xd6, 0xc1, 0x27, 0x64, 0x17, 0x96, 0x32, 0x41, 0xc4, 0x5d, 0x6c, 0x0f, 0x90, 0x52,
	0x04, 0x2f, 0xe2, 0x55, 0x36, 0xb3, 0x51, 0x94, 0xb4, 0x6c, 0xdd, 0x04, 0x29, 0xd4, 0x6a, 0x43,
	0x28, 0x6c, 0x49, 0x59, 0xb2, 0xe1, 0x5e, 0xc7, 0x4b, 0x1f, 0xc5, 0x47, 0xd9, 0x53, 0x48, 0x13,
	0xdb, 0x8b, 0x81, 0xde, 0x84, 0xc3, 0xef, 0xfc, 0xe1, 0xe4, 0x80, 0x5b, 0x2e, 0x25, 0x5f, 0x33,
	0x3f, 0x2f, 0x94, 0x6f, 0x61, 0x8d, 0xf6, 0x81, 0xcf, 0xc4, 0x6e, 0xa3, 0x7c, 0xce, 0x64, 0xa6,
	0xf3, 0x2d, 0x67, 0xba, 0x14, 0x3c, 0xd3, 0x87, 0x8a, 0xc1, 0x6a, 0x2b, 0xb5, 0xf4, 0x06, 0x56,
	0x0c, 0xf3, 0x42, 0xc1, 0xd6, 0x07, 0xf7, 0x01, 0x34, 0xbe, 0xab, 0xeb, 0x26, 0xb6, 0x2a, 0xfd,
	0x5c, 0x08, 0xa9, 0x73, 0x5d, 0x4a, 0xa1, 0xac, 0x79, 0xf4, 0x0e, 0xfa, 0x33, 0x26, 0x93, 0x26,
	0x37, 0x39, 0x54, 0x8c, 0x88, 0xdd, 0x66, 0xf4, 0x02, 0xdc, 0xd3, 0xbb, 0x77, 0x0e, 0x7a, 0x4b,
	0xba, 0x88, 0xc9, 0x24, 0x9c, 0x86, 0xe4, 0xde, 0xfd, 0xe7, 0xf5, 0xc0, 0xd9, 0x92, 0x3e, 0xd0,
	0xe8, 0x89, 0xba, 0x1d, 0xaf, 0x0f, 0x5c, 0x3c, 0x27, 0x38, 0x8b, 0xa6, 0x59, 0x48, 0x13, 0x32,
	0x27, 0x8b, 0xc4, 0x75, 0xbc, 0x4b, 0xd0, 0x7f, 0x8c, 0x26, 0x38, 0x09, 0x23, 0x5a, 0x33, 0xf1,
	0x9c, 0x2c, 0x08, 0x9d, 0x10, 0xb7, 0x3b, 0x3e, 0x76, 0xc0, 0xf0, 0x4d, 0x6e, 0xe0, 0x9f, 0xed,
	0xc7, 0x17, 0xa7, 0x2d, 0xe2, 0xba, 0x76, 0xdc, 0x79, 0x1e, 0xff, 0xf8, 0xb8, 0x5c, 0xe7, 0x82,
	0x43, 0xb9, 0xe5, 0x3e, 0x67, 0xc2, 0x7c, 0xaa, 0x59, 0xaf, 0x2a, 0xd5, 0x2f, 0x63, 0xde, 0x99,
	0xf7, 0xc3, 0xe9, 0xce, 0x30, 0xfe, 0x74, 0x06, 0x33, 0x1b, 0x85, 0x0b, 0x05, 0x2d, 0xac, 0xd1,
	0x2a, 0x80, 0xf5, 0x12, 0xea, 0xab, 0xe1, 0x53, 0x5c, 0xa8, 0xb4, 0xe5, 0xd3, 0x55, 0x90, 0x1a,
	0xfe, 0xe8, 0x0c, 0xed, 0x11, 0x21, 0x5c, 0x28, 0x84, 0x5a, 0x05, 0x42, 0xab, 0x00, 0x21, 0xa3,
	0x79, 0xfd, 0x6f, 0x8a, 0xdd, 0x7c, 0x07, 0x00, 0x00, 0xff, 0xff, 0xe3, 0x2c, 0xcb, 0xe2, 0xe4,
	0x01, 0x00, 0x00,
}
