// Code generated by protoc-gen-go. DO NOT EDIT.
// source: google/ads/googleads/v2/enums/ad_customizer_placeholder_field.proto

package enums

import (
	fmt "fmt"
	math "math"

	proto "github.com/golang/protobuf/proto"
	_ "google.golang.org/genproto/googleapis/api/annotations"
)

// Reference imports to suppress errors if they are not otherwise used.
var _ = proto.Marshal
var _ = fmt.Errorf
var _ = math.Inf

// This is a compile-time assertion to ensure that this generated file
// is compatible with the proto package it is being compiled against.
// A compilation error at this line likely means your copy of the
// proto package needs to be updated.
const _ = proto.ProtoPackageIsVersion3 // please upgrade the proto package

// Possible values for Ad Customizers placeholder fields.
type AdCustomizerPlaceholderFieldEnum_AdCustomizerPlaceholderField int32

const (
	// Not specified.
	AdCustomizerPlaceholderFieldEnum_UNSPECIFIED AdCustomizerPlaceholderFieldEnum_AdCustomizerPlaceholderField = 0
	// Used for return value only. Represents value unknown in this version.
	AdCustomizerPlaceholderFieldEnum_UNKNOWN AdCustomizerPlaceholderFieldEnum_AdCustomizerPlaceholderField = 1
	// Data Type: INT64. Integer value to be inserted.
	AdCustomizerPlaceholderFieldEnum_INTEGER AdCustomizerPlaceholderFieldEnum_AdCustomizerPlaceholderField = 2
	// Data Type: STRING. Price value to be inserted.
	AdCustomizerPlaceholderFieldEnum_PRICE AdCustomizerPlaceholderFieldEnum_AdCustomizerPlaceholderField = 3
	// Data Type: DATE_TIME. Date value to be inserted.
	AdCustomizerPlaceholderFieldEnum_DATE AdCustomizerPlaceholderFieldEnum_AdCustomizerPlaceholderField = 4
	// Data Type: STRING. String value to be inserted.
	AdCustomizerPlaceholderFieldEnum_STRING AdCustomizerPlaceholderFieldEnum_AdCustomizerPlaceholderField = 5
)

var AdCustomizerPlaceholderFieldEnum_AdCustomizerPlaceholderField_name = map[int32]string{
	0: "UNSPECIFIED",
	1: "UNKNOWN",
	2: "INTEGER",
	3: "PRICE",
	4: "DATE",
	5: "STRING",
}

var AdCustomizerPlaceholderFieldEnum_AdCustomizerPlaceholderField_value = map[string]int32{
	"UNSPECIFIED": 0,
	"UNKNOWN":     1,
	"INTEGER":     2,
	"PRICE":       3,
	"DATE":        4,
	"STRING":      5,
}

func (x AdCustomizerPlaceholderFieldEnum_AdCustomizerPlaceholderField) String() string {
	return proto.EnumName(AdCustomizerPlaceholderFieldEnum_AdCustomizerPlaceholderField_name, int32(x))
}

func (AdCustomizerPlaceholderFieldEnum_AdCustomizerPlaceholderField) EnumDescriptor() ([]byte, []int) {
	return fileDescriptor_45cbfd41720be733, []int{0, 0}
}

// Values for Ad Customizer placeholder fields.
type AdCustomizerPlaceholderFieldEnum struct {
	XXX_NoUnkeyedLiteral struct{} `json:"-"`
	XXX_unrecognized     []byte   `json:"-"`
	XXX_sizecache        int32    `json:"-"`
}

func (m *AdCustomizerPlaceholderFieldEnum) Reset()         { *m = AdCustomizerPlaceholderFieldEnum{} }
func (m *AdCustomizerPlaceholderFieldEnum) String() string { return proto.CompactTextString(m) }
func (*AdCustomizerPlaceholderFieldEnum) ProtoMessage()    {}
func (*AdCustomizerPlaceholderFieldEnum) Descriptor() ([]byte, []int) {
	return fileDescriptor_45cbfd41720be733, []int{0}
}

func (m *AdCustomizerPlaceholderFieldEnum) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_AdCustomizerPlaceholderFieldEnum.Unmarshal(m, b)
}
func (m *AdCustomizerPlaceholderFieldEnum) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_AdCustomizerPlaceholderFieldEnum.Marshal(b, m, deterministic)
}
func (m *AdCustomizerPlaceholderFieldEnum) XXX_Merge(src proto.Message) {
	xxx_messageInfo_AdCustomizerPlaceholderFieldEnum.Merge(m, src)
}
func (m *AdCustomizerPlaceholderFieldEnum) XXX_Size() int {
	return xxx_messageInfo_AdCustomizerPlaceholderFieldEnum.Size(m)
}
func (m *AdCustomizerPlaceholderFieldEnum) XXX_DiscardUnknown() {
	xxx_messageInfo_AdCustomizerPlaceholderFieldEnum.DiscardUnknown(m)
}

var xxx_messageInfo_AdCustomizerPlaceholderFieldEnum proto.InternalMessageInfo

func init() {
	proto.RegisterEnum("google.ads.googleads.v2.enums.AdCustomizerPlaceholderFieldEnum_AdCustomizerPlaceholderField", AdCustomizerPlaceholderFieldEnum_AdCustomizerPlaceholderField_name, AdCustomizerPlaceholderFieldEnum_AdCustomizerPlaceholderField_value)
	proto.RegisterType((*AdCustomizerPlaceholderFieldEnum)(nil), "google.ads.googleads.v2.enums.AdCustomizerPlaceholderFieldEnum")
}

func init() {
	proto.RegisterFile("google/ads/googleads/v2/enums/ad_customizer_placeholder_field.proto", fileDescriptor_45cbfd41720be733)
}

var fileDescriptor_45cbfd41720be733 = []byte{
	// 337 bytes of a gzipped FileDescriptorProto
	0x1f, 0x8b, 0x08, 0x00, 0x00, 0x00, 0x00, 0x00, 0x02, 0xff, 0x7c, 0x50, 0x4d, 0x4e, 0x83, 0x40,
	0x18, 0x15, 0xfa, 0xa3, 0x4e, 0x17, 0x12, 0x96, 0xa6, 0x4d, 0x6c, 0x0f, 0x30, 0x24, 0xb8, 0x1b,
	0x57, 0x53, 0x3a, 0x25, 0xc4, 0x04, 0x49, 0xff, 0x4c, 0x0c, 0x49, 0x33, 0x76, 0x46, 0xc4, 0xc0,
	0x0c, 0x61, 0x68, 0x17, 0x1e, 0xc2, 0x43, 0xb8, 0xf4, 0x28, 0x1e, 0xc5, 0x03, 0xb8, 0x36, 0x80,
	0xc5, 0x95, 0x6c, 0xc8, 0x63, 0xbe, 0xf7, 0xbd, 0xf7, 0xbd, 0x07, 0x9c, 0x48, 0xca, 0x28, 0xe1,
	0x16, 0x65, 0xca, 0xaa, 0x61, 0x89, 0x0e, 0xb6, 0xc5, 0xc5, 0x3e, 0x55, 0x16, 0x65, 0xdb, 0xdd,
	0x5e, 0x15, 0x32, 0x8d, 0x5f, 0x79, 0xbe, 0xcd, 0x12, 0xba, 0xe3, 0xcf, 0x32, 0x61, 0x3c, 0xdf,
	0x3e, 0xc5, 0x3c, 0x61, 0x30, 0xcb, 0x65, 0x21, 0xcd, 0x51, 0xbd, 0x09, 0x29, 0x53, 0xb0, 0x11,
	0x81, 0x07, 0x1b, 0x56, 0x22, 0x97, 0xc3, 0xa3, 0x47, 0x16, 0x5b, 0x54, 0x08, 0x59, 0xd0, 0x22,
	0x96, 0x42, 0xd5, 0xcb, 0x93, 0x37, 0x0d, 0x5c, 0x61, 0xe6, 0x34, 0x2e, 0xc1, 0x9f, 0xc9, 0xbc,
	0xf4, 0x20, 0x62, 0x9f, 0x4e, 0x5e, 0xc0, 0xb0, 0x8d, 0x63, 0x5e, 0x80, 0xc1, 0xda, 0x5f, 0x06,
	0xc4, 0xf1, 0xe6, 0x1e, 0x99, 0x19, 0x27, 0xe6, 0x00, 0x9c, 0xae, 0xfd, 0x5b, 0xff, 0xee, 0xde,
	0x37, 0xb4, 0xf2, 0xc7, 0xf3, 0x57, 0xc4, 0x25, 0x0b, 0x43, 0x37, 0xcf, 0x41, 0x2f, 0x58, 0x78,
	0x0e, 0x31, 0x3a, 0xe6, 0x19, 0xe8, 0xce, 0xf0, 0x8a, 0x18, 0x5d, 0x13, 0x80, 0xfe, 0x72, 0xb5,
	0xf0, 0x7c, 0xd7, 0xe8, 0x4d, 0xbf, 0x35, 0x30, 0xde, 0xc9, 0x14, 0xb6, 0x86, 0x9a, 0x8e, 0xdb,
	0xee, 0x09, 0xca, 0x64, 0x81, 0xf6, 0x30, 0xfd, 0xd5, 0x88, 0x64, 0x42, 0x45, 0x04, 0x65, 0x1e,
	0x59, 0x11, 0x17, 0x55, 0xee, 0x63, 0xdb, 0x59, 0xac, 0xfe, 0x29, 0xff, 0xa6, 0xfa, 0xbe, 0xeb,
	0x1d, 0x17, 0xe3, 0x0f, 0x7d, 0xe4, 0xd6, 0x52, 0x98, 0x29, 0x58, 0xc3, 0x12, 0x6d, 0x6c, 0x58,
	0xf6, 0xa3, 0x3e, 0x8f, 0xf3, 0x10, 0x33, 0x15, 0x36, 0xf3, 0x70, 0x63, 0x87, 0xd5, 0xfc, 0x4b,
	0x1f, 0xd7, 0x8f, 0x08, 0x61, 0xa6, 0x10, 0x6a, 0x18, 0x08, 0x6d, 0x6c, 0x84, 0x2a, 0xce, 0x63,
	0xbf, 0x3a, 0xec, 0xfa, 0x27, 0x00, 0x00, 0xff, 0xff, 0x72, 0xeb, 0xee, 0x07, 0x14, 0x02, 0x00,
	0x00,
}
