// Code generated by protoc-gen-go. DO NOT EDIT.
// source: google/ads/googleads/v2/services/expanded_landing_page_view_service.proto

package services

import (
	context "context"
	fmt "fmt"
	math "math"

	proto "github.com/golang/protobuf/proto"
	resources "google.golang.org/genproto/googleapis/ads/googleads/v2/resources"
	_ "google.golang.org/genproto/googleapis/api/annotations"
	grpc "google.golang.org/grpc"
)

// Reference imports to suppress errors if they are not otherwise used.
var _ = proto.Marshal
var _ = fmt.Errorf
var _ = math.Inf

// This is a compile-time assertion to ensure that this generated file
// is compatible with the proto package it is being compiled against.
// A compilation error at this line likely means your copy of the
// proto package needs to be updated.
const _ = proto.ProtoPackageIsVersion3 // please upgrade the proto package

// Request message for
// [ExpandedLandingPageViewService.GetExpandedLandingPageView][google.ads.googleads.v2.services.ExpandedLandingPageViewService.GetExpandedLandingPageView].
type GetExpandedLandingPageViewRequest struct {
	// The resource name of the expanded landing page view to fetch.
	ResourceName         string   `protobuf:"bytes,1,opt,name=resource_name,json=resourceName,proto3" json:"resource_name,omitempty"`
	XXX_NoUnkeyedLiteral struct{} `json:"-"`
	XXX_unrecognized     []byte   `json:"-"`
	XXX_sizecache        int32    `json:"-"`
}

func (m *GetExpandedLandingPageViewRequest) Reset()         { *m = GetExpandedLandingPageViewRequest{} }
func (m *GetExpandedLandingPageViewRequest) String() string { return proto.CompactTextString(m) }
func (*GetExpandedLandingPageViewRequest) ProtoMessage()    {}
func (*GetExpandedLandingPageViewRequest) Descriptor() ([]byte, []int) {
	return fileDescriptor_5b70cd24f444e38d, []int{0}
}

func (m *GetExpandedLandingPageViewRequest) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_GetExpandedLandingPageViewRequest.Unmarshal(m, b)
}
func (m *GetExpandedLandingPageViewRequest) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_GetExpandedLandingPageViewRequest.Marshal(b, m, deterministic)
}
func (m *GetExpandedLandingPageViewRequest) XXX_Merge(src proto.Message) {
	xxx_messageInfo_GetExpandedLandingPageViewRequest.Merge(m, src)
}
func (m *GetExpandedLandingPageViewRequest) XXX_Size() int {
	return xxx_messageInfo_GetExpandedLandingPageViewRequest.Size(m)
}
func (m *GetExpandedLandingPageViewRequest) XXX_DiscardUnknown() {
	xxx_messageInfo_GetExpandedLandingPageViewRequest.DiscardUnknown(m)
}

var xxx_messageInfo_GetExpandedLandingPageViewRequest proto.InternalMessageInfo

func (m *GetExpandedLandingPageViewRequest) GetResourceName() string {
	if m != nil {
		return m.ResourceName
	}
	return ""
}

func init() {
	proto.RegisterType((*GetExpandedLandingPageViewRequest)(nil), "google.ads.googleads.v2.services.GetExpandedLandingPageViewRequest")
}

func init() {
	proto.RegisterFile("google/ads/googleads/v2/services/expanded_landing_page_view_service.proto", fileDescriptor_5b70cd24f444e38d)
}

var fileDescriptor_5b70cd24f444e38d = []byte{
	// 400 bytes of a gzipped FileDescriptorProto
	0x1f, 0x8b, 0x08, 0x00, 0x00, 0x00, 0x00, 0x00, 0x02, 0xff, 0x84, 0x92, 0xcf, 0xaa, 0xd3, 0x40,
	0x14, 0xc6, 0x49, 0x04, 0xc1, 0xa0, 0x9b, 0x6c, 0x2c, 0x51, 0xa4, 0xb6, 0x5d, 0x48, 0x17, 0x33,
	0x10, 0x77, 0xa3, 0x2e, 0x12, 0x91, 0x56, 0x10, 0x29, 0x15, 0xb2, 0x90, 0x40, 0x18, 0x33, 0x87,
	0x61, 0x20, 0x99, 0x89, 0x99, 0x34, 0x15, 0xc4, 0x8d, 0x4b, 0xb7, 0x3e, 0x81, 0x2e, 0x7d, 0x94,
	0x6e, 0x7d, 0x02, 0xc1, 0x95, 0x4f, 0x21, 0xe9, 0x64, 0xd2, 0x7b, 0x2f, 0xa4, 0xdd, 0x7d, 0xe4,
	0x7c, 0xf3, 0xfb, 0xce, 0x9f, 0x78, 0xaf, 0xb9, 0x52, 0xbc, 0x00, 0x4c, 0x99, 0xc6, 0x46, 0x76,
	0xaa, 0x0d, 0xb1, 0x86, 0xba, 0x15, 0x39, 0x68, 0x0c, 0x9f, 0x2a, 0x2a, 0x19, 0xb0, 0xac, 0xa0,
	0x92, 0x09, 0xc9, 0xb3, 0x8a, 0x72, 0xc8, 0x5a, 0x01, 0xfb, 0xac, 0xf7, 0xa0, 0xaa, 0x56, 0x8d,
	0xf2, 0xa7, 0xe6, 0x3d, 0xa2, 0x4c, 0xa3, 0x01, 0x85, 0xda, 0x10, 0x59, 0x54, 0x10, 0x8f, 0x85,
	0xd5, 0xa0, 0xd5, 0xae, 0x3e, 0x9f, 0x66, 0x52, 0x82, 0x87, 0x96, 0x51, 0x09, 0x4c, 0xa5, 0x54,
	0x0d, 0x6d, 0x84, 0x92, 0xba, 0xaf, 0xde, 0xbf, 0x52, 0xcd, 0x0b, 0x01, 0xb2, 0x31, 0x85, 0xd9,
	0xda, 0x7b, 0xbc, 0x82, 0xe6, 0x55, 0x4f, 0x7f, 0x63, 0xe0, 0x1b, 0xca, 0x21, 0x11, 0xb0, 0xdf,
	0xc2, 0xc7, 0x1d, 0xe8, 0xc6, 0x9f, 0x7b, 0xf7, 0x6c, 0x27, 0x99, 0xa4, 0x25, 0x4c, 0x9c, 0xa9,
	0xf3, 0xe4, 0xce, 0xf6, 0xae, 0xfd, 0xf8, 0x96, 0x96, 0x10, 0xfe, 0x70, 0xbd, 0x47, 0x23, 0x9c,
	0x77, 0x66, 0x50, 0xff, 0x8f, 0xe3, 0x05, 0xe3, 0x69, 0xfe, 0x4b, 0x74, 0x69, 0x53, 0xe8, 0x62,
	0xaf, 0x01, 0x19, 0x85, 0x0c, 0xcb, 0x44, 0x23, 0x88, 0x59, 0xfc, 0xf5, 0xf7, 0xdf, 0xef, 0xee,
	0x73, 0x9f, 0x74, 0xbb, 0xff, 0x7c, 0x6d, 0xe4, 0x17, 0xf9, 0x4e, 0x37, 0xaa, 0x84, 0x5a, 0xe3,
	0xe5, 0x70, 0x8c, 0x1b, 0xef, 0x35, 0x5e, 0x7e, 0x09, 0x1e, 0x1c, 0xa2, 0xc9, 0x29, 0xb6, 0x57,
	0x95, 0xd0, 0x28, 0x57, 0x65, 0xfc, 0xcd, 0xf5, 0x16, 0xb9, 0x2a, 0x2f, 0xce, 0x19, 0xcf, 0xcf,
	0x6f, 0x72, 0xd3, 0xdd, 0x6e, 0xe3, 0xbc, 0x5f, 0xf7, 0x20, 0xae, 0x0a, 0x2a, 0x39, 0x52, 0x35,
	0xc7, 0x1c, 0xe4, 0xf1, 0xb2, 0xf8, 0x14, 0x3d, 0xfe, 0x13, 0x3f, 0xb3, 0xe2, 0xa7, 0x7b, 0x6b,
	0x15, 0x45, 0xbf, 0xdc, 0xe9, 0xca, 0x00, 0x23, 0xa6, 0x91, 0x91, 0x9d, 0x4a, 0x42, 0xd4, 0x07,
	0xeb, 0x83, 0xb5, 0xa4, 0x11, 0xd3, 0xe9, 0x60, 0x49, 0x93, 0x30, 0xb5, 0x96, 0x7f, 0xee, 0xc2,
	0x7c, 0x27, 0x24, 0x62, 0x9a, 0x90, 0xc1, 0x44, 0x48, 0x12, 0x12, 0x62, 0x6d, 0x1f, 0x6e, 0x1f,
	0xfb, 0x7c, 0xfa, 0x3f, 0x00, 0x00, 0xff, 0xff, 0xe0, 0x6d, 0xef, 0x62, 0x6b, 0x03, 0x00, 0x00,
}

// Reference imports to suppress errors if they are not otherwise used.
var _ context.Context
var _ grpc.ClientConn

// This is a compile-time assertion to ensure that this generated file
// is compatible with the grpc package it is being compiled against.
const _ = grpc.SupportPackageIsVersion4

// ExpandedLandingPageViewServiceClient is the client API for ExpandedLandingPageViewService service.
//
// For semantics around ctx use and closing/ending streaming RPCs, please refer to https://godoc.org/google.golang.org/grpc#ClientConn.NewStream.
type ExpandedLandingPageViewServiceClient interface {
	// Returns the requested expanded landing page view in full detail.
	GetExpandedLandingPageView(ctx context.Context, in *GetExpandedLandingPageViewRequest, opts ...grpc.CallOption) (*resources.ExpandedLandingPageView, error)
}

type expandedLandingPageViewServiceClient struct {
	cc *grpc.ClientConn
}

func NewExpandedLandingPageViewServiceClient(cc *grpc.ClientConn) ExpandedLandingPageViewServiceClient {
	return &expandedLandingPageViewServiceClient{cc}
}

func (c *expandedLandingPageViewServiceClient) GetExpandedLandingPageView(ctx context.Context, in *GetExpandedLandingPageViewRequest, opts ...grpc.CallOption) (*resources.ExpandedLandingPageView, error) {
	out := new(resources.ExpandedLandingPageView)
	err := c.cc.Invoke(ctx, "/google.ads.googleads.v2.services.ExpandedLandingPageViewService/GetExpandedLandingPageView", in, out, opts...)
	if err != nil {
		return nil, err
	}
	return out, nil
}

// ExpandedLandingPageViewServiceServer is the server API for ExpandedLandingPageViewService service.
type ExpandedLandingPageViewServiceServer interface {
	// Returns the requested expanded landing page view in full detail.
	GetExpandedLandingPageView(context.Context, *GetExpandedLandingPageViewRequest) (*resources.ExpandedLandingPageView, error)
}

func RegisterExpandedLandingPageViewServiceServer(s *grpc.Server, srv ExpandedLandingPageViewServiceServer) {
	s.RegisterService(&_ExpandedLandingPageViewService_serviceDesc, srv)
}

func _ExpandedLandingPageViewService_GetExpandedLandingPageView_Handler(srv interface{}, ctx context.Context, dec func(interface{}) error, interceptor grpc.UnaryServerInterceptor) (interface{}, error) {
	in := new(GetExpandedLandingPageViewRequest)
	if err := dec(in); err != nil {
		return nil, err
	}
	if interceptor == nil {
		return srv.(ExpandedLandingPageViewServiceServer).GetExpandedLandingPageView(ctx, in)
	}
	info := &grpc.UnaryServerInfo{
		Server:     srv,
		FullMethod: "/google.ads.googleads.v2.services.ExpandedLandingPageViewService/GetExpandedLandingPageView",
	}
	handler := func(ctx context.Context, req interface{}) (interface{}, error) {
		return srv.(ExpandedLandingPageViewServiceServer).GetExpandedLandingPageView(ctx, req.(*GetExpandedLandingPageViewRequest))
	}
	return interceptor(ctx, in, info, handler)
}

var _ExpandedLandingPageViewService_serviceDesc = grpc.ServiceDesc{
	ServiceName: "google.ads.googleads.v2.services.ExpandedLandingPageViewService",
	HandlerType: (*ExpandedLandingPageViewServiceServer)(nil),
	Methods: []grpc.MethodDesc{
		{
			MethodName: "GetExpandedLandingPageView",
			Handler:    _ExpandedLandingPageViewService_GetExpandedLandingPageView_Handler,
		},
	},
	Streams:  []grpc.StreamDesc{},
	Metadata: "google/ads/googleads/v2/services/expanded_landing_page_view_service.proto",
}
