// Code generated by protoc-gen-go. DO NOT EDIT.
// source: google/ads/googleads/v2/resources/ad_group_ad_asset_view.proto

package resources

import (
	fmt "fmt"
	math "math"

	proto "github.com/golang/protobuf/proto"
	wrappers "github.com/golang/protobuf/ptypes/wrappers"
	common "google.golang.org/genproto/googleapis/ads/googleads/v2/common"
	enums "google.golang.org/genproto/googleapis/ads/googleads/v2/enums"
	_ "google.golang.org/genproto/googleapis/api/annotations"
)

// Reference imports to suppress errors if they are not otherwise used.
var _ = proto.Marshal
var _ = fmt.Errorf
var _ = math.Inf

// This is a compile-time assertion to ensure that this generated file
// is compatible with the proto package it is being compiled against.
// A compilation error at this line likely means your copy of the
// proto package needs to be updated.
const _ = proto.ProtoPackageIsVersion3 // please upgrade the proto package

// A link between an AdGroupAd and an Asset.
type AdGroupAdAssetView struct {
	// The resource name of the ad group ad asset view.
	// Ad group ad asset view resource names have the form:
	//
	// `customers/{customer_id}/adGroupAdAssets/{AdGroupAdAsset.ad_group_id}~{AdGroupAdAsset.ad.ad_id}~{AdGroupAdAsset.asset_id}~{AdGroupAdAsset.asset_field_type}`
	ResourceName string `protobuf:"bytes,1,opt,name=resource_name,json=resourceName,proto3" json:"resource_name,omitempty"`
	// The ad group ad to which the asset is linked.
	AdGroupAd *wrappers.StringValue `protobuf:"bytes,5,opt,name=ad_group_ad,json=adGroupAd,proto3" json:"ad_group_ad,omitempty"`
	// The asset which is linked to the ad group ad.
	Asset *wrappers.StringValue `protobuf:"bytes,6,opt,name=asset,proto3" json:"asset,omitempty"`
	// Role that the asset takes in the ad.
	FieldType enums.AssetFieldTypeEnum_AssetFieldType `protobuf:"varint,2,opt,name=field_type,json=fieldType,proto3,enum=google.ads.googleads.v2.enums.AssetFieldTypeEnum_AssetFieldType" json:"field_type,omitempty"`
	// Policy information for the ad group ad asset.
	PolicySummary *AdGroupAdAssetPolicySummary `protobuf:"bytes,3,opt,name=policy_summary,json=policySummary,proto3" json:"policy_summary,omitempty"`
	// Performance of an asset linkage.
	PerformanceLabel     enums.AssetPerformanceLabelEnum_AssetPerformanceLabel `protobuf:"varint,4,opt,name=performance_label,json=performanceLabel,proto3,enum=google.ads.googleads.v2.enums.AssetPerformanceLabelEnum_AssetPerformanceLabel" json:"performance_label,omitempty"`
	XXX_NoUnkeyedLiteral struct{}                                              `json:"-"`
	XXX_unrecognized     []byte                                                `json:"-"`
	XXX_sizecache        int32                                                 `json:"-"`
}

func (m *AdGroupAdAssetView) Reset()         { *m = AdGroupAdAssetView{} }
func (m *AdGroupAdAssetView) String() string { return proto.CompactTextString(m) }
func (*AdGroupAdAssetView) ProtoMessage()    {}
func (*AdGroupAdAssetView) Descriptor() ([]byte, []int) {
	return fileDescriptor_b8c6610099f54310, []int{0}
}

func (m *AdGroupAdAssetView) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_AdGroupAdAssetView.Unmarshal(m, b)
}
func (m *AdGroupAdAssetView) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_AdGroupAdAssetView.Marshal(b, m, deterministic)
}
func (m *AdGroupAdAssetView) XXX_Merge(src proto.Message) {
	xxx_messageInfo_AdGroupAdAssetView.Merge(m, src)
}
func (m *AdGroupAdAssetView) XXX_Size() int {
	return xxx_messageInfo_AdGroupAdAssetView.Size(m)
}
func (m *AdGroupAdAssetView) XXX_DiscardUnknown() {
	xxx_messageInfo_AdGroupAdAssetView.DiscardUnknown(m)
}

var xxx_messageInfo_AdGroupAdAssetView proto.InternalMessageInfo

func (m *AdGroupAdAssetView) GetResourceName() string {
	if m != nil {
		return m.ResourceName
	}
	return ""
}

func (m *AdGroupAdAssetView) GetAdGroupAd() *wrappers.StringValue {
	if m != nil {
		return m.AdGroupAd
	}
	return nil
}

func (m *AdGroupAdAssetView) GetAsset() *wrappers.StringValue {
	if m != nil {
		return m.Asset
	}
	return nil
}

func (m *AdGroupAdAssetView) GetFieldType() enums.AssetFieldTypeEnum_AssetFieldType {
	if m != nil {
		return m.FieldType
	}
	return enums.AssetFieldTypeEnum_UNSPECIFIED
}

func (m *AdGroupAdAssetView) GetPolicySummary() *AdGroupAdAssetPolicySummary {
	if m != nil {
		return m.PolicySummary
	}
	return nil
}

func (m *AdGroupAdAssetView) GetPerformanceLabel() enums.AssetPerformanceLabelEnum_AssetPerformanceLabel {
	if m != nil {
		return m.PerformanceLabel
	}
	return enums.AssetPerformanceLabelEnum_UNSPECIFIED
}

// Contains policy information for an ad group ad asset.
type AdGroupAdAssetPolicySummary struct {
	// The list of policy findings for the ad group ad asset.
	PolicyTopicEntries []*common.PolicyTopicEntry `protobuf:"bytes,1,rep,name=policy_topic_entries,json=policyTopicEntries,proto3" json:"policy_topic_entries,omitempty"`
	// Where in the review process this ad group ad asset is.
	ReviewStatus enums.PolicyReviewStatusEnum_PolicyReviewStatus `protobuf:"varint,2,opt,name=review_status,json=reviewStatus,proto3,enum=google.ads.googleads.v2.enums.PolicyReviewStatusEnum_PolicyReviewStatus" json:"review_status,omitempty"`
	// The overall approval status of this ad group ad asset, calculated based on
	// the status of its individual policy topic entries.
	ApprovalStatus       enums.PolicyApprovalStatusEnum_PolicyApprovalStatus `protobuf:"varint,3,opt,name=approval_status,json=approvalStatus,proto3,enum=google.ads.googleads.v2.enums.PolicyApprovalStatusEnum_PolicyApprovalStatus" json:"approval_status,omitempty"`
	XXX_NoUnkeyedLiteral struct{}                                            `json:"-"`
	XXX_unrecognized     []byte                                              `json:"-"`
	XXX_sizecache        int32                                               `json:"-"`
}

func (m *AdGroupAdAssetPolicySummary) Reset()         { *m = AdGroupAdAssetPolicySummary{} }
func (m *AdGroupAdAssetPolicySummary) String() string { return proto.CompactTextString(m) }
func (*AdGroupAdAssetPolicySummary) ProtoMessage()    {}
func (*AdGroupAdAssetPolicySummary) Descriptor() ([]byte, []int) {
	return fileDescriptor_b8c6610099f54310, []int{1}
}

func (m *AdGroupAdAssetPolicySummary) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_AdGroupAdAssetPolicySummary.Unmarshal(m, b)
}
func (m *AdGroupAdAssetPolicySummary) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_AdGroupAdAssetPolicySummary.Marshal(b, m, deterministic)
}
func (m *AdGroupAdAssetPolicySummary) XXX_Merge(src proto.Message) {
	xxx_messageInfo_AdGroupAdAssetPolicySummary.Merge(m, src)
}
func (m *AdGroupAdAssetPolicySummary) XXX_Size() int {
	return xxx_messageInfo_AdGroupAdAssetPolicySummary.Size(m)
}
func (m *AdGroupAdAssetPolicySummary) XXX_DiscardUnknown() {
	xxx_messageInfo_AdGroupAdAssetPolicySummary.DiscardUnknown(m)
}

var xxx_messageInfo_AdGroupAdAssetPolicySummary proto.InternalMessageInfo

func (m *AdGroupAdAssetPolicySummary) GetPolicyTopicEntries() []*common.PolicyTopicEntry {
	if m != nil {
		return m.PolicyTopicEntries
	}
	return nil
}

func (m *AdGroupAdAssetPolicySummary) GetReviewStatus() enums.PolicyReviewStatusEnum_PolicyReviewStatus {
	if m != nil {
		return m.ReviewStatus
	}
	return enums.PolicyReviewStatusEnum_UNSPECIFIED
}

func (m *AdGroupAdAssetPolicySummary) GetApprovalStatus() enums.PolicyApprovalStatusEnum_PolicyApprovalStatus {
	if m != nil {
		return m.ApprovalStatus
	}
	return enums.PolicyApprovalStatusEnum_UNSPECIFIED
}

func init() {
	proto.RegisterType((*AdGroupAdAssetView)(nil), "google.ads.googleads.v2.resources.AdGroupAdAssetView")
	proto.RegisterType((*AdGroupAdAssetPolicySummary)(nil), "google.ads.googleads.v2.resources.AdGroupAdAssetPolicySummary")
}

func init() {
	proto.RegisterFile("google/ads/googleads/v2/resources/ad_group_ad_asset_view.proto", fileDescriptor_b8c6610099f54310)
}

var fileDescriptor_b8c6610099f54310 = []byte{
	// 621 bytes of a gzipped FileDescriptorProto
	0x1f, 0x8b, 0x08, 0x00, 0x00, 0x00, 0x00, 0x00, 0x02, 0xff, 0x8c, 0x94, 0xdd, 0x6a, 0xd4, 0x40,
	0x14, 0x80, 0x49, 0xd6, 0x16, 0x3a, 0xb5, 0xab, 0x0e, 0x82, 0xa1, 0x16, 0xd9, 0x56, 0x0a, 0x0b,
	0xc2, 0x44, 0xa2, 0x17, 0x92, 0x4a, 0x31, 0x85, 0x5a, 0x91, 0x52, 0x96, 0xb4, 0xec, 0x85, 0x2c,
	0x84, 0xd9, 0x64, 0x36, 0x04, 0x92, 0x99, 0x61, 0x26, 0xd9, 0x65, 0xf1, 0xd6, 0x27, 0xf1, 0xd2,
	0x47, 0xf1, 0x45, 0x04, 0xaf, 0x7c, 0x04, 0xc9, 0x4c, 0x92, 0xfd, 0x63, 0x7f, 0xee, 0xce, 0xcc,
	0x9c, 0xef, 0xfc, 0x9f, 0x01, 0x97, 0x31, 0x63, 0x71, 0x4a, 0x6c, 0x1c, 0x49, 0x5b, 0x8b, 0xa5,
	0x34, 0x76, 0x6c, 0x41, 0x24, 0x2b, 0x44, 0x48, 0xa4, 0x8d, 0xa3, 0x20, 0x16, 0xac, 0xe0, 0x01,
	0x8e, 0x02, 0x2c, 0x25, 0xc9, 0x83, 0x71, 0x42, 0x26, 0x88, 0x0b, 0x96, 0x33, 0x78, 0xaa, 0x21,
	0x84, 0x23, 0x89, 0x1a, 0x1e, 0x8d, 0x1d, 0xd4, 0xf0, 0xc7, 0x6f, 0xd6, 0xb9, 0x08, 0x59, 0x96,
	0x31, 0x6a, 0x73, 0x96, 0x26, 0xe1, 0x54, 0xdb, 0x3b, 0x7e, 0xbf, 0x4e, 0x99, 0xd0, 0x22, 0x93,
	0xb6, 0xf6, 0x3f, 0x4a, 0x48, 0x1a, 0x05, 0xf9, 0x94, 0x93, 0x8a, 0xba, 0xd8, 0x85, 0xe2, 0x44,
	0x8c, 0x98, 0xc8, 0x30, 0x0d, 0x49, 0x90, 0xe2, 0x21, 0x49, 0x2b, 0xd8, 0xdd, 0x0c, 0xeb, 0xf0,
	0x02, 0xcc, 0xb9, 0x60, 0x63, 0x9c, 0x06, 0x32, 0xc7, 0x79, 0x21, 0x2b, 0xf6, 0xc3, 0x4e, 0xac,
	0x20, 0x65, 0xc5, 0x16, 0xc9, 0x57, 0x15, 0xa9, 0x4e, 0xc3, 0x62, 0x64, 0x4f, 0x04, 0xe6, 0x9c,
	0x88, 0xfa, 0xfd, 0xa4, 0xb6, 0xcc, 0x13, 0x1b, 0x53, 0xca, 0x72, 0x9c, 0x27, 0x8c, 0x56, 0xaf,
	0x67, 0xff, 0x5a, 0x00, 0x7a, 0xd1, 0x4d, 0xd9, 0x16, 0x2f, 0xf2, 0xca, 0xf4, 0xfa, 0x09, 0x99,
	0xc0, 0xd7, 0xe0, 0xa8, 0xae, 0x7b, 0x40, 0x71, 0x46, 0x2c, 0xa3, 0x63, 0x74, 0x0f, 0xfc, 0xc7,
	0xf5, 0xe5, 0x1d, 0xce, 0x08, 0xfc, 0x08, 0x0e, 0xe7, 0x5a, 0x6a, 0xed, 0x75, 0x8c, 0xee, 0xa1,
	0x73, 0x52, 0x75, 0x0f, 0xd5, 0xf1, 0xa0, 0xfb, 0x5c, 0x24, 0x34, 0xee, 0xe3, 0xb4, 0x20, 0xfe,
	0x01, 0xae, 0x7d, 0x41, 0x07, 0xec, 0xa9, 0x72, 0x5a, 0xfb, 0x3b, 0x70, 0x5a, 0x15, 0x06, 0x00,
	0xcc, 0x5a, 0x66, 0x99, 0x1d, 0xa3, 0xdb, 0x76, 0x3e, 0xa1, 0x75, 0x93, 0xa3, 0x4a, 0x87, 0x54,
	0x52, 0x9f, 0x4b, 0xea, 0x61, 0xca, 0xc9, 0x35, 0x2d, 0xb2, 0xa5, 0x2b, 0xff, 0x60, 0x54, 0x8b,
	0x90, 0x80, 0x76, 0x55, 0x6a, 0x59, 0x64, 0x19, 0x16, 0x53, 0xab, 0xa5, 0xa2, 0xbb, 0x44, 0x5b,
	0xc7, 0x13, 0x2d, 0x96, 0xb1, 0xa7, 0xcc, 0xdc, 0x6b, 0x2b, 0xfe, 0x11, 0x9f, 0x3f, 0xc2, 0xef,
	0xe0, 0xd9, 0xca, 0x10, 0x59, 0x8f, 0x54, 0x3a, 0x77, 0xbb, 0xa4, 0xd3, 0x9b, 0xc1, 0xb7, 0x25,
	0x3b, 0xcb, 0x6a, 0xf9, 0xc5, 0x7f, 0xca, 0x97, 0x6e, 0xce, 0xfe, 0x98, 0xe0, 0xe5, 0x86, 0x58,
	0xe1, 0x10, 0x3c, 0xaf, 0x6a, 0x90, 0x33, 0x9e, 0x84, 0x01, 0xa1, 0xb9, 0x48, 0x88, 0xb4, 0x8c,
	0x4e, 0xab, 0x7b, 0xe8, 0xbc, 0x5d, 0x1b, 0x9f, 0xde, 0x42, 0xa4, 0x8d, 0x3d, 0x94, 0xe8, 0x35,
	0xcd, 0xc5, 0xd4, 0x87, 0x7c, 0xf1, 0x26, 0x21, 0x12, 0x66, 0xe5, 0x7c, 0xcd, 0xcd, 0x72, 0xd5,
	0xcb, 0x2f, 0x5b, 0x92, 0xd7, 0xb6, 0x7d, 0x45, 0xde, 0x2b, 0x50, 0x65, 0xbe, 0x7a, 0x5d, 0x4e,
	0xea, 0xec, 0x04, 0x0b, 0xf0, 0x64, 0x69, 0xed, 0x54, 0x5f, 0xdb, 0xce, 0xed, 0x4e, 0x0e, 0xbd,
	0x8a, 0x5d, 0x71, 0xb9, 0xf8, 0xe0, 0xb7, 0xf1, 0xc2, 0xf9, 0xea, 0x87, 0x09, 0xce, 0x43, 0x96,
	0x6d, 0x9f, 0x9d, 0xab, 0x17, 0xab, 0x3b, 0xd8, 0x2b, 0xf7, 0xa0, 0x67, 0x7c, 0xfb, 0x5a, 0xd1,
	0x31, 0x4b, 0x31, 0x8d, 0x11, 0x13, 0xb1, 0x1d, 0x13, 0xaa, 0xb6, 0xa4, 0xfe, 0x29, 0x78, 0x22,
	0x37, 0xfc, 0xbb, 0x17, 0x8d, 0xf4, 0xd3, 0x6c, 0xdd, 0x78, 0xde, 0x2f, 0xf3, 0xf4, 0x46, 0x9b,
	0xf4, 0x22, 0x89, 0xb4, 0x58, 0x4a, 0x7d, 0x07, 0xf9, 0xb5, 0xe6, 0xef, 0x5a, 0x67, 0xe0, 0x45,
	0x72, 0xd0, 0xe8, 0x0c, 0xfa, 0xce, 0xa0, 0xd1, 0xf9, 0x6b, 0x9e, 0xeb, 0x07, 0xd7, 0xf5, 0x22,
	0xe9, 0xba, 0x8d, 0x96, 0xeb, 0xf6, 0x1d, 0xd7, 0x6d, 0xf4, 0x86, 0xfb, 0x2a, 0xd8, 0x77, 0xff,
	0x03, 0x00, 0x00, 0xff, 0xff, 0x16, 0x2e, 0x3c, 0xc8, 0x23, 0x06, 0x00, 0x00,
}
