// Code generated by protoc-gen-go. DO NOT EDIT.
// source: google/cloud/talent/v4beta1/event_service.proto

package talent

import (
	context "context"
	fmt "fmt"
	math "math"

	proto "github.com/golang/protobuf/proto"
	_ "google.golang.org/genproto/googleapis/api/annotations"
	grpc "google.golang.org/grpc"
)

// Reference imports to suppress errors if they are not otherwise used.
var _ = proto.Marshal
var _ = fmt.Errorf
var _ = math.Inf

// This is a compile-time assertion to ensure that this generated file
// is compatible with the proto package it is being compiled against.
// A compilation error at this line likely means your copy of the
// proto package needs to be updated.
const _ = proto.ProtoPackageIsVersion3 // please upgrade the proto package

// The report event request.
type CreateClientEventRequest struct {
	// Required. Resource name of the tenant under which the event is created.
	//
	// The format is "projects/{project_id}/tenants/{tenant_id}", for example,
	// "projects/api-test-project/tenant/foo".
	//
	// Tenant id is optional and a default tenant is created if unspecified, for
	// example, "projects/api-test-project".
	Parent string `protobuf:"bytes,1,opt,name=parent,proto3" json:"parent,omitempty"`
	// Required. Events issued when end user interacts with customer's application
	// that uses Cloud Talent Solution.
	ClientEvent          *ClientEvent `protobuf:"bytes,2,opt,name=client_event,json=clientEvent,proto3" json:"client_event,omitempty"`
	XXX_NoUnkeyedLiteral struct{}     `json:"-"`
	XXX_unrecognized     []byte       `json:"-"`
	XXX_sizecache        int32        `json:"-"`
}

func (m *CreateClientEventRequest) Reset()         { *m = CreateClientEventRequest{} }
func (m *CreateClientEventRequest) String() string { return proto.CompactTextString(m) }
func (*CreateClientEventRequest) ProtoMessage()    {}
func (*CreateClientEventRequest) Descriptor() ([]byte, []int) {
	return fileDescriptor_fe732bea1e1e1bea, []int{0}
}

func (m *CreateClientEventRequest) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_CreateClientEventRequest.Unmarshal(m, b)
}
func (m *CreateClientEventRequest) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_CreateClientEventRequest.Marshal(b, m, deterministic)
}
func (m *CreateClientEventRequest) XXX_Merge(src proto.Message) {
	xxx_messageInfo_CreateClientEventRequest.Merge(m, src)
}
func (m *CreateClientEventRequest) XXX_Size() int {
	return xxx_messageInfo_CreateClientEventRequest.Size(m)
}
func (m *CreateClientEventRequest) XXX_DiscardUnknown() {
	xxx_messageInfo_CreateClientEventRequest.DiscardUnknown(m)
}

var xxx_messageInfo_CreateClientEventRequest proto.InternalMessageInfo

func (m *CreateClientEventRequest) GetParent() string {
	if m != nil {
		return m.Parent
	}
	return ""
}

func (m *CreateClientEventRequest) GetClientEvent() *ClientEvent {
	if m != nil {
		return m.ClientEvent
	}
	return nil
}

func init() {
	proto.RegisterType((*CreateClientEventRequest)(nil), "google.cloud.talent.v4beta1.CreateClientEventRequest")
}

func init() {
	proto.RegisterFile("google/cloud/talent/v4beta1/event_service.proto", fileDescriptor_fe732bea1e1e1bea)
}

var fileDescriptor_fe732bea1e1e1bea = []byte{
	// 378 bytes of a gzipped FileDescriptorProto
	0x1f, 0x8b, 0x08, 0x00, 0x00, 0x00, 0x00, 0x00, 0x02, 0xff, 0x8c, 0x92, 0xc1, 0x4e, 0xc2, 0x40,
	0x10, 0x86, 0xd3, 0x9a, 0x90, 0x58, 0xb8, 0x50, 0x13, 0x25, 0xd5, 0x44, 0xd2, 0x8b, 0x48, 0x74,
	0x37, 0x82, 0x5e, 0x30, 0x1e, 0x80, 0x78, 0xf2, 0x42, 0xc0, 0x13, 0x17, 0xb2, 0xd4, 0xb1, 0x94,
	0x94, 0xdd, 0xda, 0x1d, 0xe0, 0x60, 0x0c, 0x89, 0xaf, 0xe0, 0x1b, 0xf8, 0x38, 0x1e, 0xf5, 0x11,
	0xe4, 0x41, 0x4c, 0xbb, 0x8d, 0x34, 0xa2, 0xc5, 0xdb, 0x4e, 0x66, 0xbe, 0x99, 0xff, 0x9f, 0x1d,
	0x83, 0xba, 0x42, 0xb8, 0x3e, 0x50, 0xc7, 0x17, 0xd3, 0x3b, 0x8a, 0xcc, 0x07, 0x8e, 0x74, 0x76,
	0x3e, 0x04, 0x64, 0x67, 0x14, 0x66, 0xc0, 0x71, 0x20, 0x21, 0x9c, 0x79, 0x0e, 0x90, 0x20, 0x14,
	0x28, 0xcc, 0x7d, 0x05, 0x90, 0x18, 0x20, 0x0a, 0x20, 0x09, 0x60, 0x1d, 0x24, 0xdd, 0x58, 0xe0,
	0x51, 0xc6, 0xb9, 0x40, 0x86, 0x9e, 0xe0, 0x52, 0xa1, 0xd6, 0x5e, 0x2a, 0xeb, 0xf8, 0x5e, 0x04,
	0xaa, 0xc4, 0xd1, 0x46, 0x11, 0xaa, 0xd0, 0x5e, 0x18, 0xa5, 0x76, 0x08, 0x0c, 0xa1, 0x1d, 0xe3,
	0xd7, 0x51, 0xaa, 0x0b, 0x0f, 0x53, 0x90, 0x68, 0xee, 0x1a, 0xb9, 0x80, 0x85, 0xc0, 0xb1, 0xa4,
	0x95, 0xb5, 0xca, 0x76, 0x37, 0x89, 0xcc, 0x1b, 0xa3, 0xa0, 0x86, 0x0d, 0xe2, 0x4e, 0x25, 0xbd,
	0xac, 0x55, 0xf2, 0xb5, 0x0a, 0xc9, 0xf0, 0x41, 0xd2, 0xed, 0xf3, 0xce, 0x2a, 0xa8, 0x7d, 0xea,
	0x46, 0x21, 0x7e, 0xf5, 0xd4, 0x52, 0xcc, 0xa5, 0x66, 0x14, 0xd7, 0x24, 0x99, 0x17, 0xd9, 0xdd,
	0xff, 0xb0, 0x60, 0xfd, 0x5b, 0x94, 0xcd, 0x9f, 0x3f, 0x96, 0x2f, 0xfa, 0xc8, 0xae, 0x7f, 0xaf,
	0xe9, 0x51, 0xd9, 0xbd, 0x0a, 0x42, 0x31, 0x06, 0x07, 0x25, 0xad, 0x52, 0x04, 0xce, 0x78, 0xf4,
	0x7a, 0xa2, 0x29, 0x0f, 0xb2, 0xa1, 0x55, 0xfb, 0xc4, 0x3e, 0xce, 0x20, 0xd7, 0xea, 0x2d, 0xff,
	0xad, 0xb9, 0x33, 0x16, 0x43, 0x99, 0x08, 0x64, 0x81, 0x27, 0x89, 0x23, 0x26, 0xef, 0xcd, 0xde,
	0x08, 0x31, 0x90, 0x0d, 0x4a, 0xe7, 0xf3, 0xf9, 0x8f, 0x24, 0x65, 0x53, 0x1c, 0xa9, 0x3f, 0x3d,
	0x0d, 0x7c, 0x86, 0xf7, 0x22, 0x9c, 0x9c, 0x6c, 0x2a, 0x8f, 0x86, 0xb4, 0x16, 0xc6, 0xa1, 0x23,
	0x26, 0x59, 0xcb, 0x68, 0x15, 0xd3, 0xbf, 0xd0, 0x89, 0x8e, 0xa3, 0xa3, 0xf5, 0x9b, 0x09, 0xe1,
	0x0a, 0x9f, 0x71, 0x97, 0x88, 0xd0, 0xa5, 0x2e, 0xf0, 0xf8, 0x74, 0xe8, 0x6a, 0xd8, 0xaf, 0x67,
	0x76, 0xa9, 0xc2, 0x57, 0x7d, 0xab, 0x7d, 0xdb, 0x1b, 0xe6, 0x62, 0xa6, 0xfe, 0x15, 0x00, 0x00,
	0xff, 0xff, 0x63, 0x5f, 0x43, 0x97, 0x1e, 0x03, 0x00, 0x00,
}

// Reference imports to suppress errors if they are not otherwise used.
var _ context.Context
var _ grpc.ClientConn

// This is a compile-time assertion to ensure that this generated file
// is compatible with the grpc package it is being compiled against.
const _ = grpc.SupportPackageIsVersion4

// EventServiceClient is the client API for EventService service.
//
// For semantics around ctx use and closing/ending streaming RPCs, please refer to https://godoc.org/google.golang.org/grpc#ClientConn.NewStream.
type EventServiceClient interface {
	// Report events issued when end user interacts with customer's application
	// that uses Cloud Talent Solution. You may inspect the created events in
	// [self service
	// tools](https://console.cloud.google.com/talent-solution/overview).
	// [Learn
	// more](https://cloud.google.com/talent-solution/docs/management-tools)
	// about self service tools.
	CreateClientEvent(ctx context.Context, in *CreateClientEventRequest, opts ...grpc.CallOption) (*ClientEvent, error)
}

type eventServiceClient struct {
	cc *grpc.ClientConn
}

func NewEventServiceClient(cc *grpc.ClientConn) EventServiceClient {
	return &eventServiceClient{cc}
}

func (c *eventServiceClient) CreateClientEvent(ctx context.Context, in *CreateClientEventRequest, opts ...grpc.CallOption) (*ClientEvent, error) {
	out := new(ClientEvent)
	err := c.cc.Invoke(ctx, "/google.cloud.talent.v4beta1.EventService/CreateClientEvent", in, out, opts...)
	if err != nil {
		return nil, err
	}
	return out, nil
}

// EventServiceServer is the server API for EventService service.
type EventServiceServer interface {
	// Report events issued when end user interacts with customer's application
	// that uses Cloud Talent Solution. You may inspect the created events in
	// [self service
	// tools](https://console.cloud.google.com/talent-solution/overview).
	// [Learn
	// more](https://cloud.google.com/talent-solution/docs/management-tools)
	// about self service tools.
	CreateClientEvent(context.Context, *CreateClientEventRequest) (*ClientEvent, error)
}

func RegisterEventServiceServer(s *grpc.Server, srv EventServiceServer) {
	s.RegisterService(&_EventService_serviceDesc, srv)
}

func _EventService_CreateClientEvent_Handler(srv interface{}, ctx context.Context, dec func(interface{}) error, interceptor grpc.UnaryServerInterceptor) (interface{}, error) {
	in := new(CreateClientEventRequest)
	if err := dec(in); err != nil {
		return nil, err
	}
	if interceptor == nil {
		return srv.(EventServiceServer).CreateClientEvent(ctx, in)
	}
	info := &grpc.UnaryServerInfo{
		Server:     srv,
		FullMethod: "/google.cloud.talent.v4beta1.EventService/CreateClientEvent",
	}
	handler := func(ctx context.Context, req interface{}) (interface{}, error) {
		return srv.(EventServiceServer).CreateClientEvent(ctx, req.(*CreateClientEventRequest))
	}
	return interceptor(ctx, in, info, handler)
}

var _EventService_serviceDesc = grpc.ServiceDesc{
	ServiceName: "google.cloud.talent.v4beta1.EventService",
	HandlerType: (*EventServiceServer)(nil),
	Methods: []grpc.MethodDesc{
		{
			MethodName: "CreateClientEvent",
			Handler:    _EventService_CreateClientEvent_Handler,
		},
	},
	Streams:  []grpc.StreamDesc{},
	Metadata: "google/cloud/talent/v4beta1/event_service.proto",
}
