// Code generated by protoc-gen-go. DO NOT EDIT.
// source: google/ads/googleads/v2/services/google_ads_field_service.proto

package services

import (
	context "context"
	fmt "fmt"
	math "math"

	proto "github.com/golang/protobuf/proto"
	resources "google.golang.org/genproto/googleapis/ads/googleads/v2/resources"
	_ "google.golang.org/genproto/googleapis/api/annotations"
	grpc "google.golang.org/grpc"
)

// Reference imports to suppress errors if they are not otherwise used.
var _ = proto.Marshal
var _ = fmt.Errorf
var _ = math.Inf

// This is a compile-time assertion to ensure that this generated file
// is compatible with the proto package it is being compiled against.
// A compilation error at this line likely means your copy of the
// proto package needs to be updated.
const _ = proto.ProtoPackageIsVersion3 // please upgrade the proto package

// Request message for [GoogleAdsFieldService.GetGoogleAdsField][google.ads.googleads.v2.services.GoogleAdsFieldService.GetGoogleAdsField].
type GetGoogleAdsFieldRequest struct {
	// The resource name of the field to get.
	ResourceName         string   `protobuf:"bytes,1,opt,name=resource_name,json=resourceName,proto3" json:"resource_name,omitempty"`
	XXX_NoUnkeyedLiteral struct{} `json:"-"`
	XXX_unrecognized     []byte   `json:"-"`
	XXX_sizecache        int32    `json:"-"`
}

func (m *GetGoogleAdsFieldRequest) Reset()         { *m = GetGoogleAdsFieldRequest{} }
func (m *GetGoogleAdsFieldRequest) String() string { return proto.CompactTextString(m) }
func (*GetGoogleAdsFieldRequest) ProtoMessage()    {}
func (*GetGoogleAdsFieldRequest) Descriptor() ([]byte, []int) {
	return fileDescriptor_53bb09f9b9b195a9, []int{0}
}

func (m *GetGoogleAdsFieldRequest) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_GetGoogleAdsFieldRequest.Unmarshal(m, b)
}
func (m *GetGoogleAdsFieldRequest) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_GetGoogleAdsFieldRequest.Marshal(b, m, deterministic)
}
func (m *GetGoogleAdsFieldRequest) XXX_Merge(src proto.Message) {
	xxx_messageInfo_GetGoogleAdsFieldRequest.Merge(m, src)
}
func (m *GetGoogleAdsFieldRequest) XXX_Size() int {
	return xxx_messageInfo_GetGoogleAdsFieldRequest.Size(m)
}
func (m *GetGoogleAdsFieldRequest) XXX_DiscardUnknown() {
	xxx_messageInfo_GetGoogleAdsFieldRequest.DiscardUnknown(m)
}

var xxx_messageInfo_GetGoogleAdsFieldRequest proto.InternalMessageInfo

func (m *GetGoogleAdsFieldRequest) GetResourceName() string {
	if m != nil {
		return m.ResourceName
	}
	return ""
}

// Request message for [GoogleAdsFieldService.SearchGoogleAdsFields][google.ads.googleads.v2.services.GoogleAdsFieldService.SearchGoogleAdsFields].
type SearchGoogleAdsFieldsRequest struct {
	// The query string.
	Query string `protobuf:"bytes,1,opt,name=query,proto3" json:"query,omitempty"`
	// Token of the page to retrieve. If not specified, the first page of
	// results will be returned. Use the value obtained from `next_page_token`
	// in the previous response in order to request the next page of results.
	PageToken string `protobuf:"bytes,2,opt,name=page_token,json=pageToken,proto3" json:"page_token,omitempty"`
	// Number of elements to retrieve in a single page.
	// When too large a page is requested, the server may decide to further
	// limit the number of returned resources.
	PageSize             int32    `protobuf:"varint,3,opt,name=page_size,json=pageSize,proto3" json:"page_size,omitempty"`
	XXX_NoUnkeyedLiteral struct{} `json:"-"`
	XXX_unrecognized     []byte   `json:"-"`
	XXX_sizecache        int32    `json:"-"`
}

func (m *SearchGoogleAdsFieldsRequest) Reset()         { *m = SearchGoogleAdsFieldsRequest{} }
func (m *SearchGoogleAdsFieldsRequest) String() string { return proto.CompactTextString(m) }
func (*SearchGoogleAdsFieldsRequest) ProtoMessage()    {}
func (*SearchGoogleAdsFieldsRequest) Descriptor() ([]byte, []int) {
	return fileDescriptor_53bb09f9b9b195a9, []int{1}
}

func (m *SearchGoogleAdsFieldsRequest) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_SearchGoogleAdsFieldsRequest.Unmarshal(m, b)
}
func (m *SearchGoogleAdsFieldsRequest) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_SearchGoogleAdsFieldsRequest.Marshal(b, m, deterministic)
}
func (m *SearchGoogleAdsFieldsRequest) XXX_Merge(src proto.Message) {
	xxx_messageInfo_SearchGoogleAdsFieldsRequest.Merge(m, src)
}
func (m *SearchGoogleAdsFieldsRequest) XXX_Size() int {
	return xxx_messageInfo_SearchGoogleAdsFieldsRequest.Size(m)
}
func (m *SearchGoogleAdsFieldsRequest) XXX_DiscardUnknown() {
	xxx_messageInfo_SearchGoogleAdsFieldsRequest.DiscardUnknown(m)
}

var xxx_messageInfo_SearchGoogleAdsFieldsRequest proto.InternalMessageInfo

func (m *SearchGoogleAdsFieldsRequest) GetQuery() string {
	if m != nil {
		return m.Query
	}
	return ""
}

func (m *SearchGoogleAdsFieldsRequest) GetPageToken() string {
	if m != nil {
		return m.PageToken
	}
	return ""
}

func (m *SearchGoogleAdsFieldsRequest) GetPageSize() int32 {
	if m != nil {
		return m.PageSize
	}
	return 0
}

// Response message for [GoogleAdsFieldService.SearchGoogleAdsFields][google.ads.googleads.v2.services.GoogleAdsFieldService.SearchGoogleAdsFields].
type SearchGoogleAdsFieldsResponse struct {
	// The list of fields that matched the query.
	Results []*resources.GoogleAdsField `protobuf:"bytes,1,rep,name=results,proto3" json:"results,omitempty"`
	// Pagination token used to retrieve the next page of results. Pass the
	// content of this string as the `page_token` attribute of the next request.
	// `next_page_token` is not returned for the last page.
	NextPageToken string `protobuf:"bytes,2,opt,name=next_page_token,json=nextPageToken,proto3" json:"next_page_token,omitempty"`
	// Total number of results that match the query ignoring the LIMIT clause.
	TotalResultsCount    int64    `protobuf:"varint,3,opt,name=total_results_count,json=totalResultsCount,proto3" json:"total_results_count,omitempty"`
	XXX_NoUnkeyedLiteral struct{} `json:"-"`
	XXX_unrecognized     []byte   `json:"-"`
	XXX_sizecache        int32    `json:"-"`
}

func (m *SearchGoogleAdsFieldsResponse) Reset()         { *m = SearchGoogleAdsFieldsResponse{} }
func (m *SearchGoogleAdsFieldsResponse) String() string { return proto.CompactTextString(m) }
func (*SearchGoogleAdsFieldsResponse) ProtoMessage()    {}
func (*SearchGoogleAdsFieldsResponse) Descriptor() ([]byte, []int) {
	return fileDescriptor_53bb09f9b9b195a9, []int{2}
}

func (m *SearchGoogleAdsFieldsResponse) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_SearchGoogleAdsFieldsResponse.Unmarshal(m, b)
}
func (m *SearchGoogleAdsFieldsResponse) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_SearchGoogleAdsFieldsResponse.Marshal(b, m, deterministic)
}
func (m *SearchGoogleAdsFieldsResponse) XXX_Merge(src proto.Message) {
	xxx_messageInfo_SearchGoogleAdsFieldsResponse.Merge(m, src)
}
func (m *SearchGoogleAdsFieldsResponse) XXX_Size() int {
	return xxx_messageInfo_SearchGoogleAdsFieldsResponse.Size(m)
}
func (m *SearchGoogleAdsFieldsResponse) XXX_DiscardUnknown() {
	xxx_messageInfo_SearchGoogleAdsFieldsResponse.DiscardUnknown(m)
}

var xxx_messageInfo_SearchGoogleAdsFieldsResponse proto.InternalMessageInfo

func (m *SearchGoogleAdsFieldsResponse) GetResults() []*resources.GoogleAdsField {
	if m != nil {
		return m.Results
	}
	return nil
}

func (m *SearchGoogleAdsFieldsResponse) GetNextPageToken() string {
	if m != nil {
		return m.NextPageToken
	}
	return ""
}

func (m *SearchGoogleAdsFieldsResponse) GetTotalResultsCount() int64 {
	if m != nil {
		return m.TotalResultsCount
	}
	return 0
}

func init() {
	proto.RegisterType((*GetGoogleAdsFieldRequest)(nil), "google.ads.googleads.v2.services.GetGoogleAdsFieldRequest")
	proto.RegisterType((*SearchGoogleAdsFieldsRequest)(nil), "google.ads.googleads.v2.services.SearchGoogleAdsFieldsRequest")
	proto.RegisterType((*SearchGoogleAdsFieldsResponse)(nil), "google.ads.googleads.v2.services.SearchGoogleAdsFieldsResponse")
}

func init() {
	proto.RegisterFile("google/ads/googleads/v2/services/google_ads_field_service.proto", fileDescriptor_53bb09f9b9b195a9)
}

var fileDescriptor_53bb09f9b9b195a9 = []byte{
	// 559 bytes of a gzipped FileDescriptorProto
	0x1f, 0x8b, 0x08, 0x00, 0x00, 0x00, 0x00, 0x00, 0x02, 0xff, 0x9c, 0x54, 0xcf, 0x6e, 0xd3, 0x4e,
	0x10, 0x96, 0x1d, 0xf5, 0xf7, 0xa3, 0x0b, 0x15, 0xea, 0x42, 0x85, 0xe5, 0xb6, 0x22, 0x32, 0x2d,
	0x44, 0x95, 0x58, 0x0b, 0x73, 0x41, 0x8b, 0x20, 0x72, 0x91, 0x08, 0x12, 0x12, 0x8a, 0x12, 0x94,
	0x03, 0x8a, 0x64, 0x2d, 0xf6, 0x60, 0x2c, 0x9c, 0x5d, 0xd7, 0xbb, 0x89, 0xa0, 0x88, 0x03, 0xbc,
	0x02, 0x6f, 0xc0, 0xb1, 0x37, 0x9e, 0x80, 0x0b, 0xa7, 0x5e, 0x79, 0x05, 0x4e, 0x3c, 0x05, 0xf2,
	0x9f, 0x4d, 0x9b, 0x36, 0x21, 0x82, 0xdb, 0x7a, 0xbe, 0x99, 0xef, 0xfb, 0x76, 0x66, 0xd6, 0xa8,
	0x1d, 0x0b, 0x11, 0xa7, 0xe0, 0xb2, 0x48, 0xba, 0xd5, 0xb1, 0x38, 0x4d, 0x3c, 0x57, 0x42, 0x3e,
	0x49, 0x42, 0xd0, 0xd1, 0x80, 0x45, 0x32, 0x78, 0x95, 0x40, 0x1a, 0x05, 0x35, 0x42, 0xb2, 0x5c,
	0x28, 0x81, 0x9b, 0x15, 0x4e, 0x58, 0x24, 0xc9, 0x94, 0x80, 0x4c, 0x3c, 0xa2, 0x09, 0xec, 0x7b,
	0x8b, 0x24, 0x72, 0x90, 0x62, 0x9c, 0xcf, 0xd3, 0xa8, 0xb8, 0xed, 0x2d, 0x5d, 0x99, 0x25, 0x2e,
	0xe3, 0x5c, 0x28, 0xa6, 0x12, 0xc1, 0x65, 0x8d, 0x5e, 0x3b, 0x85, 0x86, 0x69, 0x02, 0x5c, 0x55,
	0x80, 0xd3, 0x46, 0x56, 0x07, 0x54, 0xa7, 0x44, 0xfd, 0x48, 0x3e, 0x2e, 0x18, 0x7b, 0x70, 0x30,
	0x06, 0xa9, 0xf0, 0x0d, 0xb4, 0xa6, 0x65, 0x03, 0xce, 0x46, 0x60, 0x19, 0x4d, 0xa3, 0xb5, 0xda,
	0xbb, 0xa4, 0x83, 0xcf, 0xd8, 0x08, 0x9c, 0x0c, 0x6d, 0xf5, 0x81, 0xe5, 0xe1, 0xeb, 0x59, 0x0e,
	0xa9, 0x49, 0xae, 0xa2, 0x95, 0x83, 0x31, 0xe4, 0xef, 0xea, 0xe2, 0xea, 0x03, 0x6f, 0x23, 0x94,
	0xb1, 0x18, 0x02, 0x25, 0xde, 0x00, 0xb7, 0xcc, 0x12, 0x5a, 0x2d, 0x22, 0xcf, 0x8b, 0x00, 0xde,
	0x44, 0xe5, 0x47, 0x20, 0x93, 0x43, 0xb0, 0x1a, 0x4d, 0xa3, 0xb5, 0xd2, 0xbb, 0x50, 0x04, 0xfa,
	0xc9, 0x21, 0x38, 0xdf, 0x0d, 0xb4, 0xbd, 0x40, 0x52, 0x66, 0x82, 0x4b, 0xc0, 0x4f, 0xd1, 0xff,
	0x39, 0xc8, 0x71, 0xaa, 0xa4, 0x65, 0x34, 0x1b, 0xad, 0x8b, 0xde, 0x1d, 0xb2, 0xa8, 0xf3, 0xd3,
	0xbe, 0x92, 0x33, 0x3d, 0xd0, 0x0c, 0xf8, 0x26, 0xba, 0xcc, 0xe1, 0xad, 0x0a, 0xce, 0xf9, 0x5d,
	0x2b, 0xc2, 0xdd, 0xa9, 0x67, 0x82, 0xae, 0x28, 0xa1, 0x58, 0x1a, 0xd4, 0x85, 0x41, 0x28, 0xc6,
	0x5c, 0x95, 0xee, 0x1b, 0xbd, 0xf5, 0x12, 0xea, 0x55, 0xc8, 0xa3, 0x02, 0xf0, 0x8e, 0x1a, 0x68,
	0x63, 0x56, 0xb3, 0x5f, 0x6d, 0x01, 0xfe, 0x6a, 0xa0, 0xf5, 0x73, 0x43, 0xc1, 0x94, 0x2c, 0xdb,
	0x1e, 0xb2, 0x68, 0x92, 0xf6, 0xdf, 0xdf, 0xdf, 0xb9, 0xfd, 0xe9, 0xc7, 0xcf, 0xcf, 0xe6, 0x2d,
	0xbc, 0x5b, 0x6c, 0xdf, 0xfb, 0x99, 0x3d, 0x78, 0x10, 0xcf, 0xf6, 0xdd, 0xdd, 0xfb, 0x80, 0xbf,
	0x19, 0x68, 0x63, 0xee, 0x50, 0xf0, 0xc3, 0xe5, 0xbe, 0xff, 0xb4, 0x40, 0x76, 0xfb, 0x9f, 0xeb,
	0xab, 0x6d, 0x70, 0x76, 0xcb, 0x9b, 0x5c, 0x77, 0xec, 0xe2, 0x26, 0x67, 0xac, 0x53, 0x59, 0x96,
	0x52, 0x63, 0xcf, 0xde, 0x3c, 0xf6, 0xad, 0x13, 0xfa, 0xfa, 0x94, 0x25, 0x92, 0x84, 0x62, 0xb4,
	0xff, 0xd1, 0x44, 0x3b, 0xa1, 0x18, 0x2d, 0xb5, 0xb2, 0x6f, 0xcf, 0x1d, 0x69, 0xb7, 0x78, 0x6b,
	0x5d, 0xe3, 0xc5, 0x93, 0xba, 0x3e, 0x16, 0x29, 0xe3, 0x31, 0x11, 0x79, 0xec, 0xc6, 0xc0, 0xcb,
	0x97, 0xe8, 0x9e, 0x28, 0x2e, 0xfe, 0xc1, 0xdc, 0xd7, 0x87, 0x2f, 0x66, 0xa3, 0xe3, 0xfb, 0x47,
	0x66, 0xb3, 0x92, 0x23, 0x7e, 0x74, 0x6a, 0x80, 0x64, 0xe0, 0x91, 0x5a, 0x58, 0x1e, 0xeb, 0x94,
	0xa1, 0x1f, 0xc9, 0xe1, 0x34, 0x65, 0x38, 0xf0, 0x86, 0x3a, 0xe5, 0x97, 0xb9, 0x53, 0xc5, 0x29,
	0xf5, 0x23, 0x49, 0xe9, 0x34, 0x89, 0xd2, 0x81, 0x47, 0xa9, 0x4e, 0x7b, 0xf9, 0x5f, 0xe9, 0xf3,
	0xee, 0xef, 0x00, 0x00, 0x00, 0xff, 0xff, 0xbf, 0x0c, 0xef, 0x0e, 0x07, 0x05, 0x00, 0x00,
}

// Reference imports to suppress errors if they are not otherwise used.
var _ context.Context
var _ grpc.ClientConn

// This is a compile-time assertion to ensure that this generated file
// is compatible with the grpc package it is being compiled against.
const _ = grpc.SupportPackageIsVersion4

// GoogleAdsFieldServiceClient is the client API for GoogleAdsFieldService service.
//
// For semantics around ctx use and closing/ending streaming RPCs, please refer to https://godoc.org/google.golang.org/grpc#ClientConn.NewStream.
type GoogleAdsFieldServiceClient interface {
	// Returns just the requested field.
	GetGoogleAdsField(ctx context.Context, in *GetGoogleAdsFieldRequest, opts ...grpc.CallOption) (*resources.GoogleAdsField, error)
	// Returns all fields that match the search query.
	SearchGoogleAdsFields(ctx context.Context, in *SearchGoogleAdsFieldsRequest, opts ...grpc.CallOption) (*SearchGoogleAdsFieldsResponse, error)
}

type googleAdsFieldServiceClient struct {
	cc *grpc.ClientConn
}

func NewGoogleAdsFieldServiceClient(cc *grpc.ClientConn) GoogleAdsFieldServiceClient {
	return &googleAdsFieldServiceClient{cc}
}

func (c *googleAdsFieldServiceClient) GetGoogleAdsField(ctx context.Context, in *GetGoogleAdsFieldRequest, opts ...grpc.CallOption) (*resources.GoogleAdsField, error) {
	out := new(resources.GoogleAdsField)
	err := c.cc.Invoke(ctx, "/google.ads.googleads.v2.services.GoogleAdsFieldService/GetGoogleAdsField", in, out, opts...)
	if err != nil {
		return nil, err
	}
	return out, nil
}

func (c *googleAdsFieldServiceClient) SearchGoogleAdsFields(ctx context.Context, in *SearchGoogleAdsFieldsRequest, opts ...grpc.CallOption) (*SearchGoogleAdsFieldsResponse, error) {
	out := new(SearchGoogleAdsFieldsResponse)
	err := c.cc.Invoke(ctx, "/google.ads.googleads.v2.services.GoogleAdsFieldService/SearchGoogleAdsFields", in, out, opts...)
	if err != nil {
		return nil, err
	}
	return out, nil
}

// GoogleAdsFieldServiceServer is the server API for GoogleAdsFieldService service.
type GoogleAdsFieldServiceServer interface {
	// Returns just the requested field.
	GetGoogleAdsField(context.Context, *GetGoogleAdsFieldRequest) (*resources.GoogleAdsField, error)
	// Returns all fields that match the search query.
	SearchGoogleAdsFields(context.Context, *SearchGoogleAdsFieldsRequest) (*SearchGoogleAdsFieldsResponse, error)
}

func RegisterGoogleAdsFieldServiceServer(s *grpc.Server, srv GoogleAdsFieldServiceServer) {
	s.RegisterService(&_GoogleAdsFieldService_serviceDesc, srv)
}

func _GoogleAdsFieldService_GetGoogleAdsField_Handler(srv interface{}, ctx context.Context, dec func(interface{}) error, interceptor grpc.UnaryServerInterceptor) (interface{}, error) {
	in := new(GetGoogleAdsFieldRequest)
	if err := dec(in); err != nil {
		return nil, err
	}
	if interceptor == nil {
		return srv.(GoogleAdsFieldServiceServer).GetGoogleAdsField(ctx, in)
	}
	info := &grpc.UnaryServerInfo{
		Server:     srv,
		FullMethod: "/google.ads.googleads.v2.services.GoogleAdsFieldService/GetGoogleAdsField",
	}
	handler := func(ctx context.Context, req interface{}) (interface{}, error) {
		return srv.(GoogleAdsFieldServiceServer).GetGoogleAdsField(ctx, req.(*GetGoogleAdsFieldRequest))
	}
	return interceptor(ctx, in, info, handler)
}

func _GoogleAdsFieldService_SearchGoogleAdsFields_Handler(srv interface{}, ctx context.Context, dec func(interface{}) error, interceptor grpc.UnaryServerInterceptor) (interface{}, error) {
	in := new(SearchGoogleAdsFieldsRequest)
	if err := dec(in); err != nil {
		return nil, err
	}
	if interceptor == nil {
		return srv.(GoogleAdsFieldServiceServer).SearchGoogleAdsFields(ctx, in)
	}
	info := &grpc.UnaryServerInfo{
		Server:     srv,
		FullMethod: "/google.ads.googleads.v2.services.GoogleAdsFieldService/SearchGoogleAdsFields",
	}
	handler := func(ctx context.Context, req interface{}) (interface{}, error) {
		return srv.(GoogleAdsFieldServiceServer).SearchGoogleAdsFields(ctx, req.(*SearchGoogleAdsFieldsRequest))
	}
	return interceptor(ctx, in, info, handler)
}

var _GoogleAdsFieldService_serviceDesc = grpc.ServiceDesc{
	ServiceName: "google.ads.googleads.v2.services.GoogleAdsFieldService",
	HandlerType: (*GoogleAdsFieldServiceServer)(nil),
	Methods: []grpc.MethodDesc{
		{
			MethodName: "GetGoogleAdsField",
			Handler:    _GoogleAdsFieldService_GetGoogleAdsField_Handler,
		},
		{
			MethodName: "SearchGoogleAdsFields",
			Handler:    _GoogleAdsFieldService_SearchGoogleAdsFields_Handler,
		},
	},
	Streams:  []grpc.StreamDesc{},
	Metadata: "google/ads/googleads/v2/services/google_ads_field_service.proto",
}
