// Code generated by protoc-gen-go. DO NOT EDIT.
// source: google/ads/googleads/v2/enums/policy_topic_evidence_destination_not_working_dns_error_type.proto

package enums

import (
	fmt "fmt"
	math "math"

	proto "github.com/golang/protobuf/proto"
	_ "google.golang.org/genproto/googleapis/api/annotations"
)

// Reference imports to suppress errors if they are not otherwise used.
var _ = proto.Marshal
var _ = fmt.Errorf
var _ = math.Inf

// This is a compile-time assertion to ensure that this generated file
// is compatible with the proto package it is being compiled against.
// A compilation error at this line likely means your copy of the
// proto package needs to be updated.
const _ = proto.ProtoPackageIsVersion3 // please upgrade the proto package

// The possible policy topic evidence destination not working DNS error types.
type PolicyTopicEvidenceDestinationNotWorkingDnsErrorTypeEnum_PolicyTopicEvidenceDestinationNotWorkingDnsErrorType int32

const (
	// No value has been specified.
	PolicyTopicEvidenceDestinationNotWorkingDnsErrorTypeEnum_UNSPECIFIED PolicyTopicEvidenceDestinationNotWorkingDnsErrorTypeEnum_PolicyTopicEvidenceDestinationNotWorkingDnsErrorType = 0
	// The received value is not known in this version.
	//
	// This is a response-only value.
	PolicyTopicEvidenceDestinationNotWorkingDnsErrorTypeEnum_UNKNOWN PolicyTopicEvidenceDestinationNotWorkingDnsErrorTypeEnum_PolicyTopicEvidenceDestinationNotWorkingDnsErrorType = 1
	// Host name not found in DNS when fetching landing page.
	PolicyTopicEvidenceDestinationNotWorkingDnsErrorTypeEnum_HOSTNAME_NOT_FOUND PolicyTopicEvidenceDestinationNotWorkingDnsErrorTypeEnum_PolicyTopicEvidenceDestinationNotWorkingDnsErrorType = 2
	// Google internal crawler issue when communicating with DNS. This error
	// doesn't mean the landing page doesn't work. Google will recrawl the
	// landing page.
	PolicyTopicEvidenceDestinationNotWorkingDnsErrorTypeEnum_GOOGLE_CRAWLER_DNS_ISSUE PolicyTopicEvidenceDestinationNotWorkingDnsErrorTypeEnum_PolicyTopicEvidenceDestinationNotWorkingDnsErrorType = 3
)

var PolicyTopicEvidenceDestinationNotWorkingDnsErrorTypeEnum_PolicyTopicEvidenceDestinationNotWorkingDnsErrorType_name = map[int32]string{
	0: "UNSPECIFIED",
	1: "UNKNOWN",
	2: "HOSTNAME_NOT_FOUND",
	3: "GOOGLE_CRAWLER_DNS_ISSUE",
}

var PolicyTopicEvidenceDestinationNotWorkingDnsErrorTypeEnum_PolicyTopicEvidenceDestinationNotWorkingDnsErrorType_value = map[string]int32{
	"UNSPECIFIED":              0,
	"UNKNOWN":                  1,
	"HOSTNAME_NOT_FOUND":       2,
	"GOOGLE_CRAWLER_DNS_ISSUE": 3,
}

func (x PolicyTopicEvidenceDestinationNotWorkingDnsErrorTypeEnum_PolicyTopicEvidenceDestinationNotWorkingDnsErrorType) String() string {
	return proto.EnumName(PolicyTopicEvidenceDestinationNotWorkingDnsErrorTypeEnum_PolicyTopicEvidenceDestinationNotWorkingDnsErrorType_name, int32(x))
}

func (PolicyTopicEvidenceDestinationNotWorkingDnsErrorTypeEnum_PolicyTopicEvidenceDestinationNotWorkingDnsErrorType) EnumDescriptor() ([]byte, []int) {
	return fileDescriptor_bbce72809cc27480, []int{0, 0}
}

// Container for enum describing possible policy topic evidence destination not
// working DNS error types.
type PolicyTopicEvidenceDestinationNotWorkingDnsErrorTypeEnum struct {
	XXX_NoUnkeyedLiteral struct{} `json:"-"`
	XXX_unrecognized     []byte   `json:"-"`
	XXX_sizecache        int32    `json:"-"`
}

func (m *PolicyTopicEvidenceDestinationNotWorkingDnsErrorTypeEnum) Reset() {
	*m = PolicyTopicEvidenceDestinationNotWorkingDnsErrorTypeEnum{}
}
func (m *PolicyTopicEvidenceDestinationNotWorkingDnsErrorTypeEnum) String() string {
	return proto.CompactTextString(m)
}
func (*PolicyTopicEvidenceDestinationNotWorkingDnsErrorTypeEnum) ProtoMessage() {}
func (*PolicyTopicEvidenceDestinationNotWorkingDnsErrorTypeEnum) Descriptor() ([]byte, []int) {
	return fileDescriptor_bbce72809cc27480, []int{0}
}

func (m *PolicyTopicEvidenceDestinationNotWorkingDnsErrorTypeEnum) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_PolicyTopicEvidenceDestinationNotWorkingDnsErrorTypeEnum.Unmarshal(m, b)
}
func (m *PolicyTopicEvidenceDestinationNotWorkingDnsErrorTypeEnum) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_PolicyTopicEvidenceDestinationNotWorkingDnsErrorTypeEnum.Marshal(b, m, deterministic)
}
func (m *PolicyTopicEvidenceDestinationNotWorkingDnsErrorTypeEnum) XXX_Merge(src proto.Message) {
	xxx_messageInfo_PolicyTopicEvidenceDestinationNotWorkingDnsErrorTypeEnum.Merge(m, src)
}
func (m *PolicyTopicEvidenceDestinationNotWorkingDnsErrorTypeEnum) XXX_Size() int {
	return xxx_messageInfo_PolicyTopicEvidenceDestinationNotWorkingDnsErrorTypeEnum.Size(m)
}
func (m *PolicyTopicEvidenceDestinationNotWorkingDnsErrorTypeEnum) XXX_DiscardUnknown() {
	xxx_messageInfo_PolicyTopicEvidenceDestinationNotWorkingDnsErrorTypeEnum.DiscardUnknown(m)
}

var xxx_messageInfo_PolicyTopicEvidenceDestinationNotWorkingDnsErrorTypeEnum proto.InternalMessageInfo

func init() {
	proto.RegisterEnum("google.ads.googleads.v2.enums.PolicyTopicEvidenceDestinationNotWorkingDnsErrorTypeEnum_PolicyTopicEvidenceDestinationNotWorkingDnsErrorType", PolicyTopicEvidenceDestinationNotWorkingDnsErrorTypeEnum_PolicyTopicEvidenceDestinationNotWorkingDnsErrorType_name, PolicyTopicEvidenceDestinationNotWorkingDnsErrorTypeEnum_PolicyTopicEvidenceDestinationNotWorkingDnsErrorType_value)
	proto.RegisterType((*PolicyTopicEvidenceDestinationNotWorkingDnsErrorTypeEnum)(nil), "google.ads.googleads.v2.enums.PolicyTopicEvidenceDestinationNotWorkingDnsErrorTypeEnum")
}

func init() {
	proto.RegisterFile("google/ads/googleads/v2/enums/policy_topic_evidence_destination_not_working_dns_error_type.proto", fileDescriptor_bbce72809cc27480)
}

var fileDescriptor_bbce72809cc27480 = []byte{
	// 389 bytes of a gzipped FileDescriptorProto
	0x1f, 0x8b, 0x08, 0x00, 0x00, 0x00, 0x00, 0x00, 0x02, 0xff, 0x9c, 0x91, 0xc1, 0xaa, 0xd3, 0x40,
	0x18, 0x85, 0x4d, 0x2e, 0x28, 0xcc, 0x5d, 0x18, 0xb2, 0x10, 0x91, 0x7b, 0x17, 0xf7, 0x3e, 0xc0,
	0x04, 0xa2, 0x0b, 0x1d, 0x57, 0x69, 0x33, 0x8d, 0xc5, 0x3a, 0x09, 0x4d, 0xd2, 0x82, 0x04, 0xc6,
	0x98, 0x19, 0xc2, 0x60, 0x3b, 0x13, 0x32, 0xd3, 0x4a, 0x5f, 0xc1, 0x85, 0x0f, 0xe1, 0xd2, 0x17,
	0x11, 0x7c, 0x14, 0x9f, 0x42, 0x32, 0x69, 0xeb, 0xca, 0xbb, 0xe8, 0x26, 0x1c, 0xf2, 0xcf, 0x7f,
	0xce, 0xc7, 0xf9, 0xc1, 0xa7, 0x56, 0xa9, 0x76, 0xc3, 0x83, 0x9a, 0xe9, 0x60, 0x94, 0x83, 0xda,
	0x87, 0x01, 0x97, 0xbb, 0xad, 0x0e, 0x3a, 0xb5, 0x11, 0xcd, 0x81, 0x1a, 0xd5, 0x89, 0x86, 0xf2,
	0xbd, 0x60, 0x5c, 0x36, 0x9c, 0x32, 0xae, 0x8d, 0x90, 0xb5, 0x11, 0x4a, 0x52, 0xa9, 0x0c, 0xfd,
	0xaa, 0xfa, 0x2f, 0x42, 0xb6, 0x94, 0x49, 0x4d, 0x79, 0xdf, 0xab, 0x9e, 0x9a, 0x43, 0xc7, 0x61,
	0xd7, 0x2b, 0xa3, 0xfc, 0xdb, 0xd1, 0x16, 0xd6, 0x4c, 0xc3, 0x73, 0x02, 0xdc, 0x87, 0xd0, 0x26,
	0xbc, 0xb8, 0x39, 0x01, 0x74, 0x22, 0xa8, 0xa5, 0x54, 0xc6, 0xda, 0xea, 0x71, 0xf9, 0xfe, 0x97,
	0x03, 0x5e, 0x67, 0x96, 0xa1, 0x18, 0x10, 0xf0, 0x91, 0x20, 0xfe, 0x07, 0x40, 0x94, 0x59, 0x8f,
	0xf1, 0xb1, 0xd4, 0x78, 0x08, 0x2f, 0x0e, 0x1d, 0xc7, 0x72, 0xb7, 0xbd, 0xff, 0xe6, 0x80, 0x57,
	0x97, 0x2c, 0xfb, 0x4f, 0xc1, 0x75, 0x49, 0xf2, 0x0c, 0x4f, 0xe7, 0xb3, 0x39, 0x8e, 0xbd, 0x47,
	0xfe, 0x35, 0x78, 0x52, 0x92, 0xf7, 0x24, 0x5d, 0x13, 0xcf, 0xf1, 0x9f, 0x01, 0xff, 0x5d, 0x9a,
	0x17, 0x24, 0xfa, 0x80, 0x29, 0x49, 0x0b, 0x3a, 0x4b, 0x4b, 0x12, 0x7b, 0xae, 0x7f, 0x03, 0x9e,
	0x27, 0x69, 0x9a, 0x2c, 0x30, 0x9d, 0x2e, 0xa3, 0xf5, 0x02, 0x2f, 0x69, 0x4c, 0x72, 0x3a, 0xcf,
	0xf3, 0x12, 0x7b, 0x57, 0x93, 0xef, 0x2e, 0xb8, 0x6b, 0xd4, 0x16, 0x3e, 0xd8, 0xc6, 0xe4, 0xcd,
	0x25, 0xbc, 0xd9, 0x50, 0x55, 0xe6, 0x7c, 0x9c, 0x1c, 0xbd, 0x5b, 0xb5, 0xa9, 0x65, 0x0b, 0x55,
	0xdf, 0x06, 0x2d, 0x97, 0xb6, 0xc8, 0xd3, 0x6d, 0x3b, 0xa1, 0xff, 0x73, 0xea, 0xb7, 0xf6, 0xfb,
	0xc3, 0xbd, 0x4a, 0xa2, 0xe8, 0xa7, 0x7b, 0x9b, 0x8c, 0x56, 0x11, 0xd3, 0x70, 0x94, 0x83, 0x5a,
	0x85, 0x70, 0x28, 0x56, 0xff, 0x3e, 0xcd, 0xab, 0x88, 0xe9, 0xea, 0x3c, 0xaf, 0x56, 0x61, 0x65,
	0xe7, 0x7f, 0xdc, 0xbb, 0xf1, 0x27, 0x42, 0x11, 0xd3, 0x08, 0x9d, 0x5f, 0x20, 0xb4, 0x0a, 0x11,
	0xb2, 0x6f, 0x3e, 0x3f, 0xb6, 0x60, 0x2f, 0xff, 0x06, 0x00, 0x00, 0xff, 0xff, 0xc6, 0x4f, 0x5d,
	0xe0, 0x82, 0x02, 0x00, 0x00,
}
