// Code generated by protoc-gen-go. DO NOT EDIT.
// source: google/devtools/resultstore/v2/configuration.proto

package resultstore

import (
	fmt "fmt"
	math "math"

	proto "github.com/golang/protobuf/proto"
)

// Reference imports to suppress errors if they are not otherwise used.
var _ = proto.Marshal
var _ = fmt.Errorf
var _ = math.Inf

// This is a compile-time assertion to ensure that this generated file
// is compatible with the proto package it is being compiled against.
// A compilation error at this line likely means your copy of the
// proto package needs to be updated.
const _ = proto.ProtoPackageIsVersion3 // please upgrade the proto package

// Represents a configuration within an Invocation associated with one or more
// ConfiguredTargets. It captures the environment and other settings that
// were used.
type Configuration struct {
	// The format of this Configuration resource name must be:
	// invocations/${INVOCATION_ID}/configs/${url_encode(CONFIG_ID)}
	// The configuration ID of "default" should be preferred for the default
	// configuration in a single-config invocation.
	Name string `protobuf:"bytes,1,opt,name=name,proto3" json:"name,omitempty"`
	// The resource ID components that identify the Configuration. They must match
	// the resource name after proper encoding.
	Id *Configuration_Id `protobuf:"bytes,2,opt,name=id,proto3" json:"id,omitempty"`
	// The aggregate status for this configuration.
	StatusAttributes *StatusAttributes `protobuf:"bytes,3,opt,name=status_attributes,json=statusAttributes,proto3" json:"status_attributes,omitempty"`
	// Attributes that apply only to this configuration.
	ConfigurationAttributes *ConfigurationAttributes `protobuf:"bytes,5,opt,name=configuration_attributes,json=configurationAttributes,proto3" json:"configuration_attributes,omitempty"`
	// Arbitrary name-value pairs.
	// This is implemented as a multi-map. Multiple properties are allowed with
	// the same key. Properties will be returned in lexicographical order by key.
	Properties []*Property `protobuf:"bytes,6,rep,name=properties,proto3" json:"properties,omitempty"`
	// A human-readable name for Configuration.
	// It is recommended that this name be unique.
	// If omitted, the configuration_id should be used as display_name instead.
	DisplayName          string   `protobuf:"bytes,8,opt,name=display_name,json=displayName,proto3" json:"display_name,omitempty"`
	XXX_NoUnkeyedLiteral struct{} `json:"-"`
	XXX_unrecognized     []byte   `json:"-"`
	XXX_sizecache        int32    `json:"-"`
}

func (m *Configuration) Reset()         { *m = Configuration{} }
func (m *Configuration) String() string { return proto.CompactTextString(m) }
func (*Configuration) ProtoMessage()    {}
func (*Configuration) Descriptor() ([]byte, []int) {
	return fileDescriptor_c7cb6c7dfd72e78e, []int{0}
}

func (m *Configuration) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_Configuration.Unmarshal(m, b)
}
func (m *Configuration) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_Configuration.Marshal(b, m, deterministic)
}
func (m *Configuration) XXX_Merge(src proto.Message) {
	xxx_messageInfo_Configuration.Merge(m, src)
}
func (m *Configuration) XXX_Size() int {
	return xxx_messageInfo_Configuration.Size(m)
}
func (m *Configuration) XXX_DiscardUnknown() {
	xxx_messageInfo_Configuration.DiscardUnknown(m)
}

var xxx_messageInfo_Configuration proto.InternalMessageInfo

func (m *Configuration) GetName() string {
	if m != nil {
		return m.Name
	}
	return ""
}

func (m *Configuration) GetId() *Configuration_Id {
	if m != nil {
		return m.Id
	}
	return nil
}

func (m *Configuration) GetStatusAttributes() *StatusAttributes {
	if m != nil {
		return m.StatusAttributes
	}
	return nil
}

func (m *Configuration) GetConfigurationAttributes() *ConfigurationAttributes {
	if m != nil {
		return m.ConfigurationAttributes
	}
	return nil
}

func (m *Configuration) GetProperties() []*Property {
	if m != nil {
		return m.Properties
	}
	return nil
}

func (m *Configuration) GetDisplayName() string {
	if m != nil {
		return m.DisplayName
	}
	return ""
}

// The resource ID components that identify the Configuration.
type Configuration_Id struct {
	// The Invocation ID.
	InvocationId string `protobuf:"bytes,1,opt,name=invocation_id,json=invocationId,proto3" json:"invocation_id,omitempty"`
	// The Configuration ID.
	ConfigurationId      string   `protobuf:"bytes,2,opt,name=configuration_id,json=configurationId,proto3" json:"configuration_id,omitempty"`
	XXX_NoUnkeyedLiteral struct{} `json:"-"`
	XXX_unrecognized     []byte   `json:"-"`
	XXX_sizecache        int32    `json:"-"`
}

func (m *Configuration_Id) Reset()         { *m = Configuration_Id{} }
func (m *Configuration_Id) String() string { return proto.CompactTextString(m) }
func (*Configuration_Id) ProtoMessage()    {}
func (*Configuration_Id) Descriptor() ([]byte, []int) {
	return fileDescriptor_c7cb6c7dfd72e78e, []int{0, 0}
}

func (m *Configuration_Id) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_Configuration_Id.Unmarshal(m, b)
}
func (m *Configuration_Id) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_Configuration_Id.Marshal(b, m, deterministic)
}
func (m *Configuration_Id) XXX_Merge(src proto.Message) {
	xxx_messageInfo_Configuration_Id.Merge(m, src)
}
func (m *Configuration_Id) XXX_Size() int {
	return xxx_messageInfo_Configuration_Id.Size(m)
}
func (m *Configuration_Id) XXX_DiscardUnknown() {
	xxx_messageInfo_Configuration_Id.DiscardUnknown(m)
}

var xxx_messageInfo_Configuration_Id proto.InternalMessageInfo

func (m *Configuration_Id) GetInvocationId() string {
	if m != nil {
		return m.InvocationId
	}
	return ""
}

func (m *Configuration_Id) GetConfigurationId() string {
	if m != nil {
		return m.ConfigurationId
	}
	return ""
}

// Attributes that apply only to the configuration.
type ConfigurationAttributes struct {
	// The type of cpu. (e.g. "x86", "powerpc")
	Cpu                  string   `protobuf:"bytes,1,opt,name=cpu,proto3" json:"cpu,omitempty"`
	XXX_NoUnkeyedLiteral struct{} `json:"-"`
	XXX_unrecognized     []byte   `json:"-"`
	XXX_sizecache        int32    `json:"-"`
}

func (m *ConfigurationAttributes) Reset()         { *m = ConfigurationAttributes{} }
func (m *ConfigurationAttributes) String() string { return proto.CompactTextString(m) }
func (*ConfigurationAttributes) ProtoMessage()    {}
func (*ConfigurationAttributes) Descriptor() ([]byte, []int) {
	return fileDescriptor_c7cb6c7dfd72e78e, []int{1}
}

func (m *ConfigurationAttributes) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_ConfigurationAttributes.Unmarshal(m, b)
}
func (m *ConfigurationAttributes) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_ConfigurationAttributes.Marshal(b, m, deterministic)
}
func (m *ConfigurationAttributes) XXX_Merge(src proto.Message) {
	xxx_messageInfo_ConfigurationAttributes.Merge(m, src)
}
func (m *ConfigurationAttributes) XXX_Size() int {
	return xxx_messageInfo_ConfigurationAttributes.Size(m)
}
func (m *ConfigurationAttributes) XXX_DiscardUnknown() {
	xxx_messageInfo_ConfigurationAttributes.DiscardUnknown(m)
}

var xxx_messageInfo_ConfigurationAttributes proto.InternalMessageInfo

func (m *ConfigurationAttributes) GetCpu() string {
	if m != nil {
		return m.Cpu
	}
	return ""
}

func init() {
	proto.RegisterType((*Configuration)(nil), "google.devtools.resultstore.v2.Configuration")
	proto.RegisterType((*Configuration_Id)(nil), "google.devtools.resultstore.v2.Configuration.Id")
	proto.RegisterType((*ConfigurationAttributes)(nil), "google.devtools.resultstore.v2.ConfigurationAttributes")
}

func init() {
	proto.RegisterFile("google/devtools/resultstore/v2/configuration.proto", fileDescriptor_c7cb6c7dfd72e78e)
}

var fileDescriptor_c7cb6c7dfd72e78e = []byte{
	// 357 bytes of a gzipped FileDescriptorProto
	0x1f, 0x8b, 0x08, 0x00, 0x00, 0x00, 0x00, 0x00, 0x02, 0xff, 0x94, 0x92, 0xbf, 0x4f, 0xe3, 0x30,
	0x1c, 0xc5, 0x95, 0xe4, 0xae, 0xba, 0x7e, 0xdb, 0xea, 0x7a, 0x5e, 0x1a, 0x75, 0x38, 0x95, 0xb2,
	0x04, 0x55, 0x72, 0x50, 0x18, 0x18, 0x58, 0xf8, 0xb1, 0x90, 0x05, 0x55, 0x81, 0x09, 0x09, 0x55,
	0x6e, 0x6c, 0x22, 0x4b, 0x49, 0x1c, 0x6c, 0x27, 0x52, 0xff, 0x76, 0x16, 0x84, 0x93, 0x42, 0x82,
	0x28, 0x85, 0xcd, 0x79, 0xce, 0xe7, 0x3d, 0x7f, 0x9f, 0x0d, 0x41, 0x22, 0x44, 0x92, 0x32, 0x9f,
	0xb2, 0x4a, 0x0b, 0x91, 0x2a, 0x5f, 0x32, 0x55, 0xa6, 0x5a, 0x69, 0x21, 0x99, 0x5f, 0x05, 0x7e,
	0x2c, 0xf2, 0x47, 0x9e, 0x94, 0x92, 0x68, 0x2e, 0x72, 0x5c, 0x48, 0xa1, 0x05, 0xfa, 0x5f, 0x33,
	0x78, 0xcb, 0xe0, 0x16, 0x83, 0xab, 0x60, 0xba, 0xd8, 0xeb, 0x99, 0x65, 0x5b, 0xb3, 0xf9, 0xb3,
	0x03, 0xa3, 0xab, 0x76, 0x08, 0x42, 0xf0, 0x2b, 0x27, 0x19, 0x73, 0xad, 0x99, 0xe5, 0xf5, 0x23,
	0xb3, 0x46, 0xe7, 0x60, 0x73, 0xea, 0xda, 0x33, 0xcb, 0x1b, 0x04, 0xc7, 0xf8, 0xeb, 0x7c, 0xdc,
	0xb1, 0xc3, 0x21, 0x8d, 0x6c, 0x4e, 0xd1, 0x03, 0xfc, 0x53, 0x9a, 0xe8, 0x52, 0xad, 0x88, 0xd6,
	0x92, 0xaf, 0x4b, 0xcd, 0x94, 0xeb, 0x7c, 0xcf, 0xf0, 0xd6, 0x80, 0x17, 0x6f, 0x5c, 0x34, 0x56,
	0x1f, 0x14, 0x24, 0xc1, 0xed, 0x54, 0xd5, 0x4e, 0xf9, 0x6d, 0x52, 0x4e, 0x7f, 0x74, 0xec, 0x56,
	0xd8, 0x24, 0xfe, 0x7c, 0x03, 0x5d, 0x03, 0x14, 0x52, 0x14, 0x4c, 0x6a, 0xce, 0x94, 0xdb, 0x9b,
	0x39, 0xde, 0x20, 0xf0, 0xf6, 0xa5, 0x2c, 0x6b, 0x62, 0x13, 0xb5, 0x58, 0x74, 0x00, 0x43, 0xca,
	0x55, 0x91, 0x92, 0xcd, 0xca, 0x54, 0xff, 0xc7, 0x54, 0x3f, 0x68, 0xb4, 0x1b, 0x92, 0xb1, 0xe9,
	0x1d, 0xd8, 0x21, 0x45, 0x87, 0x30, 0xe2, 0x79, 0x25, 0xe2, 0x7a, 0x46, 0x4e, 0x9b, 0x4b, 0x1a,
	0xbe, 0x8b, 0x21, 0x45, 0x47, 0x30, 0xee, 0x76, 0xd1, 0x5c, 0x5d, 0x3f, 0xfa, 0xdb, 0xd1, 0x43,
	0x3a, 0x5f, 0xc0, 0x64, 0xc7, 0xd8, 0x68, 0x0c, 0x4e, 0x5c, 0x94, 0x4d, 0xc0, 0xeb, 0xf2, 0xf2,
	0x09, 0xe6, 0xb1, 0xc8, 0xf6, 0x0c, 0xb8, 0xb4, 0xee, 0xc3, 0xe6, 0x8f, 0x44, 0xa4, 0x24, 0x4f,
	0xb0, 0x90, 0x89, 0x9f, 0xb0, 0xdc, 0x3c, 0x37, 0xbf, 0xde, 0x22, 0x05, 0x57, 0xbb, 0x9e, 0xe7,
	0x59, 0xeb, 0x73, 0xdd, 0x33, 0xd4, 0xc9, 0x4b, 0x00, 0x00, 0x00, 0xff, 0xff, 0x39, 0x87, 0xe1,
	0xa8, 0x27, 0x03, 0x00, 0x00,
}
