// Code generated by protoc-gen-go. DO NOT EDIT.
// source: google/ads/googleads/v1/resources/campaign_bid_modifier.proto

package resources

import (
	fmt "fmt"
	math "math"

	proto "github.com/golang/protobuf/proto"
	wrappers "github.com/golang/protobuf/ptypes/wrappers"
	common "google.golang.org/genproto/googleapis/ads/googleads/v1/common"
	_ "google.golang.org/genproto/googleapis/api/annotations"
)

// Reference imports to suppress errors if they are not otherwise used.
var _ = proto.Marshal
var _ = fmt.Errorf
var _ = math.Inf

// This is a compile-time assertion to ensure that this generated file
// is compatible with the proto package it is being compiled against.
// A compilation error at this line likely means your copy of the
// proto package needs to be updated.
const _ = proto.ProtoPackageIsVersion3 // please upgrade the proto package

// Represents a bid-modifiable only criterion at the campaign level.
type CampaignBidModifier struct {
	// The resource name of the campaign bid modifier.
	// Campaign bid modifier resource names have the form:
	//
	// `customers/{customer_id}/campaignBidModifiers/{campaign_id}~{criterion_id}`
	ResourceName string `protobuf:"bytes,1,opt,name=resource_name,json=resourceName,proto3" json:"resource_name,omitempty"`
	// The campaign to which this criterion belongs.
	Campaign *wrappers.StringValue `protobuf:"bytes,2,opt,name=campaign,proto3" json:"campaign,omitempty"`
	// The ID of the criterion to bid modify.
	//
	// This field is ignored for mutates.
	CriterionId *wrappers.Int64Value `protobuf:"bytes,3,opt,name=criterion_id,json=criterionId,proto3" json:"criterion_id,omitempty"`
	// The modifier for the bid when the criterion matches.
	BidModifier *wrappers.DoubleValue `protobuf:"bytes,4,opt,name=bid_modifier,json=bidModifier,proto3" json:"bid_modifier,omitempty"`
	// The criterion of this campaign bid modifier.
	//
	// Types that are valid to be assigned to Criterion:
	//	*CampaignBidModifier_InteractionType
	Criterion            isCampaignBidModifier_Criterion `protobuf_oneof:"criterion"`
	XXX_NoUnkeyedLiteral struct{}                        `json:"-"`
	XXX_unrecognized     []byte                          `json:"-"`
	XXX_sizecache        int32                           `json:"-"`
}

func (m *CampaignBidModifier) Reset()         { *m = CampaignBidModifier{} }
func (m *CampaignBidModifier) String() string { return proto.CompactTextString(m) }
func (*CampaignBidModifier) ProtoMessage()    {}
func (*CampaignBidModifier) Descriptor() ([]byte, []int) {
	return fileDescriptor_c88d20810b244847, []int{0}
}

func (m *CampaignBidModifier) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_CampaignBidModifier.Unmarshal(m, b)
}
func (m *CampaignBidModifier) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_CampaignBidModifier.Marshal(b, m, deterministic)
}
func (m *CampaignBidModifier) XXX_Merge(src proto.Message) {
	xxx_messageInfo_CampaignBidModifier.Merge(m, src)
}
func (m *CampaignBidModifier) XXX_Size() int {
	return xxx_messageInfo_CampaignBidModifier.Size(m)
}
func (m *CampaignBidModifier) XXX_DiscardUnknown() {
	xxx_messageInfo_CampaignBidModifier.DiscardUnknown(m)
}

var xxx_messageInfo_CampaignBidModifier proto.InternalMessageInfo

func (m *CampaignBidModifier) GetResourceName() string {
	if m != nil {
		return m.ResourceName
	}
	return ""
}

func (m *CampaignBidModifier) GetCampaign() *wrappers.StringValue {
	if m != nil {
		return m.Campaign
	}
	return nil
}

func (m *CampaignBidModifier) GetCriterionId() *wrappers.Int64Value {
	if m != nil {
		return m.CriterionId
	}
	return nil
}

func (m *CampaignBidModifier) GetBidModifier() *wrappers.DoubleValue {
	if m != nil {
		return m.BidModifier
	}
	return nil
}

type isCampaignBidModifier_Criterion interface {
	isCampaignBidModifier_Criterion()
}

type CampaignBidModifier_InteractionType struct {
	InteractionType *common.InteractionTypeInfo `protobuf:"bytes,5,opt,name=interaction_type,json=interactionType,proto3,oneof"`
}

func (*CampaignBidModifier_InteractionType) isCampaignBidModifier_Criterion() {}

func (m *CampaignBidModifier) GetCriterion() isCampaignBidModifier_Criterion {
	if m != nil {
		return m.Criterion
	}
	return nil
}

func (m *CampaignBidModifier) GetInteractionType() *common.InteractionTypeInfo {
	if x, ok := m.GetCriterion().(*CampaignBidModifier_InteractionType); ok {
		return x.InteractionType
	}
	return nil
}

// XXX_OneofWrappers is for the internal use of the proto package.
func (*CampaignBidModifier) XXX_OneofWrappers() []interface{} {
	return []interface{}{
		(*CampaignBidModifier_InteractionType)(nil),
	}
}

func init() {
	proto.RegisterType((*CampaignBidModifier)(nil), "google.ads.googleads.v1.resources.CampaignBidModifier")
}

func init() {
	proto.RegisterFile("google/ads/googleads/v1/resources/campaign_bid_modifier.proto", fileDescriptor_c88d20810b244847)
}

var fileDescriptor_c88d20810b244847 = []byte{
	// 440 bytes of a gzipped FileDescriptorProto
	0x1f, 0x8b, 0x08, 0x00, 0x00, 0x00, 0x00, 0x00, 0x02, 0xff, 0x84, 0x52, 0xdd, 0x6a, 0xd4, 0x40,
	0x14, 0x76, 0x53, 0x15, 0x3b, 0xbb, 0xa2, 0xc4, 0x9b, 0x50, 0x8b, 0xb4, 0x4a, 0xa1, 0x37, 0x4e,
	0x88, 0x15, 0x91, 0x88, 0x4a, 0x56, 0xa1, 0xae, 0xa0, 0x94, 0x55, 0xf6, 0x42, 0x16, 0xe2, 0x24,
	0x33, 0x1b, 0x06, 0x36, 0x73, 0x86, 0x99, 0x49, 0xa5, 0x0f, 0xe0, 0x8b, 0x78, 0xe9, 0xa3, 0xf8,
	0x1c, 0x5e, 0xf9, 0x14, 0x92, 0xcc, 0x0f, 0x2b, 0xba, 0xf6, 0xee, 0x4b, 0xce, 0xf7, 0x9d, 0xf3,
	0x7d, 0xe7, 0x0c, 0x7a, 0xde, 0x00, 0x34, 0x6b, 0x96, 0x12, 0xaa, 0x53, 0x0b, 0x7b, 0x74, 0x9e,
	0xa5, 0x8a, 0x69, 0xe8, 0x54, 0xcd, 0x74, 0x5a, 0x93, 0x56, 0x12, 0xde, 0x88, 0xb2, 0xe2, 0xb4,
	0x6c, 0x81, 0xf2, 0x15, 0x67, 0x0a, 0x4b, 0x05, 0x06, 0xe2, 0x43, 0xab, 0xc1, 0x84, 0x6a, 0x1c,
	0xe4, 0xf8, 0x3c, 0xc3, 0x41, 0xbe, 0xf7, 0x70, 0xdb, 0x84, 0x1a, 0xda, 0x16, 0x44, 0x5a, 0x2b,
	0x6e, 0x98, 0xe2, 0xc4, 0x76, 0xdc, 0xdb, 0xf7, 0x74, 0xc9, 0x53, 0x22, 0x04, 0x18, 0x62, 0x38,
	0x08, 0xed, 0xaa, 0xf7, 0x5c, 0x75, 0xf8, 0xaa, 0xba, 0x55, 0xfa, 0x45, 0x11, 0x29, 0x99, 0x72,
	0xf5, 0xfb, 0x3f, 0x23, 0x74, 0xe7, 0x95, 0xf3, 0x3b, 0xe5, 0xf4, 0x9d, 0x73, 0x1b, 0x3f, 0x40,
	0x37, 0xbd, 0xa3, 0x52, 0x90, 0x96, 0x25, 0xa3, 0x83, 0xd1, 0xf1, 0xee, 0x7c, 0xe2, 0x7f, 0xbe,
	0x27, 0x2d, 0x8b, 0x9f, 0xa2, 0x1b, 0x3e, 0x6b, 0x12, 0x1d, 0x8c, 0x8e, 0xc7, 0x8f, 0xf6, 0x5d,
	0x28, 0xec, 0xe7, 0xe1, 0x0f, 0x46, 0x71, 0xd1, 0x2c, 0xc8, 0xba, 0x63, 0xf3, 0xc0, 0x8e, 0x5f,
	0xa0, 0x89, 0x8b, 0x01, 0xa2, 0xe4, 0x34, 0xd9, 0x19, 0xd4, 0x77, 0xff, 0x52, 0xcf, 0x84, 0x79,
	0xf2, 0xd8, 0x8a, 0xc7, 0x41, 0x30, 0xa3, 0xf1, 0x4b, 0x34, 0xd9, 0x5c, 0x6e, 0x72, 0x75, 0xcb,
	0xf4, 0xd7, 0xd0, 0x55, 0x6b, 0xe6, 0x1a, 0x54, 0x1b, 0xf9, 0x3e, 0xa3, 0xdb, 0x5c, 0x18, 0xa6,
	0x48, 0xdd, 0x6f, 0xab, 0x34, 0x17, 0x92, 0x25, 0xd7, 0x86, 0x26, 0x27, 0x78, 0xdb, 0x89, 0xec,
	0xfe, 0x7b, 0x4f, 0x5e, 0xf7, 0xf1, 0x42, 0xb2, 0x99, 0x58, 0xc1, 0x9b, 0x2b, 0xf3, 0x5b, 0xfc,
	0xcf, 0xdf, 0xd3, 0x31, 0xda, 0x0d, 0x8e, 0xa7, 0x5f, 0x23, 0x74, 0x54, 0x43, 0x8b, 0x2f, 0xbd,
	0xfe, 0x34, 0xf9, 0xc7, 0x35, 0xce, 0xfa, 0x38, 0x67, 0xa3, 0x4f, 0x6f, 0x9d, 0xbc, 0x81, 0x35,
	0x11, 0x0d, 0x06, 0xd5, 0xa4, 0x0d, 0x13, 0x43, 0x58, 0xff, 0x52, 0x24, 0xd7, 0xff, 0x79, 0x9a,
	0xcf, 0x02, 0xfa, 0x16, 0xed, 0x9c, 0x16, 0xc5, 0xf7, 0xe8, 0xf0, 0xd4, 0xb6, 0x2c, 0xa8, 0xc6,
	0x16, 0xf6, 0x68, 0x91, 0xe1, 0xb9, 0x67, 0xfe, 0xf0, 0x9c, 0x65, 0x41, 0xf5, 0x32, 0x70, 0x96,
	0x8b, 0x6c, 0x19, 0x38, 0xbf, 0xa2, 0x23, 0x5b, 0xc8, 0xf3, 0x82, 0xea, 0x3c, 0x0f, 0xac, 0x3c,
	0x5f, 0x64, 0x79, 0x1e, 0x78, 0xd5, 0xf5, 0xc1, 0xec, 0xc9, 0xef, 0x00, 0x00, 0x00, 0xff, 0xff,
	0x34, 0x21, 0xbb, 0xf0, 0x46, 0x03, 0x00, 0x00,
}
